/* Automatically @generated by tree-sitter v0.25.6 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 1778
#define LARGE_STATE_COUNT 210
#define SYMBOL_COUNT 220
#define ALIAS_COUNT 2
#define TOKEN_COUNT 95
#define EXTERNAL_TOKEN_COUNT 15
#define FIELD_COUNT 10
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 36
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_LPAREN = 1,
  anon_sym_RPAREN = 2,
  anon_sym_PLUS = 3,
  anon_sym_DOT_PLUS = 4,
  anon_sym_DASH = 5,
  anon_sym_DOT_DASH = 6,
  anon_sym_STAR = 7,
  anon_sym_DOT_STAR = 8,
  anon_sym_SLASH = 9,
  anon_sym_DOT_SLASH = 10,
  anon_sym_BSLASH = 11,
  anon_sym_DOT_BSLASH = 12,
  anon_sym_CARET = 13,
  anon_sym_DOT_CARET = 14,
  anon_sym_PIPE = 15,
  anon_sym_AMP = 16,
  anon_sym_DOT = 17,
  anon_sym_TILDE = 18,
  anon_sym_QMARK = 19,
  anon_sym_AT = 20,
  anon_sym_LT = 21,
  anon_sym_LT_EQ = 22,
  anon_sym_EQ_EQ = 23,
  anon_sym_TILDE_EQ = 24,
  anon_sym_GT_EQ = 25,
  anon_sym_GT = 26,
  anon_sym_AMP_AMP = 27,
  anon_sym_PIPE_PIPE = 28,
  anon_sym_DOT_SQUOTE = 29,
  anon_sym_SQUOTE = 30,
  anon_sym_COMMA = 31,
  anon_sym_LBRACK = 32,
  anon_sym_LF = 33,
  anon_sym_SEMI = 34,
  aux_sym_matrix_token1 = 35,
  anon_sym_RBRACK = 36,
  anon_sym_LBRACE = 37,
  anon_sym_RBRACE = 38,
  anon_sym_EQ = 39,
  anon_sym_COLON = 40,
  anon_sym_return = 41,
  anon_sym_continue = 42,
  anon_sym_break = 43,
  anon_sym_elseif = 44,
  anon_sym_else = 45,
  anon_sym_if = 46,
  anon_sym_end = 47,
  anon_sym_for = 48,
  anon_sym_parfor = 49,
  anon_sym_while = 50,
  anon_sym_case = 51,
  anon_sym_otherwise = 52,
  anon_sym_switch = 53,
  anon_sym_global = 54,
  anon_sym_persistent = 55,
  anon_sym_DOT_QMARK = 56,
  anon_sym_arguments = 57,
  anon_sym_function = 58,
  anon_sym_get_DOT = 59,
  anon_sym_set_DOT = 60,
  anon_sym_endfunction = 61,
  anon_sym_vector = 62,
  anon_sym_matrix = 63,
  anon_sym_scalar = 64,
  anon_sym_properties = 65,
  anon_sym_get = 66,
  anon_sym_set = 67,
  anon_sym_methods = 68,
  anon_sym_events = 69,
  anon_sym_enumeration = 70,
  anon_sym_classdef = 71,
  anon_sym_catch = 72,
  anon_sym_try = 73,
  anon_sym_spmd = 74,
  sym_number_size = 75,
  aux_sym_number_token1 = 76,
  aux_sym_number_token2 = 77,
  aux_sym_number_token3 = 78,
  anon_sym_CR = 79,
  sym_comment = 80,
  sym_line_continuation = 81,
  sym_command_name = 82,
  sym_command_argument = 83,
  sym__single_quote_string_start = 84,
  sym__single_quote_string_end = 85,
  sym__double_quote_string_start = 86,
  sym__double_quote_string_end = 87,
  sym_formatting_sequence = 88,
  sym_escape_sequence = 89,
  sym_string_content = 90,
  sym__entry_delimiter = 91,
  sym__multioutput_variable_start = 92,
  sym__external_identifier = 93,
  sym_error_sentinel = 94,
  sym_source_file = 95,
  aux_sym__block = 96,
  sym_block = 97,
  sym_identifier = 98,
  sym__statement = 99,
  sym__expression = 100,
  sym_parenthesis = 101,
  sym__binary_expression = 102,
  sym_binary_operator = 103,
  sym_unary_operator = 104,
  sym_indirect_access = 105,
  sym_field_expression = 106,
  sym_not_operator = 107,
  sym_metaclass_operator = 108,
  sym_handle_operator = 109,
  sym_comparison_operator = 110,
  sym_boolean_operator = 111,
  sym_postfix_operator = 112,
  sym_string = 113,
  sym_row = 114,
  sym_matrix = 115,
  sym_cell = 116,
  sym_ignored_argument = 117,
  sym_assignment = 118,
  sym_multioutput_variable = 119,
  sym_spread_operator = 120,
  sym__index_boolean_operator = 121,
  sym__index_comparison_operator = 122,
  sym__index_not_operator = 123,
  sym__index_unary_operator = 124,
  sym__index_postfix_operator = 125,
  sym__index_row = 126,
  sym__index_matrix = 127,
  sym__index_range_element = 128,
  sym__index_range = 129,
  sym__index_parenthesis = 130,
  sym__index_expression = 131,
  sym__index_binary_expression = 132,
  sym__index_binary_operator = 133,
  sym__index_argument = 134,
  sym__index_arguments = 135,
  sym_arguments = 136,
  sym__args = 137,
  sym_function_call = 138,
  sym_command = 139,
  sym__range_element = 140,
  sym_range = 141,
  sym_return_statement = 142,
  sym_continue_statement = 143,
  sym_break_statement = 144,
  sym_elseif_clause = 145,
  sym_else_clause = 146,
  sym_if_statement = 147,
  sym_iterator = 148,
  sym_parfor_options = 149,
  sym_for_statement = 150,
  sym_while_statement = 151,
  sym_case_clause = 152,
  sym_otherwise_clause = 153,
  sym_switch_statement = 154,
  sym__lambda_arguments = 155,
  sym_lambda = 156,
  sym_global_operator = 157,
  sym_persistent_operator = 158,
  sym__argument_attributes = 159,
  sym_class_property = 160,
  sym_arguments_statement = 161,
  sym_function_output = 162,
  sym_function_arguments = 163,
  sym_function_definition = 164,
  sym__function_definition_with_end = 165,
  sym_attribute = 166,
  sym_attributes = 167,
  sym_superclasses = 168,
  sym_dimensions = 169,
  sym_validation_functions = 170,
  sym_default_value = 171,
  sym_property_name = 172,
  sym_property = 173,
  sym_properties = 174,
  sym_function_signature = 175,
  sym_methods = 176,
  sym_events = 177,
  sym_enum = 178,
  sym_enumeration = 179,
  sym_class_definition = 180,
  sym_catch_clause = 181,
  sym_try_statement = 182,
  sym_spmd_statement = 183,
  sym_number = 184,
  sym_end_keyword = 185,
  sym__keywords = 186,
  sym__extended_keywords = 187,
  sym__end_of_line = 188,
  aux_sym_source_file_repeat1 = 189,
  aux_sym__block_repeat1 = 190,
  aux_sym_field_expression_repeat1 = 191,
  aux_sym_metaclass_operator_repeat1 = 192,
  aux_sym_string_repeat1 = 193,
  aux_sym_row_repeat1 = 194,
  aux_sym_matrix_repeat1 = 195,
  aux_sym_matrix_repeat2 = 196,
  aux_sym_multioutput_variable_repeat1 = 197,
  aux_sym__index_row_repeat1 = 198,
  aux_sym__index_matrix_repeat1 = 199,
  aux_sym__index_arguments_repeat1 = 200,
  aux_sym_arguments_repeat1 = 201,
  aux_sym_command_repeat1 = 202,
  aux_sym_if_statement_repeat1 = 203,
  aux_sym_switch_statement_repeat1 = 204,
  aux_sym__lambda_arguments_repeat1 = 205,
  aux_sym_global_operator_repeat1 = 206,
  aux_sym__argument_attributes_repeat1 = 207,
  aux_sym_arguments_statement_repeat1 = 208,
  aux_sym_function_definition_repeat1 = 209,
  aux_sym_attributes_repeat1 = 210,
  aux_sym_superclasses_repeat1 = 211,
  aux_sym_dimensions_repeat1 = 212,
  aux_sym_validation_functions_repeat1 = 213,
  aux_sym_properties_repeat1 = 214,
  aux_sym_methods_repeat1 = 215,
  aux_sym_events_repeat1 = 216,
  aux_sym_enum_repeat1 = 217,
  aux_sym_enumeration_repeat1 = 218,
  aux_sym_class_definition_repeat1 = 219,
  alias_sym__expression = 220,
  alias_sym_superclass = 221,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_PLUS] = "+",
  [anon_sym_DOT_PLUS] = ".+",
  [anon_sym_DASH] = "-",
  [anon_sym_DOT_DASH] = ".-",
  [anon_sym_STAR] = "*",
  [anon_sym_DOT_STAR] = ".*",
  [anon_sym_SLASH] = "/",
  [anon_sym_DOT_SLASH] = "./",
  [anon_sym_BSLASH] = "\\",
  [anon_sym_DOT_BSLASH] = ".\\",
  [anon_sym_CARET] = "^",
  [anon_sym_DOT_CARET] = ".^",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP] = "&",
  [anon_sym_DOT] = ".",
  [anon_sym_TILDE] = "~",
  [anon_sym_QMARK] = "\?",
  [anon_sym_AT] = "@",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_TILDE_EQ] = "~=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_GT] = ">",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_DOT_SQUOTE] = ".'",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_COMMA] = ",",
  [anon_sym_LBRACK] = "[",
  [anon_sym_LF] = "\n",
  [anon_sym_SEMI] = ";",
  [aux_sym_matrix_token1] = "matrix_token1",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_EQ] = "=",
  [anon_sym_COLON] = ":",
  [anon_sym_return] = "return",
  [anon_sym_continue] = "continue",
  [anon_sym_break] = "break",
  [anon_sym_elseif] = "elseif",
  [anon_sym_else] = "else",
  [anon_sym_if] = "if",
  [anon_sym_end] = "end",
  [anon_sym_for] = "for",
  [anon_sym_parfor] = "parfor",
  [anon_sym_while] = "while",
  [anon_sym_case] = "case",
  [anon_sym_otherwise] = "otherwise",
  [anon_sym_switch] = "switch",
  [anon_sym_global] = "global",
  [anon_sym_persistent] = "persistent",
  [anon_sym_DOT_QMARK] = ".\?",
  [anon_sym_arguments] = "arguments",
  [anon_sym_function] = "function",
  [anon_sym_get_DOT] = "get.",
  [anon_sym_set_DOT] = "set.",
  [anon_sym_endfunction] = "endfunction",
  [anon_sym_vector] = "identifier",
  [anon_sym_matrix] = "identifier",
  [anon_sym_scalar] = "identifier",
  [anon_sym_properties] = "properties",
  [anon_sym_get] = "get",
  [anon_sym_set] = "set",
  [anon_sym_methods] = "methods",
  [anon_sym_events] = "events",
  [anon_sym_enumeration] = "enumeration",
  [anon_sym_classdef] = "classdef",
  [anon_sym_catch] = "catch",
  [anon_sym_try] = "try",
  [anon_sym_spmd] = "spmd",
  [sym_number_size] = "number_size",
  [aux_sym_number_token1] = "number_token1",
  [aux_sym_number_token2] = "number_token2",
  [aux_sym_number_token3] = "number_token3",
  [anon_sym_CR] = "\r",
  [sym_comment] = "comment",
  [sym_line_continuation] = "line_continuation",
  [sym_command_name] = "command_name",
  [sym_command_argument] = "command_argument",
  [sym__single_quote_string_start] = "'",
  [sym__single_quote_string_end] = "'",
  [sym__double_quote_string_start] = "\"",
  [sym__double_quote_string_end] = "\"",
  [sym_formatting_sequence] = "formatting_sequence",
  [sym_escape_sequence] = "escape_sequence",
  [sym_string_content] = "string_content",
  [sym__entry_delimiter] = ",",
  [sym__multioutput_variable_start] = "[",
  [sym__external_identifier] = "_external_identifier",
  [sym_error_sentinel] = "error_sentinel",
  [sym_source_file] = "source_file",
  [aux_sym__block] = "_block",
  [sym_block] = "block",
  [sym_identifier] = "identifier",
  [sym__statement] = "_statement",
  [sym__expression] = "_expression",
  [sym_parenthesis] = "parenthesis",
  [sym__binary_expression] = "_binary_expression",
  [sym_binary_operator] = "binary_operator",
  [sym_unary_operator] = "unary_operator",
  [sym_indirect_access] = "indirect_access",
  [sym_field_expression] = "field_expression",
  [sym_not_operator] = "not_operator",
  [sym_metaclass_operator] = "metaclass_operator",
  [sym_handle_operator] = "handle_operator",
  [sym_comparison_operator] = "comparison_operator",
  [sym_boolean_operator] = "boolean_operator",
  [sym_postfix_operator] = "postfix_operator",
  [sym_string] = "string",
  [sym_row] = "row",
  [sym_matrix] = "matrix",
  [sym_cell] = "cell",
  [sym_ignored_argument] = "ignored_argument",
  [sym_assignment] = "assignment",
  [sym_multioutput_variable] = "multioutput_variable",
  [sym_spread_operator] = "spread_operator",
  [sym__index_boolean_operator] = "boolean_operator",
  [sym__index_comparison_operator] = "comparison_operator",
  [sym__index_not_operator] = "not_operator",
  [sym__index_unary_operator] = "unary_operator",
  [sym__index_postfix_operator] = "postfix_operator",
  [sym__index_row] = "row",
  [sym__index_matrix] = "matrix",
  [sym__index_range_element] = "_index_range_element",
  [sym__index_range] = "range",
  [sym__index_parenthesis] = "parenthesis",
  [sym__index_expression] = "_index_expression",
  [sym__index_binary_expression] = "_index_binary_expression",
  [sym__index_binary_operator] = "binary_operator",
  [sym__index_argument] = "_index_argument",
  [sym__index_arguments] = "_index_arguments",
  [sym_arguments] = "arguments",
  [sym__args] = "_args",
  [sym_function_call] = "function_call",
  [sym_command] = "command",
  [sym__range_element] = "_range_element",
  [sym_range] = "range",
  [sym_return_statement] = "return_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [sym_elseif_clause] = "elseif_clause",
  [sym_else_clause] = "else_clause",
  [sym_if_statement] = "if_statement",
  [sym_iterator] = "iterator",
  [sym_parfor_options] = "parfor_options",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_case_clause] = "case_clause",
  [sym_otherwise_clause] = "otherwise_clause",
  [sym_switch_statement] = "switch_statement",
  [sym__lambda_arguments] = "_lambda_arguments",
  [sym_lambda] = "lambda",
  [sym_global_operator] = "global_operator",
  [sym_persistent_operator] = "persistent_operator",
  [sym__argument_attributes] = "attributes",
  [sym_class_property] = "class_property",
  [sym_arguments_statement] = "arguments_statement",
  [sym_function_output] = "function_output",
  [sym_function_arguments] = "function_arguments",
  [sym_function_definition] = "function_definition",
  [sym__function_definition_with_end] = "function_definition",
  [sym_attribute] = "attribute",
  [sym_attributes] = "attributes",
  [sym_superclasses] = "superclasses",
  [sym_dimensions] = "dimensions",
  [sym_validation_functions] = "validation_functions",
  [sym_default_value] = "default_value",
  [sym_property_name] = "property_name",
  [sym_property] = "property",
  [sym_properties] = "properties",
  [sym_function_signature] = "function_signature",
  [sym_methods] = "methods",
  [sym_events] = "events",
  [sym_enum] = "enum",
  [sym_enumeration] = "enumeration",
  [sym_class_definition] = "class_definition",
  [sym_catch_clause] = "catch_clause",
  [sym_try_statement] = "try_statement",
  [sym_spmd_statement] = "spmd_statement",
  [sym_number] = "number",
  [sym_end_keyword] = "end_keyword",
  [sym__keywords] = "_keywords",
  [sym__extended_keywords] = "identifier",
  [sym__end_of_line] = "_end_of_line",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym__block_repeat1] = "_block_repeat1",
  [aux_sym_field_expression_repeat1] = "field_expression_repeat1",
  [aux_sym_metaclass_operator_repeat1] = "metaclass_operator_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_row_repeat1] = "row_repeat1",
  [aux_sym_matrix_repeat1] = "matrix_repeat1",
  [aux_sym_matrix_repeat2] = "matrix_repeat2",
  [aux_sym_multioutput_variable_repeat1] = "multioutput_variable_repeat1",
  [aux_sym__index_row_repeat1] = "_index_row_repeat1",
  [aux_sym__index_matrix_repeat1] = "_index_matrix_repeat1",
  [aux_sym__index_arguments_repeat1] = "_index_arguments_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_command_repeat1] = "command_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_switch_statement_repeat1] = "switch_statement_repeat1",
  [aux_sym__lambda_arguments_repeat1] = "_lambda_arguments_repeat1",
  [aux_sym_global_operator_repeat1] = "global_operator_repeat1",
  [aux_sym__argument_attributes_repeat1] = "_argument_attributes_repeat1",
  [aux_sym_arguments_statement_repeat1] = "arguments_statement_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_attributes_repeat1] = "attributes_repeat1",
  [aux_sym_superclasses_repeat1] = "superclasses_repeat1",
  [aux_sym_dimensions_repeat1] = "dimensions_repeat1",
  [aux_sym_validation_functions_repeat1] = "validation_functions_repeat1",
  [aux_sym_properties_repeat1] = "properties_repeat1",
  [aux_sym_methods_repeat1] = "methods_repeat1",
  [aux_sym_events_repeat1] = "events_repeat1",
  [aux_sym_enum_repeat1] = "enum_repeat1",
  [aux_sym_enumeration_repeat1] = "enumeration_repeat1",
  [aux_sym_class_definition_repeat1] = "class_definition_repeat1",
  [alias_sym__expression] = "_expression",
  [alias_sym_superclass] = "superclass",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DOT_PLUS] = anon_sym_DOT_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_DOT_DASH] = anon_sym_DOT_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_DOT_STAR] = anon_sym_DOT_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_DOT_SLASH] = anon_sym_DOT_SLASH,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [anon_sym_DOT_BSLASH] = anon_sym_DOT_BSLASH,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_DOT_CARET] = anon_sym_DOT_CARET,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_TILDE_EQ] = anon_sym_TILDE_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_DOT_SQUOTE] = anon_sym_DOT_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [aux_sym_matrix_token1] = aux_sym_matrix_token1,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_elseif] = anon_sym_elseif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_parfor] = anon_sym_parfor,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_otherwise] = anon_sym_otherwise,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_persistent] = anon_sym_persistent,
  [anon_sym_DOT_QMARK] = anon_sym_DOT_QMARK,
  [anon_sym_arguments] = anon_sym_arguments,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_get_DOT] = anon_sym_get_DOT,
  [anon_sym_set_DOT] = anon_sym_set_DOT,
  [anon_sym_endfunction] = anon_sym_endfunction,
  [anon_sym_vector] = sym_identifier,
  [anon_sym_matrix] = sym_identifier,
  [anon_sym_scalar] = sym_identifier,
  [anon_sym_properties] = anon_sym_properties,
  [anon_sym_get] = anon_sym_get,
  [anon_sym_set] = anon_sym_set,
  [anon_sym_methods] = anon_sym_methods,
  [anon_sym_events] = anon_sym_events,
  [anon_sym_enumeration] = anon_sym_enumeration,
  [anon_sym_classdef] = anon_sym_classdef,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_spmd] = anon_sym_spmd,
  [sym_number_size] = sym_number_size,
  [aux_sym_number_token1] = aux_sym_number_token1,
  [aux_sym_number_token2] = aux_sym_number_token2,
  [aux_sym_number_token3] = aux_sym_number_token3,
  [anon_sym_CR] = anon_sym_CR,
  [sym_comment] = sym_comment,
  [sym_line_continuation] = sym_line_continuation,
  [sym_command_name] = sym_command_name,
  [sym_command_argument] = sym_command_argument,
  [sym__single_quote_string_start] = anon_sym_SQUOTE,
  [sym__single_quote_string_end] = anon_sym_SQUOTE,
  [sym__double_quote_string_start] = sym__double_quote_string_start,
  [sym__double_quote_string_end] = sym__double_quote_string_start,
  [sym_formatting_sequence] = sym_formatting_sequence,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_string_content] = sym_string_content,
  [sym__entry_delimiter] = anon_sym_COMMA,
  [sym__multioutput_variable_start] = anon_sym_LBRACK,
  [sym__external_identifier] = sym__external_identifier,
  [sym_error_sentinel] = sym_error_sentinel,
  [sym_source_file] = sym_source_file,
  [aux_sym__block] = aux_sym__block,
  [sym_block] = sym_block,
  [sym_identifier] = sym_identifier,
  [sym__statement] = sym__statement,
  [sym__expression] = sym__expression,
  [sym_parenthesis] = sym_parenthesis,
  [sym__binary_expression] = sym__binary_expression,
  [sym_binary_operator] = sym_binary_operator,
  [sym_unary_operator] = sym_unary_operator,
  [sym_indirect_access] = sym_indirect_access,
  [sym_field_expression] = sym_field_expression,
  [sym_not_operator] = sym_not_operator,
  [sym_metaclass_operator] = sym_metaclass_operator,
  [sym_handle_operator] = sym_handle_operator,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_boolean_operator] = sym_boolean_operator,
  [sym_postfix_operator] = sym_postfix_operator,
  [sym_string] = sym_string,
  [sym_row] = sym_row,
  [sym_matrix] = sym_matrix,
  [sym_cell] = sym_cell,
  [sym_ignored_argument] = sym_ignored_argument,
  [sym_assignment] = sym_assignment,
  [sym_multioutput_variable] = sym_multioutput_variable,
  [sym_spread_operator] = sym_spread_operator,
  [sym__index_boolean_operator] = sym_boolean_operator,
  [sym__index_comparison_operator] = sym_comparison_operator,
  [sym__index_not_operator] = sym_not_operator,
  [sym__index_unary_operator] = sym_unary_operator,
  [sym__index_postfix_operator] = sym_postfix_operator,
  [sym__index_row] = sym_row,
  [sym__index_matrix] = sym_matrix,
  [sym__index_range_element] = sym__index_range_element,
  [sym__index_range] = sym_range,
  [sym__index_parenthesis] = sym_parenthesis,
  [sym__index_expression] = sym__index_expression,
  [sym__index_binary_expression] = sym__index_binary_expression,
  [sym__index_binary_operator] = sym_binary_operator,
  [sym__index_argument] = sym__index_argument,
  [sym__index_arguments] = sym__index_arguments,
  [sym_arguments] = sym_arguments,
  [sym__args] = sym__args,
  [sym_function_call] = sym_function_call,
  [sym_command] = sym_command,
  [sym__range_element] = sym__range_element,
  [sym_range] = sym_range,
  [sym_return_statement] = sym_return_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_elseif_clause] = sym_elseif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_if_statement] = sym_if_statement,
  [sym_iterator] = sym_iterator,
  [sym_parfor_options] = sym_parfor_options,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_case_clause] = sym_case_clause,
  [sym_otherwise_clause] = sym_otherwise_clause,
  [sym_switch_statement] = sym_switch_statement,
  [sym__lambda_arguments] = sym__lambda_arguments,
  [sym_lambda] = sym_lambda,
  [sym_global_operator] = sym_global_operator,
  [sym_persistent_operator] = sym_persistent_operator,
  [sym__argument_attributes] = sym_attributes,
  [sym_class_property] = sym_class_property,
  [sym_arguments_statement] = sym_arguments_statement,
  [sym_function_output] = sym_function_output,
  [sym_function_arguments] = sym_function_arguments,
  [sym_function_definition] = sym_function_definition,
  [sym__function_definition_with_end] = sym_function_definition,
  [sym_attribute] = sym_attribute,
  [sym_attributes] = sym_attributes,
  [sym_superclasses] = sym_superclasses,
  [sym_dimensions] = sym_dimensions,
  [sym_validation_functions] = sym_validation_functions,
  [sym_default_value] = sym_default_value,
  [sym_property_name] = sym_property_name,
  [sym_property] = sym_property,
  [sym_properties] = sym_properties,
  [sym_function_signature] = sym_function_signature,
  [sym_methods] = sym_methods,
  [sym_events] = sym_events,
  [sym_enum] = sym_enum,
  [sym_enumeration] = sym_enumeration,
  [sym_class_definition] = sym_class_definition,
  [sym_catch_clause] = sym_catch_clause,
  [sym_try_statement] = sym_try_statement,
  [sym_spmd_statement] = sym_spmd_statement,
  [sym_number] = sym_number,
  [sym_end_keyword] = sym_end_keyword,
  [sym__keywords] = sym__keywords,
  [sym__extended_keywords] = sym_identifier,
  [sym__end_of_line] = sym__end_of_line,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym__block_repeat1] = aux_sym__block_repeat1,
  [aux_sym_field_expression_repeat1] = aux_sym_field_expression_repeat1,
  [aux_sym_metaclass_operator_repeat1] = aux_sym_metaclass_operator_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_row_repeat1] = aux_sym_row_repeat1,
  [aux_sym_matrix_repeat1] = aux_sym_matrix_repeat1,
  [aux_sym_matrix_repeat2] = aux_sym_matrix_repeat2,
  [aux_sym_multioutput_variable_repeat1] = aux_sym_multioutput_variable_repeat1,
  [aux_sym__index_row_repeat1] = aux_sym__index_row_repeat1,
  [aux_sym__index_matrix_repeat1] = aux_sym__index_matrix_repeat1,
  [aux_sym__index_arguments_repeat1] = aux_sym__index_arguments_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_command_repeat1] = aux_sym_command_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_switch_statement_repeat1] = aux_sym_switch_statement_repeat1,
  [aux_sym__lambda_arguments_repeat1] = aux_sym__lambda_arguments_repeat1,
  [aux_sym_global_operator_repeat1] = aux_sym_global_operator_repeat1,
  [aux_sym__argument_attributes_repeat1] = aux_sym__argument_attributes_repeat1,
  [aux_sym_arguments_statement_repeat1] = aux_sym_arguments_statement_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_attributes_repeat1] = aux_sym_attributes_repeat1,
  [aux_sym_superclasses_repeat1] = aux_sym_superclasses_repeat1,
  [aux_sym_dimensions_repeat1] = aux_sym_dimensions_repeat1,
  [aux_sym_validation_functions_repeat1] = aux_sym_validation_functions_repeat1,
  [aux_sym_properties_repeat1] = aux_sym_properties_repeat1,
  [aux_sym_methods_repeat1] = aux_sym_methods_repeat1,
  [aux_sym_events_repeat1] = aux_sym_events_repeat1,
  [aux_sym_enum_repeat1] = aux_sym_enum_repeat1,
  [aux_sym_enumeration_repeat1] = aux_sym_enumeration_repeat1,
  [aux_sym_class_definition_repeat1] = aux_sym_class_definition_repeat1,
  [alias_sym__expression] = alias_sym__expression,
  [alias_sym_superclass] = alias_sym_superclass,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_matrix_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_elseif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_parfor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_otherwise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_persistent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_arguments] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endfunction] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vector] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_scalar] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_properties] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_methods] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_events] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumeration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_classdef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_spmd] = {
    .visible = true,
    .named = false,
  },
  [sym_number_size] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_number_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_number_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_number_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_CR] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_line_continuation] = {
    .visible = true,
    .named = true,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_command_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__single_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__single_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym_formatting_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__entry_delimiter] = {
    .visible = true,
    .named = false,
  },
  [sym__multioutput_variable_start] = {
    .visible = true,
    .named = false,
  },
  [sym__external_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_error_sentinel] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__block] = {
    .visible = false,
    .named = false,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesis] = {
    .visible = true,
    .named = true,
  },
  [sym__binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indirect_access] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_not_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_metaclass_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_handle_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_row] = {
    .visible = true,
    .named = true,
  },
  [sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [sym_cell] = {
    .visible = true,
    .named = true,
  },
  [sym_ignored_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_multioutput_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_spread_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__index_boolean_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__index_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__index_not_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__index_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__index_postfix_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__index_row] = {
    .visible = true,
    .named = true,
  },
  [sym__index_matrix] = {
    .visible = true,
    .named = true,
  },
  [sym__index_range_element] = {
    .visible = false,
    .named = true,
  },
  [sym__index_range] = {
    .visible = true,
    .named = true,
  },
  [sym__index_parenthesis] = {
    .visible = true,
    .named = true,
  },
  [sym__index_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__index_binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__index_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__index_argument] = {
    .visible = false,
    .named = true,
  },
  [sym__index_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__args] = {
    .visible = false,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_command] = {
    .visible = true,
    .named = true,
  },
  [sym__range_element] = {
    .visible = false,
    .named = true,
  },
  [sym_range] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_iterator] = {
    .visible = true,
    .named = true,
  },
  [sym_parfor_options] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_otherwise_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__lambda_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_global_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_persistent_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__argument_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_class_property] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_function_output] = {
    .visible = true,
    .named = true,
  },
  [sym_function_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__function_definition_with_end] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_superclasses] = {
    .visible = true,
    .named = true,
  },
  [sym_dimensions] = {
    .visible = true,
    .named = true,
  },
  [sym_validation_functions] = {
    .visible = true,
    .named = true,
  },
  [sym_default_value] = {
    .visible = true,
    .named = true,
  },
  [sym_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym_properties] = {
    .visible = true,
    .named = true,
  },
  [sym_function_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_methods] = {
    .visible = true,
    .named = true,
  },
  [sym_events] = {
    .visible = true,
    .named = true,
  },
  [sym_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_enumeration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_spmd_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_end_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym__keywords] = {
    .visible = false,
    .named = true,
  },
  [sym__extended_keywords] = {
    .visible = true,
    .named = true,
  },
  [sym__end_of_line] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metaclass_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_row_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_matrix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_matrix_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_multioutput_variable_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__index_row_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__index_matrix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__index_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__lambda_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__argument_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_superclasses_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dimensions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_validation_functions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_properties_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_methods_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_events_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumeration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym__expression] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_superclass] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_argument = 1,
  field_arguments = 2,
  field_condition = 3,
  field_expression = 4,
  field_field = 5,
  field_left = 6,
  field_name = 7,
  field_object = 8,
  field_operand = 9,
  field_right = 10,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_condition] = "condition",
  [field_expression] = "expression",
  [field_field] = "field",
  [field_left] = "left",
  [field_name] = "name",
  [field_object] = "object",
  [field_operand] = "operand",
  [field_right] = "right",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 1},
  [6] = {.index = 2, .length = 1},
  [7] = {.index = 6, .length = 1},
  [8] = {.index = 7, .length = 1},
  [9] = {.index = 7, .length = 1},
  [10] = {.index = 8, .length = 2},
  [11] = {.index = 10, .length = 1},
  [12] = {.index = 11, .length = 1},
  [13] = {.index = 12, .length = 1},
  [14] = {.index = 13, .length = 1},
  [15] = {.index = 2, .length = 1},
  [16] = {.index = 14, .length = 2},
  [17] = {.index = 16, .length = 2},
  [18] = {.index = 18, .length = 1},
  [19] = {.index = 19, .length = 1},
  [20] = {.index = 19, .length = 1},
  [21] = {.index = 20, .length = 2},
  [23] = {.index = 22, .length = 2},
  [24] = {.index = 24, .length = 3},
  [25] = {.index = 27, .length = 2},
  [26] = {.index = 2, .length = 1},
  [27] = {.index = 29, .length = 1},
  [28] = {.index = 30, .length = 1},
  [29] = {.index = 31, .length = 1},
  [30] = {.index = 31, .length = 1},
  [31] = {.index = 14, .length = 2},
  [32] = {.index = 32, .length = 1},
  [33] = {.index = 33, .length = 2},
  [34] = {.index = 35, .length = 1},
  [35] = {.index = 36, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_operand, 1},
  [1] =
    {field_operand, 0},
  [2] =
    {field_name, 0},
  [3] =
    {field_field, 1, .inherited = true},
    {field_object, 0},
  [5] =
    {field_name, 0, .inherited = true},
  [6] =
    {field_condition, 1},
  [7] =
    {field_name, 1},
  [8] =
    {field_left, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [10] =
    {field_operand, 0, .inherited = true},
  [11] =
    {field_argument, 0},
  [12] =
    {field_argument, 0, .inherited = true},
  [13] =
    {field_field, 1},
  [14] =
    {field_left, 0},
    {field_right, 2},
  [16] =
    {field_field, 0, .inherited = true},
    {field_field, 1, .inherited = true},
  [18] =
    {field_expression, 3},
  [19] =
    {field_name, 2},
  [20] =
    {field_operand, 1},
    {field_operand, 1, .inherited = true},
  [22] =
    {field_operand, 0},
    {field_operand, 0, .inherited = true},
  [24] =
    {field_left, 0, .inherited = true},
    {field_operand, 0},
    {field_right, 0, .inherited = true},
  [27] =
    {field_argument, 0},
    {field_argument, 1, .inherited = true},
  [29] =
    {field_expression, 4},
  [30] =
    {field_arguments, 1},
  [31] =
    {field_name, 3},
  [32] =
    {field_argument, 1},
  [33] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [35] =
    {field_argument, 1, .inherited = true},
  [36] =
    {field_argument, 1},
    {field_argument, 2, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [6] = {
    [0] = sym_identifier,
  },
  [9] = {
    [1] = sym_identifier,
  },
  [15] = {
    [2] = alias_sym_superclass,
  },
  [20] = {
    [2] = sym_identifier,
  },
  [22] = {
    [1] = alias_sym__expression,
  },
  [26] = {
    [0] = sym_identifier,
    [2] = alias_sym_superclass,
  },
  [27] = {
    [2] = sym_arguments,
  },
  [30] = {
    [3] = sym_identifier,
  },
  [31] = {
    [0] = alias_sym__expression,
    [2] = alias_sym__expression,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__index_expression, 2,
    sym__index_expression,
    alias_sym__expression,
  sym__lambda_arguments, 2,
    sym__lambda_arguments,
    sym_arguments,
  sym_property_name, 2,
    sym_property_name,
    alias_sym_superclass,
  sym_end_keyword, 2,
    sym_end_keyword,
    sym_identifier,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 35,
  [107] = 31,
  [108] = 35,
  [109] = 109,
  [110] = 110,
  [111] = 109,
  [112] = 109,
  [113] = 109,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 140,
  [172] = 142,
  [173] = 143,
  [174] = 174,
  [175] = 145,
  [176] = 140,
  [177] = 142,
  [178] = 143,
  [179] = 142,
  [180] = 143,
  [181] = 174,
  [182] = 140,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 188,
  [191] = 189,
  [192] = 174,
  [193] = 189,
  [194] = 188,
  [195] = 195,
  [196] = 195,
  [197] = 184,
  [198] = 198,
  [199] = 186,
  [200] = 183,
  [201] = 201,
  [202] = 195,
  [203] = 201,
  [204] = 201,
  [205] = 185,
  [206] = 195,
  [207] = 201,
  [208] = 195,
  [209] = 201,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 215,
  [218] = 218,
  [219] = 218,
  [220] = 216,
  [221] = 216,
  [222] = 222,
  [223] = 215,
  [224] = 222,
  [225] = 123,
  [226] = 119,
  [227] = 120,
  [228] = 124,
  [229] = 118,
  [230] = 135,
  [231] = 138,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 233,
  [236] = 234,
  [237] = 233,
  [238] = 238,
  [239] = 239,
  [240] = 238,
  [241] = 233,
  [242] = 234,
  [243] = 239,
  [244] = 239,
  [245] = 238,
  [246] = 234,
  [247] = 239,
  [248] = 238,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 259,
  [263] = 257,
  [264] = 264,
  [265] = 249,
  [266] = 266,
  [267] = 266,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 266,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 275,
  [279] = 279,
  [280] = 256,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 254,
  [291] = 291,
  [292] = 266,
  [293] = 293,
  [294] = 294,
  [295] = 281,
  [296] = 282,
  [297] = 283,
  [298] = 284,
  [299] = 285,
  [300] = 286,
  [301] = 287,
  [302] = 288,
  [303] = 289,
  [304] = 291,
  [305] = 266,
  [306] = 293,
  [307] = 307,
  [308] = 308,
  [309] = 281,
  [310] = 282,
  [311] = 283,
  [312] = 284,
  [313] = 285,
  [314] = 286,
  [315] = 287,
  [316] = 288,
  [317] = 289,
  [318] = 318,
  [319] = 291,
  [320] = 253,
  [321] = 321,
  [322] = 266,
  [323] = 293,
  [324] = 293,
  [325] = 291,
  [326] = 281,
  [327] = 282,
  [328] = 283,
  [329] = 284,
  [330] = 285,
  [331] = 286,
  [332] = 287,
  [333] = 266,
  [334] = 288,
  [335] = 289,
  [336] = 291,
  [337] = 337,
  [338] = 338,
  [339] = 277,
  [340] = 340,
  [341] = 337,
  [342] = 277,
  [343] = 281,
  [344] = 282,
  [345] = 283,
  [346] = 340,
  [347] = 347,
  [348] = 275,
  [349] = 281,
  [350] = 282,
  [351] = 283,
  [352] = 291,
  [353] = 279,
  [354] = 281,
  [355] = 282,
  [356] = 283,
  [357] = 291,
  [358] = 266,
  [359] = 281,
  [360] = 282,
  [361] = 283,
  [362] = 291,
  [363] = 266,
  [364] = 291,
  [365] = 266,
  [366] = 337,
  [367] = 277,
  [368] = 275,
  [369] = 337,
  [370] = 337,
  [371] = 279,
  [372] = 291,
  [373] = 266,
  [374] = 291,
  [375] = 266,
  [376] = 291,
  [377] = 279,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 385,
  [388] = 388,
  [389] = 389,
  [390] = 388,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 394,
  [395] = 395,
  [396] = 396,
  [397] = 386,
  [398] = 398,
  [399] = 399,
  [400] = 398,
  [401] = 391,
  [402] = 392,
  [403] = 393,
  [404] = 394,
  [405] = 399,
  [406] = 389,
  [407] = 395,
  [408] = 396,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 135,
  [413] = 413,
  [414] = 122,
  [415] = 109,
  [416] = 109,
  [417] = 117,
  [418] = 109,
  [419] = 109,
  [420] = 118,
  [421] = 115,
  [422] = 110,
  [423] = 121,
  [424] = 126,
  [425] = 131,
  [426] = 426,
  [427] = 129,
  [428] = 139,
  [429] = 136,
  [430] = 133,
  [431] = 138,
  [432] = 134,
  [433] = 128,
  [434] = 125,
  [435] = 137,
  [436] = 109,
  [437] = 109,
  [438] = 109,
  [439] = 439,
  [440] = 109,
  [441] = 110,
  [442] = 442,
  [443] = 116,
  [444] = 444,
  [445] = 442,
  [446] = 115,
  [447] = 117,
  [448] = 114,
  [449] = 449,
  [450] = 450,
  [451] = 122,
  [452] = 121,
  [453] = 453,
  [454] = 118,
  [455] = 450,
  [456] = 442,
  [457] = 442,
  [458] = 442,
  [459] = 459,
  [460] = 450,
  [461] = 461,
  [462] = 124,
  [463] = 110,
  [464] = 127,
  [465] = 119,
  [466] = 123,
  [467] = 450,
  [468] = 449,
  [469] = 129,
  [470] = 130,
  [471] = 125,
  [472] = 131,
  [473] = 126,
  [474] = 128,
  [475] = 133,
  [476] = 120,
  [477] = 139,
  [478] = 137,
  [479] = 136,
  [480] = 135,
  [481] = 109,
  [482] = 138,
  [483] = 459,
  [484] = 109,
  [485] = 109,
  [486] = 109,
  [487] = 444,
  [488] = 450,
  [489] = 444,
  [490] = 450,
  [491] = 134,
  [492] = 118,
  [493] = 115,
  [494] = 494,
  [495] = 121,
  [496] = 117,
  [497] = 122,
  [498] = 498,
  [499] = 499,
  [500] = 132,
  [501] = 494,
  [502] = 494,
  [503] = 135,
  [504] = 499,
  [505] = 161,
  [506] = 141,
  [507] = 114,
  [508] = 139,
  [509] = 129,
  [510] = 142,
  [511] = 154,
  [512] = 152,
  [513] = 162,
  [514] = 140,
  [515] = 143,
  [516] = 155,
  [517] = 145,
  [518] = 499,
  [519] = 499,
  [520] = 163,
  [521] = 126,
  [522] = 498,
  [523] = 168,
  [524] = 169,
  [525] = 166,
  [526] = 144,
  [527] = 156,
  [528] = 499,
  [529] = 187,
  [530] = 145,
  [531] = 131,
  [532] = 157,
  [533] = 120,
  [534] = 124,
  [535] = 119,
  [536] = 123,
  [537] = 138,
  [538] = 164,
  [539] = 146,
  [540] = 158,
  [541] = 159,
  [542] = 444,
  [543] = 142,
  [544] = 143,
  [545] = 167,
  [546] = 116,
  [547] = 142,
  [548] = 174,
  [549] = 165,
  [550] = 494,
  [551] = 140,
  [552] = 128,
  [553] = 140,
  [554] = 153,
  [555] = 125,
  [556] = 494,
  [557] = 160,
  [558] = 499,
  [559] = 133,
  [560] = 142,
  [561] = 170,
  [562] = 494,
  [563] = 183,
  [564] = 184,
  [565] = 498,
  [566] = 185,
  [567] = 186,
  [568] = 143,
  [569] = 137,
  [570] = 147,
  [571] = 148,
  [572] = 136,
  [573] = 149,
  [574] = 150,
  [575] = 134,
  [576] = 576,
  [577] = 151,
  [578] = 140,
  [579] = 174,
  [580] = 143,
  [581] = 576,
  [582] = 132,
  [583] = 127,
  [584] = 130,
  [585] = 142,
  [586] = 154,
  [587] = 155,
  [588] = 150,
  [589] = 114,
  [590] = 160,
  [591] = 161,
  [592] = 162,
  [593] = 163,
  [594] = 187,
  [595] = 164,
  [596] = 174,
  [597] = 165,
  [598] = 598,
  [599] = 166,
  [600] = 167,
  [601] = 143,
  [602] = 116,
  [603] = 120,
  [604] = 124,
  [605] = 119,
  [606] = 123,
  [607] = 174,
  [608] = 168,
  [609] = 169,
  [610] = 170,
  [611] = 145,
  [612] = 140,
  [613] = 149,
  [614] = 140,
  [615] = 147,
  [616] = 156,
  [617] = 617,
  [618] = 157,
  [619] = 142,
  [620] = 148,
  [621] = 143,
  [622] = 142,
  [623] = 143,
  [624] = 174,
  [625] = 140,
  [626] = 140,
  [627] = 152,
  [628] = 158,
  [629] = 159,
  [630] = 153,
  [631] = 183,
  [632] = 184,
  [633] = 185,
  [634] = 186,
  [635] = 141,
  [636] = 142,
  [637] = 143,
  [638] = 144,
  [639] = 145,
  [640] = 146,
  [641] = 151,
  [642] = 642,
  [643] = 127,
  [644] = 130,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 647,
  [656] = 656,
  [657] = 186,
  [658] = 184,
  [659] = 659,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 132,
  [668] = 646,
  [669] = 669,
  [670] = 183,
  [671] = 671,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 656,
  [676] = 648,
  [677] = 677,
  [678] = 678,
  [679] = 679,
  [680] = 680,
  [681] = 681,
  [682] = 682,
  [683] = 683,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 649,
  [689] = 689,
  [690] = 652,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 694,
  [695] = 695,
  [696] = 185,
  [697] = 654,
  [698] = 652,
  [699] = 654,
  [700] = 647,
  [701] = 656,
  [702] = 702,
  [703] = 703,
  [704] = 144,
  [705] = 653,
  [706] = 148,
  [707] = 665,
  [708] = 149,
  [709] = 150,
  [710] = 166,
  [711] = 154,
  [712] = 167,
  [713] = 174,
  [714] = 151,
  [715] = 691,
  [716] = 671,
  [717] = 155,
  [718] = 160,
  [719] = 142,
  [720] = 672,
  [721] = 143,
  [722] = 142,
  [723] = 647,
  [724] = 143,
  [725] = 174,
  [726] = 656,
  [727] = 142,
  [728] = 669,
  [729] = 143,
  [730] = 660,
  [731] = 703,
  [732] = 140,
  [733] = 159,
  [734] = 654,
  [735] = 661,
  [736] = 152,
  [737] = 140,
  [738] = 677,
  [739] = 662,
  [740] = 141,
  [741] = 663,
  [742] = 664,
  [743] = 647,
  [744] = 646,
  [745] = 678,
  [746] = 679,
  [747] = 680,
  [748] = 681,
  [749] = 140,
  [750] = 682,
  [751] = 683,
  [752] = 684,
  [753] = 685,
  [754] = 666,
  [755] = 168,
  [756] = 169,
  [757] = 174,
  [758] = 689,
  [759] = 673,
  [760] = 647,
  [761] = 692,
  [762] = 693,
  [763] = 656,
  [764] = 652,
  [765] = 695,
  [766] = 646,
  [767] = 686,
  [768] = 161,
  [769] = 183,
  [770] = 184,
  [771] = 185,
  [772] = 162,
  [773] = 186,
  [774] = 163,
  [775] = 187,
  [776] = 164,
  [777] = 165,
  [778] = 140,
  [779] = 170,
  [780] = 654,
  [781] = 145,
  [782] = 146,
  [783] = 145,
  [784] = 156,
  [785] = 648,
  [786] = 702,
  [787] = 649,
  [788] = 642,
  [789] = 157,
  [790] = 674,
  [791] = 656,
  [792] = 147,
  [793] = 158,
  [794] = 645,
  [795] = 659,
  [796] = 648,
  [797] = 650,
  [798] = 687,
  [799] = 649,
  [800] = 652,
  [801] = 652,
  [802] = 654,
  [803] = 651,
  [804] = 142,
  [805] = 143,
  [806] = 153,
  [807] = 694,
  [808] = 808,
  [809] = 185,
  [810] = 810,
  [811] = 186,
  [812] = 812,
  [813] = 494,
  [814] = 184,
  [815] = 815,
  [816] = 183,
  [817] = 817,
  [818] = 818,
  [819] = 645,
  [820] = 815,
  [821] = 677,
  [822] = 817,
  [823] = 674,
  [824] = 817,
  [825] = 825,
  [826] = 826,
  [827] = 818,
  [828] = 659,
  [829] = 818,
  [830] = 817,
  [831] = 818,
  [832] = 832,
  [833] = 833,
  [834] = 808,
  [835] = 815,
  [836] = 818,
  [837] = 815,
  [838] = 838,
  [839] = 174,
  [840] = 817,
  [841] = 815,
  [842] = 815,
  [843] = 817,
  [844] = 818,
  [845] = 183,
  [846] = 140,
  [847] = 140,
  [848] = 140,
  [849] = 184,
  [850] = 656,
  [851] = 185,
  [852] = 186,
  [853] = 145,
  [854] = 854,
  [855] = 646,
  [856] = 856,
  [857] = 145,
  [858] = 145,
  [859] = 859,
  [860] = 860,
  [861] = 861,
  [862] = 862,
  [863] = 863,
  [864] = 864,
  [865] = 865,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 874,
  [875] = 118,
  [876] = 876,
  [877] = 877,
  [878] = 135,
  [879] = 879,
  [880] = 880,
  [881] = 881,
  [882] = 253,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 138,
  [888] = 888,
  [889] = 121,
  [890] = 122,
  [891] = 122,
  [892] = 892,
  [893] = 118,
  [894] = 118,
  [895] = 895,
  [896] = 115,
  [897] = 117,
  [898] = 135,
  [899] = 899,
  [900] = 900,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 129,
  [905] = 905,
  [906] = 906,
  [907] = 907,
  [908] = 135,
  [909] = 138,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 138,
  [918] = 119,
  [919] = 125,
  [920] = 126,
  [921] = 921,
  [922] = 128,
  [923] = 120,
  [924] = 124,
  [925] = 123,
  [926] = 131,
  [927] = 137,
  [928] = 136,
  [929] = 133,
  [930] = 134,
  [931] = 139,
  [932] = 932,
  [933] = 933,
  [934] = 118,
  [935] = 935,
  [936] = 114,
  [937] = 937,
  [938] = 938,
  [939] = 939,
  [940] = 940,
  [941] = 941,
  [942] = 942,
  [943] = 253,
  [944] = 944,
  [945] = 945,
  [946] = 946,
  [947] = 137,
  [948] = 116,
  [949] = 136,
  [950] = 950,
  [951] = 951,
  [952] = 952,
  [953] = 124,
  [954] = 127,
  [955] = 119,
  [956] = 135,
  [957] = 130,
  [958] = 120,
  [959] = 123,
  [960] = 960,
  [961] = 961,
  [962] = 138,
  [963] = 963,
  [964] = 964,
  [965] = 118,
  [966] = 966,
  [967] = 967,
  [968] = 968,
  [969] = 969,
  [970] = 138,
  [971] = 968,
  [972] = 135,
  [973] = 973,
  [974] = 974,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 810,
  [979] = 969,
  [980] = 980,
  [981] = 981,
  [982] = 980,
  [983] = 967,
  [984] = 967,
  [985] = 985,
  [986] = 980,
  [987] = 967,
  [988] = 967,
  [989] = 967,
  [990] = 967,
  [991] = 967,
  [992] = 967,
  [993] = 980,
  [994] = 994,
  [995] = 967,
  [996] = 967,
  [997] = 967,
  [998] = 998,
  [999] = 941,
  [1000] = 124,
  [1001] = 123,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 119,
  [1005] = 1005,
  [1006] = 120,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1018,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1032,
  [1033] = 1033,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1031,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1031,
  [1041] = 1038,
  [1042] = 1042,
  [1043] = 1043,
  [1044] = 1036,
  [1045] = 1038,
  [1046] = 1031,
  [1047] = 1031,
  [1048] = 1042,
  [1049] = 1043,
  [1050] = 1050,
  [1051] = 1036,
  [1052] = 1052,
  [1053] = 1043,
  [1054] = 1054,
  [1055] = 1036,
  [1056] = 1038,
  [1057] = 1057,
  [1058] = 1043,
  [1059] = 1059,
  [1060] = 1060,
  [1061] = 1038,
  [1062] = 1036,
  [1063] = 1038,
  [1064] = 1043,
  [1065] = 1065,
  [1066] = 1036,
  [1067] = 1038,
  [1068] = 1043,
  [1069] = 1069,
  [1070] = 1043,
  [1071] = 1071,
  [1072] = 1043,
  [1073] = 1036,
  [1074] = 1043,
  [1075] = 1075,
  [1076] = 1043,
  [1077] = 1077,
  [1078] = 1039,
  [1079] = 1042,
  [1080] = 1080,
  [1081] = 1043,
  [1082] = 1082,
  [1083] = 1038,
  [1084] = 1043,
  [1085] = 1085,
  [1086] = 1036,
  [1087] = 1042,
  [1088] = 1042,
  [1089] = 1031,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 1093,
  [1094] = 1094,
  [1095] = 1090,
  [1096] = 1090,
  [1097] = 1092,
  [1098] = 1098,
  [1099] = 1099,
  [1100] = 1092,
  [1101] = 1090,
  [1102] = 1102,
  [1103] = 255,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1092,
  [1108] = 1090,
  [1109] = 1092,
  [1110] = 1110,
  [1111] = 1090,
  [1112] = 1112,
  [1113] = 1092,
  [1114] = 1092,
  [1115] = 1090,
  [1116] = 1092,
  [1117] = 1117,
  [1118] = 1090,
  [1119] = 1090,
  [1120] = 1090,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 253,
  [1126] = 1126,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 1130,
  [1131] = 1131,
  [1132] = 1128,
  [1133] = 1133,
  [1134] = 1128,
  [1135] = 122,
  [1136] = 1136,
  [1137] = 1137,
  [1138] = 1128,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1144,
  [1145] = 1130,
  [1146] = 1146,
  [1147] = 1147,
  [1148] = 1148,
  [1149] = 1149,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 1148,
  [1153] = 1153,
  [1154] = 1149,
  [1155] = 1155,
  [1156] = 1148,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1148,
  [1161] = 1148,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1165,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 121,
  [1169] = 1169,
  [1170] = 1170,
  [1171] = 1171,
  [1172] = 1172,
  [1173] = 1173,
  [1174] = 1174,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1178,
  [1179] = 1179,
  [1180] = 1180,
  [1181] = 1181,
  [1182] = 1182,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1185,
  [1186] = 1186,
  [1187] = 1187,
  [1188] = 1188,
  [1189] = 1189,
  [1190] = 1190,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1206,
  [1207] = 1207,
  [1208] = 1208,
  [1209] = 1209,
  [1210] = 1210,
  [1211] = 1211,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1214,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 1219,
  [1220] = 1220,
  [1221] = 1221,
  [1222] = 1222,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1230,
  [1231] = 1231,
  [1232] = 1232,
  [1233] = 1233,
  [1234] = 1234,
  [1235] = 1235,
  [1236] = 1236,
  [1237] = 1237,
  [1238] = 1238,
  [1239] = 1239,
  [1240] = 1240,
  [1241] = 1241,
  [1242] = 1242,
  [1243] = 1243,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 1246,
  [1247] = 1247,
  [1248] = 1248,
  [1249] = 1249,
  [1250] = 1250,
  [1251] = 1251,
  [1252] = 1252,
  [1253] = 1253,
  [1254] = 1254,
  [1255] = 1255,
  [1256] = 1256,
  [1257] = 122,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1261,
  [1262] = 1262,
  [1263] = 1263,
  [1264] = 1264,
  [1265] = 1265,
  [1266] = 1266,
  [1267] = 1267,
  [1268] = 1268,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1271,
  [1272] = 1272,
  [1273] = 1273,
  [1274] = 1274,
  [1275] = 1275,
  [1276] = 1276,
  [1277] = 1277,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1280,
  [1281] = 1281,
  [1282] = 1282,
  [1283] = 1283,
  [1284] = 1284,
  [1285] = 1283,
  [1286] = 1286,
  [1287] = 1287,
  [1288] = 1288,
  [1289] = 1289,
  [1290] = 1290,
  [1291] = 1264,
  [1292] = 1292,
  [1293] = 1293,
  [1294] = 1294,
  [1295] = 121,
  [1296] = 1296,
  [1297] = 1297,
  [1298] = 1298,
  [1299] = 1299,
  [1300] = 1300,
  [1301] = 1301,
  [1302] = 1302,
  [1303] = 1303,
  [1304] = 1304,
  [1305] = 1305,
  [1306] = 1306,
  [1307] = 1307,
  [1308] = 1308,
  [1309] = 1309,
  [1310] = 1310,
  [1311] = 1311,
  [1312] = 1312,
  [1313] = 1313,
  [1314] = 1314,
  [1315] = 1315,
  [1316] = 1316,
  [1317] = 1317,
  [1318] = 1318,
  [1319] = 1319,
  [1320] = 1320,
  [1321] = 1321,
  [1322] = 1322,
  [1323] = 1323,
  [1324] = 1324,
  [1325] = 1325,
  [1326] = 1326,
  [1327] = 1327,
  [1328] = 1328,
  [1329] = 1329,
  [1330] = 1330,
  [1331] = 1331,
  [1332] = 1332,
  [1333] = 1333,
  [1334] = 1334,
  [1335] = 1335,
  [1336] = 1336,
  [1337] = 1337,
  [1338] = 1338,
  [1339] = 1339,
  [1340] = 1340,
  [1341] = 1341,
  [1342] = 1342,
  [1343] = 1343,
  [1344] = 1344,
  [1345] = 1345,
  [1346] = 1346,
  [1347] = 1347,
  [1348] = 1348,
  [1349] = 1349,
  [1350] = 1350,
  [1351] = 1351,
  [1352] = 1352,
  [1353] = 1353,
  [1354] = 1354,
  [1355] = 576,
  [1356] = 1356,
  [1357] = 1357,
  [1358] = 1358,
  [1359] = 1359,
  [1360] = 1360,
  [1361] = 1361,
  [1362] = 1362,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1365,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1369,
  [1370] = 1370,
  [1371] = 1371,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 1374,
  [1375] = 1347,
  [1376] = 1376,
  [1377] = 1356,
  [1378] = 1378,
  [1379] = 1353,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1378,
  [1383] = 1383,
  [1384] = 1363,
  [1385] = 1385,
  [1386] = 1386,
  [1387] = 1387,
  [1388] = 1388,
  [1389] = 1356,
  [1390] = 1378,
  [1391] = 1391,
  [1392] = 1347,
  [1393] = 1353,
  [1394] = 1394,
  [1395] = 1395,
  [1396] = 1356,
  [1397] = 1378,
  [1398] = 1347,
  [1399] = 1353,
  [1400] = 1400,
  [1401] = 1401,
  [1402] = 1402,
  [1403] = 1403,
  [1404] = 1404,
  [1405] = 1405,
  [1406] = 1406,
  [1407] = 1407,
  [1408] = 1408,
  [1409] = 1409,
  [1410] = 1410,
  [1411] = 1411,
  [1412] = 1412,
  [1413] = 1413,
  [1414] = 1414,
  [1415] = 1415,
  [1416] = 1416,
  [1417] = 1417,
  [1418] = 1418,
  [1419] = 1419,
  [1420] = 1420,
  [1421] = 1421,
  [1422] = 1422,
  [1423] = 1423,
  [1424] = 1424,
  [1425] = 1425,
  [1426] = 1426,
  [1427] = 1427,
  [1428] = 1428,
  [1429] = 1429,
  [1430] = 1430,
  [1431] = 1431,
  [1432] = 1432,
  [1433] = 1433,
  [1434] = 1434,
  [1435] = 1435,
  [1436] = 1436,
  [1437] = 1437,
  [1438] = 1438,
  [1439] = 1439,
  [1440] = 1440,
  [1441] = 1164,
  [1442] = 1442,
  [1443] = 1443,
  [1444] = 1444,
  [1445] = 1445,
  [1446] = 1446,
  [1447] = 1447,
  [1448] = 1448,
  [1449] = 1449,
  [1450] = 1450,
  [1451] = 1451,
  [1452] = 1452,
  [1453] = 1453,
  [1454] = 1454,
  [1455] = 1455,
  [1456] = 1456,
  [1457] = 1457,
  [1458] = 1458,
  [1459] = 1153,
  [1460] = 1460,
  [1461] = 1461,
  [1462] = 1462,
  [1463] = 1463,
  [1464] = 1464,
  [1465] = 1465,
  [1466] = 1466,
  [1467] = 1467,
  [1468] = 1468,
  [1469] = 1469,
  [1470] = 1470,
  [1471] = 1471,
  [1472] = 1472,
  [1473] = 1473,
  [1474] = 1474,
  [1475] = 1463,
  [1476] = 1476,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1479,
  [1480] = 1480,
  [1481] = 1481,
  [1482] = 1482,
  [1483] = 1483,
  [1484] = 1484,
  [1485] = 1476,
  [1486] = 1486,
  [1487] = 1487,
  [1488] = 1488,
  [1489] = 1486,
  [1490] = 1490,
  [1491] = 1491,
  [1492] = 1492,
  [1493] = 1493,
  [1494] = 1487,
  [1495] = 1495,
  [1496] = 1411,
  [1497] = 1497,
  [1498] = 1407,
  [1499] = 1499,
  [1500] = 1488,
  [1501] = 1425,
  [1502] = 1426,
  [1503] = 1503,
  [1504] = 1504,
  [1505] = 1505,
  [1506] = 1506,
  [1507] = 1507,
  [1508] = 1508,
  [1509] = 1509,
  [1510] = 1510,
  [1511] = 1511,
  [1512] = 1495,
  [1513] = 1513,
  [1514] = 1514,
  [1515] = 1515,
  [1516] = 1474,
  [1517] = 1517,
  [1518] = 1518,
  [1519] = 1519,
  [1520] = 1520,
  [1521] = 1521,
  [1522] = 1522,
  [1523] = 1523,
  [1524] = 1524,
  [1525] = 1525,
  [1526] = 1506,
  [1527] = 1527,
  [1528] = 1528,
  [1529] = 1529,
  [1530] = 1530,
  [1531] = 1531,
  [1532] = 1532,
  [1533] = 1533,
  [1534] = 1534,
  [1535] = 1474,
  [1536] = 1463,
  [1537] = 1537,
  [1538] = 1538,
  [1539] = 1539,
  [1540] = 1540,
  [1541] = 1479,
  [1542] = 1542,
  [1543] = 1480,
  [1544] = 1544,
  [1545] = 1476,
  [1546] = 1486,
  [1547] = 1487,
  [1548] = 1488,
  [1549] = 1495,
  [1550] = 1411,
  [1551] = 1551,
  [1552] = 1552,
  [1553] = 1553,
  [1554] = 1480,
  [1555] = 1555,
  [1556] = 1556,
  [1557] = 1474,
  [1558] = 1463,
  [1559] = 1559,
  [1560] = 1560,
  [1561] = 1561,
  [1562] = 1479,
  [1563] = 1480,
  [1564] = 1564,
  [1565] = 1565,
  [1566] = 1476,
  [1567] = 1486,
  [1568] = 1487,
  [1569] = 1488,
  [1570] = 1495,
  [1571] = 1411,
  [1572] = 1572,
  [1573] = 1474,
  [1574] = 1463,
  [1575] = 1479,
  [1576] = 1576,
  [1577] = 1577,
  [1578] = 1578,
  [1579] = 1474,
  [1580] = 1580,
  [1581] = 1581,
  [1582] = 1582,
  [1583] = 1583,
  [1584] = 1584,
  [1585] = 1585,
  [1586] = 1586,
  [1587] = 1587,
  [1588] = 1588,
  [1589] = 1589,
  [1590] = 1590,
  [1591] = 1591,
  [1592] = 1592,
  [1593] = 1593,
  [1594] = 1594,
  [1595] = 1595,
  [1596] = 1596,
  [1597] = 1597,
  [1598] = 1598,
  [1599] = 1599,
  [1600] = 1600,
  [1601] = 1601,
  [1602] = 1602,
  [1603] = 1603,
  [1604] = 1604,
  [1605] = 1605,
  [1606] = 1606,
  [1607] = 1607,
  [1608] = 1608,
  [1609] = 1609,
  [1610] = 1610,
  [1611] = 1611,
  [1612] = 1612,
  [1613] = 1613,
  [1614] = 1614,
  [1615] = 1615,
  [1616] = 1616,
  [1617] = 1617,
  [1618] = 1618,
  [1619] = 1619,
  [1620] = 1602,
  [1621] = 1621,
  [1622] = 1622,
  [1623] = 1623,
  [1624] = 1624,
  [1625] = 1625,
  [1626] = 1626,
  [1627] = 1627,
  [1628] = 1628,
  [1629] = 1629,
  [1630] = 1630,
  [1631] = 1631,
  [1632] = 1632,
  [1633] = 1633,
  [1634] = 1602,
  [1635] = 1635,
  [1636] = 1636,
  [1637] = 1637,
  [1638] = 1638,
  [1639] = 1606,
  [1640] = 1640,
  [1641] = 1602,
  [1642] = 1642,
  [1643] = 1643,
  [1644] = 1644,
  [1645] = 1602,
  [1646] = 1646,
  [1647] = 1647,
  [1648] = 1647,
  [1649] = 1649,
  [1650] = 1650,
  [1651] = 1651,
  [1652] = 1652,
  [1653] = 1653,
  [1654] = 1654,
  [1655] = 1655,
  [1656] = 1656,
  [1657] = 1657,
  [1658] = 1658,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 1661,
  [1662] = 1662,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1665,
  [1666] = 1666,
  [1667] = 1667,
  [1668] = 1668,
  [1669] = 1669,
  [1670] = 1670,
  [1671] = 1671,
  [1672] = 1672,
  [1673] = 1673,
  [1674] = 1674,
  [1675] = 1675,
  [1676] = 1676,
  [1677] = 1677,
  [1678] = 1678,
  [1679] = 1679,
  [1680] = 1680,
  [1681] = 941,
  [1682] = 1682,
  [1683] = 1683,
  [1684] = 1684,
  [1685] = 1685,
  [1686] = 1686,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1689,
  [1690] = 1690,
  [1691] = 1691,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1694,
  [1695] = 1695,
  [1696] = 1696,
  [1697] = 1697,
  [1698] = 1698,
  [1699] = 1699,
  [1700] = 1700,
  [1701] = 1701,
  [1702] = 1702,
  [1703] = 1703,
  [1704] = 1704,
  [1705] = 1703,
  [1706] = 1706,
  [1707] = 1707,
  [1708] = 1708,
  [1709] = 1703,
  [1710] = 1710,
  [1711] = 1711,
  [1712] = 1712,
  [1713] = 1713,
  [1714] = 1714,
  [1715] = 1703,
  [1716] = 1716,
  [1717] = 1717,
  [1718] = 1718,
  [1719] = 1703,
  [1720] = 1720,
  [1721] = 1721,
  [1722] = 1722,
  [1723] = 1723,
  [1724] = 1724,
  [1725] = 1725,
  [1726] = 1703,
  [1727] = 1710,
  [1728] = 1711,
  [1729] = 1711,
  [1730] = 1730,
  [1731] = 1731,
  [1732] = 1732,
  [1733] = 1733,
  [1734] = 1713,
  [1735] = 1735,
  [1736] = 1736,
  [1737] = 1703,
  [1738] = 1710,
  [1739] = 1739,
  [1740] = 1740,
  [1741] = 1741,
  [1742] = 1742,
  [1743] = 1743,
  [1744] = 1711,
  [1745] = 1745,
  [1746] = 1703,
  [1747] = 1747,
  [1748] = 1748,
  [1749] = 1749,
  [1750] = 1703,
  [1751] = 1721,
  [1752] = 1752,
  [1753] = 1753,
  [1754] = 1743,
  [1755] = 1755,
  [1756] = 1756,
  [1757] = 1757,
  [1758] = 1711,
  [1759] = 1721,
  [1760] = 1710,
  [1761] = 1761,
  [1762] = 1721,
  [1763] = 1763,
  [1764] = 1764,
  [1765] = 1765,
  [1766] = 1766,
  [1767] = 1703,
  [1768] = 1768,
  [1769] = 1703,
  [1770] = 1770,
  [1771] = 1703,
  [1772] = 1772,
  [1773] = 1773,
  [1774] = 1774,
  [1775] = 1775,
  [1776] = 1776,
  [1777] = 1710,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(185);
      ADVANCE_MAP(
        '&', 202,
        '\'', 222,
        '(', 186,
        ')', 187,
        '*', 192,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 204,
        '/', 194,
        '0', 274,
        ':', 234,
        ';', 227,
        '<', 213,
        '=', 233,
        '>', 218,
        '?', 211,
        '@', 212,
        '[', 224,
        '\\', 196,
        ']', 229,
        '^', 198,
        'a', 118,
        'b', 127,
        'c', 18,
        'e', 87,
        'f', 111,
        'g', 48,
        'i', 65,
        'm', 22,
        'o', 150,
        'p', 24,
        'r', 51,
        's', 11,
        't', 119,
        'u', 10,
        'v', 41,
        'w', 72,
        '{', 230,
        '|', 200,
        '}', 231,
        '~', 210,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(182);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        '&', 202,
        '(', 186,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 208,
        '0', 274,
        ';', 227,
        '<', 213,
        '=', 233,
        '>', 218,
        '?', 211,
        '@', 212,
        '[', 224,
        'a', 118,
        'b', 127,
        'c', 27,
        'e', 88,
        'f', 111,
        'g', 58,
        'i', 65,
        'm', 61,
        'o', 150,
        'p', 24,
        'r', 51,
        's', 60,
        't', 119,
        'w', 72,
        '{', 230,
        '|', 172,
        '~', 210,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(1);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        ',', 223,
        ';', 227,
        'a', 118,
        'e', 100,
        'f', 164,
        'g', 47,
        'm', 61,
        'p', 126,
        's', 52,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(2);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '\n', 226,
        '(', 186,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 175,
        '0', 274,
        '?', 211,
        '@', 212,
        '[', 224,
        ']', 229,
        'a', 118,
        'e', 100,
        'g', 57,
        'm', 61,
        'p', 126,
        's', 59,
        '{', 230,
        '}', 231,
        '~', 209,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '&', 202,
        '\'', 222,
        '(', 186,
        '*', 192,
        '+', 188,
        '-', 190,
        '.', 205,
        '/', 194,
        ':', 234,
        ';', 227,
        '<', 213,
        '=', 16,
        '>', 218,
        '@', 212,
        '\\', 196,
        ']', 229,
        '^', 198,
        's', 10,
        'u', 10,
        '{', 230,
        '|', 200,
        '}', 231,
        '~', 17,
        '\n', 228,
        '\r', 228,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(5);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '&', 202,
        '\'', 222,
        '(', 186,
        '*', 192,
        '+', 188,
        '-', 190,
        '.', 205,
        '/', 194,
        ':', 234,
        ';', 227,
        '<', 213,
        '=', 16,
        '>', 218,
        '@', 212,
        '\\', 196,
        ']', 229,
        '^', 198,
        '{', 230,
        '|', 200,
        '}', 231,
        '~', 17,
        '\n', 228,
        '\r', 228,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(5);
      END_STATE();
    case 6:
      if (lookahead == '&') ADVANCE(219);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '&', 6,
        '(', 186,
        ')', 187,
        ',', 223,
        '.', 203,
        '<', 213,
        '=', 16,
        '>', 218,
        '@', 212,
        'a', 118,
        'e', 100,
        'f', 164,
        'g', 47,
        'm', 61,
        'p', 126,
        's', 52,
        '{', 230,
        '|', 172,
        '}', 231,
        '~', 17,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '&', 6,
        '.', 203,
        ';', 227,
        '<', 213,
        '=', 16,
        '>', 218,
        ']', 229,
        '|', 172,
        '}', 231,
        '~', 17,
        '\n', 228,
        '\r', 228,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(8);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '(', 186,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 175,
        '0', 274,
        ';', 227,
        '?', 211,
        '@', 212,
        '[', 224,
        ']', 229,
        'a', 118,
        'e', 100,
        'g', 57,
        'm', 61,
        'p', 126,
        's', 59,
        '{', 230,
        '}', 231,
        '~', 209,
        '\n', 228,
        '\r', 228,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(9);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 10:
      if (lookahead == '1') ADVANCE(15);
      if (lookahead == '3') ADVANCE(13);
      if (lookahead == '6') ADVANCE(14);
      if (lookahead == '8') ADVANCE(272);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '1', 15,
        '3', 13,
        '6', 14,
        '8', 272,
        'c', 19,
        'e', 146,
        'p', 92,
        'w', 81,
      );
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '1', 15,
        '3', 13,
        '6', 14,
        '8', 272,
        'c', 19,
        'e', 149,
        'p', 92,
        'w', 81,
      );
      END_STATE();
    case 13:
      if (lookahead == '2') ADVANCE(272);
      END_STATE();
    case 14:
      if (lookahead == '4') ADVANCE(272);
      END_STATE();
    case 15:
      if (lookahead == '6') ADVANCE(272);
      END_STATE();
    case 16:
      if (lookahead == '=') ADVANCE(215);
      END_STATE();
    case 17:
      if (lookahead == '=') ADVANCE(216);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(140);
      if (lookahead == 'l') ADVANCE(21);
      if (lookahead == 'o') ADVANCE(102);
      END_STATE();
    case 19:
      if (lookahead == 'a') ADVANCE(90);
      END_STATE();
    case 20:
      if (lookahead == 'a') ADVANCE(85);
      END_STATE();
    case 21:
      if (lookahead == 'a') ADVANCE(138);
      END_STATE();
    case 22:
      if (lookahead == 'a') ADVANCE(156);
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 23:
      if (lookahead == 'a') ADVANCE(89);
      END_STATE();
    case 24:
      if (lookahead == 'a') ADVANCE(125);
      if (lookahead == 'e') ADVANCE(128);
      if (lookahead == 'r') ADVANCE(109);
      END_STATE();
    case 25:
      if (lookahead == 'a') ADVANCE(123);
      END_STATE();
    case 26:
      if (lookahead == 'a') ADVANCE(160);
      END_STATE();
    case 27:
      if (lookahead == 'a') ADVANCE(139);
      if (lookahead == 'l') ADVANCE(21);
      if (lookahead == 'o') ADVANCE(102);
      END_STATE();
    case 28:
      if (lookahead == 'b') ADVANCE(23);
      END_STATE();
    case 29:
      if (lookahead == 'c') ADVANCE(19);
      if (lookahead == 'e') ADVANCE(146);
      if (lookahead == 'p') ADVANCE(92);
      if (lookahead == 'w') ADVANCE(81);
      END_STATE();
    case 30:
      if (lookahead == 'c') ADVANCE(19);
      if (lookahead == 'e') ADVANCE(149);
      if (lookahead == 'p') ADVANCE(92);
      if (lookahead == 'w') ADVANCE(81);
      END_STATE();
    case 31:
      if (lookahead == 'c') ADVANCE(70);
      END_STATE();
    case 32:
      if (lookahead == 'c') ADVANCE(71);
      END_STATE();
    case 33:
      if (lookahead == 'c') ADVANCE(162);
      END_STATE();
    case 34:
      if (lookahead == 'c') ADVANCE(155);
      END_STATE();
    case 35:
      if (lookahead == 'c') ADVANCE(159);
      END_STATE();
    case 36:
      if (lookahead == 'd') ADVANCE(242);
      if (lookahead == 'u') ADVANCE(93);
      END_STATE();
    case 37:
      if (lookahead == 'd') ADVANCE(271);
      END_STATE();
    case 38:
      if (lookahead == 'd') ADVANCE(241);
      if (lookahead == 'u') ADVANCE(93);
      END_STATE();
    case 39:
      if (lookahead == 'd') ADVANCE(134);
      END_STATE();
    case 40:
      if (lookahead == 'd') ADVANCE(50);
      END_STATE();
    case 41:
      if (lookahead == 'e') ADVANCE(33);
      END_STATE();
    case 42:
      if (lookahead == 'e') ADVANCE(246);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(239);
      END_STATE();
    case 44:
      if (lookahead == 'e') ADVANCE(245);
      END_STATE();
    case 45:
      if (lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 46:
      if (lookahead == 'e') ADVANCE(247);
      END_STATE();
    case 47:
      if (lookahead == 'e') ADVANCE(145);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(145);
      if (lookahead == 'l') ADVANCE(108);
      END_STATE();
    case 49:
      if (lookahead == 'e') ADVANCE(20);
      END_STATE();
    case 50:
      if (lookahead == 'e') ADVANCE(67);
      END_STATE();
    case 51:
      if (lookahead == 'e') ADVANCE(151);
      END_STATE();
    case 52:
      if (lookahead == 'e') ADVANCE(146);
      END_STATE();
    case 53:
      if (lookahead == 'e') ADVANCE(121);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 55:
      if (lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(132);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(148);
      END_STATE();
    case 58:
      if (lookahead == 'e') ADVANCE(148);
      if (lookahead == 'l') ADVANCE(108);
      END_STATE();
    case 59:
      if (lookahead == 'e') ADVANCE(149);
      END_STATE();
    case 60:
      if (lookahead == 'e') ADVANCE(149);
      if (lookahead == 'p') ADVANCE(92);
      if (lookahead == 'w') ADVANCE(81);
      END_STATE();
    case 61:
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 63:
      if (lookahead == 'e') ADVANCE(104);
      END_STATE();
    case 64:
      if (lookahead == 'e') ADVANCE(105);
      END_STATE();
    case 65:
      if (lookahead == 'f') ADVANCE(240);
      END_STATE();
    case 66:
      if (lookahead == 'f') ADVANCE(238);
      END_STATE();
    case 67:
      if (lookahead == 'f') ADVANCE(268);
      END_STATE();
    case 68:
      if (lookahead == 'f') ADVANCE(115);
      END_STATE();
    case 69:
      if (lookahead == 'g') ADVANCE(167);
      END_STATE();
    case 70:
      if (lookahead == 'h') ADVANCE(269);
      END_STATE();
    case 71:
      if (lookahead == 'h') ADVANCE(248);
      END_STATE();
    case 72:
      if (lookahead == 'h') ADVANCE(76);
      END_STATE();
    case 73:
      if (lookahead == 'h') ADVANCE(110);
      END_STATE();
    case 74:
      if (lookahead == 'h') ADVANCE(53);
      END_STATE();
    case 75:
      if (lookahead == 'i') ADVANCE(170);
      END_STATE();
    case 76:
      if (lookahead == 'i') ADVANCE(91);
      END_STATE();
    case 77:
      if (lookahead == 'i') ADVANCE(101);
      END_STATE();
    case 78:
      if (lookahead == 'i') ADVANCE(112);
      END_STATE();
    case 79:
      if (lookahead == 'i') ADVANCE(143);
      END_STATE();
    case 80:
      if (lookahead == 'i') ADVANCE(113);
      END_STATE();
    case 81:
      if (lookahead == 'i') ADVANCE(161);
      END_STATE();
    case 82:
      if (lookahead == 'i') ADVANCE(114);
      END_STATE();
    case 83:
      if (lookahead == 'i') ADVANCE(54);
      END_STATE();
    case 84:
      if (lookahead == 'i') ADVANCE(144);
      END_STATE();
    case 85:
      if (lookahead == 'k') ADVANCE(237);
      END_STATE();
    case 86:
      if (lookahead == 'l') ADVANCE(21);
      if (lookahead == 'o') ADVANCE(102);
      END_STATE();
    case 87:
      if (lookahead == 'l') ADVANCE(142);
      if (lookahead == 'n') ADVANCE(36);
      if (lookahead == 'v') ADVANCE(62);
      END_STATE();
    case 88:
      if (lookahead == 'l') ADVANCE(142);
      if (lookahead == 'n') ADVANCE(38);
      if (lookahead == 'v') ADVANCE(62);
      END_STATE();
    case 89:
      if (lookahead == 'l') ADVANCE(249);
      END_STATE();
    case 90:
      if (lookahead == 'l') ADVANCE(25);
      END_STATE();
    case 91:
      if (lookahead == 'l') ADVANCE(44);
      END_STATE();
    case 92:
      if (lookahead == 'm') ADVANCE(37);
      END_STATE();
    case 93:
      if (lookahead == 'm') ADVANCE(55);
      END_STATE();
    case 94:
      if (lookahead == 'm') ADVANCE(63);
      END_STATE();
    case 95:
      if (lookahead == 'n') ADVANCE(36);
      if (lookahead == 'v') ADVANCE(62);
      END_STATE();
    case 96:
      if (lookahead == 'n') ADVANCE(235);
      END_STATE();
    case 97:
      if (lookahead == 'n') ADVANCE(253);
      END_STATE();
    case 98:
      if (lookahead == 'n') ADVANCE(256);
      END_STATE();
    case 99:
      if (lookahead == 'n') ADVANCE(267);
      END_STATE();
    case 100:
      if (lookahead == 'n') ADVANCE(38);
      if (lookahead == 'v') ADVANCE(62);
      END_STATE();
    case 101:
      if (lookahead == 'n') ADVANCE(166);
      END_STATE();
    case 102:
      if (lookahead == 'n') ADVANCE(153);
      END_STATE();
    case 103:
      if (lookahead == 'n') ADVANCE(154);
      END_STATE();
    case 104:
      if (lookahead == 'n') ADVANCE(157);
      END_STATE();
    case 105:
      if (lookahead == 'n') ADVANCE(147);
      END_STATE();
    case 106:
      if (lookahead == 'n') ADVANCE(34);
      END_STATE();
    case 107:
      if (lookahead == 'n') ADVANCE(35);
      END_STATE();
    case 108:
      if (lookahead == 'o') ADVANCE(28);
      END_STATE();
    case 109:
      if (lookahead == 'o') ADVANCE(117);
      END_STATE();
    case 110:
      if (lookahead == 'o') ADVANCE(39);
      END_STATE();
    case 111:
      if (lookahead == 'o') ADVANCE(120);
      if (lookahead == 'u') ADVANCE(106);
      END_STATE();
    case 112:
      if (lookahead == 'o') ADVANCE(97);
      END_STATE();
    case 113:
      if (lookahead == 'o') ADVANCE(98);
      END_STATE();
    case 114:
      if (lookahead == 'o') ADVANCE(99);
      END_STATE();
    case 115:
      if (lookahead == 'o') ADVANCE(122);
      END_STATE();
    case 116:
      if (lookahead == 'o') ADVANCE(124);
      END_STATE();
    case 117:
      if (lookahead == 'p') ADVANCE(56);
      END_STATE();
    case 118:
      if (lookahead == 'r') ADVANCE(69);
      END_STATE();
    case 119:
      if (lookahead == 'r') ADVANCE(171);
      END_STATE();
    case 120:
      if (lookahead == 'r') ADVANCE(243);
      END_STATE();
    case 121:
      if (lookahead == 'r') ADVANCE(169);
      END_STATE();
    case 122:
      if (lookahead == 'r') ADVANCE(244);
      END_STATE();
    case 123:
      if (lookahead == 'r') ADVANCE(259);
      END_STATE();
    case 124:
      if (lookahead == 'r') ADVANCE(257);
      END_STATE();
    case 125:
      if (lookahead == 'r') ADVANCE(68);
      END_STATE();
    case 126:
      if (lookahead == 'r') ADVANCE(109);
      END_STATE();
    case 127:
      if (lookahead == 'r') ADVANCE(49);
      END_STATE();
    case 128:
      if (lookahead == 'r') ADVANCE(141);
      END_STATE();
    case 129:
      if (lookahead == 'r') ADVANCE(96);
      END_STATE();
    case 130:
      if (lookahead == 'r') ADVANCE(75);
      END_STATE();
    case 131:
      if (lookahead == 'r') ADVANCE(26);
      END_STATE();
    case 132:
      if (lookahead == 'r') ADVANCE(158);
      END_STATE();
    case 133:
      if (lookahead == 's') ADVANCE(266);
      END_STATE();
    case 134:
      if (lookahead == 's') ADVANCE(265);
      END_STATE();
    case 135:
      if (lookahead == 's') ADVANCE(252);
      END_STATE();
    case 136:
      if (lookahead == 's') ADVANCE(260);
      END_STATE();
    case 137:
      if (lookahead == 's') ADVANCE(40);
      END_STATE();
    case 138:
      if (lookahead == 's') ADVANCE(137);
      END_STATE();
    case 139:
      if (lookahead == 's') ADVANCE(42);
      END_STATE();
    case 140:
      if (lookahead == 's') ADVANCE(42);
      if (lookahead == 't') ADVANCE(31);
      END_STATE();
    case 141:
      if (lookahead == 's') ADVANCE(79);
      END_STATE();
    case 142:
      if (lookahead == 's') ADVANCE(43);
      END_STATE();
    case 143:
      if (lookahead == 's') ADVANCE(163);
      END_STATE();
    case 144:
      if (lookahead == 's') ADVANCE(46);
      END_STATE();
    case 145:
      if (lookahead == 't') ADVANCE(262);
      END_STATE();
    case 146:
      if (lookahead == 't') ADVANCE(264);
      END_STATE();
    case 147:
      if (lookahead == 't') ADVANCE(250);
      END_STATE();
    case 148:
      if (lookahead == 't') ADVANCE(261);
      END_STATE();
    case 149:
      if (lookahead == 't') ADVANCE(263);
      END_STATE();
    case 150:
      if (lookahead == 't') ADVANCE(74);
      END_STATE();
    case 151:
      if (lookahead == 't') ADVANCE(165);
      END_STATE();
    case 152:
      if (lookahead == 't') ADVANCE(73);
      END_STATE();
    case 153:
      if (lookahead == 't') ADVANCE(77);
      END_STATE();
    case 154:
      if (lookahead == 't') ADVANCE(133);
      END_STATE();
    case 155:
      if (lookahead == 't') ADVANCE(78);
      END_STATE();
    case 156:
      if (lookahead == 't') ADVANCE(130);
      END_STATE();
    case 157:
      if (lookahead == 't') ADVANCE(135);
      END_STATE();
    case 158:
      if (lookahead == 't') ADVANCE(83);
      END_STATE();
    case 159:
      if (lookahead == 't') ADVANCE(80);
      END_STATE();
    case 160:
      if (lookahead == 't') ADVANCE(82);
      END_STATE();
    case 161:
      if (lookahead == 't') ADVANCE(32);
      END_STATE();
    case 162:
      if (lookahead == 't') ADVANCE(116);
      END_STATE();
    case 163:
      if (lookahead == 't') ADVANCE(64);
      END_STATE();
    case 164:
      if (lookahead == 'u') ADVANCE(106);
      END_STATE();
    case 165:
      if (lookahead == 'u') ADVANCE(129);
      END_STATE();
    case 166:
      if (lookahead == 'u') ADVANCE(45);
      END_STATE();
    case 167:
      if (lookahead == 'u') ADVANCE(94);
      END_STATE();
    case 168:
      if (lookahead == 'u') ADVANCE(107);
      END_STATE();
    case 169:
      if (lookahead == 'w') ADVANCE(84);
      END_STATE();
    case 170:
      if (lookahead == 'x') ADVANCE(258);
      END_STATE();
    case 171:
      if (lookahead == 'y') ADVANCE(270);
      END_STATE();
    case 172:
      if (lookahead == '|') ADVANCE(220);
      END_STATE();
    case 173:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(176);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(277);
      END_STATE();
    case 174:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(279);
      END_STATE();
    case 175:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(276);
      END_STATE();
    case 176:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(277);
      END_STATE();
    case 177:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(278);
      END_STATE();
    case 178:
      if (eof) ADVANCE(185);
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        '&', 202,
        '\'', 222,
        '(', 186,
        '*', 192,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 206,
        '/', 194,
        '0', 274,
        ':', 234,
        ';', 227,
        '<', 213,
        '=', 233,
        '>', 218,
        '?', 211,
        '@', 212,
        '[', 224,
        '\\', 196,
        '^', 198,
        'a', 118,
        'b', 127,
        'c', 27,
        'e', 88,
        'f', 111,
        'g', 58,
        'i', 65,
        'm', 22,
        'o', 150,
        'p', 24,
        'r', 51,
        's', 12,
        't', 119,
        'u', 10,
        'v', 41,
        'w', 72,
        '{', 230,
        '|', 200,
        '~', 210,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(179);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 179:
      if (eof) ADVANCE(185);
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        '&', 202,
        '\'', 222,
        '(', 186,
        '*', 192,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 206,
        '/', 194,
        '0', 274,
        ':', 234,
        ';', 227,
        '<', 213,
        '=', 233,
        '>', 218,
        '?', 211,
        '@', 212,
        '[', 224,
        '\\', 196,
        '^', 198,
        'a', 118,
        'b', 127,
        'c', 27,
        'e', 88,
        'f', 111,
        'g', 58,
        'i', 65,
        'm', 22,
        'o', 150,
        'p', 24,
        'r', 51,
        's', 30,
        't', 119,
        'v', 41,
        'w', 72,
        '{', 230,
        '|', 200,
        '~', 210,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(179);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 180:
      if (eof) ADVANCE(185);
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        '&', 201,
        '(', 186,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 207,
        '0', 274,
        ';', 227,
        '=', 232,
        '?', 211,
        '@', 212,
        '[', 224,
        'a', 118,
        'b', 127,
        'c', 18,
        'e', 88,
        'f', 111,
        'g', 58,
        'i', 65,
        'm', 61,
        'o', 150,
        'p', 24,
        'r', 51,
        's', 60,
        't', 119,
        'w', 72,
        '{', 230,
        '~', 209,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(180);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 181:
      if (eof) ADVANCE(185);
      ADVANCE_MAP(
        '\n', 225,
        '\r', 280,
        '(', 186,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 175,
        '0', 274,
        ';', 227,
        '?', 211,
        '@', 212,
        '[', 224,
        'a', 118,
        'b', 127,
        'c', 86,
        'e', 95,
        'f', 111,
        'g', 58,
        'i', 65,
        'm', 61,
        'p', 24,
        'r', 51,
        's', 60,
        't', 119,
        'w', 72,
        '{', 230,
        '~', 209,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(181);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 182:
      if (eof) ADVANCE(185);
      ADVANCE_MAP(
        '&', 202,
        '\'', 222,
        '(', 186,
        ')', 187,
        '*', 192,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 204,
        '/', 194,
        '0', 274,
        ':', 234,
        ';', 227,
        '<', 213,
        '=', 233,
        '>', 218,
        '?', 211,
        '@', 212,
        '[', 224,
        '\\', 196,
        ']', 229,
        '^', 198,
        'a', 118,
        'b', 127,
        'c', 18,
        'e', 87,
        'f', 111,
        'g', 48,
        'i', 65,
        'm', 22,
        'o', 150,
        'p', 24,
        'r', 51,
        's', 29,
        't', 119,
        'v', 41,
        'w', 72,
        '{', 230,
        '|', 200,
        '}', 231,
        '~', 210,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(182);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 183:
      if (eof) ADVANCE(185);
      ADVANCE_MAP(
        '(', 186,
        ')', 187,
        '*', 192,
        '+', 188,
        ',', 223,
        '-', 190,
        '.', 208,
        '0', 274,
        ':', 234,
        ';', 227,
        '=', 232,
        '?', 211,
        '@', 212,
        '[', 224,
        ']', 229,
        'a', 118,
        'b', 127,
        'c', 18,
        'e', 88,
        'f', 111,
        'g', 58,
        'i', 65,
        'm', 61,
        'o', 150,
        'p', 24,
        'r', 51,
        's', 60,
        't', 119,
        'w', 72,
        '{', 230,
        '}', 231,
        '~', 209,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(183);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 184:
      if (eof) ADVANCE(185);
      ADVANCE_MAP(
        '(', 186,
        '+', 188,
        '-', 190,
        '.', 175,
        '0', 274,
        '?', 211,
        '@', 212,
        '[', 224,
        'a', 118,
        'b', 127,
        'c', 86,
        'e', 95,
        'f', 111,
        'g', 58,
        'i', 65,
        'm', 61,
        'p', 24,
        'r', 51,
        's', 60,
        't', 119,
        'w', 72,
        '{', 230,
        '~', 209,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(184);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_DOT_PLUS);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_DOT_DASH);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_DOT_STAR);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_DOT_SLASH);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_DOT_BSLASH);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_DOT_CARET);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(220);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(219);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_DOT);
      ADVANCE_MAP(
        '\'', 221,
        '*', 193,
        '+', 189,
        '-', 191,
        '/', 195,
        '?', 251,
        '\\', 197,
        '^', 199,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(276);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(221);
      if (lookahead == '*') ADVANCE(193);
      if (lookahead == '+') ADVANCE(189);
      if (lookahead == '-') ADVANCE(191);
      if (lookahead == '/') ADVANCE(195);
      if (lookahead == '\\') ADVANCE(197);
      if (lookahead == '^') ADVANCE(199);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(221);
      if (lookahead == '*') ADVANCE(193);
      if (lookahead == '+') ADVANCE(189);
      if (lookahead == '-') ADVANCE(191);
      if (lookahead == '/') ADVANCE(195);
      if (lookahead == '\\') ADVANCE(197);
      if (lookahead == '^') ADVANCE(199);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(276);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '?') ADVANCE(251);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(276);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(276);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '=') ADVANCE(216);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(214);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_TILDE_EQ);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(217);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(anon_sym_DOT_SQUOTE);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(225);
      if (lookahead == '\r') ADVANCE(280);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(226);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(aux_sym_matrix_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(228);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(215);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(anon_sym_elseif);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == 'i') ADVANCE(66);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(anon_sym_end);
      if (lookahead == 'f') ADVANCE(168);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(anon_sym_parfor);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(anon_sym_otherwise);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_persistent);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(anon_sym_DOT_QMARK);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(anon_sym_arguments);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(anon_sym_get_DOT);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(anon_sym_set_DOT);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(anon_sym_endfunction);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(anon_sym_vector);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_matrix);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_scalar);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(anon_sym_properties);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(anon_sym_get);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_get);
      if (lookahead == '.') ADVANCE(254);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(anon_sym_set);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_set);
      if (lookahead == '.') ADVANCE(255);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_methods);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(anon_sym_events);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(anon_sym_enumeration);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(anon_sym_classdef);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(anon_sym_spmd);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(sym_number_size);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(aux_sym_number_token1);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '.') ADVANCE(276);
      if (lookahead == 'b') ADVANCE(174);
      if (lookahead == 'x') ADVANCE(177);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(173);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(273);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == '.') ADVANCE(276);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(173);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(273);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(275);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(173);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(273);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(276);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(aux_sym_number_token1);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(273);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(277);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(aux_sym_number_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(278);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(aux_sym_number_token3);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(279);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(anon_sym_CR);
      if (lookahead == '\n') ADVANCE(225);
      if (lookahead == '\r') ADVANCE(280);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 183, .external_lex_state = 2},
  [2] = {.lex_state = 178, .external_lex_state = 2},
  [3] = {.lex_state = 178, .external_lex_state = 2},
  [4] = {.lex_state = 178, .external_lex_state = 2},
  [5] = {.lex_state = 178, .external_lex_state = 2},
  [6] = {.lex_state = 180, .external_lex_state = 2},
  [7] = {.lex_state = 180, .external_lex_state = 2},
  [8] = {.lex_state = 180, .external_lex_state = 2},
  [9] = {.lex_state = 180, .external_lex_state = 2},
  [10] = {.lex_state = 180, .external_lex_state = 2},
  [11] = {.lex_state = 180, .external_lex_state = 2},
  [12] = {.lex_state = 180, .external_lex_state = 2},
  [13] = {.lex_state = 180, .external_lex_state = 2},
  [14] = {.lex_state = 180, .external_lex_state = 2},
  [15] = {.lex_state = 180, .external_lex_state = 2},
  [16] = {.lex_state = 180, .external_lex_state = 2},
  [17] = {.lex_state = 180, .external_lex_state = 2},
  [18] = {.lex_state = 180, .external_lex_state = 2},
  [19] = {.lex_state = 180, .external_lex_state = 2},
  [20] = {.lex_state = 180, .external_lex_state = 2},
  [21] = {.lex_state = 180, .external_lex_state = 2},
  [22] = {.lex_state = 180, .external_lex_state = 2},
  [23] = {.lex_state = 180, .external_lex_state = 2},
  [24] = {.lex_state = 180, .external_lex_state = 2},
  [25] = {.lex_state = 180, .external_lex_state = 2},
  [26] = {.lex_state = 180, .external_lex_state = 2},
  [27] = {.lex_state = 180, .external_lex_state = 2},
  [28] = {.lex_state = 180, .external_lex_state = 2},
  [29] = {.lex_state = 180, .external_lex_state = 2},
  [30] = {.lex_state = 180, .external_lex_state = 2},
  [31] = {.lex_state = 183, .external_lex_state = 2},
  [32] = {.lex_state = 184, .external_lex_state = 2},
  [33] = {.lex_state = 184, .external_lex_state = 2},
  [34] = {.lex_state = 184, .external_lex_state = 2},
  [35] = {.lex_state = 183, .external_lex_state = 2},
  [36] = {.lex_state = 184, .external_lex_state = 2},
  [37] = {.lex_state = 184, .external_lex_state = 2},
  [38] = {.lex_state = 184, .external_lex_state = 2},
  [39] = {.lex_state = 184, .external_lex_state = 2},
  [40] = {.lex_state = 184, .external_lex_state = 2},
  [41] = {.lex_state = 184, .external_lex_state = 2},
  [42] = {.lex_state = 184, .external_lex_state = 2},
  [43] = {.lex_state = 184, .external_lex_state = 2},
  [44] = {.lex_state = 184, .external_lex_state = 2},
  [45] = {.lex_state = 184, .external_lex_state = 2},
  [46] = {.lex_state = 184, .external_lex_state = 2},
  [47] = {.lex_state = 184, .external_lex_state = 2},
  [48] = {.lex_state = 184, .external_lex_state = 2},
  [49] = {.lex_state = 184, .external_lex_state = 2},
  [50] = {.lex_state = 184, .external_lex_state = 2},
  [51] = {.lex_state = 184, .external_lex_state = 2},
  [52] = {.lex_state = 184, .external_lex_state = 2},
  [53] = {.lex_state = 184, .external_lex_state = 2},
  [54] = {.lex_state = 184, .external_lex_state = 2},
  [55] = {.lex_state = 184, .external_lex_state = 2},
  [56] = {.lex_state = 184, .external_lex_state = 2},
  [57] = {.lex_state = 184, .external_lex_state = 2},
  [58] = {.lex_state = 184, .external_lex_state = 2},
  [59] = {.lex_state = 184, .external_lex_state = 2},
  [60] = {.lex_state = 184, .external_lex_state = 2},
  [61] = {.lex_state = 184, .external_lex_state = 2},
  [62] = {.lex_state = 184, .external_lex_state = 2},
  [63] = {.lex_state = 184, .external_lex_state = 2},
  [64] = {.lex_state = 184, .external_lex_state = 2},
  [65] = {.lex_state = 184, .external_lex_state = 2},
  [66] = {.lex_state = 184, .external_lex_state = 2},
  [67] = {.lex_state = 184, .external_lex_state = 2},
  [68] = {.lex_state = 184, .external_lex_state = 2},
  [69] = {.lex_state = 184, .external_lex_state = 2},
  [70] = {.lex_state = 184, .external_lex_state = 2},
  [71] = {.lex_state = 184, .external_lex_state = 2},
  [72] = {.lex_state = 184, .external_lex_state = 2},
  [73] = {.lex_state = 184, .external_lex_state = 2},
  [74] = {.lex_state = 184, .external_lex_state = 2},
  [75] = {.lex_state = 184, .external_lex_state = 2},
  [76] = {.lex_state = 184, .external_lex_state = 2},
  [77] = {.lex_state = 184, .external_lex_state = 2},
  [78] = {.lex_state = 184, .external_lex_state = 2},
  [79] = {.lex_state = 184, .external_lex_state = 2},
  [80] = {.lex_state = 184, .external_lex_state = 2},
  [81] = {.lex_state = 184, .external_lex_state = 2},
  [82] = {.lex_state = 184, .external_lex_state = 2},
  [83] = {.lex_state = 184, .external_lex_state = 2},
  [84] = {.lex_state = 184, .external_lex_state = 2},
  [85] = {.lex_state = 184, .external_lex_state = 2},
  [86] = {.lex_state = 184, .external_lex_state = 2},
  [87] = {.lex_state = 184, .external_lex_state = 2},
  [88] = {.lex_state = 184, .external_lex_state = 2},
  [89] = {.lex_state = 184, .external_lex_state = 2},
  [90] = {.lex_state = 184, .external_lex_state = 2},
  [91] = {.lex_state = 184, .external_lex_state = 2},
  [92] = {.lex_state = 184, .external_lex_state = 2},
  [93] = {.lex_state = 184, .external_lex_state = 2},
  [94] = {.lex_state = 184, .external_lex_state = 2},
  [95] = {.lex_state = 184, .external_lex_state = 2},
  [96] = {.lex_state = 184, .external_lex_state = 2},
  [97] = {.lex_state = 184, .external_lex_state = 2},
  [98] = {.lex_state = 184, .external_lex_state = 2},
  [99] = {.lex_state = 184, .external_lex_state = 2},
  [100] = {.lex_state = 184, .external_lex_state = 2},
  [101] = {.lex_state = 184, .external_lex_state = 2},
  [102] = {.lex_state = 184, .external_lex_state = 2},
  [103] = {.lex_state = 184, .external_lex_state = 2},
  [104] = {.lex_state = 184, .external_lex_state = 2},
  [105] = {.lex_state = 183, .external_lex_state = 2},
  [106] = {.lex_state = 184, .external_lex_state = 2},
  [107] = {.lex_state = 184, .external_lex_state = 2},
  [108] = {.lex_state = 184, .external_lex_state = 2},
  [109] = {.lex_state = 178, .external_lex_state = 2},
  [110] = {.lex_state = 178, .external_lex_state = 2},
  [111] = {.lex_state = 178, .external_lex_state = 2},
  [112] = {.lex_state = 178, .external_lex_state = 2},
  [113] = {.lex_state = 178, .external_lex_state = 2},
  [114] = {.lex_state = 178, .external_lex_state = 2},
  [115] = {.lex_state = 178, .external_lex_state = 2},
  [116] = {.lex_state = 178, .external_lex_state = 2},
  [117] = {.lex_state = 178, .external_lex_state = 2},
  [118] = {.lex_state = 178, .external_lex_state = 2},
  [119] = {.lex_state = 178, .external_lex_state = 2},
  [120] = {.lex_state = 178, .external_lex_state = 2},
  [121] = {.lex_state = 178, .external_lex_state = 2},
  [122] = {.lex_state = 178, .external_lex_state = 2},
  [123] = {.lex_state = 178, .external_lex_state = 2},
  [124] = {.lex_state = 178, .external_lex_state = 2},
  [125] = {.lex_state = 178, .external_lex_state = 2},
  [126] = {.lex_state = 178, .external_lex_state = 2},
  [127] = {.lex_state = 178, .external_lex_state = 2},
  [128] = {.lex_state = 178, .external_lex_state = 2},
  [129] = {.lex_state = 178, .external_lex_state = 2},
  [130] = {.lex_state = 178, .external_lex_state = 2},
  [131] = {.lex_state = 178, .external_lex_state = 2},
  [132] = {.lex_state = 178, .external_lex_state = 2},
  [133] = {.lex_state = 178, .external_lex_state = 2},
  [134] = {.lex_state = 178, .external_lex_state = 2},
  [135] = {.lex_state = 178, .external_lex_state = 2},
  [136] = {.lex_state = 178, .external_lex_state = 2},
  [137] = {.lex_state = 178, .external_lex_state = 2},
  [138] = {.lex_state = 178, .external_lex_state = 2},
  [139] = {.lex_state = 178, .external_lex_state = 2},
  [140] = {.lex_state = 178, .external_lex_state = 2},
  [141] = {.lex_state = 178, .external_lex_state = 2},
  [142] = {.lex_state = 178, .external_lex_state = 2},
  [143] = {.lex_state = 178, .external_lex_state = 2},
  [144] = {.lex_state = 178, .external_lex_state = 2},
  [145] = {.lex_state = 178, .external_lex_state = 2},
  [146] = {.lex_state = 178, .external_lex_state = 2},
  [147] = {.lex_state = 178, .external_lex_state = 2},
  [148] = {.lex_state = 178, .external_lex_state = 2},
  [149] = {.lex_state = 178, .external_lex_state = 2},
  [150] = {.lex_state = 178, .external_lex_state = 2},
  [151] = {.lex_state = 178, .external_lex_state = 2},
  [152] = {.lex_state = 178, .external_lex_state = 2},
  [153] = {.lex_state = 178, .external_lex_state = 2},
  [154] = {.lex_state = 178, .external_lex_state = 2},
  [155] = {.lex_state = 178, .external_lex_state = 2},
  [156] = {.lex_state = 178, .external_lex_state = 2},
  [157] = {.lex_state = 178, .external_lex_state = 2},
  [158] = {.lex_state = 178, .external_lex_state = 2},
  [159] = {.lex_state = 178, .external_lex_state = 2},
  [160] = {.lex_state = 178, .external_lex_state = 2},
  [161] = {.lex_state = 178, .external_lex_state = 2},
  [162] = {.lex_state = 178, .external_lex_state = 2},
  [163] = {.lex_state = 178, .external_lex_state = 2},
  [164] = {.lex_state = 178, .external_lex_state = 2},
  [165] = {.lex_state = 178, .external_lex_state = 2},
  [166] = {.lex_state = 178, .external_lex_state = 2},
  [167] = {.lex_state = 178, .external_lex_state = 2},
  [168] = {.lex_state = 178, .external_lex_state = 2},
  [169] = {.lex_state = 178, .external_lex_state = 2},
  [170] = {.lex_state = 178, .external_lex_state = 2},
  [171] = {.lex_state = 178, .external_lex_state = 2},
  [172] = {.lex_state = 178, .external_lex_state = 2},
  [173] = {.lex_state = 178, .external_lex_state = 2},
  [174] = {.lex_state = 178, .external_lex_state = 2},
  [175] = {.lex_state = 178, .external_lex_state = 2},
  [176] = {.lex_state = 178, .external_lex_state = 2},
  [177] = {.lex_state = 178, .external_lex_state = 2},
  [178] = {.lex_state = 178, .external_lex_state = 2},
  [179] = {.lex_state = 178, .external_lex_state = 2},
  [180] = {.lex_state = 178, .external_lex_state = 2},
  [181] = {.lex_state = 178, .external_lex_state = 2},
  [182] = {.lex_state = 178, .external_lex_state = 2},
  [183] = {.lex_state = 178, .external_lex_state = 2},
  [184] = {.lex_state = 178, .external_lex_state = 2},
  [185] = {.lex_state = 178, .external_lex_state = 2},
  [186] = {.lex_state = 178, .external_lex_state = 2},
  [187] = {.lex_state = 178, .external_lex_state = 2},
  [188] = {.lex_state = 3, .external_lex_state = 3},
  [189] = {.lex_state = 3, .external_lex_state = 3},
  [190] = {.lex_state = 3, .external_lex_state = 3},
  [191] = {.lex_state = 3, .external_lex_state = 3},
  [192] = {.lex_state = 178, .external_lex_state = 2},
  [193] = {.lex_state = 3, .external_lex_state = 3},
  [194] = {.lex_state = 3, .external_lex_state = 3},
  [195] = {.lex_state = 183, .external_lex_state = 3},
  [196] = {.lex_state = 183, .external_lex_state = 3},
  [197] = {.lex_state = 178, .external_lex_state = 2},
  [198] = {.lex_state = 183, .external_lex_state = 3},
  [199] = {.lex_state = 178, .external_lex_state = 2},
  [200] = {.lex_state = 178, .external_lex_state = 2},
  [201] = {.lex_state = 183, .external_lex_state = 3},
  [202] = {.lex_state = 183, .external_lex_state = 3},
  [203] = {.lex_state = 183, .external_lex_state = 3},
  [204] = {.lex_state = 183, .external_lex_state = 3},
  [205] = {.lex_state = 178, .external_lex_state = 2},
  [206] = {.lex_state = 183, .external_lex_state = 3},
  [207] = {.lex_state = 183, .external_lex_state = 3},
  [208] = {.lex_state = 183, .external_lex_state = 3},
  [209] = {.lex_state = 183, .external_lex_state = 3},
  [210] = {.lex_state = 9, .external_lex_state = 4},
  [211] = {.lex_state = 9, .external_lex_state = 3},
  [212] = {.lex_state = 9, .external_lex_state = 3},
  [213] = {.lex_state = 183, .external_lex_state = 3},
  [214] = {.lex_state = 183, .external_lex_state = 3},
  [215] = {.lex_state = 183, .external_lex_state = 3},
  [216] = {.lex_state = 183, .external_lex_state = 3},
  [217] = {.lex_state = 183, .external_lex_state = 3},
  [218] = {.lex_state = 183, .external_lex_state = 3},
  [219] = {.lex_state = 183, .external_lex_state = 3},
  [220] = {.lex_state = 183, .external_lex_state = 3},
  [221] = {.lex_state = 183, .external_lex_state = 3},
  [222] = {.lex_state = 183, .external_lex_state = 3},
  [223] = {.lex_state = 183, .external_lex_state = 3},
  [224] = {.lex_state = 183, .external_lex_state = 3},
  [225] = {.lex_state = 1, .external_lex_state = 2},
  [226] = {.lex_state = 1, .external_lex_state = 2},
  [227] = {.lex_state = 1, .external_lex_state = 2},
  [228] = {.lex_state = 1, .external_lex_state = 2},
  [229] = {.lex_state = 1, .external_lex_state = 2},
  [230] = {.lex_state = 1, .external_lex_state = 2},
  [231] = {.lex_state = 1, .external_lex_state = 2},
  [232] = {.lex_state = 9, .external_lex_state = 3},
  [233] = {.lex_state = 3, .external_lex_state = 3},
  [234] = {.lex_state = 3, .external_lex_state = 3},
  [235] = {.lex_state = 3, .external_lex_state = 3},
  [236] = {.lex_state = 3, .external_lex_state = 3},
  [237] = {.lex_state = 3, .external_lex_state = 3},
  [238] = {.lex_state = 3, .external_lex_state = 3},
  [239] = {.lex_state = 3, .external_lex_state = 3},
  [240] = {.lex_state = 3, .external_lex_state = 3},
  [241] = {.lex_state = 3, .external_lex_state = 3},
  [242] = {.lex_state = 3, .external_lex_state = 3},
  [243] = {.lex_state = 3, .external_lex_state = 3},
  [244] = {.lex_state = 3, .external_lex_state = 3},
  [245] = {.lex_state = 3, .external_lex_state = 3},
  [246] = {.lex_state = 3, .external_lex_state = 3},
  [247] = {.lex_state = 3, .external_lex_state = 3},
  [248] = {.lex_state = 3, .external_lex_state = 3},
  [249] = {.lex_state = 9, .external_lex_state = 4},
  [250] = {.lex_state = 9, .external_lex_state = 3},
  [251] = {.lex_state = 9, .external_lex_state = 3},
  [252] = {.lex_state = 9, .external_lex_state = 3},
  [253] = {.lex_state = 180, .external_lex_state = 2},
  [254] = {.lex_state = 180, .external_lex_state = 2},
  [255] = {.lex_state = 178, .external_lex_state = 2},
  [256] = {.lex_state = 180, .external_lex_state = 2},
  [257] = {.lex_state = 3, .external_lex_state = 3},
  [258] = {.lex_state = 9, .external_lex_state = 3},
  [259] = {.lex_state = 3, .external_lex_state = 3},
  [260] = {.lex_state = 183, .external_lex_state = 3},
  [261] = {.lex_state = 183, .external_lex_state = 3},
  [262] = {.lex_state = 3, .external_lex_state = 3},
  [263] = {.lex_state = 3, .external_lex_state = 3},
  [264] = {.lex_state = 183, .external_lex_state = 3},
  [265] = {.lex_state = 183, .external_lex_state = 3},
  [266] = {.lex_state = 183, .external_lex_state = 3},
  [267] = {.lex_state = 183, .external_lex_state = 3},
  [268] = {.lex_state = 183, .external_lex_state = 3},
  [269] = {.lex_state = 183, .external_lex_state = 3},
  [270] = {.lex_state = 183, .external_lex_state = 3},
  [271] = {.lex_state = 183, .external_lex_state = 3},
  [272] = {.lex_state = 183, .external_lex_state = 3},
  [273] = {.lex_state = 183, .external_lex_state = 3},
  [274] = {.lex_state = 183, .external_lex_state = 3},
  [275] = {.lex_state = 183, .external_lex_state = 3},
  [276] = {.lex_state = 183, .external_lex_state = 3},
  [277] = {.lex_state = 183, .external_lex_state = 3},
  [278] = {.lex_state = 183, .external_lex_state = 3},
  [279] = {.lex_state = 183, .external_lex_state = 3},
  [280] = {.lex_state = 181, .external_lex_state = 2},
  [281] = {.lex_state = 183, .external_lex_state = 3},
  [282] = {.lex_state = 183, .external_lex_state = 3},
  [283] = {.lex_state = 183, .external_lex_state = 3},
  [284] = {.lex_state = 183, .external_lex_state = 3},
  [285] = {.lex_state = 183, .external_lex_state = 3},
  [286] = {.lex_state = 183, .external_lex_state = 3},
  [287] = {.lex_state = 183, .external_lex_state = 3},
  [288] = {.lex_state = 183, .external_lex_state = 3},
  [289] = {.lex_state = 183, .external_lex_state = 3},
  [290] = {.lex_state = 181, .external_lex_state = 2},
  [291] = {.lex_state = 183, .external_lex_state = 3},
  [292] = {.lex_state = 183, .external_lex_state = 3},
  [293] = {.lex_state = 183, .external_lex_state = 3},
  [294] = {.lex_state = 183, .external_lex_state = 3},
  [295] = {.lex_state = 183, .external_lex_state = 3},
  [296] = {.lex_state = 183, .external_lex_state = 3},
  [297] = {.lex_state = 183, .external_lex_state = 3},
  [298] = {.lex_state = 183, .external_lex_state = 3},
  [299] = {.lex_state = 183, .external_lex_state = 3},
  [300] = {.lex_state = 183, .external_lex_state = 3},
  [301] = {.lex_state = 183, .external_lex_state = 3},
  [302] = {.lex_state = 183, .external_lex_state = 3},
  [303] = {.lex_state = 183, .external_lex_state = 3},
  [304] = {.lex_state = 183, .external_lex_state = 3},
  [305] = {.lex_state = 183, .external_lex_state = 3},
  [306] = {.lex_state = 183, .external_lex_state = 3},
  [307] = {.lex_state = 183, .external_lex_state = 3},
  [308] = {.lex_state = 183, .external_lex_state = 3},
  [309] = {.lex_state = 183, .external_lex_state = 3},
  [310] = {.lex_state = 183, .external_lex_state = 3},
  [311] = {.lex_state = 183, .external_lex_state = 3},
  [312] = {.lex_state = 183, .external_lex_state = 3},
  [313] = {.lex_state = 183, .external_lex_state = 3},
  [314] = {.lex_state = 183, .external_lex_state = 3},
  [315] = {.lex_state = 183, .external_lex_state = 3},
  [316] = {.lex_state = 183, .external_lex_state = 3},
  [317] = {.lex_state = 183, .external_lex_state = 3},
  [318] = {.lex_state = 183, .external_lex_state = 3},
  [319] = {.lex_state = 183, .external_lex_state = 3},
  [320] = {.lex_state = 181, .external_lex_state = 2},
  [321] = {.lex_state = 183, .external_lex_state = 3},
  [322] = {.lex_state = 183, .external_lex_state = 3},
  [323] = {.lex_state = 183, .external_lex_state = 3},
  [324] = {.lex_state = 183, .external_lex_state = 3},
  [325] = {.lex_state = 183, .external_lex_state = 3},
  [326] = {.lex_state = 183, .external_lex_state = 3},
  [327] = {.lex_state = 183, .external_lex_state = 3},
  [328] = {.lex_state = 183, .external_lex_state = 3},
  [329] = {.lex_state = 183, .external_lex_state = 3},
  [330] = {.lex_state = 183, .external_lex_state = 3},
  [331] = {.lex_state = 183, .external_lex_state = 3},
  [332] = {.lex_state = 183, .external_lex_state = 3},
  [333] = {.lex_state = 183, .external_lex_state = 3},
  [334] = {.lex_state = 183, .external_lex_state = 3},
  [335] = {.lex_state = 183, .external_lex_state = 3},
  [336] = {.lex_state = 183, .external_lex_state = 3},
  [337] = {.lex_state = 183, .external_lex_state = 3},
  [338] = {.lex_state = 183, .external_lex_state = 3},
  [339] = {.lex_state = 183, .external_lex_state = 3},
  [340] = {.lex_state = 183, .external_lex_state = 3},
  [341] = {.lex_state = 183, .external_lex_state = 3},
  [342] = {.lex_state = 183, .external_lex_state = 3},
  [343] = {.lex_state = 183, .external_lex_state = 3},
  [344] = {.lex_state = 183, .external_lex_state = 3},
  [345] = {.lex_state = 183, .external_lex_state = 3},
  [346] = {.lex_state = 183, .external_lex_state = 3},
  [347] = {.lex_state = 183, .external_lex_state = 3},
  [348] = {.lex_state = 183, .external_lex_state = 3},
  [349] = {.lex_state = 183, .external_lex_state = 3},
  [350] = {.lex_state = 183, .external_lex_state = 3},
  [351] = {.lex_state = 183, .external_lex_state = 3},
  [352] = {.lex_state = 183, .external_lex_state = 3},
  [353] = {.lex_state = 183, .external_lex_state = 3},
  [354] = {.lex_state = 183, .external_lex_state = 3},
  [355] = {.lex_state = 183, .external_lex_state = 3},
  [356] = {.lex_state = 183, .external_lex_state = 3},
  [357] = {.lex_state = 183, .external_lex_state = 3},
  [358] = {.lex_state = 183, .external_lex_state = 3},
  [359] = {.lex_state = 183, .external_lex_state = 3},
  [360] = {.lex_state = 183, .external_lex_state = 3},
  [361] = {.lex_state = 183, .external_lex_state = 3},
  [362] = {.lex_state = 183, .external_lex_state = 3},
  [363] = {.lex_state = 183, .external_lex_state = 3},
  [364] = {.lex_state = 183, .external_lex_state = 3},
  [365] = {.lex_state = 183, .external_lex_state = 3},
  [366] = {.lex_state = 183, .external_lex_state = 3},
  [367] = {.lex_state = 183, .external_lex_state = 3},
  [368] = {.lex_state = 183, .external_lex_state = 3},
  [369] = {.lex_state = 183, .external_lex_state = 3},
  [370] = {.lex_state = 183, .external_lex_state = 3},
  [371] = {.lex_state = 183, .external_lex_state = 3},
  [372] = {.lex_state = 183, .external_lex_state = 3},
  [373] = {.lex_state = 183, .external_lex_state = 3},
  [374] = {.lex_state = 183, .external_lex_state = 3},
  [375] = {.lex_state = 183, .external_lex_state = 3},
  [376] = {.lex_state = 183, .external_lex_state = 3},
  [377] = {.lex_state = 183, .external_lex_state = 3},
  [378] = {.lex_state = 9, .external_lex_state = 3},
  [379] = {.lex_state = 9, .external_lex_state = 3},
  [380] = {.lex_state = 9, .external_lex_state = 4},
  [381] = {.lex_state = 9, .external_lex_state = 3},
  [382] = {.lex_state = 183, .external_lex_state = 3},
  [383] = {.lex_state = 183, .external_lex_state = 3},
  [384] = {.lex_state = 184, .external_lex_state = 2},
  [385] = {.lex_state = 183, .external_lex_state = 3},
  [386] = {.lex_state = 183, .external_lex_state = 3},
  [387] = {.lex_state = 183, .external_lex_state = 3},
  [388] = {.lex_state = 183, .external_lex_state = 3},
  [389] = {.lex_state = 183, .external_lex_state = 3},
  [390] = {.lex_state = 183, .external_lex_state = 3},
  [391] = {.lex_state = 183, .external_lex_state = 3},
  [392] = {.lex_state = 183, .external_lex_state = 3},
  [393] = {.lex_state = 183, .external_lex_state = 3},
  [394] = {.lex_state = 183, .external_lex_state = 3},
  [395] = {.lex_state = 183, .external_lex_state = 3},
  [396] = {.lex_state = 183, .external_lex_state = 3},
  [397] = {.lex_state = 183, .external_lex_state = 3},
  [398] = {.lex_state = 183, .external_lex_state = 3},
  [399] = {.lex_state = 183, .external_lex_state = 3},
  [400] = {.lex_state = 183, .external_lex_state = 3},
  [401] = {.lex_state = 183, .external_lex_state = 3},
  [402] = {.lex_state = 183, .external_lex_state = 3},
  [403] = {.lex_state = 183, .external_lex_state = 3},
  [404] = {.lex_state = 183, .external_lex_state = 3},
  [405] = {.lex_state = 183, .external_lex_state = 3},
  [406] = {.lex_state = 183, .external_lex_state = 3},
  [407] = {.lex_state = 183, .external_lex_state = 3},
  [408] = {.lex_state = 183, .external_lex_state = 3},
  [409] = {.lex_state = 184, .external_lex_state = 2},
  [410] = {.lex_state = 184, .external_lex_state = 2},
  [411] = {.lex_state = 184, .external_lex_state = 2},
  [412] = {.lex_state = 178, .external_lex_state = 5},
  [413] = {.lex_state = 184, .external_lex_state = 2},
  [414] = {.lex_state = 178, .external_lex_state = 5},
  [415] = {.lex_state = 178, .external_lex_state = 5},
  [416] = {.lex_state = 178, .external_lex_state = 5},
  [417] = {.lex_state = 178, .external_lex_state = 5},
  [418] = {.lex_state = 178, .external_lex_state = 5},
  [419] = {.lex_state = 178, .external_lex_state = 5},
  [420] = {.lex_state = 178, .external_lex_state = 5},
  [421] = {.lex_state = 178, .external_lex_state = 5},
  [422] = {.lex_state = 178, .external_lex_state = 5},
  [423] = {.lex_state = 178, .external_lex_state = 5},
  [424] = {.lex_state = 178, .external_lex_state = 5},
  [425] = {.lex_state = 178, .external_lex_state = 5},
  [426] = {.lex_state = 178, .external_lex_state = 5},
  [427] = {.lex_state = 178, .external_lex_state = 5},
  [428] = {.lex_state = 178, .external_lex_state = 5},
  [429] = {.lex_state = 178, .external_lex_state = 5},
  [430] = {.lex_state = 178, .external_lex_state = 5},
  [431] = {.lex_state = 178, .external_lex_state = 5},
  [432] = {.lex_state = 178, .external_lex_state = 5},
  [433] = {.lex_state = 178, .external_lex_state = 5},
  [434] = {.lex_state = 178, .external_lex_state = 5},
  [435] = {.lex_state = 178, .external_lex_state = 5},
  [436] = {.lex_state = 4, .external_lex_state = 6},
  [437] = {.lex_state = 4, .external_lex_state = 6},
  [438] = {.lex_state = 4, .external_lex_state = 6},
  [439] = {.lex_state = 178, .external_lex_state = 5},
  [440] = {.lex_state = 4, .external_lex_state = 6},
  [441] = {.lex_state = 4, .external_lex_state = 6},
  [442] = {.lex_state = 183, .external_lex_state = 7},
  [443] = {.lex_state = 178, .external_lex_state = 5},
  [444] = {.lex_state = 4, .external_lex_state = 6},
  [445] = {.lex_state = 183, .external_lex_state = 7},
  [446] = {.lex_state = 4, .external_lex_state = 6},
  [447] = {.lex_state = 4, .external_lex_state = 6},
  [448] = {.lex_state = 178, .external_lex_state = 5},
  [449] = {.lex_state = 4, .external_lex_state = 6},
  [450] = {.lex_state = 4, .external_lex_state = 6},
  [451] = {.lex_state = 4, .external_lex_state = 6},
  [452] = {.lex_state = 4, .external_lex_state = 6},
  [453] = {.lex_state = 0, .external_lex_state = 5},
  [454] = {.lex_state = 4, .external_lex_state = 6},
  [455] = {.lex_state = 4, .external_lex_state = 6},
  [456] = {.lex_state = 183, .external_lex_state = 7},
  [457] = {.lex_state = 183, .external_lex_state = 7},
  [458] = {.lex_state = 183, .external_lex_state = 7},
  [459] = {.lex_state = 4, .external_lex_state = 6},
  [460] = {.lex_state = 4, .external_lex_state = 6},
  [461] = {.lex_state = 0, .external_lex_state = 5},
  [462] = {.lex_state = 178, .external_lex_state = 5},
  [463] = {.lex_state = 0, .external_lex_state = 5},
  [464] = {.lex_state = 178, .external_lex_state = 5},
  [465] = {.lex_state = 178, .external_lex_state = 5},
  [466] = {.lex_state = 178, .external_lex_state = 5},
  [467] = {.lex_state = 0, .external_lex_state = 5},
  [468] = {.lex_state = 0, .external_lex_state = 5},
  [469] = {.lex_state = 4, .external_lex_state = 6},
  [470] = {.lex_state = 178, .external_lex_state = 5},
  [471] = {.lex_state = 4, .external_lex_state = 6},
  [472] = {.lex_state = 4, .external_lex_state = 6},
  [473] = {.lex_state = 4, .external_lex_state = 6},
  [474] = {.lex_state = 4, .external_lex_state = 6},
  [475] = {.lex_state = 4, .external_lex_state = 6},
  [476] = {.lex_state = 178, .external_lex_state = 5},
  [477] = {.lex_state = 4, .external_lex_state = 6},
  [478] = {.lex_state = 4, .external_lex_state = 6},
  [479] = {.lex_state = 4, .external_lex_state = 6},
  [480] = {.lex_state = 4, .external_lex_state = 6},
  [481] = {.lex_state = 0, .external_lex_state = 5},
  [482] = {.lex_state = 4, .external_lex_state = 6},
  [483] = {.lex_state = 0, .external_lex_state = 5},
  [484] = {.lex_state = 0, .external_lex_state = 5},
  [485] = {.lex_state = 0, .external_lex_state = 5},
  [486] = {.lex_state = 0, .external_lex_state = 5},
  [487] = {.lex_state = 0, .external_lex_state = 5},
  [488] = {.lex_state = 0, .external_lex_state = 5},
  [489] = {.lex_state = 0, .external_lex_state = 5},
  [490] = {.lex_state = 0, .external_lex_state = 5},
  [491] = {.lex_state = 4, .external_lex_state = 6},
  [492] = {.lex_state = 0, .external_lex_state = 5},
  [493] = {.lex_state = 0, .external_lex_state = 5},
  [494] = {.lex_state = 4, .external_lex_state = 6},
  [495] = {.lex_state = 0, .external_lex_state = 5},
  [496] = {.lex_state = 0, .external_lex_state = 5},
  [497] = {.lex_state = 0, .external_lex_state = 5},
  [498] = {.lex_state = 0, .external_lex_state = 5},
  [499] = {.lex_state = 0, .external_lex_state = 5},
  [500] = {.lex_state = 178, .external_lex_state = 5},
  [501] = {.lex_state = 4, .external_lex_state = 6},
  [502] = {.lex_state = 4, .external_lex_state = 6},
  [503] = {.lex_state = 0, .external_lex_state = 5},
  [504] = {.lex_state = 0, .external_lex_state = 5},
  [505] = {.lex_state = 178, .external_lex_state = 5},
  [506] = {.lex_state = 178, .external_lex_state = 5},
  [507] = {.lex_state = 4, .external_lex_state = 6},
  [508] = {.lex_state = 0, .external_lex_state = 5},
  [509] = {.lex_state = 0, .external_lex_state = 5},
  [510] = {.lex_state = 178, .external_lex_state = 5},
  [511] = {.lex_state = 178, .external_lex_state = 5},
  [512] = {.lex_state = 178, .external_lex_state = 5},
  [513] = {.lex_state = 178, .external_lex_state = 5},
  [514] = {.lex_state = 178, .external_lex_state = 5},
  [515] = {.lex_state = 178, .external_lex_state = 5},
  [516] = {.lex_state = 178, .external_lex_state = 5},
  [517] = {.lex_state = 178, .external_lex_state = 5},
  [518] = {.lex_state = 0, .external_lex_state = 5},
  [519] = {.lex_state = 0, .external_lex_state = 5},
  [520] = {.lex_state = 178, .external_lex_state = 5},
  [521] = {.lex_state = 0, .external_lex_state = 5},
  [522] = {.lex_state = 0, .external_lex_state = 5},
  [523] = {.lex_state = 178, .external_lex_state = 5},
  [524] = {.lex_state = 178, .external_lex_state = 5},
  [525] = {.lex_state = 178, .external_lex_state = 5},
  [526] = {.lex_state = 178, .external_lex_state = 5},
  [527] = {.lex_state = 178, .external_lex_state = 5},
  [528] = {.lex_state = 0, .external_lex_state = 5},
  [529] = {.lex_state = 178, .external_lex_state = 5},
  [530] = {.lex_state = 178, .external_lex_state = 5},
  [531] = {.lex_state = 0, .external_lex_state = 5},
  [532] = {.lex_state = 178, .external_lex_state = 5},
  [533] = {.lex_state = 4, .external_lex_state = 6},
  [534] = {.lex_state = 4, .external_lex_state = 6},
  [535] = {.lex_state = 4, .external_lex_state = 6},
  [536] = {.lex_state = 4, .external_lex_state = 6},
  [537] = {.lex_state = 0, .external_lex_state = 5},
  [538] = {.lex_state = 178, .external_lex_state = 5},
  [539] = {.lex_state = 178, .external_lex_state = 5},
  [540] = {.lex_state = 178, .external_lex_state = 5},
  [541] = {.lex_state = 178, .external_lex_state = 5},
  [542] = {.lex_state = 0, .external_lex_state = 5},
  [543] = {.lex_state = 178, .external_lex_state = 5},
  [544] = {.lex_state = 178, .external_lex_state = 5},
  [545] = {.lex_state = 178, .external_lex_state = 5},
  [546] = {.lex_state = 4, .external_lex_state = 6},
  [547] = {.lex_state = 178, .external_lex_state = 5},
  [548] = {.lex_state = 178, .external_lex_state = 5},
  [549] = {.lex_state = 178, .external_lex_state = 5},
  [550] = {.lex_state = 0, .external_lex_state = 5},
  [551] = {.lex_state = 178, .external_lex_state = 5},
  [552] = {.lex_state = 0, .external_lex_state = 5},
  [553] = {.lex_state = 178, .external_lex_state = 5},
  [554] = {.lex_state = 178, .external_lex_state = 5},
  [555] = {.lex_state = 0, .external_lex_state = 5},
  [556] = {.lex_state = 0, .external_lex_state = 5},
  [557] = {.lex_state = 178, .external_lex_state = 5},
  [558] = {.lex_state = 0, .external_lex_state = 5},
  [559] = {.lex_state = 0, .external_lex_state = 5},
  [560] = {.lex_state = 178, .external_lex_state = 5},
  [561] = {.lex_state = 178, .external_lex_state = 5},
  [562] = {.lex_state = 0, .external_lex_state = 5},
  [563] = {.lex_state = 178, .external_lex_state = 5},
  [564] = {.lex_state = 178, .external_lex_state = 5},
  [565] = {.lex_state = 0, .external_lex_state = 5},
  [566] = {.lex_state = 178, .external_lex_state = 5},
  [567] = {.lex_state = 178, .external_lex_state = 5},
  [568] = {.lex_state = 178, .external_lex_state = 5},
  [569] = {.lex_state = 0, .external_lex_state = 5},
  [570] = {.lex_state = 178, .external_lex_state = 5},
  [571] = {.lex_state = 178, .external_lex_state = 5},
  [572] = {.lex_state = 0, .external_lex_state = 5},
  [573] = {.lex_state = 178, .external_lex_state = 5},
  [574] = {.lex_state = 178, .external_lex_state = 5},
  [575] = {.lex_state = 0, .external_lex_state = 5},
  [576] = {.lex_state = 4, .external_lex_state = 6},
  [577] = {.lex_state = 178, .external_lex_state = 5},
  [578] = {.lex_state = 178, .external_lex_state = 5},
  [579] = {.lex_state = 178, .external_lex_state = 5},
  [580] = {.lex_state = 178, .external_lex_state = 5},
  [581] = {.lex_state = 0, .external_lex_state = 5},
  [582] = {.lex_state = 4, .external_lex_state = 6},
  [583] = {.lex_state = 4, .external_lex_state = 6},
  [584] = {.lex_state = 4, .external_lex_state = 6},
  [585] = {.lex_state = 4, .external_lex_state = 6},
  [586] = {.lex_state = 4, .external_lex_state = 6},
  [587] = {.lex_state = 4, .external_lex_state = 6},
  [588] = {.lex_state = 4, .external_lex_state = 6},
  [589] = {.lex_state = 0, .external_lex_state = 5},
  [590] = {.lex_state = 4, .external_lex_state = 6},
  [591] = {.lex_state = 4, .external_lex_state = 6},
  [592] = {.lex_state = 4, .external_lex_state = 6},
  [593] = {.lex_state = 4, .external_lex_state = 6},
  [594] = {.lex_state = 4, .external_lex_state = 6},
  [595] = {.lex_state = 4, .external_lex_state = 6},
  [596] = {.lex_state = 178, .external_lex_state = 5},
  [597] = {.lex_state = 4, .external_lex_state = 6},
  [598] = {.lex_state = 0, .external_lex_state = 5},
  [599] = {.lex_state = 4, .external_lex_state = 6},
  [600] = {.lex_state = 4, .external_lex_state = 6},
  [601] = {.lex_state = 4, .external_lex_state = 6},
  [602] = {.lex_state = 0, .external_lex_state = 5},
  [603] = {.lex_state = 0, .external_lex_state = 5},
  [604] = {.lex_state = 0, .external_lex_state = 5},
  [605] = {.lex_state = 0, .external_lex_state = 5},
  [606] = {.lex_state = 0, .external_lex_state = 5},
  [607] = {.lex_state = 4, .external_lex_state = 6},
  [608] = {.lex_state = 4, .external_lex_state = 6},
  [609] = {.lex_state = 4, .external_lex_state = 6},
  [610] = {.lex_state = 4, .external_lex_state = 6},
  [611] = {.lex_state = 4, .external_lex_state = 6},
  [612] = {.lex_state = 4, .external_lex_state = 6},
  [613] = {.lex_state = 4, .external_lex_state = 6},
  [614] = {.lex_state = 4, .external_lex_state = 6},
  [615] = {.lex_state = 4, .external_lex_state = 6},
  [616] = {.lex_state = 4, .external_lex_state = 6},
  [617] = {.lex_state = 178, .external_lex_state = 5},
  [618] = {.lex_state = 4, .external_lex_state = 6},
  [619] = {.lex_state = 4, .external_lex_state = 6},
  [620] = {.lex_state = 4, .external_lex_state = 6},
  [621] = {.lex_state = 4, .external_lex_state = 6},
  [622] = {.lex_state = 4, .external_lex_state = 6},
  [623] = {.lex_state = 4, .external_lex_state = 6},
  [624] = {.lex_state = 4, .external_lex_state = 6},
  [625] = {.lex_state = 4, .external_lex_state = 6},
  [626] = {.lex_state = 4, .external_lex_state = 6},
  [627] = {.lex_state = 4, .external_lex_state = 6},
  [628] = {.lex_state = 4, .external_lex_state = 6},
  [629] = {.lex_state = 4, .external_lex_state = 6},
  [630] = {.lex_state = 4, .external_lex_state = 6},
  [631] = {.lex_state = 4, .external_lex_state = 6},
  [632] = {.lex_state = 4, .external_lex_state = 6},
  [633] = {.lex_state = 4, .external_lex_state = 6},
  [634] = {.lex_state = 4, .external_lex_state = 6},
  [635] = {.lex_state = 4, .external_lex_state = 6},
  [636] = {.lex_state = 4, .external_lex_state = 6},
  [637] = {.lex_state = 4, .external_lex_state = 6},
  [638] = {.lex_state = 4, .external_lex_state = 6},
  [639] = {.lex_state = 4, .external_lex_state = 6},
  [640] = {.lex_state = 4, .external_lex_state = 6},
  [641] = {.lex_state = 4, .external_lex_state = 6},
  [642] = {.lex_state = 4, .external_lex_state = 6},
  [643] = {.lex_state = 0, .external_lex_state = 5},
  [644] = {.lex_state = 0, .external_lex_state = 5},
  [645] = {.lex_state = 4, .external_lex_state = 6},
  [646] = {.lex_state = 4, .external_lex_state = 6},
  [647] = {.lex_state = 4, .external_lex_state = 6},
  [648] = {.lex_state = 4, .external_lex_state = 6},
  [649] = {.lex_state = 4, .external_lex_state = 6},
  [650] = {.lex_state = 4, .external_lex_state = 6},
  [651] = {.lex_state = 4, .external_lex_state = 6},
  [652] = {.lex_state = 4, .external_lex_state = 6},
  [653] = {.lex_state = 4, .external_lex_state = 6},
  [654] = {.lex_state = 4, .external_lex_state = 6},
  [655] = {.lex_state = 4, .external_lex_state = 6},
  [656] = {.lex_state = 4, .external_lex_state = 6},
  [657] = {.lex_state = 178, .external_lex_state = 5},
  [658] = {.lex_state = 178, .external_lex_state = 5},
  [659] = {.lex_state = 4, .external_lex_state = 6},
  [660] = {.lex_state = 4, .external_lex_state = 6},
  [661] = {.lex_state = 4, .external_lex_state = 6},
  [662] = {.lex_state = 4, .external_lex_state = 6},
  [663] = {.lex_state = 4, .external_lex_state = 6},
  [664] = {.lex_state = 4, .external_lex_state = 6},
  [665] = {.lex_state = 4, .external_lex_state = 6},
  [666] = {.lex_state = 4, .external_lex_state = 6},
  [667] = {.lex_state = 0, .external_lex_state = 5},
  [668] = {.lex_state = 4, .external_lex_state = 6},
  [669] = {.lex_state = 4, .external_lex_state = 6},
  [670] = {.lex_state = 178, .external_lex_state = 5},
  [671] = {.lex_state = 4, .external_lex_state = 6},
  [672] = {.lex_state = 4, .external_lex_state = 6},
  [673] = {.lex_state = 4, .external_lex_state = 6},
  [674] = {.lex_state = 4, .external_lex_state = 6},
  [675] = {.lex_state = 4, .external_lex_state = 6},
  [676] = {.lex_state = 4, .external_lex_state = 6},
  [677] = {.lex_state = 4, .external_lex_state = 6},
  [678] = {.lex_state = 4, .external_lex_state = 6},
  [679] = {.lex_state = 4, .external_lex_state = 6},
  [680] = {.lex_state = 4, .external_lex_state = 6},
  [681] = {.lex_state = 4, .external_lex_state = 6},
  [682] = {.lex_state = 4, .external_lex_state = 6},
  [683] = {.lex_state = 4, .external_lex_state = 6},
  [684] = {.lex_state = 4, .external_lex_state = 6},
  [685] = {.lex_state = 4, .external_lex_state = 6},
  [686] = {.lex_state = 4, .external_lex_state = 6},
  [687] = {.lex_state = 4, .external_lex_state = 6},
  [688] = {.lex_state = 4, .external_lex_state = 6},
  [689] = {.lex_state = 4, .external_lex_state = 6},
  [690] = {.lex_state = 4, .external_lex_state = 6},
  [691] = {.lex_state = 4, .external_lex_state = 6},
  [692] = {.lex_state = 4, .external_lex_state = 6},
  [693] = {.lex_state = 4, .external_lex_state = 6},
  [694] = {.lex_state = 4, .external_lex_state = 6},
  [695] = {.lex_state = 4, .external_lex_state = 6},
  [696] = {.lex_state = 178, .external_lex_state = 5},
  [697] = {.lex_state = 4, .external_lex_state = 6},
  [698] = {.lex_state = 4, .external_lex_state = 6},
  [699] = {.lex_state = 4, .external_lex_state = 6},
  [700] = {.lex_state = 4, .external_lex_state = 6},
  [701] = {.lex_state = 4, .external_lex_state = 6},
  [702] = {.lex_state = 4, .external_lex_state = 6},
  [703] = {.lex_state = 4, .external_lex_state = 6},
  [704] = {.lex_state = 0, .external_lex_state = 5},
  [705] = {.lex_state = 0, .external_lex_state = 5},
  [706] = {.lex_state = 0, .external_lex_state = 5},
  [707] = {.lex_state = 0, .external_lex_state = 5},
  [708] = {.lex_state = 0, .external_lex_state = 5},
  [709] = {.lex_state = 0, .external_lex_state = 5},
  [710] = {.lex_state = 0, .external_lex_state = 5},
  [711] = {.lex_state = 0, .external_lex_state = 5},
  [712] = {.lex_state = 0, .external_lex_state = 5},
  [713] = {.lex_state = 4, .external_lex_state = 6},
  [714] = {.lex_state = 0, .external_lex_state = 5},
  [715] = {.lex_state = 0, .external_lex_state = 5},
  [716] = {.lex_state = 0, .external_lex_state = 5},
  [717] = {.lex_state = 0, .external_lex_state = 5},
  [718] = {.lex_state = 0, .external_lex_state = 5},
  [719] = {.lex_state = 0, .external_lex_state = 5},
  [720] = {.lex_state = 0, .external_lex_state = 5},
  [721] = {.lex_state = 0, .external_lex_state = 5},
  [722] = {.lex_state = 0, .external_lex_state = 5},
  [723] = {.lex_state = 0, .external_lex_state = 5},
  [724] = {.lex_state = 0, .external_lex_state = 5},
  [725] = {.lex_state = 0, .external_lex_state = 5},
  [726] = {.lex_state = 0, .external_lex_state = 5},
  [727] = {.lex_state = 0, .external_lex_state = 5},
  [728] = {.lex_state = 0, .external_lex_state = 5},
  [729] = {.lex_state = 0, .external_lex_state = 5},
  [730] = {.lex_state = 0, .external_lex_state = 5},
  [731] = {.lex_state = 0, .external_lex_state = 5},
  [732] = {.lex_state = 0, .external_lex_state = 5},
  [733] = {.lex_state = 0, .external_lex_state = 5},
  [734] = {.lex_state = 0, .external_lex_state = 5},
  [735] = {.lex_state = 0, .external_lex_state = 5},
  [736] = {.lex_state = 0, .external_lex_state = 5},
  [737] = {.lex_state = 0, .external_lex_state = 5},
  [738] = {.lex_state = 0, .external_lex_state = 5},
  [739] = {.lex_state = 0, .external_lex_state = 5},
  [740] = {.lex_state = 0, .external_lex_state = 5},
  [741] = {.lex_state = 0, .external_lex_state = 5},
  [742] = {.lex_state = 0, .external_lex_state = 5},
  [743] = {.lex_state = 0, .external_lex_state = 5},
  [744] = {.lex_state = 0, .external_lex_state = 5},
  [745] = {.lex_state = 0, .external_lex_state = 5},
  [746] = {.lex_state = 0, .external_lex_state = 5},
  [747] = {.lex_state = 0, .external_lex_state = 5},
  [748] = {.lex_state = 0, .external_lex_state = 5},
  [749] = {.lex_state = 0, .external_lex_state = 5},
  [750] = {.lex_state = 0, .external_lex_state = 5},
  [751] = {.lex_state = 0, .external_lex_state = 5},
  [752] = {.lex_state = 0, .external_lex_state = 5},
  [753] = {.lex_state = 0, .external_lex_state = 5},
  [754] = {.lex_state = 0, .external_lex_state = 5},
  [755] = {.lex_state = 0, .external_lex_state = 5},
  [756] = {.lex_state = 0, .external_lex_state = 5},
  [757] = {.lex_state = 0, .external_lex_state = 5},
  [758] = {.lex_state = 0, .external_lex_state = 5},
  [759] = {.lex_state = 0, .external_lex_state = 5},
  [760] = {.lex_state = 0, .external_lex_state = 5},
  [761] = {.lex_state = 0, .external_lex_state = 5},
  [762] = {.lex_state = 0, .external_lex_state = 5},
  [763] = {.lex_state = 0, .external_lex_state = 5},
  [764] = {.lex_state = 0, .external_lex_state = 5},
  [765] = {.lex_state = 0, .external_lex_state = 5},
  [766] = {.lex_state = 0, .external_lex_state = 5},
  [767] = {.lex_state = 0, .external_lex_state = 5},
  [768] = {.lex_state = 0, .external_lex_state = 5},
  [769] = {.lex_state = 0, .external_lex_state = 5},
  [770] = {.lex_state = 0, .external_lex_state = 5},
  [771] = {.lex_state = 0, .external_lex_state = 5},
  [772] = {.lex_state = 0, .external_lex_state = 5},
  [773] = {.lex_state = 0, .external_lex_state = 5},
  [774] = {.lex_state = 0, .external_lex_state = 5},
  [775] = {.lex_state = 0, .external_lex_state = 5},
  [776] = {.lex_state = 0, .external_lex_state = 5},
  [777] = {.lex_state = 0, .external_lex_state = 5},
  [778] = {.lex_state = 0, .external_lex_state = 5},
  [779] = {.lex_state = 0, .external_lex_state = 5},
  [780] = {.lex_state = 0, .external_lex_state = 5},
  [781] = {.lex_state = 0, .external_lex_state = 5},
  [782] = {.lex_state = 0, .external_lex_state = 5},
  [783] = {.lex_state = 0, .external_lex_state = 5},
  [784] = {.lex_state = 0, .external_lex_state = 5},
  [785] = {.lex_state = 0, .external_lex_state = 5},
  [786] = {.lex_state = 0, .external_lex_state = 5},
  [787] = {.lex_state = 0, .external_lex_state = 5},
  [788] = {.lex_state = 0, .external_lex_state = 5},
  [789] = {.lex_state = 0, .external_lex_state = 5},
  [790] = {.lex_state = 0, .external_lex_state = 5},
  [791] = {.lex_state = 0, .external_lex_state = 5},
  [792] = {.lex_state = 0, .external_lex_state = 5},
  [793] = {.lex_state = 0, .external_lex_state = 5},
  [794] = {.lex_state = 0, .external_lex_state = 5},
  [795] = {.lex_state = 0, .external_lex_state = 5},
  [796] = {.lex_state = 0, .external_lex_state = 5},
  [797] = {.lex_state = 0, .external_lex_state = 5},
  [798] = {.lex_state = 0, .external_lex_state = 5},
  [799] = {.lex_state = 0, .external_lex_state = 5},
  [800] = {.lex_state = 0, .external_lex_state = 5},
  [801] = {.lex_state = 0, .external_lex_state = 5},
  [802] = {.lex_state = 0, .external_lex_state = 5},
  [803] = {.lex_state = 0, .external_lex_state = 5},
  [804] = {.lex_state = 0, .external_lex_state = 5},
  [805] = {.lex_state = 0, .external_lex_state = 5},
  [806] = {.lex_state = 0, .external_lex_state = 5},
  [807] = {.lex_state = 0, .external_lex_state = 5},
  [808] = {.lex_state = 0, .external_lex_state = 5},
  [809] = {.lex_state = 4, .external_lex_state = 6},
  [810] = {.lex_state = 3, .external_lex_state = 3},
  [811] = {.lex_state = 4, .external_lex_state = 6},
  [812] = {.lex_state = 180, .external_lex_state = 7},
  [813] = {.lex_state = 0, .external_lex_state = 5},
  [814] = {.lex_state = 4, .external_lex_state = 6},
  [815] = {.lex_state = 0, .external_lex_state = 5},
  [816] = {.lex_state = 4, .external_lex_state = 6},
  [817] = {.lex_state = 0, .external_lex_state = 5},
  [818] = {.lex_state = 0, .external_lex_state = 5},
  [819] = {.lex_state = 0, .external_lex_state = 5},
  [820] = {.lex_state = 0, .external_lex_state = 5},
  [821] = {.lex_state = 0, .external_lex_state = 5},
  [822] = {.lex_state = 0, .external_lex_state = 5},
  [823] = {.lex_state = 0, .external_lex_state = 5},
  [824] = {.lex_state = 0, .external_lex_state = 5},
  [825] = {.lex_state = 180, .external_lex_state = 7},
  [826] = {.lex_state = 2, .external_lex_state = 8},
  [827] = {.lex_state = 0, .external_lex_state = 5},
  [828] = {.lex_state = 0, .external_lex_state = 5},
  [829] = {.lex_state = 0, .external_lex_state = 5},
  [830] = {.lex_state = 0, .external_lex_state = 5},
  [831] = {.lex_state = 0, .external_lex_state = 5},
  [832] = {.lex_state = 183, .external_lex_state = 7},
  [833] = {.lex_state = 183, .external_lex_state = 7},
  [834] = {.lex_state = 0, .external_lex_state = 5},
  [835] = {.lex_state = 0, .external_lex_state = 5},
  [836] = {.lex_state = 0, .external_lex_state = 5},
  [837] = {.lex_state = 0, .external_lex_state = 5},
  [838] = {.lex_state = 2, .external_lex_state = 8},
  [839] = {.lex_state = 0, .external_lex_state = 5},
  [840] = {.lex_state = 0, .external_lex_state = 5},
  [841] = {.lex_state = 0, .external_lex_state = 5},
  [842] = {.lex_state = 0, .external_lex_state = 5},
  [843] = {.lex_state = 0, .external_lex_state = 5},
  [844] = {.lex_state = 0, .external_lex_state = 5},
  [845] = {.lex_state = 0, .external_lex_state = 5},
  [846] = {.lex_state = 0, .external_lex_state = 5},
  [847] = {.lex_state = 0, .external_lex_state = 5},
  [848] = {.lex_state = 0, .external_lex_state = 5},
  [849] = {.lex_state = 0, .external_lex_state = 5},
  [850] = {.lex_state = 0, .external_lex_state = 5},
  [851] = {.lex_state = 0, .external_lex_state = 5},
  [852] = {.lex_state = 0, .external_lex_state = 5},
  [853] = {.lex_state = 0, .external_lex_state = 5},
  [854] = {.lex_state = 183, .external_lex_state = 7},
  [855] = {.lex_state = 0, .external_lex_state = 5},
  [856] = {.lex_state = 178, .external_lex_state = 7},
  [857] = {.lex_state = 0, .external_lex_state = 5},
  [858] = {.lex_state = 0, .external_lex_state = 5},
  [859] = {.lex_state = 180, .external_lex_state = 7},
  [860] = {.lex_state = 183, .external_lex_state = 3},
  [861] = {.lex_state = 180, .external_lex_state = 7},
  [862] = {.lex_state = 180, .external_lex_state = 7},
  [863] = {.lex_state = 180, .external_lex_state = 7},
  [864] = {.lex_state = 183, .external_lex_state = 7},
  [865] = {.lex_state = 183, .external_lex_state = 7},
  [866] = {.lex_state = 3, .external_lex_state = 7},
  [867] = {.lex_state = 183, .external_lex_state = 7},
  [868] = {.lex_state = 3, .external_lex_state = 7},
  [869] = {.lex_state = 183, .external_lex_state = 7},
  [870] = {.lex_state = 178, .external_lex_state = 7},
  [871] = {.lex_state = 183, .external_lex_state = 7},
  [872] = {.lex_state = 178, .external_lex_state = 5},
  [873] = {.lex_state = 7, .external_lex_state = 8},
  [874] = {.lex_state = 7, .external_lex_state = 8},
  [875] = {.lex_state = 1, .external_lex_state = 5},
  [876] = {.lex_state = 7, .external_lex_state = 8},
  [877] = {.lex_state = 2, .external_lex_state = 8},
  [878] = {.lex_state = 1, .external_lex_state = 5},
  [879] = {.lex_state = 183, .external_lex_state = 7},
  [880] = {.lex_state = 2, .external_lex_state = 8},
  [881] = {.lex_state = 183, .external_lex_state = 7},
  [882] = {.lex_state = 2, .external_lex_state = 8},
  [883] = {.lex_state = 183, .external_lex_state = 7},
  [884] = {.lex_state = 183, .external_lex_state = 7},
  [885] = {.lex_state = 183, .external_lex_state = 7},
  [886] = {.lex_state = 183, .external_lex_state = 7},
  [887] = {.lex_state = 1, .external_lex_state = 5},
  [888] = {.lex_state = 178, .external_lex_state = 7},
  [889] = {.lex_state = 183, .external_lex_state = 7},
  [890] = {.lex_state = 180, .external_lex_state = 7},
  [891] = {.lex_state = 183, .external_lex_state = 7},
  [892] = {.lex_state = 183, .external_lex_state = 7},
  [893] = {.lex_state = 180, .external_lex_state = 7},
  [894] = {.lex_state = 183, .external_lex_state = 7},
  [895] = {.lex_state = 178, .external_lex_state = 7},
  [896] = {.lex_state = 183, .external_lex_state = 7},
  [897] = {.lex_state = 183, .external_lex_state = 7},
  [898] = {.lex_state = 180, .external_lex_state = 7},
  [899] = {.lex_state = 178, .external_lex_state = 7},
  [900] = {.lex_state = 178, .external_lex_state = 7},
  [901] = {.lex_state = 183, .external_lex_state = 7},
  [902] = {.lex_state = 183, .external_lex_state = 7},
  [903] = {.lex_state = 178, .external_lex_state = 7},
  [904] = {.lex_state = 183, .external_lex_state = 7},
  [905] = {.lex_state = 183, .external_lex_state = 7},
  [906] = {.lex_state = 183, .external_lex_state = 7},
  [907] = {.lex_state = 183, .external_lex_state = 7},
  [908] = {.lex_state = 183, .external_lex_state = 7},
  [909] = {.lex_state = 183, .external_lex_state = 7},
  [910] = {.lex_state = 7, .external_lex_state = 8},
  [911] = {.lex_state = 178, .external_lex_state = 7},
  [912] = {.lex_state = 178, .external_lex_state = 7},
  [913] = {.lex_state = 178, .external_lex_state = 7},
  [914] = {.lex_state = 178, .external_lex_state = 7},
  [915] = {.lex_state = 7, .external_lex_state = 8},
  [916] = {.lex_state = 183, .external_lex_state = 7},
  [917] = {.lex_state = 180, .external_lex_state = 7},
  [918] = {.lex_state = 1, .external_lex_state = 5},
  [919] = {.lex_state = 183, .external_lex_state = 7},
  [920] = {.lex_state = 183, .external_lex_state = 7},
  [921] = {.lex_state = 178, .external_lex_state = 7},
  [922] = {.lex_state = 183, .external_lex_state = 7},
  [923] = {.lex_state = 1, .external_lex_state = 5},
  [924] = {.lex_state = 1, .external_lex_state = 5},
  [925] = {.lex_state = 1, .external_lex_state = 5},
  [926] = {.lex_state = 183, .external_lex_state = 7},
  [927] = {.lex_state = 183, .external_lex_state = 7},
  [928] = {.lex_state = 183, .external_lex_state = 7},
  [929] = {.lex_state = 183, .external_lex_state = 7},
  [930] = {.lex_state = 183, .external_lex_state = 7},
  [931] = {.lex_state = 183, .external_lex_state = 7},
  [932] = {.lex_state = 7, .external_lex_state = 8},
  [933] = {.lex_state = 183, .external_lex_state = 7},
  [934] = {.lex_state = 7, .external_lex_state = 5},
  [935] = {.lex_state = 183, .external_lex_state = 7},
  [936] = {.lex_state = 183, .external_lex_state = 7},
  [937] = {.lex_state = 180, .external_lex_state = 7},
  [938] = {.lex_state = 180, .external_lex_state = 7},
  [939] = {.lex_state = 183, .external_lex_state = 7},
  [940] = {.lex_state = 180, .external_lex_state = 7},
  [941] = {.lex_state = 178, .external_lex_state = 7},
  [942] = {.lex_state = 183, .external_lex_state = 7},
  [943] = {.lex_state = 180, .external_lex_state = 7},
  [944] = {.lex_state = 180, .external_lex_state = 7},
  [945] = {.lex_state = 180, .external_lex_state = 7},
  [946] = {.lex_state = 183, .external_lex_state = 7},
  [947] = {.lex_state = 178, .external_lex_state = 7},
  [948] = {.lex_state = 183, .external_lex_state = 7},
  [949] = {.lex_state = 178, .external_lex_state = 7},
  [950] = {.lex_state = 178, .external_lex_state = 7},
  [951] = {.lex_state = 180, .external_lex_state = 7},
  [952] = {.lex_state = 183, .external_lex_state = 7},
  [953] = {.lex_state = 8, .external_lex_state = 6},
  [954] = {.lex_state = 183, .external_lex_state = 7},
  [955] = {.lex_state = 8, .external_lex_state = 6},
  [956] = {.lex_state = 7, .external_lex_state = 5},
  [957] = {.lex_state = 183, .external_lex_state = 7},
  [958] = {.lex_state = 8, .external_lex_state = 6},
  [959] = {.lex_state = 8, .external_lex_state = 6},
  [960] = {.lex_state = 178, .external_lex_state = 7},
  [961] = {.lex_state = 178, .external_lex_state = 7},
  [962] = {.lex_state = 7, .external_lex_state = 5},
  [963] = {.lex_state = 178, .external_lex_state = 7},
  [964] = {.lex_state = 178, .external_lex_state = 7},
  [965] = {.lex_state = 8, .external_lex_state = 6},
  [966] = {.lex_state = 178, .external_lex_state = 7},
  [967] = {.lex_state = 183, .external_lex_state = 7},
  [968] = {.lex_state = 0, .external_lex_state = 5},
  [969] = {.lex_state = 178, .external_lex_state = 5},
  [970] = {.lex_state = 8, .external_lex_state = 6},
  [971] = {.lex_state = 0, .external_lex_state = 5},
  [972] = {.lex_state = 8, .external_lex_state = 6},
  [973] = {.lex_state = 178, .external_lex_state = 7},
  [974] = {.lex_state = 7, .external_lex_state = 7},
  [975] = {.lex_state = 7, .external_lex_state = 7},
  [976] = {.lex_state = 4, .external_lex_state = 6},
  [977] = {.lex_state = 7, .external_lex_state = 7},
  [978] = {.lex_state = 3, .external_lex_state = 7},
  [979] = {.lex_state = 178, .external_lex_state = 5},
  [980] = {.lex_state = 0, .external_lex_state = 5},
  [981] = {.lex_state = 178, .external_lex_state = 5},
  [982] = {.lex_state = 0, .external_lex_state = 5},
  [983] = {.lex_state = 183, .external_lex_state = 7},
  [984] = {.lex_state = 183, .external_lex_state = 7},
  [985] = {.lex_state = 178, .external_lex_state = 7},
  [986] = {.lex_state = 0, .external_lex_state = 5},
  [987] = {.lex_state = 183, .external_lex_state = 7},
  [988] = {.lex_state = 183, .external_lex_state = 7},
  [989] = {.lex_state = 183, .external_lex_state = 7},
  [990] = {.lex_state = 183, .external_lex_state = 7},
  [991] = {.lex_state = 183, .external_lex_state = 7},
  [992] = {.lex_state = 183, .external_lex_state = 7},
  [993] = {.lex_state = 0, .external_lex_state = 5},
  [994] = {.lex_state = 183, .external_lex_state = 7},
  [995] = {.lex_state = 183, .external_lex_state = 7},
  [996] = {.lex_state = 183, .external_lex_state = 7},
  [997] = {.lex_state = 183, .external_lex_state = 7},
  [998] = {.lex_state = 4, .external_lex_state = 6},
  [999] = {.lex_state = 183, .external_lex_state = 7},
  [1000] = {.lex_state = 7, .external_lex_state = 5},
  [1001] = {.lex_state = 7, .external_lex_state = 5},
  [1002] = {.lex_state = 4, .external_lex_state = 6},
  [1003] = {.lex_state = 178, .external_lex_state = 7},
  [1004] = {.lex_state = 7, .external_lex_state = 5},
  [1005] = {.lex_state = 4, .external_lex_state = 6},
  [1006] = {.lex_state = 7, .external_lex_state = 5},
  [1007] = {.lex_state = 178, .external_lex_state = 7},
  [1008] = {.lex_state = 183, .external_lex_state = 7},
  [1009] = {.lex_state = 4, .external_lex_state = 6},
  [1010] = {.lex_state = 183, .external_lex_state = 7},
  [1011] = {.lex_state = 183, .external_lex_state = 7},
  [1012] = {.lex_state = 183, .external_lex_state = 7},
  [1013] = {.lex_state = 178, .external_lex_state = 5},
  [1014] = {.lex_state = 180, .external_lex_state = 5},
  [1015] = {.lex_state = 180, .external_lex_state = 5},
  [1016] = {.lex_state = 178, .external_lex_state = 5},
  [1017] = {.lex_state = 178, .external_lex_state = 5},
  [1018] = {.lex_state = 183, .external_lex_state = 7},
  [1019] = {.lex_state = 183, .external_lex_state = 7},
  [1020] = {.lex_state = 0, .external_lex_state = 5},
  [1021] = {.lex_state = 183, .external_lex_state = 7},
  [1022] = {.lex_state = 183, .external_lex_state = 7},
  [1023] = {.lex_state = 0, .external_lex_state = 5},
  [1024] = {.lex_state = 183, .external_lex_state = 7},
  [1025] = {.lex_state = 183, .external_lex_state = 7},
  [1026] = {.lex_state = 183, .external_lex_state = 7},
  [1027] = {.lex_state = 183, .external_lex_state = 7},
  [1028] = {.lex_state = 4, .external_lex_state = 6},
  [1029] = {.lex_state = 183, .external_lex_state = 5},
  [1030] = {.lex_state = 183, .external_lex_state = 5},
  [1031] = {.lex_state = 183, .external_lex_state = 7},
  [1032] = {.lex_state = 0, .external_lex_state = 5},
  [1033] = {.lex_state = 0, .external_lex_state = 5},
  [1034] = {.lex_state = 183, .external_lex_state = 5},
  [1035] = {.lex_state = 183, .external_lex_state = 7},
  [1036] = {.lex_state = 183, .external_lex_state = 7},
  [1037] = {.lex_state = 183, .external_lex_state = 7},
  [1038] = {.lex_state = 183, .external_lex_state = 7},
  [1039] = {.lex_state = 183, .external_lex_state = 7},
  [1040] = {.lex_state = 183, .external_lex_state = 7},
  [1041] = {.lex_state = 183, .external_lex_state = 7},
  [1042] = {.lex_state = 183, .external_lex_state = 7},
  [1043] = {.lex_state = 183, .external_lex_state = 7},
  [1044] = {.lex_state = 183, .external_lex_state = 7},
  [1045] = {.lex_state = 183, .external_lex_state = 7},
  [1046] = {.lex_state = 183, .external_lex_state = 7},
  [1047] = {.lex_state = 183, .external_lex_state = 7},
  [1048] = {.lex_state = 183, .external_lex_state = 7},
  [1049] = {.lex_state = 183, .external_lex_state = 7},
  [1050] = {.lex_state = 0, .external_lex_state = 5},
  [1051] = {.lex_state = 183, .external_lex_state = 7},
  [1052] = {.lex_state = 183, .external_lex_state = 7},
  [1053] = {.lex_state = 183, .external_lex_state = 7},
  [1054] = {.lex_state = 183, .external_lex_state = 7},
  [1055] = {.lex_state = 183, .external_lex_state = 7},
  [1056] = {.lex_state = 183, .external_lex_state = 7},
  [1057] = {.lex_state = 7, .external_lex_state = 7},
  [1058] = {.lex_state = 183, .external_lex_state = 7},
  [1059] = {.lex_state = 0, .external_lex_state = 5},
  [1060] = {.lex_state = 183, .external_lex_state = 5},
  [1061] = {.lex_state = 183, .external_lex_state = 7},
  [1062] = {.lex_state = 183, .external_lex_state = 7},
  [1063] = {.lex_state = 183, .external_lex_state = 7},
  [1064] = {.lex_state = 183, .external_lex_state = 7},
  [1065] = {.lex_state = 183, .external_lex_state = 5},
  [1066] = {.lex_state = 183, .external_lex_state = 7},
  [1067] = {.lex_state = 183, .external_lex_state = 7},
  [1068] = {.lex_state = 183, .external_lex_state = 7},
  [1069] = {.lex_state = 183, .external_lex_state = 7},
  [1070] = {.lex_state = 183, .external_lex_state = 7},
  [1071] = {.lex_state = 183, .external_lex_state = 7},
  [1072] = {.lex_state = 183, .external_lex_state = 7},
  [1073] = {.lex_state = 183, .external_lex_state = 7},
  [1074] = {.lex_state = 183, .external_lex_state = 7},
  [1075] = {.lex_state = 183, .external_lex_state = 5},
  [1076] = {.lex_state = 183, .external_lex_state = 7},
  [1077] = {.lex_state = 183, .external_lex_state = 5},
  [1078] = {.lex_state = 183, .external_lex_state = 7},
  [1079] = {.lex_state = 183, .external_lex_state = 7},
  [1080] = {.lex_state = 183, .external_lex_state = 5},
  [1081] = {.lex_state = 183, .external_lex_state = 7},
  [1082] = {.lex_state = 183, .external_lex_state = 5},
  [1083] = {.lex_state = 183, .external_lex_state = 7},
  [1084] = {.lex_state = 183, .external_lex_state = 7},
  [1085] = {.lex_state = 178, .external_lex_state = 5},
  [1086] = {.lex_state = 183, .external_lex_state = 7},
  [1087] = {.lex_state = 183, .external_lex_state = 7},
  [1088] = {.lex_state = 183, .external_lex_state = 7},
  [1089] = {.lex_state = 183, .external_lex_state = 7},
  [1090] = {.lex_state = 183, .external_lex_state = 7},
  [1091] = {.lex_state = 0, .external_lex_state = 5},
  [1092] = {.lex_state = 183, .external_lex_state = 7},
  [1093] = {.lex_state = 183, .external_lex_state = 7},
  [1094] = {.lex_state = 183, .external_lex_state = 7},
  [1095] = {.lex_state = 183, .external_lex_state = 7},
  [1096] = {.lex_state = 183, .external_lex_state = 7},
  [1097] = {.lex_state = 183, .external_lex_state = 7},
  [1098] = {.lex_state = 0, .external_lex_state = 5},
  [1099] = {.lex_state = 0, .external_lex_state = 5},
  [1100] = {.lex_state = 183, .external_lex_state = 7},
  [1101] = {.lex_state = 183, .external_lex_state = 7},
  [1102] = {.lex_state = 178, .external_lex_state = 5},
  [1103] = {.lex_state = 0, .external_lex_state = 5},
  [1104] = {.lex_state = 183, .external_lex_state = 7},
  [1105] = {.lex_state = 178, .external_lex_state = 5},
  [1106] = {.lex_state = 183, .external_lex_state = 7},
  [1107] = {.lex_state = 183, .external_lex_state = 7},
  [1108] = {.lex_state = 183, .external_lex_state = 7},
  [1109] = {.lex_state = 183, .external_lex_state = 7},
  [1110] = {.lex_state = 183, .external_lex_state = 7},
  [1111] = {.lex_state = 183, .external_lex_state = 7},
  [1112] = {.lex_state = 183, .external_lex_state = 7},
  [1113] = {.lex_state = 183, .external_lex_state = 7},
  [1114] = {.lex_state = 183, .external_lex_state = 7},
  [1115] = {.lex_state = 183, .external_lex_state = 7},
  [1116] = {.lex_state = 183, .external_lex_state = 7},
  [1117] = {.lex_state = 183, .external_lex_state = 7},
  [1118] = {.lex_state = 183, .external_lex_state = 7},
  [1119] = {.lex_state = 183, .external_lex_state = 7},
  [1120] = {.lex_state = 183, .external_lex_state = 7},
  [1121] = {.lex_state = 178, .external_lex_state = 5},
  [1122] = {.lex_state = 178, .external_lex_state = 5},
  [1123] = {.lex_state = 178, .external_lex_state = 5},
  [1124] = {.lex_state = 178, .external_lex_state = 5},
  [1125] = {.lex_state = 178, .external_lex_state = 5},
  [1126] = {.lex_state = 178, .external_lex_state = 5},
  [1127] = {.lex_state = 178, .external_lex_state = 5},
  [1128] = {.lex_state = 0, .external_lex_state = 5},
  [1129] = {.lex_state = 0, .external_lex_state = 5},
  [1130] = {.lex_state = 0, .external_lex_state = 5},
  [1131] = {.lex_state = 178, .external_lex_state = 5},
  [1132] = {.lex_state = 0, .external_lex_state = 5},
  [1133] = {.lex_state = 178, .external_lex_state = 5},
  [1134] = {.lex_state = 0, .external_lex_state = 5},
  [1135] = {.lex_state = 180, .external_lex_state = 5},
  [1136] = {.lex_state = 178, .external_lex_state = 5},
  [1137] = {.lex_state = 178, .external_lex_state = 5},
  [1138] = {.lex_state = 0, .external_lex_state = 5},
  [1139] = {.lex_state = 178, .external_lex_state = 5},
  [1140] = {.lex_state = 178, .external_lex_state = 5},
  [1141] = {.lex_state = 178, .external_lex_state = 5},
  [1142] = {.lex_state = 178, .external_lex_state = 5},
  [1143] = {.lex_state = 178, .external_lex_state = 5},
  [1144] = {.lex_state = 178, .external_lex_state = 5},
  [1145] = {.lex_state = 0, .external_lex_state = 5},
  [1146] = {.lex_state = 178, .external_lex_state = 5},
  [1147] = {.lex_state = 178, .external_lex_state = 5},
  [1148] = {.lex_state = 0, .external_lex_state = 5},
  [1149] = {.lex_state = 0, .external_lex_state = 5},
  [1150] = {.lex_state = 178, .external_lex_state = 5},
  [1151] = {.lex_state = 178, .external_lex_state = 5},
  [1152] = {.lex_state = 0, .external_lex_state = 5},
  [1153] = {.lex_state = 183, .external_lex_state = 7},
  [1154] = {.lex_state = 0, .external_lex_state = 5},
  [1155] = {.lex_state = 178, .external_lex_state = 5},
  [1156] = {.lex_state = 0, .external_lex_state = 5},
  [1157] = {.lex_state = 178, .external_lex_state = 5},
  [1158] = {.lex_state = 178, .external_lex_state = 5},
  [1159] = {.lex_state = 178, .external_lex_state = 5},
  [1160] = {.lex_state = 0, .external_lex_state = 5},
  [1161] = {.lex_state = 0, .external_lex_state = 5},
  [1162] = {.lex_state = 178, .external_lex_state = 5},
  [1163] = {.lex_state = 178, .external_lex_state = 5},
  [1164] = {.lex_state = 183, .external_lex_state = 7},
  [1165] = {.lex_state = 178, .external_lex_state = 5},
  [1166] = {.lex_state = 178, .external_lex_state = 5},
  [1167] = {.lex_state = 178, .external_lex_state = 5},
  [1168] = {.lex_state = 180, .external_lex_state = 5},
  [1169] = {.lex_state = 178, .external_lex_state = 5},
  [1170] = {.lex_state = 178, .external_lex_state = 5},
  [1171] = {.lex_state = 178, .external_lex_state = 5},
  [1172] = {.lex_state = 178, .external_lex_state = 5},
  [1173] = {.lex_state = 178, .external_lex_state = 5},
  [1174] = {.lex_state = 178, .external_lex_state = 5},
  [1175] = {.lex_state = 178, .external_lex_state = 5},
  [1176] = {.lex_state = 178, .external_lex_state = 5},
  [1177] = {.lex_state = 178, .external_lex_state = 5},
  [1178] = {.lex_state = 178, .external_lex_state = 5},
  [1179] = {.lex_state = 178, .external_lex_state = 5},
  [1180] = {.lex_state = 178, .external_lex_state = 5},
  [1181] = {.lex_state = 178, .external_lex_state = 5},
  [1182] = {.lex_state = 178, .external_lex_state = 5},
  [1183] = {.lex_state = 178, .external_lex_state = 5},
  [1184] = {.lex_state = 178, .external_lex_state = 5},
  [1185] = {.lex_state = 178, .external_lex_state = 5},
  [1186] = {.lex_state = 178, .external_lex_state = 5},
  [1187] = {.lex_state = 178, .external_lex_state = 5},
  [1188] = {.lex_state = 178, .external_lex_state = 5},
  [1189] = {.lex_state = 178, .external_lex_state = 5},
  [1190] = {.lex_state = 178, .external_lex_state = 5},
  [1191] = {.lex_state = 178, .external_lex_state = 5},
  [1192] = {.lex_state = 178, .external_lex_state = 5},
  [1193] = {.lex_state = 178, .external_lex_state = 5},
  [1194] = {.lex_state = 178, .external_lex_state = 5},
  [1195] = {.lex_state = 178, .external_lex_state = 5},
  [1196] = {.lex_state = 178, .external_lex_state = 5},
  [1197] = {.lex_state = 178, .external_lex_state = 5},
  [1198] = {.lex_state = 178, .external_lex_state = 5},
  [1199] = {.lex_state = 178, .external_lex_state = 5},
  [1200] = {.lex_state = 178, .external_lex_state = 5},
  [1201] = {.lex_state = 178, .external_lex_state = 5},
  [1202] = {.lex_state = 178, .external_lex_state = 5},
  [1203] = {.lex_state = 178, .external_lex_state = 5},
  [1204] = {.lex_state = 178, .external_lex_state = 5},
  [1205] = {.lex_state = 178, .external_lex_state = 5},
  [1206] = {.lex_state = 178, .external_lex_state = 5},
  [1207] = {.lex_state = 178, .external_lex_state = 5},
  [1208] = {.lex_state = 178, .external_lex_state = 5},
  [1209] = {.lex_state = 178, .external_lex_state = 5},
  [1210] = {.lex_state = 178, .external_lex_state = 5},
  [1211] = {.lex_state = 178, .external_lex_state = 5},
  [1212] = {.lex_state = 178, .external_lex_state = 5},
  [1213] = {.lex_state = 178, .external_lex_state = 5},
  [1214] = {.lex_state = 178, .external_lex_state = 5},
  [1215] = {.lex_state = 178, .external_lex_state = 5},
  [1216] = {.lex_state = 178, .external_lex_state = 5},
  [1217] = {.lex_state = 178, .external_lex_state = 5},
  [1218] = {.lex_state = 178, .external_lex_state = 5},
  [1219] = {.lex_state = 178, .external_lex_state = 5},
  [1220] = {.lex_state = 178, .external_lex_state = 5},
  [1221] = {.lex_state = 178, .external_lex_state = 5},
  [1222] = {.lex_state = 178, .external_lex_state = 5},
  [1223] = {.lex_state = 178, .external_lex_state = 5},
  [1224] = {.lex_state = 178, .external_lex_state = 5},
  [1225] = {.lex_state = 178, .external_lex_state = 5},
  [1226] = {.lex_state = 178, .external_lex_state = 5},
  [1227] = {.lex_state = 180, .external_lex_state = 5},
  [1228] = {.lex_state = 178, .external_lex_state = 5},
  [1229] = {.lex_state = 178, .external_lex_state = 5},
  [1230] = {.lex_state = 178, .external_lex_state = 5},
  [1231] = {.lex_state = 178, .external_lex_state = 5},
  [1232] = {.lex_state = 178, .external_lex_state = 5},
  [1233] = {.lex_state = 178, .external_lex_state = 5},
  [1234] = {.lex_state = 178, .external_lex_state = 5},
  [1235] = {.lex_state = 9, .external_lex_state = 6},
  [1236] = {.lex_state = 183, .external_lex_state = 5},
  [1237] = {.lex_state = 9, .external_lex_state = 6},
  [1238] = {.lex_state = 178, .external_lex_state = 5},
  [1239] = {.lex_state = 178, .external_lex_state = 5},
  [1240] = {.lex_state = 183, .external_lex_state = 5},
  [1241] = {.lex_state = 9, .external_lex_state = 6},
  [1242] = {.lex_state = 178, .external_lex_state = 5},
  [1243] = {.lex_state = 183, .external_lex_state = 5},
  [1244] = {.lex_state = 183, .external_lex_state = 5},
  [1245] = {.lex_state = 183, .external_lex_state = 5},
  [1246] = {.lex_state = 183, .external_lex_state = 5},
  [1247] = {.lex_state = 178, .external_lex_state = 5},
  [1248] = {.lex_state = 183, .external_lex_state = 5},
  [1249] = {.lex_state = 178, .external_lex_state = 5},
  [1250] = {.lex_state = 183, .external_lex_state = 5},
  [1251] = {.lex_state = 178, .external_lex_state = 5},
  [1252] = {.lex_state = 178, .external_lex_state = 5},
  [1253] = {.lex_state = 0, .external_lex_state = 7},
  [1254] = {.lex_state = 178, .external_lex_state = 5},
  [1255] = {.lex_state = 183, .external_lex_state = 5},
  [1256] = {.lex_state = 183, .external_lex_state = 5},
  [1257] = {.lex_state = 183, .external_lex_state = 5},
  [1258] = {.lex_state = 178, .external_lex_state = 5},
  [1259] = {.lex_state = 178, .external_lex_state = 5},
  [1260] = {.lex_state = 183, .external_lex_state = 5},
  [1261] = {.lex_state = 183, .external_lex_state = 5},
  [1262] = {.lex_state = 9, .external_lex_state = 6},
  [1263] = {.lex_state = 178, .external_lex_state = 5},
  [1264] = {.lex_state = 178, .external_lex_state = 5},
  [1265] = {.lex_state = 0, .external_lex_state = 5},
  [1266] = {.lex_state = 178, .external_lex_state = 9},
  [1267] = {.lex_state = 0, .external_lex_state = 5},
  [1268] = {.lex_state = 0, .external_lex_state = 5},
  [1269] = {.lex_state = 183, .external_lex_state = 5},
  [1270] = {.lex_state = 0, .external_lex_state = 5},
  [1271] = {.lex_state = 183, .external_lex_state = 5},
  [1272] = {.lex_state = 178, .external_lex_state = 5},
  [1273] = {.lex_state = 183, .external_lex_state = 5},
  [1274] = {.lex_state = 0, .external_lex_state = 5},
  [1275] = {.lex_state = 183, .external_lex_state = 5},
  [1276] = {.lex_state = 0, .external_lex_state = 5},
  [1277] = {.lex_state = 178, .external_lex_state = 5},
  [1278] = {.lex_state = 178, .external_lex_state = 5},
  [1279] = {.lex_state = 0, .external_lex_state = 5},
  [1280] = {.lex_state = 178, .external_lex_state = 5},
  [1281] = {.lex_state = 9, .external_lex_state = 6},
  [1282] = {.lex_state = 0, .external_lex_state = 5},
  [1283] = {.lex_state = 178, .external_lex_state = 5},
  [1284] = {.lex_state = 0, .external_lex_state = 5},
  [1285] = {.lex_state = 178, .external_lex_state = 5},
  [1286] = {.lex_state = 0, .external_lex_state = 5},
  [1287] = {.lex_state = 178, .external_lex_state = 5},
  [1288] = {.lex_state = 178, .external_lex_state = 5},
  [1289] = {.lex_state = 183, .external_lex_state = 5},
  [1290] = {.lex_state = 0, .external_lex_state = 5},
  [1291] = {.lex_state = 178, .external_lex_state = 5},
  [1292] = {.lex_state = 178, .external_lex_state = 5},
  [1293] = {.lex_state = 0, .external_lex_state = 5},
  [1294] = {.lex_state = 178, .external_lex_state = 5},
  [1295] = {.lex_state = 183, .external_lex_state = 5},
  [1296] = {.lex_state = 178, .external_lex_state = 5},
  [1297] = {.lex_state = 0, .external_lex_state = 5},
  [1298] = {.lex_state = 0, .external_lex_state = 5},
  [1299] = {.lex_state = 0, .external_lex_state = 5},
  [1300] = {.lex_state = 178, .external_lex_state = 5},
  [1301] = {.lex_state = 178, .external_lex_state = 5},
  [1302] = {.lex_state = 178, .external_lex_state = 5},
  [1303] = {.lex_state = 178, .external_lex_state = 5},
  [1304] = {.lex_state = 178, .external_lex_state = 5},
  [1305] = {.lex_state = 178, .external_lex_state = 5},
  [1306] = {.lex_state = 178, .external_lex_state = 5},
  [1307] = {.lex_state = 178, .external_lex_state = 9},
  [1308] = {.lex_state = 178, .external_lex_state = 5},
  [1309] = {.lex_state = 0, .external_lex_state = 5},
  [1310] = {.lex_state = 178, .external_lex_state = 5},
  [1311] = {.lex_state = 178, .external_lex_state = 5},
  [1312] = {.lex_state = 178, .external_lex_state = 5},
  [1313] = {.lex_state = 178, .external_lex_state = 9},
  [1314] = {.lex_state = 178, .external_lex_state = 5},
  [1315] = {.lex_state = 178, .external_lex_state = 5},
  [1316] = {.lex_state = 178, .external_lex_state = 5},
  [1317] = {.lex_state = 178, .external_lex_state = 5},
  [1318] = {.lex_state = 178, .external_lex_state = 5},
  [1319] = {.lex_state = 178, .external_lex_state = 5},
  [1320] = {.lex_state = 178, .external_lex_state = 5},
  [1321] = {.lex_state = 180, .external_lex_state = 5},
  [1322] = {.lex_state = 178, .external_lex_state = 5},
  [1323] = {.lex_state = 9, .external_lex_state = 6},
  [1324] = {.lex_state = 178, .external_lex_state = 5},
  [1325] = {.lex_state = 178, .external_lex_state = 5},
  [1326] = {.lex_state = 178, .external_lex_state = 5},
  [1327] = {.lex_state = 178, .external_lex_state = 5},
  [1328] = {.lex_state = 178, .external_lex_state = 5},
  [1329] = {.lex_state = 178, .external_lex_state = 5},
  [1330] = {.lex_state = 178, .external_lex_state = 5},
  [1331] = {.lex_state = 178, .external_lex_state = 5},
  [1332] = {.lex_state = 178, .external_lex_state = 5},
  [1333] = {.lex_state = 178, .external_lex_state = 5},
  [1334] = {.lex_state = 0, .external_lex_state = 5},
  [1335] = {.lex_state = 178, .external_lex_state = 5},
  [1336] = {.lex_state = 178, .external_lex_state = 5},
  [1337] = {.lex_state = 178, .external_lex_state = 5},
  [1338] = {.lex_state = 0, .external_lex_state = 5},
  [1339] = {.lex_state = 178, .external_lex_state = 5},
  [1340] = {.lex_state = 178, .external_lex_state = 5},
  [1341] = {.lex_state = 178, .external_lex_state = 5},
  [1342] = {.lex_state = 0, .external_lex_state = 5},
  [1343] = {.lex_state = 183, .external_lex_state = 5},
  [1344] = {.lex_state = 9, .external_lex_state = 6},
  [1345] = {.lex_state = 183, .external_lex_state = 5},
  [1346] = {.lex_state = 0, .external_lex_state = 5},
  [1347] = {.lex_state = 0, .external_lex_state = 10},
  [1348] = {.lex_state = 178, .external_lex_state = 5},
  [1349] = {.lex_state = 178, .external_lex_state = 5},
  [1350] = {.lex_state = 9, .external_lex_state = 6},
  [1351] = {.lex_state = 178, .external_lex_state = 5},
  [1352] = {.lex_state = 9, .external_lex_state = 6},
  [1353] = {.lex_state = 0, .external_lex_state = 11},
  [1354] = {.lex_state = 9, .external_lex_state = 6},
  [1355] = {.lex_state = 178, .external_lex_state = 5},
  [1356] = {.lex_state = 0, .external_lex_state = 10},
  [1357] = {.lex_state = 178, .external_lex_state = 5},
  [1358] = {.lex_state = 178, .external_lex_state = 5},
  [1359] = {.lex_state = 9, .external_lex_state = 6},
  [1360] = {.lex_state = 9, .external_lex_state = 5},
  [1361] = {.lex_state = 178, .external_lex_state = 5},
  [1362] = {.lex_state = 178, .external_lex_state = 5},
  [1363] = {.lex_state = 0, .external_lex_state = 11},
  [1364] = {.lex_state = 9, .external_lex_state = 6},
  [1365] = {.lex_state = 183, .external_lex_state = 5},
  [1366] = {.lex_state = 183, .external_lex_state = 5},
  [1367] = {.lex_state = 178, .external_lex_state = 5},
  [1368] = {.lex_state = 178, .external_lex_state = 5},
  [1369] = {.lex_state = 178, .external_lex_state = 5},
  [1370] = {.lex_state = 178, .external_lex_state = 5},
  [1371] = {.lex_state = 178, .external_lex_state = 5},
  [1372] = {.lex_state = 178, .external_lex_state = 5},
  [1373] = {.lex_state = 178, .external_lex_state = 5},
  [1374] = {.lex_state = 178, .external_lex_state = 5},
  [1375] = {.lex_state = 0, .external_lex_state = 10},
  [1376] = {.lex_state = 9, .external_lex_state = 6},
  [1377] = {.lex_state = 0, .external_lex_state = 10},
  [1378] = {.lex_state = 0, .external_lex_state = 11},
  [1379] = {.lex_state = 0, .external_lex_state = 11},
  [1380] = {.lex_state = 0, .external_lex_state = 5},
  [1381] = {.lex_state = 178, .external_lex_state = 5},
  [1382] = {.lex_state = 0, .external_lex_state = 11},
  [1383] = {.lex_state = 178, .external_lex_state = 5},
  [1384] = {.lex_state = 0, .external_lex_state = 10},
  [1385] = {.lex_state = 178, .external_lex_state = 5},
  [1386] = {.lex_state = 178, .external_lex_state = 5},
  [1387] = {.lex_state = 178, .external_lex_state = 5},
  [1388] = {.lex_state = 178, .external_lex_state = 5},
  [1389] = {.lex_state = 0, .external_lex_state = 10},
  [1390] = {.lex_state = 0, .external_lex_state = 11},
  [1391] = {.lex_state = 178, .external_lex_state = 5},
  [1392] = {.lex_state = 0, .external_lex_state = 10},
  [1393] = {.lex_state = 0, .external_lex_state = 11},
  [1394] = {.lex_state = 178, .external_lex_state = 5},
  [1395] = {.lex_state = 178, .external_lex_state = 5},
  [1396] = {.lex_state = 0, .external_lex_state = 10},
  [1397] = {.lex_state = 0, .external_lex_state = 11},
  [1398] = {.lex_state = 0, .external_lex_state = 10},
  [1399] = {.lex_state = 0, .external_lex_state = 11},
  [1400] = {.lex_state = 178, .external_lex_state = 5},
  [1401] = {.lex_state = 178, .external_lex_state = 5},
  [1402] = {.lex_state = 178, .external_lex_state = 5},
  [1403] = {.lex_state = 178, .external_lex_state = 5},
  [1404] = {.lex_state = 0, .external_lex_state = 5},
  [1405] = {.lex_state = 0, .external_lex_state = 5},
  [1406] = {.lex_state = 178, .external_lex_state = 5},
  [1407] = {.lex_state = 9, .external_lex_state = 5},
  [1408] = {.lex_state = 0, .external_lex_state = 5},
  [1409] = {.lex_state = 178, .external_lex_state = 5},
  [1410] = {.lex_state = 178, .external_lex_state = 5},
  [1411] = {.lex_state = 9, .external_lex_state = 5},
  [1412] = {.lex_state = 0, .external_lex_state = 5},
  [1413] = {.lex_state = 178, .external_lex_state = 5},
  [1414] = {.lex_state = 178, .external_lex_state = 5},
  [1415] = {.lex_state = 178, .external_lex_state = 5},
  [1416] = {.lex_state = 178, .external_lex_state = 5},
  [1417] = {.lex_state = 0, .external_lex_state = 5},
  [1418] = {.lex_state = 178, .external_lex_state = 5},
  [1419] = {.lex_state = 178, .external_lex_state = 5},
  [1420] = {.lex_state = 178, .external_lex_state = 5},
  [1421] = {.lex_state = 0, .external_lex_state = 5},
  [1422] = {.lex_state = 178, .external_lex_state = 5},
  [1423] = {.lex_state = 178, .external_lex_state = 5},
  [1424] = {.lex_state = 178, .external_lex_state = 5},
  [1425] = {.lex_state = 9, .external_lex_state = 5},
  [1426] = {.lex_state = 9, .external_lex_state = 5},
  [1427] = {.lex_state = 178, .external_lex_state = 5},
  [1428] = {.lex_state = 0, .external_lex_state = 5},
  [1429] = {.lex_state = 178, .external_lex_state = 5},
  [1430] = {.lex_state = 0, .external_lex_state = 5},
  [1431] = {.lex_state = 178, .external_lex_state = 5},
  [1432] = {.lex_state = 0, .external_lex_state = 5},
  [1433] = {.lex_state = 178, .external_lex_state = 5},
  [1434] = {.lex_state = 178, .external_lex_state = 5},
  [1435] = {.lex_state = 0, .external_lex_state = 5},
  [1436] = {.lex_state = 0, .external_lex_state = 5},
  [1437] = {.lex_state = 178, .external_lex_state = 5},
  [1438] = {.lex_state = 178, .external_lex_state = 5},
  [1439] = {.lex_state = 183, .external_lex_state = 7},
  [1440] = {.lex_state = 0, .external_lex_state = 5},
  [1441] = {.lex_state = 178, .external_lex_state = 5},
  [1442] = {.lex_state = 0, .external_lex_state = 5},
  [1443] = {.lex_state = 178, .external_lex_state = 5},
  [1444] = {.lex_state = 178, .external_lex_state = 5},
  [1445] = {.lex_state = 178, .external_lex_state = 5},
  [1446] = {.lex_state = 178, .external_lex_state = 5},
  [1447] = {.lex_state = 178, .external_lex_state = 5},
  [1448] = {.lex_state = 178, .external_lex_state = 5},
  [1449] = {.lex_state = 178, .external_lex_state = 5},
  [1450] = {.lex_state = 178, .external_lex_state = 5},
  [1451] = {.lex_state = 178, .external_lex_state = 5},
  [1452] = {.lex_state = 0, .external_lex_state = 5},
  [1453] = {.lex_state = 178, .external_lex_state = 5},
  [1454] = {.lex_state = 178, .external_lex_state = 5},
  [1455] = {.lex_state = 178, .external_lex_state = 5},
  [1456] = {.lex_state = 178, .external_lex_state = 5},
  [1457] = {.lex_state = 178, .external_lex_state = 5},
  [1458] = {.lex_state = 0, .external_lex_state = 5},
  [1459] = {.lex_state = 178, .external_lex_state = 5},
  [1460] = {.lex_state = 178, .external_lex_state = 5},
  [1461] = {.lex_state = 178, .external_lex_state = 5},
  [1462] = {.lex_state = 178, .external_lex_state = 5},
  [1463] = {.lex_state = 0, .external_lex_state = 5},
  [1464] = {.lex_state = 178, .external_lex_state = 5},
  [1465] = {.lex_state = 0, .external_lex_state = 5},
  [1466] = {.lex_state = 0, .external_lex_state = 5},
  [1467] = {.lex_state = 178, .external_lex_state = 5},
  [1468] = {.lex_state = 0, .external_lex_state = 5},
  [1469] = {.lex_state = 0, .external_lex_state = 5},
  [1470] = {.lex_state = 0, .external_lex_state = 5},
  [1471] = {.lex_state = 0, .external_lex_state = 5},
  [1472] = {.lex_state = 0, .external_lex_state = 5},
  [1473] = {.lex_state = 0, .external_lex_state = 5},
  [1474] = {.lex_state = 0, .external_lex_state = 5},
  [1475] = {.lex_state = 0, .external_lex_state = 5},
  [1476] = {.lex_state = 9, .external_lex_state = 5},
  [1477] = {.lex_state = 0, .external_lex_state = 5},
  [1478] = {.lex_state = 178, .external_lex_state = 5},
  [1479] = {.lex_state = 9, .external_lex_state = 5},
  [1480] = {.lex_state = 9, .external_lex_state = 5},
  [1481] = {.lex_state = 0, .external_lex_state = 5},
  [1482] = {.lex_state = 178, .external_lex_state = 5},
  [1483] = {.lex_state = 0, .external_lex_state = 5},
  [1484] = {.lex_state = 178, .external_lex_state = 5},
  [1485] = {.lex_state = 9, .external_lex_state = 5},
  [1486] = {.lex_state = 9, .external_lex_state = 5},
  [1487] = {.lex_state = 9, .external_lex_state = 5},
  [1488] = {.lex_state = 9, .external_lex_state = 5},
  [1489] = {.lex_state = 9, .external_lex_state = 5},
  [1490] = {.lex_state = 178, .external_lex_state = 5},
  [1491] = {.lex_state = 0, .external_lex_state = 5},
  [1492] = {.lex_state = 0, .external_lex_state = 5},
  [1493] = {.lex_state = 178, .external_lex_state = 5},
  [1494] = {.lex_state = 9, .external_lex_state = 5},
  [1495] = {.lex_state = 9, .external_lex_state = 5},
  [1496] = {.lex_state = 9, .external_lex_state = 5},
  [1497] = {.lex_state = 0, .external_lex_state = 5},
  [1498] = {.lex_state = 9, .external_lex_state = 5},
  [1499] = {.lex_state = 0, .external_lex_state = 5},
  [1500] = {.lex_state = 9, .external_lex_state = 5},
  [1501] = {.lex_state = 9, .external_lex_state = 5},
  [1502] = {.lex_state = 9, .external_lex_state = 5},
  [1503] = {.lex_state = 0, .external_lex_state = 5},
  [1504] = {.lex_state = 178, .external_lex_state = 5},
  [1505] = {.lex_state = 0, .external_lex_state = 5},
  [1506] = {.lex_state = 9, .external_lex_state = 5},
  [1507] = {.lex_state = 178, .external_lex_state = 5},
  [1508] = {.lex_state = 0, .external_lex_state = 5},
  [1509] = {.lex_state = 178, .external_lex_state = 5},
  [1510] = {.lex_state = 178, .external_lex_state = 5},
  [1511] = {.lex_state = 0, .external_lex_state = 5},
  [1512] = {.lex_state = 9, .external_lex_state = 5},
  [1513] = {.lex_state = 0, .external_lex_state = 5},
  [1514] = {.lex_state = 183, .external_lex_state = 7},
  [1515] = {.lex_state = 178, .external_lex_state = 5},
  [1516] = {.lex_state = 0, .external_lex_state = 5},
  [1517] = {.lex_state = 178, .external_lex_state = 5},
  [1518] = {.lex_state = 9, .external_lex_state = 5},
  [1519] = {.lex_state = 178, .external_lex_state = 5},
  [1520] = {.lex_state = 178, .external_lex_state = 5},
  [1521] = {.lex_state = 9, .external_lex_state = 6},
  [1522] = {.lex_state = 178, .external_lex_state = 5},
  [1523] = {.lex_state = 178, .external_lex_state = 5},
  [1524] = {.lex_state = 178, .external_lex_state = 5},
  [1525] = {.lex_state = 178, .external_lex_state = 5},
  [1526] = {.lex_state = 9, .external_lex_state = 5},
  [1527] = {.lex_state = 178, .external_lex_state = 5},
  [1528] = {.lex_state = 178, .external_lex_state = 5},
  [1529] = {.lex_state = 178, .external_lex_state = 5},
  [1530] = {.lex_state = 178, .external_lex_state = 5},
  [1531] = {.lex_state = 0, .external_lex_state = 5},
  [1532] = {.lex_state = 178, .external_lex_state = 5},
  [1533] = {.lex_state = 178, .external_lex_state = 5},
  [1534] = {.lex_state = 178, .external_lex_state = 5},
  [1535] = {.lex_state = 0, .external_lex_state = 5},
  [1536] = {.lex_state = 0, .external_lex_state = 5},
  [1537] = {.lex_state = 9, .external_lex_state = 6},
  [1538] = {.lex_state = 178, .external_lex_state = 5},
  [1539] = {.lex_state = 178, .external_lex_state = 5},
  [1540] = {.lex_state = 178, .external_lex_state = 5},
  [1541] = {.lex_state = 9, .external_lex_state = 5},
  [1542] = {.lex_state = 0, .external_lex_state = 5},
  [1543] = {.lex_state = 9, .external_lex_state = 5},
  [1544] = {.lex_state = 0, .external_lex_state = 5},
  [1545] = {.lex_state = 9, .external_lex_state = 5},
  [1546] = {.lex_state = 9, .external_lex_state = 5},
  [1547] = {.lex_state = 9, .external_lex_state = 5},
  [1548] = {.lex_state = 9, .external_lex_state = 5},
  [1549] = {.lex_state = 9, .external_lex_state = 5},
  [1550] = {.lex_state = 9, .external_lex_state = 5},
  [1551] = {.lex_state = 178, .external_lex_state = 5},
  [1552] = {.lex_state = 0, .external_lex_state = 5},
  [1553] = {.lex_state = 0, .external_lex_state = 5},
  [1554] = {.lex_state = 9, .external_lex_state = 5},
  [1555] = {.lex_state = 9, .external_lex_state = 5},
  [1556] = {.lex_state = 0, .external_lex_state = 5},
  [1557] = {.lex_state = 0, .external_lex_state = 5},
  [1558] = {.lex_state = 0, .external_lex_state = 5},
  [1559] = {.lex_state = 178, .external_lex_state = 5},
  [1560] = {.lex_state = 0, .external_lex_state = 5},
  [1561] = {.lex_state = 178, .external_lex_state = 5},
  [1562] = {.lex_state = 9, .external_lex_state = 5},
  [1563] = {.lex_state = 9, .external_lex_state = 5},
  [1564] = {.lex_state = 178, .external_lex_state = 5},
  [1565] = {.lex_state = 178, .external_lex_state = 5},
  [1566] = {.lex_state = 9, .external_lex_state = 5},
  [1567] = {.lex_state = 9, .external_lex_state = 5},
  [1568] = {.lex_state = 9, .external_lex_state = 5},
  [1569] = {.lex_state = 9, .external_lex_state = 5},
  [1570] = {.lex_state = 9, .external_lex_state = 5},
  [1571] = {.lex_state = 9, .external_lex_state = 5},
  [1572] = {.lex_state = 178, .external_lex_state = 5},
  [1573] = {.lex_state = 0, .external_lex_state = 5},
  [1574] = {.lex_state = 0, .external_lex_state = 5},
  [1575] = {.lex_state = 9, .external_lex_state = 5},
  [1576] = {.lex_state = 178, .external_lex_state = 5},
  [1577] = {.lex_state = 178, .external_lex_state = 5},
  [1578] = {.lex_state = 0, .external_lex_state = 5},
  [1579] = {.lex_state = 0, .external_lex_state = 5},
  [1580] = {.lex_state = 178, .external_lex_state = 5},
  [1581] = {.lex_state = 178, .external_lex_state = 5},
  [1582] = {.lex_state = 178, .external_lex_state = 5},
  [1583] = {.lex_state = 178, .external_lex_state = 5},
  [1584] = {.lex_state = 178, .external_lex_state = 5},
  [1585] = {.lex_state = 178, .external_lex_state = 5},
  [1586] = {.lex_state = 178, .external_lex_state = 5},
  [1587] = {.lex_state = 178, .external_lex_state = 5},
  [1588] = {.lex_state = 178, .external_lex_state = 5},
  [1589] = {.lex_state = 178, .external_lex_state = 5},
  [1590] = {.lex_state = 178, .external_lex_state = 5},
  [1591] = {.lex_state = 178, .external_lex_state = 5},
  [1592] = {.lex_state = 178, .external_lex_state = 5},
  [1593] = {.lex_state = 178, .external_lex_state = 5},
  [1594] = {.lex_state = 178, .external_lex_state = 5},
  [1595] = {.lex_state = 178, .external_lex_state = 5},
  [1596] = {.lex_state = 178, .external_lex_state = 5},
  [1597] = {.lex_state = 0, .external_lex_state = 5},
  [1598] = {.lex_state = 178, .external_lex_state = 5},
  [1599] = {.lex_state = 0, .external_lex_state = 5},
  [1600] = {.lex_state = 0, .external_lex_state = 5},
  [1601] = {.lex_state = 0, .external_lex_state = 5},
  [1602] = {.lex_state = 0, .external_lex_state = 5},
  [1603] = {.lex_state = 183, .external_lex_state = 5},
  [1604] = {.lex_state = 9, .external_lex_state = 5},
  [1605] = {.lex_state = 183, .external_lex_state = 5},
  [1606] = {.lex_state = 0, .external_lex_state = 5},
  [1607] = {.lex_state = 0, .external_lex_state = 5},
  [1608] = {.lex_state = 0, .external_lex_state = 5},
  [1609] = {.lex_state = 183, .external_lex_state = 5},
  [1610] = {.lex_state = 0, .external_lex_state = 5},
  [1611] = {.lex_state = 0, .external_lex_state = 5},
  [1612] = {.lex_state = 0, .external_lex_state = 5},
  [1613] = {.lex_state = 0, .external_lex_state = 5},
  [1614] = {.lex_state = 0, .external_lex_state = 5},
  [1615] = {.lex_state = 0, .external_lex_state = 5},
  [1616] = {.lex_state = 0, .external_lex_state = 5},
  [1617] = {.lex_state = 0, .external_lex_state = 5},
  [1618] = {.lex_state = 0, .external_lex_state = 5},
  [1619] = {.lex_state = 0, .external_lex_state = 5},
  [1620] = {.lex_state = 0, .external_lex_state = 5},
  [1621] = {.lex_state = 0, .external_lex_state = 5},
  [1622] = {.lex_state = 0, .external_lex_state = 5},
  [1623] = {.lex_state = 0, .external_lex_state = 5},
  [1624] = {.lex_state = 0, .external_lex_state = 5},
  [1625] = {.lex_state = 0, .external_lex_state = 5},
  [1626] = {.lex_state = 0, .external_lex_state = 5},
  [1627] = {.lex_state = 0, .external_lex_state = 5},
  [1628] = {.lex_state = 0, .external_lex_state = 5},
  [1629] = {.lex_state = 0, .external_lex_state = 5},
  [1630] = {.lex_state = 0, .external_lex_state = 5},
  [1631] = {.lex_state = 0, .external_lex_state = 5},
  [1632] = {.lex_state = 0, .external_lex_state = 5},
  [1633] = {.lex_state = 0, .external_lex_state = 5},
  [1634] = {.lex_state = 0, .external_lex_state = 5},
  [1635] = {.lex_state = 0, .external_lex_state = 5},
  [1636] = {.lex_state = 0, .external_lex_state = 5},
  [1637] = {.lex_state = 0, .external_lex_state = 5},
  [1638] = {.lex_state = 0, .external_lex_state = 5},
  [1639] = {.lex_state = 0, .external_lex_state = 5},
  [1640] = {.lex_state = 0, .external_lex_state = 5},
  [1641] = {.lex_state = 0, .external_lex_state = 5},
  [1642] = {.lex_state = 183, .external_lex_state = 5},
  [1643] = {.lex_state = 183, .external_lex_state = 5},
  [1644] = {.lex_state = 0, .external_lex_state = 5},
  [1645] = {.lex_state = 0, .external_lex_state = 5},
  [1646] = {.lex_state = 0, .external_lex_state = 5},
  [1647] = {.lex_state = 0, .external_lex_state = 5},
  [1648] = {.lex_state = 0, .external_lex_state = 5},
  [1649] = {.lex_state = 0, .external_lex_state = 5},
  [1650] = {.lex_state = 0, .external_lex_state = 5},
  [1651] = {.lex_state = 0, .external_lex_state = 5},
  [1652] = {.lex_state = 0, .external_lex_state = 5},
  [1653] = {.lex_state = 0, .external_lex_state = 5},
  [1654] = {.lex_state = 0, .external_lex_state = 5},
  [1655] = {.lex_state = 0, .external_lex_state = 5},
  [1656] = {.lex_state = 0, .external_lex_state = 5},
  [1657] = {.lex_state = 0, .external_lex_state = 5},
  [1658] = {.lex_state = 0, .external_lex_state = 5},
  [1659] = {.lex_state = 0, .external_lex_state = 5},
  [1660] = {.lex_state = 0, .external_lex_state = 5},
  [1661] = {.lex_state = 0, .external_lex_state = 5},
  [1662] = {.lex_state = 0, .external_lex_state = 5},
  [1663] = {.lex_state = 0, .external_lex_state = 5},
  [1664] = {.lex_state = 0, .external_lex_state = 5},
  [1665] = {.lex_state = 0, .external_lex_state = 5},
  [1666] = {.lex_state = 0, .external_lex_state = 5},
  [1667] = {.lex_state = 0, .external_lex_state = 5},
  [1668] = {.lex_state = 0, .external_lex_state = 5},
  [1669] = {.lex_state = 0, .external_lex_state = 5},
  [1670] = {.lex_state = 0, .external_lex_state = 5},
  [1671] = {.lex_state = 0, .external_lex_state = 5},
  [1672] = {.lex_state = 0, .external_lex_state = 5},
  [1673] = {.lex_state = 0, .external_lex_state = 5},
  [1674] = {.lex_state = 0, .external_lex_state = 5},
  [1675] = {.lex_state = 0, .external_lex_state = 5},
  [1676] = {.lex_state = 0, .external_lex_state = 5},
  [1677] = {.lex_state = 0, .external_lex_state = 5},
  [1678] = {.lex_state = 0, .external_lex_state = 5},
  [1679] = {.lex_state = 0, .external_lex_state = 5},
  [1680] = {.lex_state = 0, .external_lex_state = 5},
  [1681] = {.lex_state = 0, .external_lex_state = 5},
  [1682] = {.lex_state = 0, .external_lex_state = 5},
  [1683] = {.lex_state = 0, .external_lex_state = 5},
  [1684] = {.lex_state = 0, .external_lex_state = 5},
  [1685] = {.lex_state = 0, .external_lex_state = 5},
  [1686] = {.lex_state = 0, .external_lex_state = 5},
  [1687] = {.lex_state = 0, .external_lex_state = 5},
  [1688] = {.lex_state = 0, .external_lex_state = 5},
  [1689] = {.lex_state = 0, .external_lex_state = 5},
  [1690] = {.lex_state = 0, .external_lex_state = 5},
  [1691] = {.lex_state = 0, .external_lex_state = 5},
  [1692] = {.lex_state = 0, .external_lex_state = 5},
  [1693] = {.lex_state = 0, .external_lex_state = 5},
  [1694] = {.lex_state = 0, .external_lex_state = 5},
  [1695] = {.lex_state = 0, .external_lex_state = 5},
  [1696] = {.lex_state = 0, .external_lex_state = 5},
  [1697] = {.lex_state = 0, .external_lex_state = 5},
  [1698] = {.lex_state = 0, .external_lex_state = 5},
  [1699] = {.lex_state = 0, .external_lex_state = 5},
  [1700] = {.lex_state = 0, .external_lex_state = 5},
  [1701] = {.lex_state = 0, .external_lex_state = 5},
  [1702] = {.lex_state = 0, .external_lex_state = 5},
  [1703] = {.lex_state = 0, .external_lex_state = 5},
  [1704] = {.lex_state = 183, .external_lex_state = 5},
  [1705] = {.lex_state = 0, .external_lex_state = 5},
  [1706] = {.lex_state = 183, .external_lex_state = 5},
  [1707] = {.lex_state = 0, .external_lex_state = 5},
  [1708] = {.lex_state = 183, .external_lex_state = 5},
  [1709] = {.lex_state = 0, .external_lex_state = 5},
  [1710] = {.lex_state = 0, .external_lex_state = 5},
  [1711] = {.lex_state = 0, .external_lex_state = 5},
  [1712] = {.lex_state = 0, .external_lex_state = 5},
  [1713] = {.lex_state = 0, .external_lex_state = 5},
  [1714] = {.lex_state = 183, .external_lex_state = 5},
  [1715] = {.lex_state = 0, .external_lex_state = 5},
  [1716] = {.lex_state = 183, .external_lex_state = 5},
  [1717] = {.lex_state = 0, .external_lex_state = 5},
  [1718] = {.lex_state = 183, .external_lex_state = 5},
  [1719] = {.lex_state = 0, .external_lex_state = 5},
  [1720] = {.lex_state = 0, .external_lex_state = 5},
  [1721] = {.lex_state = 0, .external_lex_state = 5},
  [1722] = {.lex_state = 0, .external_lex_state = 5},
  [1723] = {.lex_state = 183, .external_lex_state = 5},
  [1724] = {.lex_state = 0, .external_lex_state = 5},
  [1725] = {.lex_state = 183, .external_lex_state = 5},
  [1726] = {.lex_state = 0, .external_lex_state = 5},
  [1727] = {.lex_state = 0, .external_lex_state = 5},
  [1728] = {.lex_state = 0, .external_lex_state = 5},
  [1729] = {.lex_state = 0, .external_lex_state = 5},
  [1730] = {.lex_state = 183, .external_lex_state = 5},
  [1731] = {.lex_state = 183, .external_lex_state = 5},
  [1732] = {.lex_state = 183, .external_lex_state = 5},
  [1733] = {.lex_state = 183, .external_lex_state = 5},
  [1734] = {.lex_state = 0, .external_lex_state = 5},
  [1735] = {.lex_state = 183, .external_lex_state = 5},
  [1736] = {.lex_state = 183, .external_lex_state = 5},
  [1737] = {.lex_state = 0, .external_lex_state = 5},
  [1738] = {.lex_state = 0, .external_lex_state = 5},
  [1739] = {.lex_state = 183, .external_lex_state = 5},
  [1740] = {.lex_state = 0, .external_lex_state = 5},
  [1741] = {.lex_state = 183, .external_lex_state = 5},
  [1742] = {.lex_state = 183, .external_lex_state = 5},
  [1743] = {.lex_state = 0, .external_lex_state = 5},
  [1744] = {.lex_state = 0, .external_lex_state = 5},
  [1745] = {.lex_state = 183, .external_lex_state = 5},
  [1746] = {.lex_state = 0, .external_lex_state = 5},
  [1747] = {.lex_state = 183, .external_lex_state = 5},
  [1748] = {.lex_state = 183, .external_lex_state = 5},
  [1749] = {.lex_state = 0, .external_lex_state = 5},
  [1750] = {.lex_state = 0, .external_lex_state = 5},
  [1751] = {.lex_state = 0, .external_lex_state = 5},
  [1752] = {.lex_state = 0, .external_lex_state = 5},
  [1753] = {.lex_state = 0, .external_lex_state = 5},
  [1754] = {.lex_state = 0, .external_lex_state = 5},
  [1755] = {.lex_state = 183, .external_lex_state = 5},
  [1756] = {.lex_state = 183, .external_lex_state = 5},
  [1757] = {.lex_state = 0, .external_lex_state = 5},
  [1758] = {.lex_state = 0, .external_lex_state = 5},
  [1759] = {.lex_state = 0, .external_lex_state = 5},
  [1760] = {.lex_state = 0, .external_lex_state = 5},
  [1761] = {.lex_state = 183, .external_lex_state = 5},
  [1762] = {.lex_state = 0, .external_lex_state = 5},
  [1763] = {.lex_state = 183, .external_lex_state = 5},
  [1764] = {.lex_state = 0, .external_lex_state = 5},
  [1765] = {.lex_state = 183, .external_lex_state = 5},
  [1766] = {.lex_state = 183, .external_lex_state = 5},
  [1767] = {.lex_state = 0, .external_lex_state = 5},
  [1768] = {.lex_state = 183, .external_lex_state = 5},
  [1769] = {.lex_state = 0, .external_lex_state = 5},
  [1770] = {.lex_state = 183, .external_lex_state = 5},
  [1771] = {.lex_state = 0, .external_lex_state = 5},
  [1772] = {.lex_state = 0, .external_lex_state = 5},
  [1773] = {.lex_state = 183, .external_lex_state = 5},
  [1774] = {.lex_state = 0, .external_lex_state = 5},
  [1775] = {.lex_state = 183, .external_lex_state = 5},
  [1776] = {.lex_state = 183, .external_lex_state = 5},
  [1777] = {.lex_state = 0, .external_lex_state = 5},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DOT_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_DOT_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_DOT_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_DOT_SLASH] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_DOT_BSLASH] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_DOT_CARET] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_TILDE_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_DOT_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_elseif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_parfor] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_otherwise] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_persistent] = ACTIONS(1),
    [anon_sym_DOT_QMARK] = ACTIONS(1),
    [anon_sym_arguments] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_get_DOT] = ACTIONS(1),
    [anon_sym_set_DOT] = ACTIONS(1),
    [anon_sym_endfunction] = ACTIONS(1),
    [anon_sym_vector] = ACTIONS(1),
    [anon_sym_matrix] = ACTIONS(1),
    [anon_sym_scalar] = ACTIONS(1),
    [anon_sym_properties] = ACTIONS(1),
    [anon_sym_get] = ACTIONS(1),
    [anon_sym_set] = ACTIONS(1),
    [anon_sym_methods] = ACTIONS(1),
    [anon_sym_events] = ACTIONS(1),
    [anon_sym_enumeration] = ACTIONS(1),
    [anon_sym_classdef] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_spmd] = ACTIONS(1),
    [sym_number_size] = ACTIONS(1),
    [aux_sym_number_token1] = ACTIONS(1),
    [aux_sym_number_token2] = ACTIONS(1),
    [aux_sym_number_token3] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(1),
    [sym_command_argument] = ACTIONS(1),
    [sym__single_quote_string_start] = ACTIONS(1),
    [sym__single_quote_string_end] = ACTIONS(1),
    [sym__double_quote_string_start] = ACTIONS(1),
    [sym__double_quote_string_end] = ACTIONS(1),
    [sym_formatting_sequence] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_string_content] = ACTIONS(1),
    [sym__entry_delimiter] = ACTIONS(1),
    [sym__multioutput_variable_start] = ACTIONS(1),
    [sym__external_identifier] = ACTIONS(1),
    [sym_error_sentinel] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(1724),
    [aux_sym__block] = STATE(105),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym_function_definition] = STATE(1469),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_source_file_repeat1] = STATE(1469),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(43),
    [anon_sym_function] = ACTIONS(45),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(2)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1755),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(25),
    [aux_sym__block_repeat1] = STATE(25),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DOT_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_DOT_DASH] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_DOT_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(69),
    [anon_sym_DOT_SLASH] = ACTIONS(69),
    [anon_sym_BSLASH] = ACTIONS(69),
    [anon_sym_DOT_BSLASH] = ACTIONS(69),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_DOT_CARET] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(69),
    [anon_sym_AMP] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_DOT_SQUOTE] = ACTIONS(69),
    [anon_sym_SQUOTE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(77),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(77),
    [anon_sym_SEMI] = ACTIONS(77),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_COLON] = ACTIONS(69),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(91),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(3)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1250),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_elseif_clause] = STATE(1275),
    [sym_else_clause] = STATE(1714),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(6),
    [aux_sym__block_repeat1] = STATE(6),
    [aux_sym_if_statement_repeat1] = STATE(1275),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LT] = ACTIONS(117),
    [anon_sym_LT_EQ] = ACTIONS(117),
    [anon_sym_EQ_EQ] = ACTIONS(117),
    [anon_sym_TILDE_EQ] = ACTIONS(117),
    [anon_sym_GT_EQ] = ACTIONS(117),
    [anon_sym_GT] = ACTIONS(117),
    [anon_sym_AMP_AMP] = ACTIONS(119),
    [anon_sym_PIPE_PIPE] = ACTIONS(121),
    [anon_sym_COMMA] = ACTIONS(123),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(123),
    [anon_sym_SEMI] = ACTIONS(123),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_elseif] = ACTIONS(125),
    [anon_sym_else] = ACTIONS(127),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(129),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(123),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(4)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1609),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(9),
    [aux_sym__block_repeat1] = STATE(9),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LT] = ACTIONS(117),
    [anon_sym_LT_EQ] = ACTIONS(117),
    [anon_sym_EQ_EQ] = ACTIONS(117),
    [anon_sym_TILDE_EQ] = ACTIONS(117),
    [anon_sym_GT_EQ] = ACTIONS(117),
    [anon_sym_GT] = ACTIONS(117),
    [anon_sym_AMP_AMP] = ACTIONS(119),
    [anon_sym_PIPE_PIPE] = ACTIONS(121),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_elseif] = ACTIONS(133),
    [anon_sym_else] = ACTIONS(133),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(133),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(5)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1763),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(17),
    [aux_sym__block_repeat1] = STATE(17),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LT] = ACTIONS(117),
    [anon_sym_LT_EQ] = ACTIONS(117),
    [anon_sym_EQ_EQ] = ACTIONS(117),
    [anon_sym_TILDE_EQ] = ACTIONS(117),
    [anon_sym_GT_EQ] = ACTIONS(117),
    [anon_sym_GT] = ACTIONS(117),
    [anon_sym_AMP_AMP] = ACTIONS(119),
    [anon_sym_PIPE_PIPE] = ACTIONS(121),
    [anon_sym_COMMA] = ACTIONS(135),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(135),
    [anon_sym_SEMI] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(137),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(135),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(6)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1248),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_elseif_clause] = STATE(1246),
    [sym_else_clause] = STATE(1730),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [aux_sym_if_statement_repeat1] = STATE(1246),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_elseif] = ACTIONS(125),
    [anon_sym_else] = ACTIONS(127),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(7)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1605),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_catch_clause] = STATE(1741),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(143),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_catch] = ACTIONS(145),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(8)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1642),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_catch_clause] = STATE(1739),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(7),
    [aux_sym__block_repeat1] = STATE(7),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(147),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(147),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(149),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_catch] = ACTIONS(145),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(147),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(9)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1643),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_elseif] = ACTIONS(151),
    [anon_sym_else] = ACTIONS(151),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(151),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(10)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1603),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_otherwise] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(11)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1747),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(15),
    [aux_sym__block_repeat1] = STATE(15),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(155),
    [anon_sym_SEMI] = ACTIONS(155),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(155),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(12)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1735),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(159),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(13)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1708),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(12),
    [aux_sym__block_repeat1] = STATE(12),
    [anon_sym_LPAREN] = ACTIONS(161),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(163),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(163),
    [anon_sym_SEMI] = ACTIONS(163),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(165),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(163),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(14)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1776),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(28),
    [aux_sym__block_repeat1] = STATE(28),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(167),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(167),
    [anon_sym_SEMI] = ACTIONS(167),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(167),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(15)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1773),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(171),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(16)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1706),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(21),
    [aux_sym__block_repeat1] = STATE(21),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(173),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(173),
    [anon_sym_SEMI] = ACTIONS(173),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(175),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(173),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(17)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1748),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(177),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(18)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1745),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(179),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(19)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1731),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(23),
    [aux_sym__block_repeat1] = STATE(23),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(181),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(20)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1770),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(21)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1732),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(187),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(22)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1765),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(24),
    [aux_sym__block_repeat1] = STATE(24),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(189),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(189),
    [anon_sym_SEMI] = ACTIONS(189),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(191),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(189),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(23)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1755),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(91),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(24)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1704),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(193),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(25)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1766),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(195),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(26)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1718),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(29),
    [aux_sym__block_repeat1] = STATE(29),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(197),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(197),
    [anon_sym_SEMI] = ACTIONS(197),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(199),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(197),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(27)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1761),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(30),
    [aux_sym__block_repeat1] = STATE(30),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(201),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(201),
    [anon_sym_SEMI] = ACTIONS(201),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(28)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1723),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(205),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(29)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1725),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(207),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(30)] = {
    [aux_sym__block] = STATE(35),
    [sym_block] = STATE(1742),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [sym__end_of_line] = STATE(253),
    [aux_sym__block_repeat1] = STATE(253),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(79),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(81),
    [anon_sym_return] = ACTIONS(83),
    [anon_sym_continue] = ACTIONS(85),
    [anon_sym_break] = ACTIONS(87),
    [anon_sym_if] = ACTIONS(89),
    [anon_sym_end] = ACTIONS(209),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_parfor] = ACTIONS(95),
    [anon_sym_while] = ACTIONS(97),
    [anon_sym_switch] = ACTIONS(99),
    [anon_sym_global] = ACTIONS(101),
    [anon_sym_persistent] = ACTIONS(103),
    [anon_sym_arguments] = ACTIONS(105),
    [anon_sym_function] = ACTIONS(107),
    [anon_sym_properties] = ACTIONS(105),
    [anon_sym_get] = ACTIONS(105),
    [anon_sym_set] = ACTIONS(105),
    [anon_sym_methods] = ACTIONS(105),
    [anon_sym_events] = ACTIONS(105),
    [anon_sym_enumeration] = ACTIONS(105),
    [anon_sym_classdef] = ACTIONS(109),
    [anon_sym_try] = ACTIONS(111),
    [anon_sym_spmd] = ACTIONS(113),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(115),
    [aux_sym_number_token3] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(31)] = {
    [aux_sym__block] = STATE(31),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [ts_builtin_sym_end] = ACTIONS(211),
    [anon_sym_LPAREN] = ACTIONS(213),
    [anon_sym_PLUS] = ACTIONS(216),
    [anon_sym_DASH] = ACTIONS(216),
    [anon_sym_TILDE] = ACTIONS(219),
    [anon_sym_QMARK] = ACTIONS(222),
    [anon_sym_AT] = ACTIONS(225),
    [anon_sym_LBRACK] = ACTIONS(228),
    [anon_sym_LBRACE] = ACTIONS(231),
    [anon_sym_return] = ACTIONS(234),
    [anon_sym_continue] = ACTIONS(237),
    [anon_sym_break] = ACTIONS(240),
    [anon_sym_elseif] = ACTIONS(211),
    [anon_sym_else] = ACTIONS(243),
    [anon_sym_if] = ACTIONS(245),
    [anon_sym_end] = ACTIONS(248),
    [anon_sym_for] = ACTIONS(251),
    [anon_sym_parfor] = ACTIONS(254),
    [anon_sym_while] = ACTIONS(257),
    [anon_sym_case] = ACTIONS(211),
    [anon_sym_otherwise] = ACTIONS(211),
    [anon_sym_switch] = ACTIONS(260),
    [anon_sym_global] = ACTIONS(263),
    [anon_sym_persistent] = ACTIONS(266),
    [anon_sym_arguments] = ACTIONS(269),
    [anon_sym_function] = ACTIONS(272),
    [anon_sym_properties] = ACTIONS(269),
    [anon_sym_get] = ACTIONS(269),
    [anon_sym_set] = ACTIONS(269),
    [anon_sym_methods] = ACTIONS(269),
    [anon_sym_events] = ACTIONS(269),
    [anon_sym_enumeration] = ACTIONS(269),
    [anon_sym_classdef] = ACTIONS(275),
    [anon_sym_catch] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(278),
    [anon_sym_spmd] = ACTIONS(281),
    [aux_sym_number_token1] = ACTIONS(284),
    [aux_sym_number_token2] = ACTIONS(287),
    [aux_sym_number_token3] = ACTIONS(287),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(290),
    [sym__single_quote_string_start] = ACTIONS(293),
    [sym__double_quote_string_start] = ACTIONS(296),
    [sym__multioutput_variable_start] = ACTIONS(299),
    [sym__external_identifier] = ACTIONS(269),
  },
  [STATE(32)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1477),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(75),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(75),
    [ts_builtin_sym_end] = ACTIONS(302),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(304),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(310),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(33)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1440),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(50),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(312),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(314),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(316),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(34)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1442),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(52),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(52),
    [ts_builtin_sym_end] = ACTIONS(318),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(320),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(322),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(35)] = {
    [aux_sym__block] = STATE(31),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_elseif] = ACTIONS(324),
    [anon_sym_else] = ACTIONS(326),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(328),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_case] = ACTIONS(324),
    [anon_sym_otherwise] = ACTIONS(324),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(43),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_catch] = ACTIONS(324),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(36)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1499),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(39),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(39),
    [ts_builtin_sym_end] = ACTIONS(331),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(333),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(335),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(37)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1508),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(41),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(41),
    [ts_builtin_sym_end] = ACTIONS(337),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(339),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(341),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(38)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1458),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(54),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(54),
    [ts_builtin_sym_end] = ACTIONS(343),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(345),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(347),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(39)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1458),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(343),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(345),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(347),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(40)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1465),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(55),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(55),
    [ts_builtin_sym_end] = ACTIONS(349),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(351),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(353),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(41)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1465),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(349),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(351),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(353),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(42)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1472),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(355),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(357),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(359),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(43)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1491),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(57),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(57),
    [ts_builtin_sym_end] = ACTIONS(302),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(361),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(363),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(44)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1497),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(59),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(59),
    [ts_builtin_sym_end] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(367),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(369),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(45)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1505),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(371),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(373),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(375),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(46)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1599),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(42),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(42),
    [ts_builtin_sym_end] = ACTIONS(377),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(379),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(381),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(47)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1578),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(62),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(62),
    [ts_builtin_sym_end] = ACTIONS(331),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(383),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(385),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(48)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1405),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(64),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(64),
    [ts_builtin_sym_end] = ACTIONS(337),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(387),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(389),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(49)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1408),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(65),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(65),
    [ts_builtin_sym_end] = ACTIONS(377),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(391),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(393),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(50)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1408),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(377),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(391),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(393),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(51)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1412),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(68),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(68),
    [ts_builtin_sym_end] = ACTIONS(395),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(397),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(399),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(52)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1412),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(395),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(397),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(399),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(53)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1599),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(377),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(379),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(381),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(54)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1417),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(401),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(403),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(405),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(55)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1421),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(407),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(409),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(411),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(56)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1452),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(53),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(53),
    [ts_builtin_sym_end] = ACTIONS(312),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(413),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(415),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(57)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1432),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(417),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(419),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(421),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(58)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1435),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(70),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(70),
    [ts_builtin_sym_end] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(425),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(427),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(59)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1435),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(425),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(427),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(60)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1553),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(45),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(45),
    [ts_builtin_sym_end] = ACTIONS(395),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(429),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(431),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(61)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1468),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(72),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(72),
    [ts_builtin_sym_end] = ACTIONS(343),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(433),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(435),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(62)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1468),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(343),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(433),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(435),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(63)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1471),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(73),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(73),
    [ts_builtin_sym_end] = ACTIONS(349),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(437),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(439),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(64)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1471),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(349),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(437),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(439),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(65)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1473),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(355),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(441),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(443),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(66)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1553),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(395),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(429),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(431),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(67)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1481),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(77),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(77),
    [ts_builtin_sym_end] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(445),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(447),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(68)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1483),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(371),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(451),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(69)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1511),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(453),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(455),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(457),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(70)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1513),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(459),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(461),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(463),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(71)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1470),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(66),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(66),
    [ts_builtin_sym_end] = ACTIONS(318),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(465),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(467),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(72)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1544),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(401),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(469),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(471),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(73)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1552),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(407),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(473),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(475),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(74)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1556),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(78),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(78),
    [ts_builtin_sym_end] = ACTIONS(417),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(477),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(479),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(75)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1556),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(417),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(477),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(479),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(76)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1560),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(79),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(79),
    [ts_builtin_sym_end] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(481),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(483),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(77)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1560),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(423),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(481),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(483),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(78)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1597),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(453),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(487),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(79)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1404),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [ts_builtin_sym_end] = ACTIONS(459),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(489),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(491),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(80)] = {
    [aux_sym__block] = STATE(106),
    [sym_block] = STATE(1432),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(69),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(69),
    [ts_builtin_sym_end] = ACTIONS(417),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(419),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(421),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(81)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1677),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(493),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(495),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(82)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1688),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(499),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(83)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1700),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(81),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(81),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(503),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(84)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1673),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(97),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(97),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(505),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(507),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(85)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1700),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(501),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(503),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(86)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1665),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(509),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(511),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(87)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1672),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(515),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(88)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1674),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(90),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(90),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(519),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(89)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1680),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(100),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(100),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(521),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(523),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(90)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1680),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(521),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(523),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(91)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1686),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(101),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(101),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(525),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(527),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(92)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1686),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(525),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(527),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(93)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1658),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(99),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(99),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(529),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(531),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(94)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1659),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(92),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(92),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(533),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(535),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(95)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1670),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(537),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(539),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(96)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1685),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(86),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(86),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(541),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(543),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(97)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1685),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(541),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(543),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(98)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1694),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(95),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(95),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(545),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(547),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(99)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1694),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(545),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(547),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(100)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1691),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(549),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(551),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(101)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1692),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(384),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(384),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(553),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(555),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(102)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1678),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(82),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(82),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(557),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(559),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(103)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1683),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(85),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(85),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(561),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(563),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(104)] = {
    [aux_sym__block] = STATE(108),
    [sym_block] = STATE(1688),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym_arguments_statement] = STATE(87),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_function_definition_repeat1] = STATE(87),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(497),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(306),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(499),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(105)] = {
    [aux_sym__block] = STATE(31),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1283),
    [sym__expression] = STATE(969),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(969),
    [sym_handle_operator] = STATE(969),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1283),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1283),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(969),
    [sym_return_statement] = STATE(1283),
    [sym_continue_statement] = STATE(1283),
    [sym_break_statement] = STATE(1283),
    [sym_if_statement] = STATE(1283),
    [sym_for_statement] = STATE(1283),
    [sym_while_statement] = STATE(1283),
    [sym_switch_statement] = STATE(1283),
    [sym_lambda] = STATE(969),
    [sym_global_operator] = STATE(1283),
    [sym_persistent_operator] = STATE(1283),
    [sym_function_definition] = STATE(1492),
    [sym__function_definition_with_end] = STATE(1264),
    [sym_class_definition] = STATE(1283),
    [sym_try_statement] = STATE(1283),
    [sym_spmd_statement] = STATE(1283),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [aux_sym_source_file_repeat1] = STATE(1492),
    [ts_builtin_sym_end] = ACTIONS(565),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(43),
    [anon_sym_function] = ACTIONS(45),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(106)] = {
    [aux_sym__block] = STATE(107),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [ts_builtin_sym_end] = ACTIONS(324),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(567),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(43),
    [anon_sym_function] = ACTIONS(570),
    [anon_sym_endfunction] = ACTIONS(324),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(107)] = {
    [aux_sym__block] = STATE(107),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [ts_builtin_sym_end] = ACTIONS(211),
    [anon_sym_LPAREN] = ACTIONS(213),
    [anon_sym_PLUS] = ACTIONS(216),
    [anon_sym_DASH] = ACTIONS(216),
    [anon_sym_TILDE] = ACTIONS(219),
    [anon_sym_QMARK] = ACTIONS(222),
    [anon_sym_AT] = ACTIONS(225),
    [anon_sym_LBRACK] = ACTIONS(228),
    [anon_sym_LBRACE] = ACTIONS(231),
    [anon_sym_return] = ACTIONS(234),
    [anon_sym_continue] = ACTIONS(237),
    [anon_sym_break] = ACTIONS(240),
    [anon_sym_if] = ACTIONS(245),
    [anon_sym_end] = ACTIONS(573),
    [anon_sym_for] = ACTIONS(251),
    [anon_sym_parfor] = ACTIONS(254),
    [anon_sym_while] = ACTIONS(257),
    [anon_sym_switch] = ACTIONS(260),
    [anon_sym_global] = ACTIONS(263),
    [anon_sym_persistent] = ACTIONS(266),
    [anon_sym_arguments] = ACTIONS(269),
    [anon_sym_function] = ACTIONS(272),
    [anon_sym_endfunction] = ACTIONS(211),
    [anon_sym_properties] = ACTIONS(269),
    [anon_sym_get] = ACTIONS(269),
    [anon_sym_set] = ACTIONS(269),
    [anon_sym_methods] = ACTIONS(269),
    [anon_sym_events] = ACTIONS(269),
    [anon_sym_enumeration] = ACTIONS(269),
    [anon_sym_classdef] = ACTIONS(275),
    [anon_sym_try] = ACTIONS(278),
    [anon_sym_spmd] = ACTIONS(281),
    [aux_sym_number_token1] = ACTIONS(284),
    [aux_sym_number_token2] = ACTIONS(287),
    [aux_sym_number_token3] = ACTIONS(287),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(290),
    [sym__single_quote_string_start] = ACTIONS(293),
    [sym__double_quote_string_start] = ACTIONS(296),
    [sym__multioutput_variable_start] = ACTIONS(299),
    [sym__external_identifier] = ACTIONS(269),
  },
  [STATE(108)] = {
    [aux_sym__block] = STATE(107),
    [sym_identifier] = STATE(439),
    [sym__statement] = STATE(1285),
    [sym__expression] = STATE(979),
    [sym_parenthesis] = STATE(510),
    [sym__binary_expression] = STATE(993),
    [sym_binary_operator] = STATE(514),
    [sym_unary_operator] = STATE(515),
    [sym_indirect_access] = STATE(1516),
    [sym_field_expression] = STATE(617),
    [sym_not_operator] = STATE(596),
    [sym_metaclass_operator] = STATE(979),
    [sym_handle_operator] = STATE(979),
    [sym_comparison_operator] = STATE(526),
    [sym_boolean_operator] = STATE(526),
    [sym_postfix_operator] = STATE(510),
    [sym_string] = STATE(510),
    [sym_matrix] = STATE(510),
    [sym_cell] = STATE(530),
    [sym_ignored_argument] = STATE(1757),
    [sym_assignment] = STATE(1285),
    [sym_multioutput_variable] = STATE(1757),
    [sym_function_call] = STATE(439),
    [sym_command] = STATE(1285),
    [sym__range_element] = STATE(1721),
    [sym_range] = STATE(979),
    [sym_return_statement] = STATE(1285),
    [sym_continue_statement] = STATE(1285),
    [sym_break_statement] = STATE(1285),
    [sym_if_statement] = STATE(1285),
    [sym_for_statement] = STATE(1285),
    [sym_while_statement] = STATE(1285),
    [sym_switch_statement] = STATE(1285),
    [sym_lambda] = STATE(979),
    [sym_global_operator] = STATE(1285),
    [sym_persistent_operator] = STATE(1285),
    [sym__function_definition_with_end] = STATE(1291),
    [sym_class_definition] = STATE(1285),
    [sym_try_statement] = STATE(1285),
    [sym_spmd_statement] = STATE(1285),
    [sym_number] = STATE(510),
    [sym_end_keyword] = STATE(1463),
    [sym__keywords] = STATE(412),
    [anon_sym_LPAREN] = ACTIONS(7),
    [anon_sym_PLUS] = ACTIONS(9),
    [anon_sym_DASH] = ACTIONS(9),
    [anon_sym_TILDE] = ACTIONS(11),
    [anon_sym_QMARK] = ACTIONS(13),
    [anon_sym_AT] = ACTIONS(15),
    [anon_sym_LBRACK] = ACTIONS(17),
    [anon_sym_LBRACE] = ACTIONS(19),
    [anon_sym_return] = ACTIONS(21),
    [anon_sym_continue] = ACTIONS(23),
    [anon_sym_break] = ACTIONS(25),
    [anon_sym_if] = ACTIONS(27),
    [anon_sym_end] = ACTIONS(567),
    [anon_sym_for] = ACTIONS(31),
    [anon_sym_parfor] = ACTIONS(33),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_switch] = ACTIONS(37),
    [anon_sym_global] = ACTIONS(39),
    [anon_sym_persistent] = ACTIONS(41),
    [anon_sym_arguments] = ACTIONS(43),
    [anon_sym_function] = ACTIONS(308),
    [anon_sym_endfunction] = ACTIONS(324),
    [anon_sym_properties] = ACTIONS(43),
    [anon_sym_get] = ACTIONS(43),
    [anon_sym_set] = ACTIONS(43),
    [anon_sym_methods] = ACTIONS(43),
    [anon_sym_events] = ACTIONS(43),
    [anon_sym_enumeration] = ACTIONS(43),
    [anon_sym_classdef] = ACTIONS(47),
    [anon_sym_try] = ACTIONS(49),
    [anon_sym_spmd] = ACTIONS(51),
    [aux_sym_number_token1] = ACTIONS(53),
    [aux_sym_number_token2] = ACTIONS(55),
    [aux_sym_number_token3] = ACTIONS(55),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(57),
    [sym__single_quote_string_start] = ACTIONS(59),
    [sym__double_quote_string_start] = ACTIONS(61),
    [sym__multioutput_variable_start] = ACTIONS(63),
    [sym__external_identifier] = ACTIONS(43),
  },
  [STATE(109)] = {
    [sym__args] = STATE(129),
    [aux_sym_field_expression_repeat1] = STATE(116),
    [anon_sym_LPAREN] = ACTIONS(576),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_DOT] = ACTIONS(580),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_COLON] = ACTIONS(590),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(110)] = {
    [sym__args] = STATE(129),
    [aux_sym_field_expression_repeat1] = STATE(116),
    [anon_sym_LPAREN] = ACTIONS(576),
    [anon_sym_PLUS] = ACTIONS(595),
    [anon_sym_DOT_PLUS] = ACTIONS(595),
    [anon_sym_DASH] = ACTIONS(595),
    [anon_sym_DOT_DASH] = ACTIONS(595),
    [anon_sym_STAR] = ACTIONS(595),
    [anon_sym_DOT_STAR] = ACTIONS(595),
    [anon_sym_SLASH] = ACTIONS(595),
    [anon_sym_DOT_SLASH] = ACTIONS(595),
    [anon_sym_BSLASH] = ACTIONS(595),
    [anon_sym_DOT_BSLASH] = ACTIONS(595),
    [anon_sym_CARET] = ACTIONS(595),
    [anon_sym_DOT_CARET] = ACTIONS(595),
    [anon_sym_PIPE] = ACTIONS(595),
    [anon_sym_AMP] = ACTIONS(595),
    [anon_sym_DOT] = ACTIONS(580),
    [anon_sym_TILDE] = ACTIONS(595),
    [anon_sym_QMARK] = ACTIONS(595),
    [anon_sym_AT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(595),
    [anon_sym_LT_EQ] = ACTIONS(595),
    [anon_sym_EQ_EQ] = ACTIONS(595),
    [anon_sym_TILDE_EQ] = ACTIONS(595),
    [anon_sym_GT_EQ] = ACTIONS(595),
    [anon_sym_GT] = ACTIONS(595),
    [anon_sym_AMP_AMP] = ACTIONS(595),
    [anon_sym_PIPE_PIPE] = ACTIONS(595),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(595),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_LF] = ACTIONS(595),
    [anon_sym_SEMI] = ACTIONS(595),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_COLON] = ACTIONS(595),
    [anon_sym_return] = ACTIONS(595),
    [anon_sym_continue] = ACTIONS(595),
    [anon_sym_break] = ACTIONS(595),
    [anon_sym_elseif] = ACTIONS(595),
    [anon_sym_else] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_end] = ACTIONS(595),
    [anon_sym_for] = ACTIONS(595),
    [anon_sym_parfor] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(595),
    [anon_sym_switch] = ACTIONS(595),
    [anon_sym_global] = ACTIONS(595),
    [anon_sym_persistent] = ACTIONS(595),
    [anon_sym_arguments] = ACTIONS(595),
    [anon_sym_function] = ACTIONS(595),
    [anon_sym_properties] = ACTIONS(595),
    [anon_sym_get] = ACTIONS(595),
    [anon_sym_set] = ACTIONS(595),
    [anon_sym_methods] = ACTIONS(595),
    [anon_sym_events] = ACTIONS(595),
    [anon_sym_enumeration] = ACTIONS(595),
    [anon_sym_classdef] = ACTIONS(595),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_spmd] = ACTIONS(595),
    [aux_sym_number_token1] = ACTIONS(595),
    [aux_sym_number_token2] = ACTIONS(595),
    [aux_sym_number_token3] = ACTIONS(595),
    [anon_sym_CR] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(597),
    [sym__single_quote_string_start] = ACTIONS(597),
    [sym__double_quote_string_start] = ACTIONS(597),
    [sym__multioutput_variable_start] = ACTIONS(597),
    [sym__external_identifier] = ACTIONS(597),
  },
  [STATE(111)] = {
    [sym__args] = STATE(129),
    [aux_sym_field_expression_repeat1] = STATE(116),
    [anon_sym_LPAREN] = ACTIONS(576),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_DOT] = ACTIONS(580),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_COLON] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(112)] = {
    [sym__args] = STATE(129),
    [aux_sym_field_expression_repeat1] = STATE(116),
    [anon_sym_LPAREN] = ACTIONS(576),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_DOT] = ACTIONS(580),
    [anon_sym_TILDE] = ACTIONS(578),
    [anon_sym_QMARK] = ACTIONS(578),
    [anon_sym_AT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(578),
    [anon_sym_LT_EQ] = ACTIONS(578),
    [anon_sym_EQ_EQ] = ACTIONS(578),
    [anon_sym_TILDE_EQ] = ACTIONS(578),
    [anon_sym_GT_EQ] = ACTIONS(578),
    [anon_sym_GT] = ACTIONS(578),
    [anon_sym_AMP_AMP] = ACTIONS(578),
    [anon_sym_PIPE_PIPE] = ACTIONS(578),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(578),
    [anon_sym_LBRACK] = ACTIONS(578),
    [anon_sym_LF] = ACTIONS(578),
    [anon_sym_SEMI] = ACTIONS(578),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_COLON] = ACTIONS(578),
    [anon_sym_return] = ACTIONS(578),
    [anon_sym_continue] = ACTIONS(578),
    [anon_sym_break] = ACTIONS(578),
    [anon_sym_elseif] = ACTIONS(578),
    [anon_sym_else] = ACTIONS(578),
    [anon_sym_if] = ACTIONS(578),
    [anon_sym_end] = ACTIONS(578),
    [anon_sym_for] = ACTIONS(578),
    [anon_sym_parfor] = ACTIONS(578),
    [anon_sym_while] = ACTIONS(578),
    [anon_sym_switch] = ACTIONS(578),
    [anon_sym_global] = ACTIONS(578),
    [anon_sym_persistent] = ACTIONS(578),
    [anon_sym_arguments] = ACTIONS(578),
    [anon_sym_function] = ACTIONS(578),
    [anon_sym_properties] = ACTIONS(578),
    [anon_sym_get] = ACTIONS(578),
    [anon_sym_set] = ACTIONS(578),
    [anon_sym_methods] = ACTIONS(578),
    [anon_sym_events] = ACTIONS(578),
    [anon_sym_enumeration] = ACTIONS(578),
    [anon_sym_classdef] = ACTIONS(578),
    [anon_sym_try] = ACTIONS(578),
    [anon_sym_spmd] = ACTIONS(578),
    [aux_sym_number_token1] = ACTIONS(578),
    [aux_sym_number_token2] = ACTIONS(578),
    [aux_sym_number_token3] = ACTIONS(578),
    [anon_sym_CR] = ACTIONS(578),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(601),
    [sym__single_quote_string_start] = ACTIONS(601),
    [sym__double_quote_string_start] = ACTIONS(601),
    [sym__multioutput_variable_start] = ACTIONS(601),
    [sym__external_identifier] = ACTIONS(601),
  },
  [STATE(113)] = {
    [sym__args] = STATE(129),
    [aux_sym_field_expression_repeat1] = STATE(116),
    [anon_sym_LPAREN] = ACTIONS(576),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_DOT] = ACTIONS(580),
    [anon_sym_TILDE] = ACTIONS(599),
    [anon_sym_QMARK] = ACTIONS(599),
    [anon_sym_AT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(590),
    [anon_sym_LT_EQ] = ACTIONS(590),
    [anon_sym_EQ_EQ] = ACTIONS(590),
    [anon_sym_TILDE_EQ] = ACTIONS(590),
    [anon_sym_GT_EQ] = ACTIONS(590),
    [anon_sym_GT] = ACTIONS(590),
    [anon_sym_AMP_AMP] = ACTIONS(590),
    [anon_sym_PIPE_PIPE] = ACTIONS(590),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(599),
    [anon_sym_LBRACK] = ACTIONS(599),
    [anon_sym_LF] = ACTIONS(599),
    [anon_sym_SEMI] = ACTIONS(599),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_COLON] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(599),
    [anon_sym_continue] = ACTIONS(599),
    [anon_sym_break] = ACTIONS(599),
    [anon_sym_elseif] = ACTIONS(599),
    [anon_sym_else] = ACTIONS(599),
    [anon_sym_if] = ACTIONS(599),
    [anon_sym_end] = ACTIONS(599),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_parfor] = ACTIONS(599),
    [anon_sym_while] = ACTIONS(599),
    [anon_sym_switch] = ACTIONS(599),
    [anon_sym_global] = ACTIONS(599),
    [anon_sym_persistent] = ACTIONS(599),
    [anon_sym_arguments] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(599),
    [anon_sym_properties] = ACTIONS(599),
    [anon_sym_get] = ACTIONS(599),
    [anon_sym_set] = ACTIONS(599),
    [anon_sym_methods] = ACTIONS(599),
    [anon_sym_events] = ACTIONS(599),
    [anon_sym_enumeration] = ACTIONS(599),
    [anon_sym_classdef] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(599),
    [anon_sym_spmd] = ACTIONS(599),
    [aux_sym_number_token1] = ACTIONS(599),
    [aux_sym_number_token2] = ACTIONS(599),
    [aux_sym_number_token3] = ACTIONS(599),
    [anon_sym_CR] = ACTIONS(599),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(603),
    [sym__single_quote_string_start] = ACTIONS(603),
    [sym__double_quote_string_start] = ACTIONS(603),
    [sym__multioutput_variable_start] = ACTIONS(603),
    [sym__external_identifier] = ACTIONS(603),
  },
  [STATE(114)] = {
    [aux_sym_field_expression_repeat1] = STATE(114),
    [anon_sym_LPAREN] = ACTIONS(605),
    [anon_sym_PLUS] = ACTIONS(605),
    [anon_sym_DOT_PLUS] = ACTIONS(605),
    [anon_sym_DASH] = ACTIONS(605),
    [anon_sym_DOT_DASH] = ACTIONS(605),
    [anon_sym_STAR] = ACTIONS(605),
    [anon_sym_DOT_STAR] = ACTIONS(605),
    [anon_sym_SLASH] = ACTIONS(605),
    [anon_sym_DOT_SLASH] = ACTIONS(605),
    [anon_sym_BSLASH] = ACTIONS(605),
    [anon_sym_DOT_BSLASH] = ACTIONS(605),
    [anon_sym_CARET] = ACTIONS(605),
    [anon_sym_DOT_CARET] = ACTIONS(605),
    [anon_sym_PIPE] = ACTIONS(605),
    [anon_sym_AMP] = ACTIONS(605),
    [anon_sym_DOT] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(605),
    [anon_sym_QMARK] = ACTIONS(605),
    [anon_sym_AT] = ACTIONS(605),
    [anon_sym_LT] = ACTIONS(605),
    [anon_sym_LT_EQ] = ACTIONS(605),
    [anon_sym_EQ_EQ] = ACTIONS(605),
    [anon_sym_TILDE_EQ] = ACTIONS(605),
    [anon_sym_GT_EQ] = ACTIONS(605),
    [anon_sym_GT] = ACTIONS(605),
    [anon_sym_AMP_AMP] = ACTIONS(605),
    [anon_sym_PIPE_PIPE] = ACTIONS(605),
    [anon_sym_DOT_SQUOTE] = ACTIONS(605),
    [anon_sym_SQUOTE] = ACTIONS(605),
    [anon_sym_COMMA] = ACTIONS(605),
    [anon_sym_LBRACK] = ACTIONS(605),
    [anon_sym_LF] = ACTIONS(605),
    [anon_sym_SEMI] = ACTIONS(605),
    [anon_sym_LBRACE] = ACTIONS(605),
    [anon_sym_COLON] = ACTIONS(605),
    [anon_sym_return] = ACTIONS(605),
    [anon_sym_continue] = ACTIONS(605),
    [anon_sym_break] = ACTIONS(605),
    [anon_sym_elseif] = ACTIONS(605),
    [anon_sym_else] = ACTIONS(605),
    [anon_sym_if] = ACTIONS(605),
    [anon_sym_end] = ACTIONS(605),
    [anon_sym_for] = ACTIONS(605),
    [anon_sym_parfor] = ACTIONS(605),
    [anon_sym_while] = ACTIONS(605),
    [anon_sym_switch] = ACTIONS(605),
    [anon_sym_global] = ACTIONS(605),
    [anon_sym_persistent] = ACTIONS(605),
    [anon_sym_arguments] = ACTIONS(605),
    [anon_sym_function] = ACTIONS(605),
    [anon_sym_properties] = ACTIONS(605),
    [anon_sym_get] = ACTIONS(605),
    [anon_sym_set] = ACTIONS(605),
    [anon_sym_methods] = ACTIONS(605),
    [anon_sym_events] = ACTIONS(605),
    [anon_sym_enumeration] = ACTIONS(605),
    [anon_sym_classdef] = ACTIONS(605),
    [anon_sym_try] = ACTIONS(605),
    [anon_sym_spmd] = ACTIONS(605),
    [aux_sym_number_token1] = ACTIONS(605),
    [aux_sym_number_token2] = ACTIONS(605),
    [aux_sym_number_token3] = ACTIONS(605),
    [anon_sym_CR] = ACTIONS(605),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(610),
    [sym__single_quote_string_start] = ACTIONS(610),
    [sym__double_quote_string_start] = ACTIONS(610),
    [sym__multioutput_variable_start] = ACTIONS(610),
    [sym__external_identifier] = ACTIONS(610),
  },
  [STATE(115)] = {
    [sym__args] = STATE(129),
    [anon_sym_LPAREN] = ACTIONS(576),
    [anon_sym_PLUS] = ACTIONS(612),
    [anon_sym_DOT_PLUS] = ACTIONS(612),
    [anon_sym_DASH] = ACTIONS(612),
    [anon_sym_DOT_DASH] = ACTIONS(612),
    [anon_sym_STAR] = ACTIONS(612),
    [anon_sym_DOT_STAR] = ACTIONS(612),
    [anon_sym_SLASH] = ACTIONS(612),
    [anon_sym_DOT_SLASH] = ACTIONS(612),
    [anon_sym_BSLASH] = ACTIONS(612),
    [anon_sym_DOT_BSLASH] = ACTIONS(612),
    [anon_sym_CARET] = ACTIONS(612),
    [anon_sym_DOT_CARET] = ACTIONS(612),
    [anon_sym_PIPE] = ACTIONS(612),
    [anon_sym_AMP] = ACTIONS(612),
    [anon_sym_DOT] = ACTIONS(612),
    [anon_sym_TILDE] = ACTIONS(612),
    [anon_sym_QMARK] = ACTIONS(612),
    [anon_sym_AT] = ACTIONS(584),
    [anon_sym_LT] = ACTIONS(612),
    [anon_sym_LT_EQ] = ACTIONS(612),
    [anon_sym_EQ_EQ] = ACTIONS(612),
    [anon_sym_TILDE_EQ] = ACTIONS(612),
    [anon_sym_GT_EQ] = ACTIONS(612),
    [anon_sym_GT] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(612),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_DOT_SQUOTE] = ACTIONS(612),
    [anon_sym_SQUOTE] = ACTIONS(612),
    [anon_sym_COMMA] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(612),
    [anon_sym_LF] = ACTIONS(612),
    [anon_sym_SEMI] = ACTIONS(612),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_COLON] = ACTIONS(612),
    [anon_sym_return] = ACTIONS(612),
    [anon_sym_continue] = ACTIONS(612),
    [anon_sym_break] = ACTIONS(612),
    [anon_sym_elseif] = ACTIONS(612),
    [anon_sym_else] = ACTIONS(612),
    [anon_sym_if] = ACTIONS(612),
    [anon_sym_end] = ACTIONS(612),
    [anon_sym_for] = ACTIONS(612),
    [anon_sym_parfor] = ACTIONS(612),
    [anon_sym_while] = ACTIONS(612),
    [anon_sym_switch] = ACTIONS(612),
    [anon_sym_global] = ACTIONS(612),
    [anon_sym_persistent] = ACTIONS(612),
    [anon_sym_arguments] = ACTIONS(612),
    [anon_sym_function] = ACTIONS(612),
    [anon_sym_properties] = ACTIONS(612),
    [anon_sym_get] = ACTIONS(612),
    [anon_sym_set] = ACTIONS(612),
    [anon_sym_methods] = ACTIONS(612),
    [anon_sym_events] = ACTIONS(612),
    [anon_sym_enumeration] = ACTIONS(612),
    [anon_sym_classdef] = ACTIONS(612),
    [anon_sym_try] = ACTIONS(612),
    [anon_sym_spmd] = ACTIONS(612),
    [aux_sym_number_token1] = ACTIONS(612),
    [aux_sym_number_token2] = ACTIONS(612),
    [aux_sym_number_token3] = ACTIONS(612),
    [anon_sym_CR] = ACTIONS(612),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(614),
    [sym__single_quote_string_start] = ACTIONS(614),
    [sym__double_quote_string_start] = ACTIONS(614),
    [sym__multioutput_variable_start] = ACTIONS(614),
    [sym__external_identifier] = ACTIONS(614),
  },
  [STATE(116)] = {
    [aux_sym_field_expression_repeat1] = STATE(114),
    [anon_sym_LPAREN] = ACTIONS(616),
    [anon_sym_PLUS] = ACTIONS(616),
    [anon_sym_DOT_PLUS] = ACTIONS(616),
    [anon_sym_DASH] = ACTIONS(616),
    [anon_sym_DOT_DASH] = ACTIONS(616),
    [anon_sym_STAR] = ACTIONS(616),
    [anon_sym_DOT_STAR] = ACTIONS(616),
    [anon_sym_SLASH] = ACTIONS(616),
    [anon_sym_DOT_SLASH] = ACTIONS(616),
    [anon_sym_BSLASH] = ACTIONS(616),
    [anon_sym_DOT_BSLASH] = ACTIONS(616),
    [anon_sym_CARET] = ACTIONS(616),
    [anon_sym_DOT_CARET] = ACTIONS(616),
    [anon_sym_PIPE] = ACTIONS(616),
    [anon_sym_AMP] = ACTIONS(616),
    [anon_sym_DOT] = ACTIONS(580),
    [anon_sym_TILDE] = ACTIONS(616),
    [anon_sym_QMARK] = ACTIONS(616),
    [anon_sym_AT] = ACTIONS(616),
    [anon_sym_LT] = ACTIONS(616),
    [anon_sym_LT_EQ] = ACTIONS(616),
    [anon_sym_EQ_EQ] = ACTIONS(616),
    [anon_sym_TILDE_EQ] = ACTIONS(616),
    [anon_sym_GT_EQ] = ACTIONS(616),
    [anon_sym_GT] = ACTIONS(616),
    [anon_sym_AMP_AMP] = ACTIONS(616),
    [anon_sym_PIPE_PIPE] = ACTIONS(616),
    [anon_sym_DOT_SQUOTE] = ACTIONS(616),
    [anon_sym_SQUOTE] = ACTIONS(616),
    [anon_sym_COMMA] = ACTIONS(616),
    [anon_sym_LBRACK] = ACTIONS(616),
    [anon_sym_LF] = ACTIONS(616),
    [anon_sym_SEMI] = ACTIONS(616),
    [anon_sym_LBRACE] = ACTIONS(616),
    [anon_sym_COLON] = ACTIONS(616),
    [anon_sym_return] = ACTIONS(616),
    [anon_sym_continue] = ACTIONS(616),
    [anon_sym_break] = ACTIONS(616),
    [anon_sym_elseif] = ACTIONS(616),
    [anon_sym_else] = ACTIONS(616),
    [anon_sym_if] = ACTIONS(616),
    [anon_sym_end] = ACTIONS(616),
    [anon_sym_for] = ACTIONS(616),
    [anon_sym_parfor] = ACTIONS(616),
    [anon_sym_while] = ACTIONS(616),
    [anon_sym_switch] = ACTIONS(616),
    [anon_sym_global] = ACTIONS(616),
    [anon_sym_persistent] = ACTIONS(616),
    [anon_sym_arguments] = ACTIONS(616),
    [anon_sym_function] = ACTIONS(616),
    [anon_sym_properties] = ACTIONS(616),
    [anon_sym_get] = ACTIONS(616),
    [anon_sym_set] = ACTIONS(616),
    [anon_sym_methods] = ACTIONS(616),
    [anon_sym_events] = ACTIONS(616),
    [anon_sym_enumeration] = ACTIONS(616),
    [anon_sym_classdef] = ACTIONS(616),
    [anon_sym_try] = ACTIONS(616),
    [anon_sym_spmd] = ACTIONS(616),
    [aux_sym_number_token1] = ACTIONS(616),
    [aux_sym_number_token2] = ACTIONS(616),
    [aux_sym_number_token3] = ACTIONS(616),
    [anon_sym_CR] = ACTIONS(616),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(618),
    [sym__single_quote_string_start] = ACTIONS(618),
    [sym__double_quote_string_start] = ACTIONS(618),
    [sym__multioutput_variable_start] = ACTIONS(618),
    [sym__external_identifier] = ACTIONS(618),
  },
  [STATE(117)] = {
    [sym__args] = STATE(134),
    [anon_sym_LPAREN] = ACTIONS(576),
    [anon_sym_PLUS] = ACTIONS(620),
    [anon_sym_DOT_PLUS] = ACTIONS(620),
    [anon_sym_DASH] = ACTIONS(620),
    [anon_sym_DOT_DASH] = ACTIONS(620),
    [anon_sym_STAR] = ACTIONS(620),
    [anon_sym_DOT_STAR] = ACTIONS(620),
    [anon_sym_SLASH] = ACTIONS(620),
    [anon_sym_DOT_SLASH] = ACTIONS(620),
    [anon_sym_BSLASH] = ACTIONS(620),
    [anon_sym_DOT_BSLASH] = ACTIONS(620),
    [anon_sym_CARET] = ACTIONS(620),
    [anon_sym_DOT_CARET] = ACTIONS(620),
    [anon_sym_PIPE] = ACTIONS(620),
    [anon_sym_AMP] = ACTIONS(620),
    [anon_sym_DOT] = ACTIONS(620),
    [anon_sym_TILDE] = ACTIONS(620),
    [anon_sym_QMARK] = ACTIONS(620),
    [anon_sym_AT] = ACTIONS(620),
    [anon_sym_LT] = ACTIONS(620),
    [anon_sym_LT_EQ] = ACTIONS(620),
    [anon_sym_EQ_EQ] = ACTIONS(620),
    [anon_sym_TILDE_EQ] = ACTIONS(620),
    [anon_sym_GT_EQ] = ACTIONS(620),
    [anon_sym_GT] = ACTIONS(620),
    [anon_sym_AMP_AMP] = ACTIONS(620),
    [anon_sym_PIPE_PIPE] = ACTIONS(620),
    [anon_sym_DOT_SQUOTE] = ACTIONS(620),
    [anon_sym_SQUOTE] = ACTIONS(620),
    [anon_sym_COMMA] = ACTIONS(620),
    [anon_sym_LBRACK] = ACTIONS(620),
    [anon_sym_LF] = ACTIONS(620),
    [anon_sym_SEMI] = ACTIONS(620),
    [anon_sym_LBRACE] = ACTIONS(588),
    [anon_sym_COLON] = ACTIONS(620),
    [anon_sym_return] = ACTIONS(620),
    [anon_sym_continue] = ACTIONS(620),
    [anon_sym_break] = ACTIONS(620),
    [anon_sym_elseif] = ACTIONS(620),
    [anon_sym_else] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(620),
    [anon_sym_end] = ACTIONS(620),
    [anon_sym_for] = ACTIONS(620),
    [anon_sym_parfor] = ACTIONS(620),
    [anon_sym_while] = ACTIONS(620),
    [anon_sym_switch] = ACTIONS(620),
    [anon_sym_global] = ACTIONS(620),
    [anon_sym_persistent] = ACTIONS(620),
    [anon_sym_arguments] = ACTIONS(620),
    [anon_sym_function] = ACTIONS(620),
    [anon_sym_properties] = ACTIONS(620),
    [anon_sym_get] = ACTIONS(620),
    [anon_sym_set] = ACTIONS(620),
    [anon_sym_methods] = ACTIONS(620),
    [anon_sym_events] = ACTIONS(620),
    [anon_sym_enumeration] = ACTIONS(620),
    [anon_sym_classdef] = ACTIONS(620),
    [anon_sym_try] = ACTIONS(620),
    [anon_sym_spmd] = ACTIONS(620),
    [aux_sym_number_token1] = ACTIONS(620),
    [aux_sym_number_token2] = ACTIONS(620),
    [aux_sym_number_token3] = ACTIONS(620),
    [anon_sym_CR] = ACTIONS(620),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(622),
    [sym__single_quote_string_start] = ACTIONS(622),
    [sym__double_quote_string_start] = ACTIONS(622),
    [sym__multioutput_variable_start] = ACTIONS(622),
    [sym__external_identifier] = ACTIONS(622),
  },
  [STATE(118)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(118),
    [anon_sym_LPAREN] = ACTIONS(624),
    [anon_sym_PLUS] = ACTIONS(624),
    [anon_sym_DOT_PLUS] = ACTIONS(624),
    [anon_sym_DASH] = ACTIONS(624),
    [anon_sym_DOT_DASH] = ACTIONS(624),
    [anon_sym_STAR] = ACTIONS(624),
    [anon_sym_DOT_STAR] = ACTIONS(624),
    [anon_sym_SLASH] = ACTIONS(624),
    [anon_sym_DOT_SLASH] = ACTIONS(624),
    [anon_sym_BSLASH] = ACTIONS(624),
    [anon_sym_DOT_BSLASH] = ACTIONS(624),
    [anon_sym_CARET] = ACTIONS(624),
    [anon_sym_DOT_CARET] = ACTIONS(624),
    [anon_sym_PIPE] = ACTIONS(624),
    [anon_sym_AMP] = ACTIONS(624),
    [anon_sym_DOT] = ACTIONS(626),
    [anon_sym_TILDE] = ACTIONS(624),
    [anon_sym_QMARK] = ACTIONS(624),
    [anon_sym_AT] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_EQ_EQ] = ACTIONS(624),
    [anon_sym_TILDE_EQ] = ACTIONS(624),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_GT] = ACTIONS(624),
    [anon_sym_AMP_AMP] = ACTIONS(624),
    [anon_sym_PIPE_PIPE] = ACTIONS(624),
    [anon_sym_DOT_SQUOTE] = ACTIONS(624),
    [anon_sym_SQUOTE] = ACTIONS(624),
    [anon_sym_COMMA] = ACTIONS(624),
    [anon_sym_LBRACK] = ACTIONS(624),
    [anon_sym_LF] = ACTIONS(624),
    [anon_sym_SEMI] = ACTIONS(624),
    [anon_sym_LBRACE] = ACTIONS(624),
    [anon_sym_COLON] = ACTIONS(624),
    [anon_sym_return] = ACTIONS(624),
    [anon_sym_continue] = ACTIONS(624),
    [anon_sym_break] = ACTIONS(624),
    [anon_sym_elseif] = ACTIONS(624),
    [anon_sym_else] = ACTIONS(624),
    [anon_sym_if] = ACTIONS(624),
    [anon_sym_end] = ACTIONS(624),
    [anon_sym_for] = ACTIONS(624),
    [anon_sym_parfor] = ACTIONS(624),
    [anon_sym_while] = ACTIONS(624),
    [anon_sym_switch] = ACTIONS(624),
    [anon_sym_global] = ACTIONS(624),
    [anon_sym_persistent] = ACTIONS(624),
    [anon_sym_arguments] = ACTIONS(624),
    [anon_sym_function] = ACTIONS(624),
    [anon_sym_properties] = ACTIONS(624),
    [anon_sym_get] = ACTIONS(624),
    [anon_sym_set] = ACTIONS(624),
    [anon_sym_methods] = ACTIONS(624),
    [anon_sym_events] = ACTIONS(624),
    [anon_sym_enumeration] = ACTIONS(624),
    [anon_sym_classdef] = ACTIONS(624),
    [anon_sym_try] = ACTIONS(624),
    [anon_sym_spmd] = ACTIONS(624),
    [aux_sym_number_token1] = ACTIONS(624),
    [aux_sym_number_token2] = ACTIONS(624),
    [aux_sym_number_token3] = ACTIONS(624),
    [anon_sym_CR] = ACTIONS(624),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(629),
    [sym__single_quote_string_start] = ACTIONS(629),
    [sym__double_quote_string_start] = ACTIONS(629),
    [sym__multioutput_variable_start] = ACTIONS(629),
    [sym__external_identifier] = ACTIONS(629),
  },
  [STATE(119)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(118),
    [anon_sym_LPAREN] = ACTIONS(631),
    [anon_sym_PLUS] = ACTIONS(631),
    [anon_sym_DOT_PLUS] = ACTIONS(631),
    [anon_sym_DASH] = ACTIONS(631),
    [anon_sym_DOT_DASH] = ACTIONS(631),
    [anon_sym_STAR] = ACTIONS(631),
    [anon_sym_DOT_STAR] = ACTIONS(631),
    [anon_sym_SLASH] = ACTIONS(631),
    [anon_sym_DOT_SLASH] = ACTIONS(631),
    [anon_sym_BSLASH] = ACTIONS(631),
    [anon_sym_DOT_BSLASH] = ACTIONS(631),
    [anon_sym_CARET] = ACTIONS(631),
    [anon_sym_DOT_CARET] = ACTIONS(631),
    [anon_sym_PIPE] = ACTIONS(631),
    [anon_sym_AMP] = ACTIONS(631),
    [anon_sym_DOT] = ACTIONS(633),
    [anon_sym_TILDE] = ACTIONS(631),
    [anon_sym_QMARK] = ACTIONS(631),
    [anon_sym_AT] = ACTIONS(631),
    [anon_sym_LT] = ACTIONS(631),
    [anon_sym_LT_EQ] = ACTIONS(631),
    [anon_sym_EQ_EQ] = ACTIONS(631),
    [anon_sym_TILDE_EQ] = ACTIONS(631),
    [anon_sym_GT_EQ] = ACTIONS(631),
    [anon_sym_GT] = ACTIONS(631),
    [anon_sym_AMP_AMP] = ACTIONS(631),
    [anon_sym_PIPE_PIPE] = ACTIONS(631),
    [anon_sym_DOT_SQUOTE] = ACTIONS(631),
    [anon_sym_SQUOTE] = ACTIONS(631),
    [anon_sym_COMMA] = ACTIONS(631),
    [anon_sym_LBRACK] = ACTIONS(631),
    [anon_sym_LF] = ACTIONS(631),
    [anon_sym_SEMI] = ACTIONS(631),
    [anon_sym_LBRACE] = ACTIONS(631),
    [anon_sym_COLON] = ACTIONS(631),
    [anon_sym_return] = ACTIONS(631),
    [anon_sym_continue] = ACTIONS(631),
    [anon_sym_break] = ACTIONS(631),
    [anon_sym_elseif] = ACTIONS(631),
    [anon_sym_else] = ACTIONS(631),
    [anon_sym_if] = ACTIONS(631),
    [anon_sym_end] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(631),
    [anon_sym_parfor] = ACTIONS(631),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_switch] = ACTIONS(631),
    [anon_sym_global] = ACTIONS(631),
    [anon_sym_persistent] = ACTIONS(631),
    [anon_sym_arguments] = ACTIONS(631),
    [anon_sym_function] = ACTIONS(631),
    [anon_sym_properties] = ACTIONS(631),
    [anon_sym_get] = ACTIONS(631),
    [anon_sym_set] = ACTIONS(631),
    [anon_sym_methods] = ACTIONS(631),
    [anon_sym_events] = ACTIONS(631),
    [anon_sym_enumeration] = ACTIONS(631),
    [anon_sym_classdef] = ACTIONS(631),
    [anon_sym_try] = ACTIONS(631),
    [anon_sym_spmd] = ACTIONS(631),
    [aux_sym_number_token1] = ACTIONS(631),
    [aux_sym_number_token2] = ACTIONS(631),
    [aux_sym_number_token3] = ACTIONS(631),
    [anon_sym_CR] = ACTIONS(631),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(635),
    [sym__single_quote_string_start] = ACTIONS(635),
    [sym__double_quote_string_start] = ACTIONS(635),
    [sym__multioutput_variable_start] = ACTIONS(635),
    [sym__external_identifier] = ACTIONS(635),
  },
  [STATE(120)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(119),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_PLUS] = ACTIONS(637),
    [anon_sym_DOT_PLUS] = ACTIONS(637),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_DOT_DASH] = ACTIONS(637),
    [anon_sym_STAR] = ACTIONS(637),
    [anon_sym_DOT_STAR] = ACTIONS(637),
    [anon_sym_SLASH] = ACTIONS(637),
    [anon_sym_DOT_SLASH] = ACTIONS(637),
    [anon_sym_BSLASH] = ACTIONS(637),
    [anon_sym_DOT_BSLASH] = ACTIONS(637),
    [anon_sym_CARET] = ACTIONS(637),
    [anon_sym_DOT_CARET] = ACTIONS(637),
    [anon_sym_PIPE] = ACTIONS(637),
    [anon_sym_AMP] = ACTIONS(637),
    [anon_sym_DOT] = ACTIONS(633),
    [anon_sym_TILDE] = ACTIONS(637),
    [anon_sym_QMARK] = ACTIONS(637),
    [anon_sym_AT] = ACTIONS(637),
    [anon_sym_LT] = ACTIONS(637),
    [anon_sym_LT_EQ] = ACTIONS(637),
    [anon_sym_EQ_EQ] = ACTIONS(637),
    [anon_sym_TILDE_EQ] = ACTIONS(637),
    [anon_sym_GT_EQ] = ACTIONS(637),
    [anon_sym_GT] = ACTIONS(637),
    [anon_sym_AMP_AMP] = ACTIONS(637),
    [anon_sym_PIPE_PIPE] = ACTIONS(637),
    [anon_sym_DOT_SQUOTE] = ACTIONS(637),
    [anon_sym_SQUOTE] = ACTIONS(637),
    [anon_sym_COMMA] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(637),
    [anon_sym_LF] = ACTIONS(637),
    [anon_sym_SEMI] = ACTIONS(637),
    [anon_sym_LBRACE] = ACTIONS(637),
    [anon_sym_COLON] = ACTIONS(637),
    [anon_sym_return] = ACTIONS(637),
    [anon_sym_continue] = ACTIONS(637),
    [anon_sym_break] = ACTIONS(637),
    [anon_sym_elseif] = ACTIONS(637),
    [anon_sym_else] = ACTIONS(637),
    [anon_sym_if] = ACTIONS(637),
    [anon_sym_end] = ACTIONS(637),
    [anon_sym_for] = ACTIONS(637),
    [anon_sym_parfor] = ACTIONS(637),
    [anon_sym_while] = ACTIONS(637),
    [anon_sym_switch] = ACTIONS(637),
    [anon_sym_global] = ACTIONS(637),
    [anon_sym_persistent] = ACTIONS(637),
    [anon_sym_arguments] = ACTIONS(637),
    [anon_sym_function] = ACTIONS(637),
    [anon_sym_properties] = ACTIONS(637),
    [anon_sym_get] = ACTIONS(637),
    [anon_sym_set] = ACTIONS(637),
    [anon_sym_methods] = ACTIONS(637),
    [anon_sym_events] = ACTIONS(637),
    [anon_sym_enumeration] = ACTIONS(637),
    [anon_sym_classdef] = ACTIONS(637),
    [anon_sym_try] = ACTIONS(637),
    [anon_sym_spmd] = ACTIONS(637),
    [aux_sym_number_token1] = ACTIONS(637),
    [aux_sym_number_token2] = ACTIONS(637),
    [aux_sym_number_token3] = ACTIONS(637),
    [anon_sym_CR] = ACTIONS(637),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(639),
    [sym__single_quote_string_start] = ACTIONS(639),
    [sym__double_quote_string_start] = ACTIONS(639),
    [sym__multioutput_variable_start] = ACTIONS(639),
    [sym__external_identifier] = ACTIONS(639),
  },
  [STATE(121)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(122),
    [anon_sym_LPAREN] = ACTIONS(641),
    [anon_sym_PLUS] = ACTIONS(641),
    [anon_sym_DOT_PLUS] = ACTIONS(641),
    [anon_sym_DASH] = ACTIONS(641),
    [anon_sym_DOT_DASH] = ACTIONS(641),
    [anon_sym_STAR] = ACTIONS(641),
    [anon_sym_DOT_STAR] = ACTIONS(641),
    [anon_sym_SLASH] = ACTIONS(641),
    [anon_sym_DOT_SLASH] = ACTIONS(641),
    [anon_sym_BSLASH] = ACTIONS(641),
    [anon_sym_DOT_BSLASH] = ACTIONS(641),
    [anon_sym_CARET] = ACTIONS(641),
    [anon_sym_DOT_CARET] = ACTIONS(641),
    [anon_sym_PIPE] = ACTIONS(641),
    [anon_sym_AMP] = ACTIONS(641),
    [anon_sym_DOT] = ACTIONS(643),
    [anon_sym_TILDE] = ACTIONS(641),
    [anon_sym_QMARK] = ACTIONS(641),
    [anon_sym_AT] = ACTIONS(641),
    [anon_sym_LT] = ACTIONS(641),
    [anon_sym_LT_EQ] = ACTIONS(641),
    [anon_sym_EQ_EQ] = ACTIONS(641),
    [anon_sym_TILDE_EQ] = ACTIONS(641),
    [anon_sym_GT_EQ] = ACTIONS(641),
    [anon_sym_GT] = ACTIONS(641),
    [anon_sym_AMP_AMP] = ACTIONS(641),
    [anon_sym_PIPE_PIPE] = ACTIONS(641),
    [anon_sym_DOT_SQUOTE] = ACTIONS(641),
    [anon_sym_SQUOTE] = ACTIONS(641),
    [anon_sym_COMMA] = ACTIONS(641),
    [anon_sym_LBRACK] = ACTIONS(641),
    [anon_sym_LF] = ACTIONS(641),
    [anon_sym_SEMI] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(641),
    [anon_sym_COLON] = ACTIONS(641),
    [anon_sym_return] = ACTIONS(641),
    [anon_sym_continue] = ACTIONS(641),
    [anon_sym_break] = ACTIONS(641),
    [anon_sym_elseif] = ACTIONS(641),
    [anon_sym_else] = ACTIONS(641),
    [anon_sym_if] = ACTIONS(641),
    [anon_sym_end] = ACTIONS(641),
    [anon_sym_for] = ACTIONS(641),
    [anon_sym_parfor] = ACTIONS(641),
    [anon_sym_while] = ACTIONS(641),
    [anon_sym_switch] = ACTIONS(641),
    [anon_sym_global] = ACTIONS(641),
    [anon_sym_persistent] = ACTIONS(641),
    [anon_sym_arguments] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(641),
    [anon_sym_properties] = ACTIONS(641),
    [anon_sym_get] = ACTIONS(641),
    [anon_sym_set] = ACTIONS(641),
    [anon_sym_methods] = ACTIONS(641),
    [anon_sym_events] = ACTIONS(641),
    [anon_sym_enumeration] = ACTIONS(641),
    [anon_sym_classdef] = ACTIONS(641),
    [anon_sym_try] = ACTIONS(641),
    [anon_sym_spmd] = ACTIONS(641),
    [aux_sym_number_token1] = ACTIONS(641),
    [aux_sym_number_token2] = ACTIONS(641),
    [aux_sym_number_token3] = ACTIONS(641),
    [anon_sym_CR] = ACTIONS(641),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(645),
    [sym__single_quote_string_start] = ACTIONS(645),
    [sym__double_quote_string_start] = ACTIONS(645),
    [sym__multioutput_variable_start] = ACTIONS(645),
    [sym__external_identifier] = ACTIONS(645),
  },
  [STATE(122)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(118),
    [anon_sym_LPAREN] = ACTIONS(647),
    [anon_sym_PLUS] = ACTIONS(647),
    [anon_sym_DOT_PLUS] = ACTIONS(647),
    [anon_sym_DASH] = ACTIONS(647),
    [anon_sym_DOT_DASH] = ACTIONS(647),
    [anon_sym_STAR] = ACTIONS(647),
    [anon_sym_DOT_STAR] = ACTIONS(647),
    [anon_sym_SLASH] = ACTIONS(647),
    [anon_sym_DOT_SLASH] = ACTIONS(647),
    [anon_sym_BSLASH] = ACTIONS(647),
    [anon_sym_DOT_BSLASH] = ACTIONS(647),
    [anon_sym_CARET] = ACTIONS(647),
    [anon_sym_DOT_CARET] = ACTIONS(647),
    [anon_sym_PIPE] = ACTIONS(647),
    [anon_sym_AMP] = ACTIONS(647),
    [anon_sym_DOT] = ACTIONS(649),
    [anon_sym_TILDE] = ACTIONS(647),
    [anon_sym_QMARK] = ACTIONS(647),
    [anon_sym_AT] = ACTIONS(647),
    [anon_sym_LT] = ACTIONS(647),
    [anon_sym_LT_EQ] = ACTIONS(647),
    [anon_sym_EQ_EQ] = ACTIONS(647),
    [anon_sym_TILDE_EQ] = ACTIONS(647),
    [anon_sym_GT_EQ] = ACTIONS(647),
    [anon_sym_GT] = ACTIONS(647),
    [anon_sym_AMP_AMP] = ACTIONS(647),
    [anon_sym_PIPE_PIPE] = ACTIONS(647),
    [anon_sym_DOT_SQUOTE] = ACTIONS(647),
    [anon_sym_SQUOTE] = ACTIONS(647),
    [anon_sym_COMMA] = ACTIONS(647),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_LF] = ACTIONS(647),
    [anon_sym_SEMI] = ACTIONS(647),
    [anon_sym_LBRACE] = ACTIONS(647),
    [anon_sym_COLON] = ACTIONS(647),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_continue] = ACTIONS(647),
    [anon_sym_break] = ACTIONS(647),
    [anon_sym_elseif] = ACTIONS(647),
    [anon_sym_else] = ACTIONS(647),
    [anon_sym_if] = ACTIONS(647),
    [anon_sym_end] = ACTIONS(647),
    [anon_sym_for] = ACTIONS(647),
    [anon_sym_parfor] = ACTIONS(647),
    [anon_sym_while] = ACTIONS(647),
    [anon_sym_switch] = ACTIONS(647),
    [anon_sym_global] = ACTIONS(647),
    [anon_sym_persistent] = ACTIONS(647),
    [anon_sym_arguments] = ACTIONS(647),
    [anon_sym_function] = ACTIONS(647),
    [anon_sym_properties] = ACTIONS(647),
    [anon_sym_get] = ACTIONS(647),
    [anon_sym_set] = ACTIONS(647),
    [anon_sym_methods] = ACTIONS(647),
    [anon_sym_events] = ACTIONS(647),
    [anon_sym_enumeration] = ACTIONS(647),
    [anon_sym_classdef] = ACTIONS(647),
    [anon_sym_try] = ACTIONS(647),
    [anon_sym_spmd] = ACTIONS(647),
    [aux_sym_number_token1] = ACTIONS(647),
    [aux_sym_number_token2] = ACTIONS(647),
    [aux_sym_number_token3] = ACTIONS(647),
    [anon_sym_CR] = ACTIONS(647),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(651),
    [sym__single_quote_string_start] = ACTIONS(651),
    [sym__double_quote_string_start] = ACTIONS(651),
    [sym__multioutput_variable_start] = ACTIONS(651),
    [sym__external_identifier] = ACTIONS(651),
  },
  [STATE(123)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(118),
    [anon_sym_LPAREN] = ACTIONS(653),
    [anon_sym_PLUS] = ACTIONS(653),
    [anon_sym_DOT_PLUS] = ACTIONS(653),
    [anon_sym_DASH] = ACTIONS(653),
    [anon_sym_DOT_DASH] = ACTIONS(653),
    [anon_sym_STAR] = ACTIONS(653),
    [anon_sym_DOT_STAR] = ACTIONS(653),
    [anon_sym_SLASH] = ACTIONS(653),
    [anon_sym_DOT_SLASH] = ACTIONS(653),
    [anon_sym_BSLASH] = ACTIONS(653),
    [anon_sym_DOT_BSLASH] = ACTIONS(653),
    [anon_sym_CARET] = ACTIONS(653),
    [anon_sym_DOT_CARET] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(653),
    [anon_sym_AMP] = ACTIONS(653),
    [anon_sym_DOT] = ACTIONS(633),
    [anon_sym_TILDE] = ACTIONS(653),
    [anon_sym_QMARK] = ACTIONS(653),
    [anon_sym_AT] = ACTIONS(653),
    [anon_sym_LT] = ACTIONS(653),
    [anon_sym_LT_EQ] = ACTIONS(653),
    [anon_sym_EQ_EQ] = ACTIONS(653),
    [anon_sym_TILDE_EQ] = ACTIONS(653),
    [anon_sym_GT_EQ] = ACTIONS(653),
    [anon_sym_GT] = ACTIONS(653),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE_PIPE] = ACTIONS(653),
    [anon_sym_DOT_SQUOTE] = ACTIONS(653),
    [anon_sym_SQUOTE] = ACTIONS(653),
    [anon_sym_COMMA] = ACTIONS(653),
    [anon_sym_LBRACK] = ACTIONS(653),
    [anon_sym_LF] = ACTIONS(653),
    [anon_sym_SEMI] = ACTIONS(653),
    [anon_sym_LBRACE] = ACTIONS(653),
    [anon_sym_COLON] = ACTIONS(653),
    [anon_sym_return] = ACTIONS(653),
    [anon_sym_continue] = ACTIONS(653),
    [anon_sym_break] = ACTIONS(653),
    [anon_sym_elseif] = ACTIONS(653),
    [anon_sym_else] = ACTIONS(653),
    [anon_sym_if] = ACTIONS(653),
    [anon_sym_end] = ACTIONS(653),
    [anon_sym_for] = ACTIONS(653),
    [anon_sym_parfor] = ACTIONS(653),
    [anon_sym_while] = ACTIONS(653),
    [anon_sym_switch] = ACTIONS(653),
    [anon_sym_global] = ACTIONS(653),
    [anon_sym_persistent] = ACTIONS(653),
    [anon_sym_arguments] = ACTIONS(653),
    [anon_sym_function] = ACTIONS(653),
    [anon_sym_properties] = ACTIONS(653),
    [anon_sym_get] = ACTIONS(653),
    [anon_sym_set] = ACTIONS(653),
    [anon_sym_methods] = ACTIONS(653),
    [anon_sym_events] = ACTIONS(653),
    [anon_sym_enumeration] = ACTIONS(653),
    [anon_sym_classdef] = ACTIONS(653),
    [anon_sym_try] = ACTIONS(653),
    [anon_sym_spmd] = ACTIONS(653),
    [aux_sym_number_token1] = ACTIONS(653),
    [aux_sym_number_token2] = ACTIONS(653),
    [aux_sym_number_token3] = ACTIONS(653),
    [anon_sym_CR] = ACTIONS(653),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(655),
    [sym__single_quote_string_start] = ACTIONS(655),
    [sym__double_quote_string_start] = ACTIONS(655),
    [sym__multioutput_variable_start] = ACTIONS(655),
    [sym__external_identifier] = ACTIONS(655),
  },
  [STATE(124)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(123),
    [anon_sym_LPAREN] = ACTIONS(657),
    [anon_sym_PLUS] = ACTIONS(657),
    [anon_sym_DOT_PLUS] = ACTIONS(657),
    [anon_sym_DASH] = ACTIONS(657),
    [anon_sym_DOT_DASH] = ACTIONS(657),
    [anon_sym_STAR] = ACTIONS(657),
    [anon_sym_DOT_STAR] = ACTIONS(657),
    [anon_sym_SLASH] = ACTIONS(657),
    [anon_sym_DOT_SLASH] = ACTIONS(657),
    [anon_sym_BSLASH] = ACTIONS(657),
    [anon_sym_DOT_BSLASH] = ACTIONS(657),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_DOT_CARET] = ACTIONS(657),
    [anon_sym_PIPE] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(657),
    [anon_sym_DOT] = ACTIONS(633),
    [anon_sym_TILDE] = ACTIONS(657),
    [anon_sym_QMARK] = ACTIONS(657),
    [anon_sym_AT] = ACTIONS(657),
    [anon_sym_LT] = ACTIONS(657),
    [anon_sym_LT_EQ] = ACTIONS(657),
    [anon_sym_EQ_EQ] = ACTIONS(657),
    [anon_sym_TILDE_EQ] = ACTIONS(657),
    [anon_sym_GT_EQ] = ACTIONS(657),
    [anon_sym_GT] = ACTIONS(657),
    [anon_sym_AMP_AMP] = ACTIONS(657),
    [anon_sym_PIPE_PIPE] = ACTIONS(657),
    [anon_sym_DOT_SQUOTE] = ACTIONS(657),
    [anon_sym_SQUOTE] = ACTIONS(657),
    [anon_sym_COMMA] = ACTIONS(657),
    [anon_sym_LBRACK] = ACTIONS(657),
    [anon_sym_LF] = ACTIONS(657),
    [anon_sym_SEMI] = ACTIONS(657),
    [anon_sym_LBRACE] = ACTIONS(657),
    [anon_sym_COLON] = ACTIONS(657),
    [anon_sym_return] = ACTIONS(657),
    [anon_sym_continue] = ACTIONS(657),
    [anon_sym_break] = ACTIONS(657),
    [anon_sym_elseif] = ACTIONS(657),
    [anon_sym_else] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(657),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_for] = ACTIONS(657),
    [anon_sym_parfor] = ACTIONS(657),
    [anon_sym_while] = ACTIONS(657),
    [anon_sym_switch] = ACTIONS(657),
    [anon_sym_global] = ACTIONS(657),
    [anon_sym_persistent] = ACTIONS(657),
    [anon_sym_arguments] = ACTIONS(657),
    [anon_sym_function] = ACTIONS(657),
    [anon_sym_properties] = ACTIONS(657),
    [anon_sym_get] = ACTIONS(657),
    [anon_sym_set] = ACTIONS(657),
    [anon_sym_methods] = ACTIONS(657),
    [anon_sym_events] = ACTIONS(657),
    [anon_sym_enumeration] = ACTIONS(657),
    [anon_sym_classdef] = ACTIONS(657),
    [anon_sym_try] = ACTIONS(657),
    [anon_sym_spmd] = ACTIONS(657),
    [aux_sym_number_token1] = ACTIONS(657),
    [aux_sym_number_token2] = ACTIONS(657),
    [aux_sym_number_token3] = ACTIONS(657),
    [anon_sym_CR] = ACTIONS(657),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(659),
    [sym__single_quote_string_start] = ACTIONS(659),
    [sym__double_quote_string_start] = ACTIONS(659),
    [sym__multioutput_variable_start] = ACTIONS(659),
    [sym__external_identifier] = ACTIONS(659),
  },
  [STATE(125)] = {
    [anon_sym_LPAREN] = ACTIONS(661),
    [anon_sym_PLUS] = ACTIONS(661),
    [anon_sym_DOT_PLUS] = ACTIONS(661),
    [anon_sym_DASH] = ACTIONS(661),
    [anon_sym_DOT_DASH] = ACTIONS(661),
    [anon_sym_STAR] = ACTIONS(661),
    [anon_sym_DOT_STAR] = ACTIONS(661),
    [anon_sym_SLASH] = ACTIONS(661),
    [anon_sym_DOT_SLASH] = ACTIONS(661),
    [anon_sym_BSLASH] = ACTIONS(661),
    [anon_sym_DOT_BSLASH] = ACTIONS(661),
    [anon_sym_CARET] = ACTIONS(661),
    [anon_sym_DOT_CARET] = ACTIONS(661),
    [anon_sym_PIPE] = ACTIONS(661),
    [anon_sym_AMP] = ACTIONS(661),
    [anon_sym_DOT] = ACTIONS(661),
    [anon_sym_TILDE] = ACTIONS(661),
    [anon_sym_QMARK] = ACTIONS(661),
    [anon_sym_AT] = ACTIONS(661),
    [anon_sym_LT] = ACTIONS(661),
    [anon_sym_LT_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_TILDE_EQ] = ACTIONS(661),
    [anon_sym_GT_EQ] = ACTIONS(661),
    [anon_sym_GT] = ACTIONS(661),
    [anon_sym_AMP_AMP] = ACTIONS(661),
    [anon_sym_PIPE_PIPE] = ACTIONS(661),
    [anon_sym_DOT_SQUOTE] = ACTIONS(661),
    [anon_sym_SQUOTE] = ACTIONS(661),
    [anon_sym_COMMA] = ACTIONS(661),
    [anon_sym_LBRACK] = ACTIONS(661),
    [anon_sym_LF] = ACTIONS(661),
    [anon_sym_SEMI] = ACTIONS(661),
    [anon_sym_LBRACE] = ACTIONS(661),
    [anon_sym_COLON] = ACTIONS(661),
    [anon_sym_return] = ACTIONS(661),
    [anon_sym_continue] = ACTIONS(661),
    [anon_sym_break] = ACTIONS(661),
    [anon_sym_elseif] = ACTIONS(661),
    [anon_sym_else] = ACTIONS(661),
    [anon_sym_if] = ACTIONS(661),
    [anon_sym_end] = ACTIONS(661),
    [anon_sym_for] = ACTIONS(661),
    [anon_sym_parfor] = ACTIONS(661),
    [anon_sym_while] = ACTIONS(661),
    [anon_sym_switch] = ACTIONS(661),
    [anon_sym_global] = ACTIONS(661),
    [anon_sym_persistent] = ACTIONS(661),
    [anon_sym_arguments] = ACTIONS(661),
    [anon_sym_function] = ACTIONS(661),
    [anon_sym_properties] = ACTIONS(661),
    [anon_sym_get] = ACTIONS(661),
    [anon_sym_set] = ACTIONS(661),
    [anon_sym_methods] = ACTIONS(661),
    [anon_sym_events] = ACTIONS(661),
    [anon_sym_enumeration] = ACTIONS(661),
    [anon_sym_classdef] = ACTIONS(661),
    [anon_sym_try] = ACTIONS(661),
    [anon_sym_spmd] = ACTIONS(661),
    [aux_sym_number_token1] = ACTIONS(661),
    [aux_sym_number_token2] = ACTIONS(661),
    [aux_sym_number_token3] = ACTIONS(661),
    [anon_sym_CR] = ACTIONS(661),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(663),
    [sym__single_quote_string_start] = ACTIONS(663),
    [sym__double_quote_string_start] = ACTIONS(663),
    [sym__multioutput_variable_start] = ACTIONS(663),
    [sym__external_identifier] = ACTIONS(663),
  },
  [STATE(126)] = {
    [anon_sym_LPAREN] = ACTIONS(665),
    [anon_sym_PLUS] = ACTIONS(665),
    [anon_sym_DOT_PLUS] = ACTIONS(665),
    [anon_sym_DASH] = ACTIONS(665),
    [anon_sym_DOT_DASH] = ACTIONS(665),
    [anon_sym_STAR] = ACTIONS(665),
    [anon_sym_DOT_STAR] = ACTIONS(665),
    [anon_sym_SLASH] = ACTIONS(665),
    [anon_sym_DOT_SLASH] = ACTIONS(665),
    [anon_sym_BSLASH] = ACTIONS(665),
    [anon_sym_DOT_BSLASH] = ACTIONS(665),
    [anon_sym_CARET] = ACTIONS(665),
    [anon_sym_DOT_CARET] = ACTIONS(665),
    [anon_sym_PIPE] = ACTIONS(665),
    [anon_sym_AMP] = ACTIONS(665),
    [anon_sym_DOT] = ACTIONS(665),
    [anon_sym_TILDE] = ACTIONS(665),
    [anon_sym_QMARK] = ACTIONS(665),
    [anon_sym_AT] = ACTIONS(665),
    [anon_sym_LT] = ACTIONS(665),
    [anon_sym_LT_EQ] = ACTIONS(665),
    [anon_sym_EQ_EQ] = ACTIONS(665),
    [anon_sym_TILDE_EQ] = ACTIONS(665),
    [anon_sym_GT_EQ] = ACTIONS(665),
    [anon_sym_GT] = ACTIONS(665),
    [anon_sym_AMP_AMP] = ACTIONS(665),
    [anon_sym_PIPE_PIPE] = ACTIONS(665),
    [anon_sym_DOT_SQUOTE] = ACTIONS(665),
    [anon_sym_SQUOTE] = ACTIONS(665),
    [anon_sym_COMMA] = ACTIONS(665),
    [anon_sym_LBRACK] = ACTIONS(665),
    [anon_sym_LF] = ACTIONS(665),
    [anon_sym_SEMI] = ACTIONS(665),
    [anon_sym_LBRACE] = ACTIONS(665),
    [anon_sym_COLON] = ACTIONS(665),
    [anon_sym_return] = ACTIONS(665),
    [anon_sym_continue] = ACTIONS(665),
    [anon_sym_break] = ACTIONS(665),
    [anon_sym_elseif] = ACTIONS(665),
    [anon_sym_else] = ACTIONS(665),
    [anon_sym_if] = ACTIONS(665),
    [anon_sym_end] = ACTIONS(665),
    [anon_sym_for] = ACTIONS(665),
    [anon_sym_parfor] = ACTIONS(665),
    [anon_sym_while] = ACTIONS(665),
    [anon_sym_switch] = ACTIONS(665),
    [anon_sym_global] = ACTIONS(665),
    [anon_sym_persistent] = ACTIONS(665),
    [anon_sym_arguments] = ACTIONS(665),
    [anon_sym_function] = ACTIONS(665),
    [anon_sym_properties] = ACTIONS(665),
    [anon_sym_get] = ACTIONS(665),
    [anon_sym_set] = ACTIONS(665),
    [anon_sym_methods] = ACTIONS(665),
    [anon_sym_events] = ACTIONS(665),
    [anon_sym_enumeration] = ACTIONS(665),
    [anon_sym_classdef] = ACTIONS(665),
    [anon_sym_try] = ACTIONS(665),
    [anon_sym_spmd] = ACTIONS(665),
    [aux_sym_number_token1] = ACTIONS(665),
    [aux_sym_number_token2] = ACTIONS(665),
    [aux_sym_number_token3] = ACTIONS(665),
    [anon_sym_CR] = ACTIONS(665),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(667),
    [sym__single_quote_string_start] = ACTIONS(667),
    [sym__double_quote_string_start] = ACTIONS(667),
    [sym__multioutput_variable_start] = ACTIONS(667),
    [sym__external_identifier] = ACTIONS(667),
  },
  [STATE(127)] = {
    [anon_sym_LPAREN] = ACTIONS(669),
    [anon_sym_PLUS] = ACTIONS(669),
    [anon_sym_DOT_PLUS] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(669),
    [anon_sym_DOT_DASH] = ACTIONS(669),
    [anon_sym_STAR] = ACTIONS(669),
    [anon_sym_DOT_STAR] = ACTIONS(669),
    [anon_sym_SLASH] = ACTIONS(669),
    [anon_sym_DOT_SLASH] = ACTIONS(669),
    [anon_sym_BSLASH] = ACTIONS(669),
    [anon_sym_DOT_BSLASH] = ACTIONS(669),
    [anon_sym_CARET] = ACTIONS(669),
    [anon_sym_DOT_CARET] = ACTIONS(669),
    [anon_sym_PIPE] = ACTIONS(669),
    [anon_sym_AMP] = ACTIONS(669),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(669),
    [anon_sym_AT] = ACTIONS(669),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_LT_EQ] = ACTIONS(669),
    [anon_sym_EQ_EQ] = ACTIONS(669),
    [anon_sym_TILDE_EQ] = ACTIONS(669),
    [anon_sym_GT_EQ] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_AMP_AMP] = ACTIONS(669),
    [anon_sym_PIPE_PIPE] = ACTIONS(669),
    [anon_sym_DOT_SQUOTE] = ACTIONS(669),
    [anon_sym_SQUOTE] = ACTIONS(669),
    [anon_sym_COMMA] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(669),
    [anon_sym_LF] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(669),
    [anon_sym_LBRACE] = ACTIONS(669),
    [anon_sym_COLON] = ACTIONS(669),
    [anon_sym_return] = ACTIONS(669),
    [anon_sym_continue] = ACTIONS(669),
    [anon_sym_break] = ACTIONS(669),
    [anon_sym_elseif] = ACTIONS(669),
    [anon_sym_else] = ACTIONS(669),
    [anon_sym_if] = ACTIONS(669),
    [anon_sym_end] = ACTIONS(669),
    [anon_sym_for] = ACTIONS(669),
    [anon_sym_parfor] = ACTIONS(669),
    [anon_sym_while] = ACTIONS(669),
    [anon_sym_switch] = ACTIONS(669),
    [anon_sym_global] = ACTIONS(669),
    [anon_sym_persistent] = ACTIONS(669),
    [anon_sym_arguments] = ACTIONS(669),
    [anon_sym_function] = ACTIONS(669),
    [anon_sym_properties] = ACTIONS(669),
    [anon_sym_get] = ACTIONS(669),
    [anon_sym_set] = ACTIONS(669),
    [anon_sym_methods] = ACTIONS(669),
    [anon_sym_events] = ACTIONS(669),
    [anon_sym_enumeration] = ACTIONS(669),
    [anon_sym_classdef] = ACTIONS(669),
    [anon_sym_try] = ACTIONS(669),
    [anon_sym_spmd] = ACTIONS(669),
    [aux_sym_number_token1] = ACTIONS(669),
    [aux_sym_number_token2] = ACTIONS(669),
    [aux_sym_number_token3] = ACTIONS(669),
    [anon_sym_CR] = ACTIONS(669),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(671),
    [sym__single_quote_string_start] = ACTIONS(671),
    [sym__double_quote_string_start] = ACTIONS(671),
    [sym__multioutput_variable_start] = ACTIONS(671),
    [sym__external_identifier] = ACTIONS(671),
  },
  [STATE(128)] = {
    [anon_sym_LPAREN] = ACTIONS(669),
    [anon_sym_PLUS] = ACTIONS(669),
    [anon_sym_DOT_PLUS] = ACTIONS(669),
    [anon_sym_DASH] = ACTIONS(669),
    [anon_sym_DOT_DASH] = ACTIONS(669),
    [anon_sym_STAR] = ACTIONS(669),
    [anon_sym_DOT_STAR] = ACTIONS(669),
    [anon_sym_SLASH] = ACTIONS(669),
    [anon_sym_DOT_SLASH] = ACTIONS(669),
    [anon_sym_BSLASH] = ACTIONS(669),
    [anon_sym_DOT_BSLASH] = ACTIONS(669),
    [anon_sym_CARET] = ACTIONS(669),
    [anon_sym_DOT_CARET] = ACTIONS(669),
    [anon_sym_PIPE] = ACTIONS(669),
    [anon_sym_AMP] = ACTIONS(669),
    [anon_sym_DOT] = ACTIONS(669),
    [anon_sym_TILDE] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(669),
    [anon_sym_AT] = ACTIONS(669),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_LT_EQ] = ACTIONS(669),
    [anon_sym_EQ_EQ] = ACTIONS(669),
    [anon_sym_TILDE_EQ] = ACTIONS(669),
    [anon_sym_GT_EQ] = ACTIONS(669),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_AMP_AMP] = ACTIONS(669),
    [anon_sym_PIPE_PIPE] = ACTIONS(669),
    [anon_sym_DOT_SQUOTE] = ACTIONS(669),
    [anon_sym_SQUOTE] = ACTIONS(669),
    [anon_sym_COMMA] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(669),
    [anon_sym_LF] = ACTIONS(669),
    [anon_sym_SEMI] = ACTIONS(669),
    [anon_sym_LBRACE] = ACTIONS(669),
    [anon_sym_COLON] = ACTIONS(669),
    [anon_sym_return] = ACTIONS(669),
    [anon_sym_continue] = ACTIONS(669),
    [anon_sym_break] = ACTIONS(669),
    [anon_sym_elseif] = ACTIONS(669),
    [anon_sym_else] = ACTIONS(669),
    [anon_sym_if] = ACTIONS(669),
    [anon_sym_end] = ACTIONS(669),
    [anon_sym_for] = ACTIONS(669),
    [anon_sym_parfor] = ACTIONS(669),
    [anon_sym_while] = ACTIONS(669),
    [anon_sym_switch] = ACTIONS(669),
    [anon_sym_global] = ACTIONS(669),
    [anon_sym_persistent] = ACTIONS(669),
    [anon_sym_arguments] = ACTIONS(669),
    [anon_sym_function] = ACTIONS(669),
    [anon_sym_properties] = ACTIONS(669),
    [anon_sym_get] = ACTIONS(669),
    [anon_sym_set] = ACTIONS(669),
    [anon_sym_methods] = ACTIONS(669),
    [anon_sym_events] = ACTIONS(669),
    [anon_sym_enumeration] = ACTIONS(669),
    [anon_sym_classdef] = ACTIONS(669),
    [anon_sym_try] = ACTIONS(669),
    [anon_sym_spmd] = ACTIONS(669),
    [aux_sym_number_token1] = ACTIONS(669),
    [aux_sym_number_token2] = ACTIONS(669),
    [aux_sym_number_token3] = ACTIONS(669),
    [anon_sym_CR] = ACTIONS(669),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(671),
    [sym__single_quote_string_start] = ACTIONS(671),
    [sym__double_quote_string_start] = ACTIONS(671),
    [sym__multioutput_variable_start] = ACTIONS(671),
    [sym__external_identifier] = ACTIONS(671),
  },
  [STATE(129)] = {
    [anon_sym_LPAREN] = ACTIONS(673),
    [anon_sym_PLUS] = ACTIONS(673),
    [anon_sym_DOT_PLUS] = ACTIONS(673),
    [anon_sym_DASH] = ACTIONS(673),
    [anon_sym_DOT_DASH] = ACTIONS(673),
    [anon_sym_STAR] = ACTIONS(673),
    [anon_sym_DOT_STAR] = ACTIONS(673),
    [anon_sym_SLASH] = ACTIONS(673),
    [anon_sym_DOT_SLASH] = ACTIONS(673),
    [anon_sym_BSLASH] = ACTIONS(673),
    [anon_sym_DOT_BSLASH] = ACTIONS(673),
    [anon_sym_CARET] = ACTIONS(673),
    [anon_sym_DOT_CARET] = ACTIONS(673),
    [anon_sym_PIPE] = ACTIONS(673),
    [anon_sym_AMP] = ACTIONS(673),
    [anon_sym_DOT] = ACTIONS(673),
    [anon_sym_TILDE] = ACTIONS(673),
    [anon_sym_QMARK] = ACTIONS(673),
    [anon_sym_AT] = ACTIONS(673),
    [anon_sym_LT] = ACTIONS(673),
    [anon_sym_LT_EQ] = ACTIONS(673),
    [anon_sym_EQ_EQ] = ACTIONS(673),
    [anon_sym_TILDE_EQ] = ACTIONS(673),
    [anon_sym_GT_EQ] = ACTIONS(673),
    [anon_sym_GT] = ACTIONS(673),
    [anon_sym_AMP_AMP] = ACTIONS(673),
    [anon_sym_PIPE_PIPE] = ACTIONS(673),
    [anon_sym_DOT_SQUOTE] = ACTIONS(673),
    [anon_sym_SQUOTE] = ACTIONS(673),
    [anon_sym_COMMA] = ACTIONS(673),
    [anon_sym_LBRACK] = ACTIONS(673),
    [anon_sym_LF] = ACTIONS(673),
    [anon_sym_SEMI] = ACTIONS(673),
    [anon_sym_LBRACE] = ACTIONS(673),
    [anon_sym_COLON] = ACTIONS(673),
    [anon_sym_return] = ACTIONS(673),
    [anon_sym_continue] = ACTIONS(673),
    [anon_sym_break] = ACTIONS(673),
    [anon_sym_elseif] = ACTIONS(673),
    [anon_sym_else] = ACTIONS(673),
    [anon_sym_if] = ACTIONS(673),
    [anon_sym_end] = ACTIONS(673),
    [anon_sym_for] = ACTIONS(673),
    [anon_sym_parfor] = ACTIONS(673),
    [anon_sym_while] = ACTIONS(673),
    [anon_sym_switch] = ACTIONS(673),
    [anon_sym_global] = ACTIONS(673),
    [anon_sym_persistent] = ACTIONS(673),
    [anon_sym_arguments] = ACTIONS(673),
    [anon_sym_function] = ACTIONS(673),
    [anon_sym_properties] = ACTIONS(673),
    [anon_sym_get] = ACTIONS(673),
    [anon_sym_set] = ACTIONS(673),
    [anon_sym_methods] = ACTIONS(673),
    [anon_sym_events] = ACTIONS(673),
    [anon_sym_enumeration] = ACTIONS(673),
    [anon_sym_classdef] = ACTIONS(673),
    [anon_sym_try] = ACTIONS(673),
    [anon_sym_spmd] = ACTIONS(673),
    [aux_sym_number_token1] = ACTIONS(673),
    [aux_sym_number_token2] = ACTIONS(673),
    [aux_sym_number_token3] = ACTIONS(673),
    [anon_sym_CR] = ACTIONS(673),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(675),
    [sym__single_quote_string_start] = ACTIONS(675),
    [sym__double_quote_string_start] = ACTIONS(675),
    [sym__multioutput_variable_start] = ACTIONS(675),
    [sym__external_identifier] = ACTIONS(675),
  },
  [STATE(130)] = {
    [anon_sym_LPAREN] = ACTIONS(612),
    [anon_sym_PLUS] = ACTIONS(612),
    [anon_sym_DOT_PLUS] = ACTIONS(612),
    [anon_sym_DASH] = ACTIONS(612),
    [anon_sym_DOT_DASH] = ACTIONS(612),
    [anon_sym_STAR] = ACTIONS(612),
    [anon_sym_DOT_STAR] = ACTIONS(612),
    [anon_sym_SLASH] = ACTIONS(612),
    [anon_sym_DOT_SLASH] = ACTIONS(612),
    [anon_sym_BSLASH] = ACTIONS(612),
    [anon_sym_DOT_BSLASH] = ACTIONS(612),
    [anon_sym_CARET] = ACTIONS(612),
    [anon_sym_DOT_CARET] = ACTIONS(612),
    [anon_sym_PIPE] = ACTIONS(612),
    [anon_sym_AMP] = ACTIONS(612),
    [anon_sym_DOT] = ACTIONS(612),
    [anon_sym_TILDE] = ACTIONS(612),
    [anon_sym_QMARK] = ACTIONS(612),
    [anon_sym_AT] = ACTIONS(612),
    [anon_sym_LT] = ACTIONS(612),
    [anon_sym_LT_EQ] = ACTIONS(612),
    [anon_sym_EQ_EQ] = ACTIONS(612),
    [anon_sym_TILDE_EQ] = ACTIONS(612),
    [anon_sym_GT_EQ] = ACTIONS(612),
    [anon_sym_GT] = ACTIONS(612),
    [anon_sym_AMP_AMP] = ACTIONS(612),
    [anon_sym_PIPE_PIPE] = ACTIONS(612),
    [anon_sym_DOT_SQUOTE] = ACTIONS(612),
    [anon_sym_SQUOTE] = ACTIONS(612),
    [anon_sym_COMMA] = ACTIONS(612),
    [anon_sym_LBRACK] = ACTIONS(612),
    [anon_sym_LF] = ACTIONS(612),
    [anon_sym_SEMI] = ACTIONS(612),
    [anon_sym_LBRACE] = ACTIONS(612),
    [anon_sym_COLON] = ACTIONS(612),
    [anon_sym_return] = ACTIONS(612),
    [anon_sym_continue] = ACTIONS(612),
    [anon_sym_break] = ACTIONS(612),
    [anon_sym_elseif] = ACTIONS(612),
    [anon_sym_else] = ACTIONS(612),
    [anon_sym_if] = ACTIONS(612),
    [anon_sym_end] = ACTIONS(612),
    [anon_sym_for] = ACTIONS(612),
    [anon_sym_parfor] = ACTIONS(612),
    [anon_sym_while] = ACTIONS(612),
    [anon_sym_switch] = ACTIONS(612),
    [anon_sym_global] = ACTIONS(612),
    [anon_sym_persistent] = ACTIONS(612),
    [anon_sym_arguments] = ACTIONS(612),
    [anon_sym_function] = ACTIONS(612),
    [anon_sym_properties] = ACTIONS(612),
    [anon_sym_get] = ACTIONS(612),
    [anon_sym_set] = ACTIONS(612),
    [anon_sym_methods] = ACTIONS(612),
    [anon_sym_events] = ACTIONS(612),
    [anon_sym_enumeration] = ACTIONS(612),
    [anon_sym_classdef] = ACTIONS(612),
    [anon_sym_try] = ACTIONS(612),
    [anon_sym_spmd] = ACTIONS(612),
    [aux_sym_number_token1] = ACTIONS(612),
    [aux_sym_number_token2] = ACTIONS(612),
    [aux_sym_number_token3] = ACTIONS(612),
    [anon_sym_CR] = ACTIONS(612),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(614),
    [sym__single_quote_string_start] = ACTIONS(614),
    [sym__double_quote_string_start] = ACTIONS(614),
    [sym__multioutput_variable_start] = ACTIONS(614),
    [sym__external_identifier] = ACTIONS(614),
  },
  [STATE(131)] = {
    [anon_sym_LPAREN] = ACTIONS(677),
    [anon_sym_PLUS] = ACTIONS(677),
    [anon_sym_DOT_PLUS] = ACTIONS(677),
    [anon_sym_DASH] = ACTIONS(677),
    [anon_sym_DOT_DASH] = ACTIONS(677),
    [anon_sym_STAR] = ACTIONS(677),
    [anon_sym_DOT_STAR] = ACTIONS(677),
    [anon_sym_SLASH] = ACTIONS(677),
    [anon_sym_DOT_SLASH] = ACTIONS(677),
    [anon_sym_BSLASH] = ACTIONS(677),
    [anon_sym_DOT_BSLASH] = ACTIONS(677),
    [anon_sym_CARET] = ACTIONS(677),
    [anon_sym_DOT_CARET] = ACTIONS(677),
    [anon_sym_PIPE] = ACTIONS(677),
    [anon_sym_AMP] = ACTIONS(677),
    [anon_sym_DOT] = ACTIONS(677),
    [anon_sym_TILDE] = ACTIONS(677),
    [anon_sym_QMARK] = ACTIONS(677),
    [anon_sym_AT] = ACTIONS(677),
    [anon_sym_LT] = ACTIONS(677),
    [anon_sym_LT_EQ] = ACTIONS(677),
    [anon_sym_EQ_EQ] = ACTIONS(677),
    [anon_sym_TILDE_EQ] = ACTIONS(677),
    [anon_sym_GT_EQ] = ACTIONS(677),
    [anon_sym_GT] = ACTIONS(677),
    [anon_sym_AMP_AMP] = ACTIONS(677),
    [anon_sym_PIPE_PIPE] = ACTIONS(677),
    [anon_sym_DOT_SQUOTE] = ACTIONS(677),
    [anon_sym_SQUOTE] = ACTIONS(677),
    [anon_sym_COMMA] = ACTIONS(677),
    [anon_sym_LBRACK] = ACTIONS(677),
    [anon_sym_LF] = ACTIONS(677),
    [anon_sym_SEMI] = ACTIONS(677),
    [anon_sym_LBRACE] = ACTIONS(677),
    [anon_sym_COLON] = ACTIONS(677),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_continue] = ACTIONS(677),
    [anon_sym_break] = ACTIONS(677),
    [anon_sym_elseif] = ACTIONS(677),
    [anon_sym_else] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(677),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_for] = ACTIONS(677),
    [anon_sym_parfor] = ACTIONS(677),
    [anon_sym_while] = ACTIONS(677),
    [anon_sym_switch] = ACTIONS(677),
    [anon_sym_global] = ACTIONS(677),
    [anon_sym_persistent] = ACTIONS(677),
    [anon_sym_arguments] = ACTIONS(677),
    [anon_sym_function] = ACTIONS(677),
    [anon_sym_properties] = ACTIONS(677),
    [anon_sym_get] = ACTIONS(677),
    [anon_sym_set] = ACTIONS(677),
    [anon_sym_methods] = ACTIONS(677),
    [anon_sym_events] = ACTIONS(677),
    [anon_sym_enumeration] = ACTIONS(677),
    [anon_sym_classdef] = ACTIONS(677),
    [anon_sym_try] = ACTIONS(677),
    [anon_sym_spmd] = ACTIONS(677),
    [aux_sym_number_token1] = ACTIONS(677),
    [aux_sym_number_token2] = ACTIONS(677),
    [aux_sym_number_token3] = ACTIONS(677),
    [anon_sym_CR] = ACTIONS(677),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(679),
    [sym__single_quote_string_start] = ACTIONS(679),
    [sym__double_quote_string_start] = ACTIONS(679),
    [sym__multioutput_variable_start] = ACTIONS(679),
    [sym__external_identifier] = ACTIONS(679),
  },
  [STATE(132)] = {
    [anon_sym_LPAREN] = ACTIONS(681),
    [anon_sym_PLUS] = ACTIONS(681),
    [anon_sym_DOT_PLUS] = ACTIONS(681),
    [anon_sym_DASH] = ACTIONS(681),
    [anon_sym_DOT_DASH] = ACTIONS(681),
    [anon_sym_STAR] = ACTIONS(681),
    [anon_sym_DOT_STAR] = ACTIONS(681),
    [anon_sym_SLASH] = ACTIONS(681),
    [anon_sym_DOT_SLASH] = ACTIONS(681),
    [anon_sym_BSLASH] = ACTIONS(681),
    [anon_sym_DOT_BSLASH] = ACTIONS(681),
    [anon_sym_CARET] = ACTIONS(681),
    [anon_sym_DOT_CARET] = ACTIONS(681),
    [anon_sym_PIPE] = ACTIONS(681),
    [anon_sym_AMP] = ACTIONS(681),
    [anon_sym_TILDE] = ACTIONS(681),
    [anon_sym_QMARK] = ACTIONS(681),
    [anon_sym_AT] = ACTIONS(681),
    [anon_sym_LT] = ACTIONS(681),
    [anon_sym_LT_EQ] = ACTIONS(681),
    [anon_sym_EQ_EQ] = ACTIONS(681),
    [anon_sym_TILDE_EQ] = ACTIONS(681),
    [anon_sym_GT_EQ] = ACTIONS(681),
    [anon_sym_GT] = ACTIONS(681),
    [anon_sym_AMP_AMP] = ACTIONS(681),
    [anon_sym_PIPE_PIPE] = ACTIONS(681),
    [anon_sym_DOT_SQUOTE] = ACTIONS(681),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_COMMA] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(681),
    [anon_sym_LF] = ACTIONS(681),
    [anon_sym_SEMI] = ACTIONS(681),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_COLON] = ACTIONS(681),
    [anon_sym_return] = ACTIONS(681),
    [anon_sym_continue] = ACTIONS(681),
    [anon_sym_break] = ACTIONS(681),
    [anon_sym_elseif] = ACTIONS(681),
    [anon_sym_else] = ACTIONS(681),
    [anon_sym_if] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(681),
    [anon_sym_for] = ACTIONS(681),
    [anon_sym_parfor] = ACTIONS(681),
    [anon_sym_while] = ACTIONS(681),
    [anon_sym_switch] = ACTIONS(681),
    [anon_sym_global] = ACTIONS(681),
    [anon_sym_persistent] = ACTIONS(681),
    [anon_sym_arguments] = ACTIONS(681),
    [anon_sym_function] = ACTIONS(681),
    [anon_sym_properties] = ACTIONS(681),
    [anon_sym_get] = ACTIONS(681),
    [anon_sym_set] = ACTIONS(681),
    [anon_sym_methods] = ACTIONS(681),
    [anon_sym_events] = ACTIONS(681),
    [anon_sym_enumeration] = ACTIONS(681),
    [anon_sym_classdef] = ACTIONS(681),
    [anon_sym_try] = ACTIONS(681),
    [anon_sym_spmd] = ACTIONS(681),
    [sym_number_size] = ACTIONS(683),
    [aux_sym_number_token1] = ACTIONS(681),
    [aux_sym_number_token2] = ACTIONS(681),
    [aux_sym_number_token3] = ACTIONS(681),
    [anon_sym_CR] = ACTIONS(681),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(685),
    [sym__single_quote_string_start] = ACTIONS(685),
    [sym__double_quote_string_start] = ACTIONS(685),
    [sym__multioutput_variable_start] = ACTIONS(685),
    [sym__external_identifier] = ACTIONS(685),
  },
  [STATE(133)] = {
    [anon_sym_LPAREN] = ACTIONS(687),
    [anon_sym_PLUS] = ACTIONS(687),
    [anon_sym_DOT_PLUS] = ACTIONS(687),
    [anon_sym_DASH] = ACTIONS(687),
    [anon_sym_DOT_DASH] = ACTIONS(687),
    [anon_sym_STAR] = ACTIONS(687),
    [anon_sym_DOT_STAR] = ACTIONS(687),
    [anon_sym_SLASH] = ACTIONS(687),
    [anon_sym_DOT_SLASH] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(687),
    [anon_sym_DOT_BSLASH] = ACTIONS(687),
    [anon_sym_CARET] = ACTIONS(687),
    [anon_sym_DOT_CARET] = ACTIONS(687),
    [anon_sym_PIPE] = ACTIONS(687),
    [anon_sym_AMP] = ACTIONS(687),
    [anon_sym_DOT] = ACTIONS(687),
    [anon_sym_TILDE] = ACTIONS(687),
    [anon_sym_QMARK] = ACTIONS(687),
    [anon_sym_AT] = ACTIONS(687),
    [anon_sym_LT] = ACTIONS(687),
    [anon_sym_LT_EQ] = ACTIONS(687),
    [anon_sym_EQ_EQ] = ACTIONS(687),
    [anon_sym_TILDE_EQ] = ACTIONS(687),
    [anon_sym_GT_EQ] = ACTIONS(687),
    [anon_sym_GT] = ACTIONS(687),
    [anon_sym_AMP_AMP] = ACTIONS(687),
    [anon_sym_PIPE_PIPE] = ACTIONS(687),
    [anon_sym_DOT_SQUOTE] = ACTIONS(687),
    [anon_sym_SQUOTE] = ACTIONS(687),
    [anon_sym_COMMA] = ACTIONS(687),
    [anon_sym_LBRACK] = ACTIONS(687),
    [anon_sym_LF] = ACTIONS(687),
    [anon_sym_SEMI] = ACTIONS(687),
    [anon_sym_LBRACE] = ACTIONS(687),
    [anon_sym_COLON] = ACTIONS(687),
    [anon_sym_return] = ACTIONS(687),
    [anon_sym_continue] = ACTIONS(687),
    [anon_sym_break] = ACTIONS(687),
    [anon_sym_elseif] = ACTIONS(687),
    [anon_sym_else] = ACTIONS(687),
    [anon_sym_if] = ACTIONS(687),
    [anon_sym_end] = ACTIONS(687),
    [anon_sym_for] = ACTIONS(687),
    [anon_sym_parfor] = ACTIONS(687),
    [anon_sym_while] = ACTIONS(687),
    [anon_sym_switch] = ACTIONS(687),
    [anon_sym_global] = ACTIONS(687),
    [anon_sym_persistent] = ACTIONS(687),
    [anon_sym_arguments] = ACTIONS(687),
    [anon_sym_function] = ACTIONS(687),
    [anon_sym_properties] = ACTIONS(687),
    [anon_sym_get] = ACTIONS(687),
    [anon_sym_set] = ACTIONS(687),
    [anon_sym_methods] = ACTIONS(687),
    [anon_sym_events] = ACTIONS(687),
    [anon_sym_enumeration] = ACTIONS(687),
    [anon_sym_classdef] = ACTIONS(687),
    [anon_sym_try] = ACTIONS(687),
    [anon_sym_spmd] = ACTIONS(687),
    [aux_sym_number_token1] = ACTIONS(687),
    [aux_sym_number_token2] = ACTIONS(687),
    [aux_sym_number_token3] = ACTIONS(687),
    [anon_sym_CR] = ACTIONS(687),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(689),
    [sym__single_quote_string_start] = ACTIONS(689),
    [sym__double_quote_string_start] = ACTIONS(689),
    [sym__multioutput_variable_start] = ACTIONS(689),
    [sym__external_identifier] = ACTIONS(689),
  },
  [STATE(134)] = {
    [anon_sym_LPAREN] = ACTIONS(691),
    [anon_sym_PLUS] = ACTIONS(691),
    [anon_sym_DOT_PLUS] = ACTIONS(691),
    [anon_sym_DASH] = ACTIONS(691),
    [anon_sym_DOT_DASH] = ACTIONS(691),
    [anon_sym_STAR] = ACTIONS(691),
    [anon_sym_DOT_STAR] = ACTIONS(691),
    [anon_sym_SLASH] = ACTIONS(691),
    [anon_sym_DOT_SLASH] = ACTIONS(691),
    [anon_sym_BSLASH] = ACTIONS(691),
    [anon_sym_DOT_BSLASH] = ACTIONS(691),
    [anon_sym_CARET] = ACTIONS(691),
    [anon_sym_DOT_CARET] = ACTIONS(691),
    [anon_sym_PIPE] = ACTIONS(691),
    [anon_sym_AMP] = ACTIONS(691),
    [anon_sym_DOT] = ACTIONS(691),
    [anon_sym_TILDE] = ACTIONS(691),
    [anon_sym_QMARK] = ACTIONS(691),
    [anon_sym_AT] = ACTIONS(691),
    [anon_sym_LT] = ACTIONS(691),
    [anon_sym_LT_EQ] = ACTIONS(691),
    [anon_sym_EQ_EQ] = ACTIONS(691),
    [anon_sym_TILDE_EQ] = ACTIONS(691),
    [anon_sym_GT_EQ] = ACTIONS(691),
    [anon_sym_GT] = ACTIONS(691),
    [anon_sym_AMP_AMP] = ACTIONS(691),
    [anon_sym_PIPE_PIPE] = ACTIONS(691),
    [anon_sym_DOT_SQUOTE] = ACTIONS(691),
    [anon_sym_SQUOTE] = ACTIONS(691),
    [anon_sym_COMMA] = ACTIONS(691),
    [anon_sym_LBRACK] = ACTIONS(691),
    [anon_sym_LF] = ACTIONS(691),
    [anon_sym_SEMI] = ACTIONS(691),
    [anon_sym_LBRACE] = ACTIONS(691),
    [anon_sym_COLON] = ACTIONS(691),
    [anon_sym_return] = ACTIONS(691),
    [anon_sym_continue] = ACTIONS(691),
    [anon_sym_break] = ACTIONS(691),
    [anon_sym_elseif] = ACTIONS(691),
    [anon_sym_else] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(691),
    [anon_sym_end] = ACTIONS(691),
    [anon_sym_for] = ACTIONS(691),
    [anon_sym_parfor] = ACTIONS(691),
    [anon_sym_while] = ACTIONS(691),
    [anon_sym_switch] = ACTIONS(691),
    [anon_sym_global] = ACTIONS(691),
    [anon_sym_persistent] = ACTIONS(691),
    [anon_sym_arguments] = ACTIONS(691),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_properties] = ACTIONS(691),
    [anon_sym_get] = ACTIONS(691),
    [anon_sym_set] = ACTIONS(691),
    [anon_sym_methods] = ACTIONS(691),
    [anon_sym_events] = ACTIONS(691),
    [anon_sym_enumeration] = ACTIONS(691),
    [anon_sym_classdef] = ACTIONS(691),
    [anon_sym_try] = ACTIONS(691),
    [anon_sym_spmd] = ACTIONS(691),
    [aux_sym_number_token1] = ACTIONS(691),
    [aux_sym_number_token2] = ACTIONS(691),
    [aux_sym_number_token3] = ACTIONS(691),
    [anon_sym_CR] = ACTIONS(691),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(693),
    [sym__single_quote_string_start] = ACTIONS(693),
    [sym__double_quote_string_start] = ACTIONS(693),
    [sym__multioutput_variable_start] = ACTIONS(693),
    [sym__external_identifier] = ACTIONS(693),
  },
  [STATE(135)] = {
    [anon_sym_LPAREN] = ACTIONS(695),
    [anon_sym_PLUS] = ACTIONS(695),
    [anon_sym_DOT_PLUS] = ACTIONS(695),
    [anon_sym_DASH] = ACTIONS(695),
    [anon_sym_DOT_DASH] = ACTIONS(695),
    [anon_sym_STAR] = ACTIONS(695),
    [anon_sym_DOT_STAR] = ACTIONS(695),
    [anon_sym_SLASH] = ACTIONS(695),
    [anon_sym_DOT_SLASH] = ACTIONS(695),
    [anon_sym_BSLASH] = ACTIONS(695),
    [anon_sym_DOT_BSLASH] = ACTIONS(695),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_DOT_CARET] = ACTIONS(695),
    [anon_sym_PIPE] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_DOT] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_QMARK] = ACTIONS(695),
    [anon_sym_AT] = ACTIONS(695),
    [anon_sym_LT] = ACTIONS(695),
    [anon_sym_LT_EQ] = ACTIONS(695),
    [anon_sym_EQ_EQ] = ACTIONS(695),
    [anon_sym_TILDE_EQ] = ACTIONS(695),
    [anon_sym_GT_EQ] = ACTIONS(695),
    [anon_sym_GT] = ACTIONS(695),
    [anon_sym_AMP_AMP] = ACTIONS(695),
    [anon_sym_PIPE_PIPE] = ACTIONS(695),
    [anon_sym_DOT_SQUOTE] = ACTIONS(695),
    [anon_sym_SQUOTE] = ACTIONS(695),
    [anon_sym_COMMA] = ACTIONS(695),
    [anon_sym_LBRACK] = ACTIONS(695),
    [anon_sym_LF] = ACTIONS(695),
    [anon_sym_SEMI] = ACTIONS(695),
    [anon_sym_LBRACE] = ACTIONS(695),
    [anon_sym_COLON] = ACTIONS(695),
    [anon_sym_return] = ACTIONS(695),
    [anon_sym_continue] = ACTIONS(695),
    [anon_sym_break] = ACTIONS(695),
    [anon_sym_elseif] = ACTIONS(695),
    [anon_sym_else] = ACTIONS(695),
    [anon_sym_if] = ACTIONS(695),
    [anon_sym_end] = ACTIONS(695),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_parfor] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(695),
    [anon_sym_switch] = ACTIONS(695),
    [anon_sym_global] = ACTIONS(695),
    [anon_sym_persistent] = ACTIONS(695),
    [anon_sym_arguments] = ACTIONS(695),
    [anon_sym_function] = ACTIONS(695),
    [anon_sym_properties] = ACTIONS(695),
    [anon_sym_get] = ACTIONS(695),
    [anon_sym_set] = ACTIONS(695),
    [anon_sym_methods] = ACTIONS(695),
    [anon_sym_events] = ACTIONS(695),
    [anon_sym_enumeration] = ACTIONS(695),
    [anon_sym_classdef] = ACTIONS(695),
    [anon_sym_try] = ACTIONS(695),
    [anon_sym_spmd] = ACTIONS(695),
    [aux_sym_number_token1] = ACTIONS(695),
    [aux_sym_number_token2] = ACTIONS(695),
    [aux_sym_number_token3] = ACTIONS(695),
    [anon_sym_CR] = ACTIONS(695),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(697),
    [sym__single_quote_string_start] = ACTIONS(697),
    [sym__double_quote_string_start] = ACTIONS(697),
    [sym__multioutput_variable_start] = ACTIONS(697),
    [sym__external_identifier] = ACTIONS(697),
  },
  [STATE(136)] = {
    [anon_sym_LPAREN] = ACTIONS(699),
    [anon_sym_PLUS] = ACTIONS(699),
    [anon_sym_DOT_PLUS] = ACTIONS(699),
    [anon_sym_DASH] = ACTIONS(699),
    [anon_sym_DOT_DASH] = ACTIONS(699),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_DOT_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(699),
    [anon_sym_DOT_SLASH] = ACTIONS(699),
    [anon_sym_BSLASH] = ACTIONS(699),
    [anon_sym_DOT_BSLASH] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(699),
    [anon_sym_DOT_CARET] = ACTIONS(699),
    [anon_sym_PIPE] = ACTIONS(699),
    [anon_sym_AMP] = ACTIONS(699),
    [anon_sym_DOT] = ACTIONS(699),
    [anon_sym_TILDE] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(699),
    [anon_sym_AT] = ACTIONS(699),
    [anon_sym_LT] = ACTIONS(699),
    [anon_sym_LT_EQ] = ACTIONS(699),
    [anon_sym_EQ_EQ] = ACTIONS(699),
    [anon_sym_TILDE_EQ] = ACTIONS(699),
    [anon_sym_GT_EQ] = ACTIONS(699),
    [anon_sym_GT] = ACTIONS(699),
    [anon_sym_AMP_AMP] = ACTIONS(699),
    [anon_sym_PIPE_PIPE] = ACTIONS(699),
    [anon_sym_DOT_SQUOTE] = ACTIONS(699),
    [anon_sym_SQUOTE] = ACTIONS(699),
    [anon_sym_COMMA] = ACTIONS(699),
    [anon_sym_LBRACK] = ACTIONS(699),
    [anon_sym_LF] = ACTIONS(699),
    [anon_sym_SEMI] = ACTIONS(699),
    [anon_sym_LBRACE] = ACTIONS(699),
    [anon_sym_COLON] = ACTIONS(699),
    [anon_sym_return] = ACTIONS(699),
    [anon_sym_continue] = ACTIONS(699),
    [anon_sym_break] = ACTIONS(699),
    [anon_sym_elseif] = ACTIONS(699),
    [anon_sym_else] = ACTIONS(699),
    [anon_sym_if] = ACTIONS(699),
    [anon_sym_end] = ACTIONS(699),
    [anon_sym_for] = ACTIONS(699),
    [anon_sym_parfor] = ACTIONS(699),
    [anon_sym_while] = ACTIONS(699),
    [anon_sym_switch] = ACTIONS(699),
    [anon_sym_global] = ACTIONS(699),
    [anon_sym_persistent] = ACTIONS(699),
    [anon_sym_arguments] = ACTIONS(699),
    [anon_sym_function] = ACTIONS(699),
    [anon_sym_properties] = ACTIONS(699),
    [anon_sym_get] = ACTIONS(699),
    [anon_sym_set] = ACTIONS(699),
    [anon_sym_methods] = ACTIONS(699),
    [anon_sym_events] = ACTIONS(699),
    [anon_sym_enumeration] = ACTIONS(699),
    [anon_sym_classdef] = ACTIONS(699),
    [anon_sym_try] = ACTIONS(699),
    [anon_sym_spmd] = ACTIONS(699),
    [aux_sym_number_token1] = ACTIONS(699),
    [aux_sym_number_token2] = ACTIONS(699),
    [aux_sym_number_token3] = ACTIONS(699),
    [anon_sym_CR] = ACTIONS(699),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(701),
    [sym__single_quote_string_start] = ACTIONS(701),
    [sym__double_quote_string_start] = ACTIONS(701),
    [sym__multioutput_variable_start] = ACTIONS(701),
    [sym__external_identifier] = ACTIONS(701),
  },
  [STATE(137)] = {
    [anon_sym_LPAREN] = ACTIONS(703),
    [anon_sym_PLUS] = ACTIONS(703),
    [anon_sym_DOT_PLUS] = ACTIONS(703),
    [anon_sym_DASH] = ACTIONS(703),
    [anon_sym_DOT_DASH] = ACTIONS(703),
    [anon_sym_STAR] = ACTIONS(703),
    [anon_sym_DOT_STAR] = ACTIONS(703),
    [anon_sym_SLASH] = ACTIONS(703),
    [anon_sym_DOT_SLASH] = ACTIONS(703),
    [anon_sym_BSLASH] = ACTIONS(703),
    [anon_sym_DOT_BSLASH] = ACTIONS(703),
    [anon_sym_CARET] = ACTIONS(703),
    [anon_sym_DOT_CARET] = ACTIONS(703),
    [anon_sym_PIPE] = ACTIONS(703),
    [anon_sym_AMP] = ACTIONS(703),
    [anon_sym_DOT] = ACTIONS(703),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_QMARK] = ACTIONS(703),
    [anon_sym_AT] = ACTIONS(703),
    [anon_sym_LT] = ACTIONS(703),
    [anon_sym_LT_EQ] = ACTIONS(703),
    [anon_sym_EQ_EQ] = ACTIONS(703),
    [anon_sym_TILDE_EQ] = ACTIONS(703),
    [anon_sym_GT_EQ] = ACTIONS(703),
    [anon_sym_GT] = ACTIONS(703),
    [anon_sym_AMP_AMP] = ACTIONS(703),
    [anon_sym_PIPE_PIPE] = ACTIONS(703),
    [anon_sym_DOT_SQUOTE] = ACTIONS(703),
    [anon_sym_SQUOTE] = ACTIONS(703),
    [anon_sym_COMMA] = ACTIONS(703),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_LF] = ACTIONS(703),
    [anon_sym_SEMI] = ACTIONS(703),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_COLON] = ACTIONS(703),
    [anon_sym_return] = ACTIONS(703),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_break] = ACTIONS(703),
    [anon_sym_elseif] = ACTIONS(703),
    [anon_sym_else] = ACTIONS(703),
    [anon_sym_if] = ACTIONS(703),
    [anon_sym_end] = ACTIONS(703),
    [anon_sym_for] = ACTIONS(703),
    [anon_sym_parfor] = ACTIONS(703),
    [anon_sym_while] = ACTIONS(703),
    [anon_sym_switch] = ACTIONS(703),
    [anon_sym_global] = ACTIONS(703),
    [anon_sym_persistent] = ACTIONS(703),
    [anon_sym_arguments] = ACTIONS(703),
    [anon_sym_function] = ACTIONS(703),
    [anon_sym_properties] = ACTIONS(703),
    [anon_sym_get] = ACTIONS(703),
    [anon_sym_set] = ACTIONS(703),
    [anon_sym_methods] = ACTIONS(703),
    [anon_sym_events] = ACTIONS(703),
    [anon_sym_enumeration] = ACTIONS(703),
    [anon_sym_classdef] = ACTIONS(703),
    [anon_sym_try] = ACTIONS(703),
    [anon_sym_spmd] = ACTIONS(703),
    [aux_sym_number_token1] = ACTIONS(703),
    [aux_sym_number_token2] = ACTIONS(703),
    [aux_sym_number_token3] = ACTIONS(703),
    [anon_sym_CR] = ACTIONS(703),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(705),
    [sym__single_quote_string_start] = ACTIONS(705),
    [sym__double_quote_string_start] = ACTIONS(705),
    [sym__multioutput_variable_start] = ACTIONS(705),
    [sym__external_identifier] = ACTIONS(705),
  },
  [STATE(138)] = {
    [anon_sym_LPAREN] = ACTIONS(624),
    [anon_sym_PLUS] = ACTIONS(624),
    [anon_sym_DOT_PLUS] = ACTIONS(624),
    [anon_sym_DASH] = ACTIONS(624),
    [anon_sym_DOT_DASH] = ACTIONS(624),
    [anon_sym_STAR] = ACTIONS(624),
    [anon_sym_DOT_STAR] = ACTIONS(624),
    [anon_sym_SLASH] = ACTIONS(624),
    [anon_sym_DOT_SLASH] = ACTIONS(624),
    [anon_sym_BSLASH] = ACTIONS(624),
    [anon_sym_DOT_BSLASH] = ACTIONS(624),
    [anon_sym_CARET] = ACTIONS(624),
    [anon_sym_DOT_CARET] = ACTIONS(624),
    [anon_sym_PIPE] = ACTIONS(624),
    [anon_sym_AMP] = ACTIONS(624),
    [anon_sym_DOT] = ACTIONS(624),
    [anon_sym_TILDE] = ACTIONS(624),
    [anon_sym_QMARK] = ACTIONS(624),
    [anon_sym_AT] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(624),
    [anon_sym_LT_EQ] = ACTIONS(624),
    [anon_sym_EQ_EQ] = ACTIONS(624),
    [anon_sym_TILDE_EQ] = ACTIONS(624),
    [anon_sym_GT_EQ] = ACTIONS(624),
    [anon_sym_GT] = ACTIONS(624),
    [anon_sym_AMP_AMP] = ACTIONS(624),
    [anon_sym_PIPE_PIPE] = ACTIONS(624),
    [anon_sym_DOT_SQUOTE] = ACTIONS(624),
    [anon_sym_SQUOTE] = ACTIONS(624),
    [anon_sym_COMMA] = ACTIONS(624),
    [anon_sym_LBRACK] = ACTIONS(624),
    [anon_sym_LF] = ACTIONS(624),
    [anon_sym_SEMI] = ACTIONS(624),
    [anon_sym_LBRACE] = ACTIONS(624),
    [anon_sym_COLON] = ACTIONS(624),
    [anon_sym_return] = ACTIONS(624),
    [anon_sym_continue] = ACTIONS(624),
    [anon_sym_break] = ACTIONS(624),
    [anon_sym_elseif] = ACTIONS(624),
    [anon_sym_else] = ACTIONS(624),
    [anon_sym_if] = ACTIONS(624),
    [anon_sym_end] = ACTIONS(624),
    [anon_sym_for] = ACTIONS(624),
    [anon_sym_parfor] = ACTIONS(624),
    [anon_sym_while] = ACTIONS(624),
    [anon_sym_switch] = ACTIONS(624),
    [anon_sym_global] = ACTIONS(624),
    [anon_sym_persistent] = ACTIONS(624),
    [anon_sym_arguments] = ACTIONS(624),
    [anon_sym_function] = ACTIONS(624),
    [anon_sym_properties] = ACTIONS(624),
    [anon_sym_get] = ACTIONS(624),
    [anon_sym_set] = ACTIONS(624),
    [anon_sym_methods] = ACTIONS(624),
    [anon_sym_events] = ACTIONS(624),
    [anon_sym_enumeration] = ACTIONS(624),
    [anon_sym_classdef] = ACTIONS(624),
    [anon_sym_try] = ACTIONS(624),
    [anon_sym_spmd] = ACTIONS(624),
    [aux_sym_number_token1] = ACTIONS(624),
    [aux_sym_number_token2] = ACTIONS(624),
    [aux_sym_number_token3] = ACTIONS(624),
    [anon_sym_CR] = ACTIONS(624),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(629),
    [sym__single_quote_string_start] = ACTIONS(629),
    [sym__double_quote_string_start] = ACTIONS(629),
    [sym__multioutput_variable_start] = ACTIONS(629),
    [sym__external_identifier] = ACTIONS(629),
  },
  [STATE(139)] = {
    [anon_sym_LPAREN] = ACTIONS(707),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DOT_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_DOT_DASH] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DOT_STAR] = ACTIONS(707),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_DOT_SLASH] = ACTIONS(707),
    [anon_sym_BSLASH] = ACTIONS(707),
    [anon_sym_DOT_BSLASH] = ACTIONS(707),
    [anon_sym_CARET] = ACTIONS(707),
    [anon_sym_DOT_CARET] = ACTIONS(707),
    [anon_sym_PIPE] = ACTIONS(707),
    [anon_sym_AMP] = ACTIONS(707),
    [anon_sym_DOT] = ACTIONS(707),
    [anon_sym_TILDE] = ACTIONS(707),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_LT_EQ] = ACTIONS(707),
    [anon_sym_EQ_EQ] = ACTIONS(707),
    [anon_sym_TILDE_EQ] = ACTIONS(707),
    [anon_sym_GT_EQ] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_AMP_AMP] = ACTIONS(707),
    [anon_sym_PIPE_PIPE] = ACTIONS(707),
    [anon_sym_DOT_SQUOTE] = ACTIONS(707),
    [anon_sym_SQUOTE] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(707),
    [anon_sym_LBRACK] = ACTIONS(707),
    [anon_sym_LF] = ACTIONS(707),
    [anon_sym_SEMI] = ACTIONS(707),
    [anon_sym_LBRACE] = ACTIONS(707),
    [anon_sym_COLON] = ACTIONS(707),
    [anon_sym_return] = ACTIONS(707),
    [anon_sym_continue] = ACTIONS(707),
    [anon_sym_break] = ACTIONS(707),
    [anon_sym_elseif] = ACTIONS(707),
    [anon_sym_else] = ACTIONS(707),
    [anon_sym_if] = ACTIONS(707),
    [anon_sym_end] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(707),
    [anon_sym_parfor] = ACTIONS(707),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_switch] = ACTIONS(707),
    [anon_sym_global] = ACTIONS(707),
    [anon_sym_persistent] = ACTIONS(707),
    [anon_sym_arguments] = ACTIONS(707),
    [anon_sym_function] = ACTIONS(707),
    [anon_sym_properties] = ACTIONS(707),
    [anon_sym_get] = ACTIONS(707),
    [anon_sym_set] = ACTIONS(707),
    [anon_sym_methods] = ACTIONS(707),
    [anon_sym_events] = ACTIONS(707),
    [anon_sym_enumeration] = ACTIONS(707),
    [anon_sym_classdef] = ACTIONS(707),
    [anon_sym_try] = ACTIONS(707),
    [anon_sym_spmd] = ACTIONS(707),
    [aux_sym_number_token1] = ACTIONS(707),
    [aux_sym_number_token2] = ACTIONS(707),
    [aux_sym_number_token3] = ACTIONS(707),
    [anon_sym_CR] = ACTIONS(707),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(709),
    [sym__single_quote_string_start] = ACTIONS(709),
    [sym__double_quote_string_start] = ACTIONS(709),
    [sym__multioutput_variable_start] = ACTIONS(709),
    [sym__external_identifier] = ACTIONS(709),
  },
  [STATE(140)] = {
    [anon_sym_LPAREN] = ACTIONS(711),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(711),
    [anon_sym_QMARK] = ACTIONS(711),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT] = ACTIONS(713),
    [anon_sym_LT_EQ] = ACTIONS(713),
    [anon_sym_EQ_EQ] = ACTIONS(713),
    [anon_sym_TILDE_EQ] = ACTIONS(713),
    [anon_sym_GT_EQ] = ACTIONS(713),
    [anon_sym_GT] = ACTIONS(713),
    [anon_sym_AMP_AMP] = ACTIONS(713),
    [anon_sym_PIPE_PIPE] = ACTIONS(713),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(711),
    [anon_sym_LF] = ACTIONS(711),
    [anon_sym_SEMI] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(711),
    [anon_sym_COLON] = ACTIONS(711),
    [anon_sym_return] = ACTIONS(711),
    [anon_sym_continue] = ACTIONS(711),
    [anon_sym_break] = ACTIONS(711),
    [anon_sym_elseif] = ACTIONS(711),
    [anon_sym_else] = ACTIONS(711),
    [anon_sym_if] = ACTIONS(711),
    [anon_sym_end] = ACTIONS(711),
    [anon_sym_for] = ACTIONS(711),
    [anon_sym_parfor] = ACTIONS(711),
    [anon_sym_while] = ACTIONS(711),
    [anon_sym_switch] = ACTIONS(711),
    [anon_sym_global] = ACTIONS(711),
    [anon_sym_persistent] = ACTIONS(711),
    [anon_sym_arguments] = ACTIONS(711),
    [anon_sym_function] = ACTIONS(711),
    [anon_sym_properties] = ACTIONS(711),
    [anon_sym_get] = ACTIONS(711),
    [anon_sym_set] = ACTIONS(711),
    [anon_sym_methods] = ACTIONS(711),
    [anon_sym_events] = ACTIONS(711),
    [anon_sym_enumeration] = ACTIONS(711),
    [anon_sym_classdef] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(711),
    [anon_sym_spmd] = ACTIONS(711),
    [aux_sym_number_token1] = ACTIONS(711),
    [aux_sym_number_token2] = ACTIONS(711),
    [aux_sym_number_token3] = ACTIONS(711),
    [anon_sym_CR] = ACTIONS(711),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(716),
    [sym__single_quote_string_start] = ACTIONS(716),
    [sym__double_quote_string_start] = ACTIONS(716),
    [sym__multioutput_variable_start] = ACTIONS(716),
    [sym__external_identifier] = ACTIONS(716),
  },
  [STATE(141)] = {
    [anon_sym_LPAREN] = ACTIONS(681),
    [anon_sym_PLUS] = ACTIONS(681),
    [anon_sym_DOT_PLUS] = ACTIONS(681),
    [anon_sym_DASH] = ACTIONS(681),
    [anon_sym_DOT_DASH] = ACTIONS(681),
    [anon_sym_STAR] = ACTIONS(681),
    [anon_sym_DOT_STAR] = ACTIONS(681),
    [anon_sym_SLASH] = ACTIONS(681),
    [anon_sym_DOT_SLASH] = ACTIONS(681),
    [anon_sym_BSLASH] = ACTIONS(681),
    [anon_sym_DOT_BSLASH] = ACTIONS(681),
    [anon_sym_CARET] = ACTIONS(681),
    [anon_sym_DOT_CARET] = ACTIONS(681),
    [anon_sym_PIPE] = ACTIONS(681),
    [anon_sym_AMP] = ACTIONS(681),
    [anon_sym_TILDE] = ACTIONS(681),
    [anon_sym_QMARK] = ACTIONS(681),
    [anon_sym_AT] = ACTIONS(681),
    [anon_sym_LT] = ACTIONS(681),
    [anon_sym_LT_EQ] = ACTIONS(681),
    [anon_sym_EQ_EQ] = ACTIONS(681),
    [anon_sym_TILDE_EQ] = ACTIONS(681),
    [anon_sym_GT_EQ] = ACTIONS(681),
    [anon_sym_GT] = ACTIONS(681),
    [anon_sym_AMP_AMP] = ACTIONS(681),
    [anon_sym_PIPE_PIPE] = ACTIONS(681),
    [anon_sym_DOT_SQUOTE] = ACTIONS(681),
    [anon_sym_SQUOTE] = ACTIONS(681),
    [anon_sym_COMMA] = ACTIONS(681),
    [anon_sym_LBRACK] = ACTIONS(681),
    [anon_sym_LF] = ACTIONS(681),
    [anon_sym_SEMI] = ACTIONS(681),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_COLON] = ACTIONS(681),
    [anon_sym_return] = ACTIONS(681),
    [anon_sym_continue] = ACTIONS(681),
    [anon_sym_break] = ACTIONS(681),
    [anon_sym_elseif] = ACTIONS(681),
    [anon_sym_else] = ACTIONS(681),
    [anon_sym_if] = ACTIONS(681),
    [anon_sym_end] = ACTIONS(681),
    [anon_sym_for] = ACTIONS(681),
    [anon_sym_parfor] = ACTIONS(681),
    [anon_sym_while] = ACTIONS(681),
    [anon_sym_switch] = ACTIONS(681),
    [anon_sym_global] = ACTIONS(681),
    [anon_sym_persistent] = ACTIONS(681),
    [anon_sym_arguments] = ACTIONS(681),
    [anon_sym_function] = ACTIONS(681),
    [anon_sym_properties] = ACTIONS(681),
    [anon_sym_get] = ACTIONS(681),
    [anon_sym_set] = ACTIONS(681),
    [anon_sym_methods] = ACTIONS(681),
    [anon_sym_events] = ACTIONS(681),
    [anon_sym_enumeration] = ACTIONS(681),
    [anon_sym_classdef] = ACTIONS(681),
    [anon_sym_try] = ACTIONS(681),
    [anon_sym_spmd] = ACTIONS(681),
    [aux_sym_number_token1] = ACTIONS(681),
    [aux_sym_number_token2] = ACTIONS(681),
    [aux_sym_number_token3] = ACTIONS(681),
    [anon_sym_CR] = ACTIONS(681),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(685),
    [sym__single_quote_string_start] = ACTIONS(685),
    [sym__double_quote_string_start] = ACTIONS(685),
    [sym__multioutput_variable_start] = ACTIONS(685),
    [sym__external_identifier] = ACTIONS(685),
  },
  [STATE(142)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(143)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(718),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(144)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(582),
    [anon_sym_SQUOTE] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(582),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(145)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(582),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(146)] = {
    [anon_sym_LPAREN] = ACTIONS(720),
    [anon_sym_PLUS] = ACTIONS(720),
    [anon_sym_DOT_PLUS] = ACTIONS(720),
    [anon_sym_DASH] = ACTIONS(720),
    [anon_sym_DOT_DASH] = ACTIONS(720),
    [anon_sym_STAR] = ACTIONS(720),
    [anon_sym_DOT_STAR] = ACTIONS(720),
    [anon_sym_SLASH] = ACTIONS(720),
    [anon_sym_DOT_SLASH] = ACTIONS(720),
    [anon_sym_BSLASH] = ACTIONS(720),
    [anon_sym_DOT_BSLASH] = ACTIONS(720),
    [anon_sym_CARET] = ACTIONS(720),
    [anon_sym_DOT_CARET] = ACTIONS(720),
    [anon_sym_PIPE] = ACTIONS(720),
    [anon_sym_AMP] = ACTIONS(720),
    [anon_sym_TILDE] = ACTIONS(720),
    [anon_sym_QMARK] = ACTIONS(720),
    [anon_sym_AT] = ACTIONS(720),
    [anon_sym_LT] = ACTIONS(720),
    [anon_sym_LT_EQ] = ACTIONS(720),
    [anon_sym_EQ_EQ] = ACTIONS(720),
    [anon_sym_TILDE_EQ] = ACTIONS(720),
    [anon_sym_GT_EQ] = ACTIONS(720),
    [anon_sym_GT] = ACTIONS(720),
    [anon_sym_AMP_AMP] = ACTIONS(720),
    [anon_sym_PIPE_PIPE] = ACTIONS(720),
    [anon_sym_DOT_SQUOTE] = ACTIONS(720),
    [anon_sym_SQUOTE] = ACTIONS(720),
    [anon_sym_COMMA] = ACTIONS(720),
    [anon_sym_LBRACK] = ACTIONS(720),
    [anon_sym_LF] = ACTIONS(720),
    [anon_sym_SEMI] = ACTIONS(720),
    [anon_sym_LBRACE] = ACTIONS(720),
    [anon_sym_COLON] = ACTIONS(720),
    [anon_sym_return] = ACTIONS(720),
    [anon_sym_continue] = ACTIONS(720),
    [anon_sym_break] = ACTIONS(720),
    [anon_sym_elseif] = ACTIONS(720),
    [anon_sym_else] = ACTIONS(720),
    [anon_sym_if] = ACTIONS(720),
    [anon_sym_end] = ACTIONS(720),
    [anon_sym_for] = ACTIONS(720),
    [anon_sym_parfor] = ACTIONS(720),
    [anon_sym_while] = ACTIONS(720),
    [anon_sym_switch] = ACTIONS(720),
    [anon_sym_global] = ACTIONS(720),
    [anon_sym_persistent] = ACTIONS(720),
    [anon_sym_arguments] = ACTIONS(720),
    [anon_sym_function] = ACTIONS(720),
    [anon_sym_properties] = ACTIONS(720),
    [anon_sym_get] = ACTIONS(720),
    [anon_sym_set] = ACTIONS(720),
    [anon_sym_methods] = ACTIONS(720),
    [anon_sym_events] = ACTIONS(720),
    [anon_sym_enumeration] = ACTIONS(720),
    [anon_sym_classdef] = ACTIONS(720),
    [anon_sym_try] = ACTIONS(720),
    [anon_sym_spmd] = ACTIONS(720),
    [aux_sym_number_token1] = ACTIONS(720),
    [aux_sym_number_token2] = ACTIONS(720),
    [aux_sym_number_token3] = ACTIONS(720),
    [anon_sym_CR] = ACTIONS(720),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(722),
    [sym__single_quote_string_start] = ACTIONS(722),
    [sym__double_quote_string_start] = ACTIONS(722),
    [sym__multioutput_variable_start] = ACTIONS(722),
    [sym__external_identifier] = ACTIONS(722),
  },
  [STATE(147)] = {
    [anon_sym_LPAREN] = ACTIONS(595),
    [anon_sym_PLUS] = ACTIONS(595),
    [anon_sym_DOT_PLUS] = ACTIONS(595),
    [anon_sym_DASH] = ACTIONS(595),
    [anon_sym_DOT_DASH] = ACTIONS(595),
    [anon_sym_STAR] = ACTIONS(595),
    [anon_sym_DOT_STAR] = ACTIONS(595),
    [anon_sym_SLASH] = ACTIONS(595),
    [anon_sym_DOT_SLASH] = ACTIONS(595),
    [anon_sym_BSLASH] = ACTIONS(595),
    [anon_sym_DOT_BSLASH] = ACTIONS(595),
    [anon_sym_CARET] = ACTIONS(595),
    [anon_sym_DOT_CARET] = ACTIONS(595),
    [anon_sym_PIPE] = ACTIONS(595),
    [anon_sym_AMP] = ACTIONS(595),
    [anon_sym_TILDE] = ACTIONS(595),
    [anon_sym_QMARK] = ACTIONS(595),
    [anon_sym_AT] = ACTIONS(595),
    [anon_sym_LT] = ACTIONS(595),
    [anon_sym_LT_EQ] = ACTIONS(595),
    [anon_sym_EQ_EQ] = ACTIONS(595),
    [anon_sym_TILDE_EQ] = ACTIONS(595),
    [anon_sym_GT_EQ] = ACTIONS(595),
    [anon_sym_GT] = ACTIONS(595),
    [anon_sym_AMP_AMP] = ACTIONS(595),
    [anon_sym_PIPE_PIPE] = ACTIONS(595),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(595),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_LF] = ACTIONS(595),
    [anon_sym_SEMI] = ACTIONS(595),
    [anon_sym_LBRACE] = ACTIONS(595),
    [anon_sym_COLON] = ACTIONS(595),
    [anon_sym_return] = ACTIONS(595),
    [anon_sym_continue] = ACTIONS(595),
    [anon_sym_break] = ACTIONS(595),
    [anon_sym_elseif] = ACTIONS(595),
    [anon_sym_else] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_end] = ACTIONS(595),
    [anon_sym_for] = ACTIONS(595),
    [anon_sym_parfor] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(595),
    [anon_sym_switch] = ACTIONS(595),
    [anon_sym_global] = ACTIONS(595),
    [anon_sym_persistent] = ACTIONS(595),
    [anon_sym_arguments] = ACTIONS(595),
    [anon_sym_function] = ACTIONS(595),
    [anon_sym_properties] = ACTIONS(595),
    [anon_sym_get] = ACTIONS(595),
    [anon_sym_set] = ACTIONS(595),
    [anon_sym_methods] = ACTIONS(595),
    [anon_sym_events] = ACTIONS(595),
    [anon_sym_enumeration] = ACTIONS(595),
    [anon_sym_classdef] = ACTIONS(595),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_spmd] = ACTIONS(595),
    [aux_sym_number_token1] = ACTIONS(595),
    [aux_sym_number_token2] = ACTIONS(595),
    [aux_sym_number_token3] = ACTIONS(595),
    [anon_sym_CR] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(597),
    [sym__single_quote_string_start] = ACTIONS(597),
    [sym__double_quote_string_start] = ACTIONS(597),
    [sym__multioutput_variable_start] = ACTIONS(597),
    [sym__external_identifier] = ACTIONS(597),
  },
  [STATE(148)] = {
    [anon_sym_LPAREN] = ACTIONS(595),
    [anon_sym_PLUS] = ACTIONS(595),
    [anon_sym_DOT_PLUS] = ACTIONS(595),
    [anon_sym_DASH] = ACTIONS(595),
    [anon_sym_DOT_DASH] = ACTIONS(595),
    [anon_sym_STAR] = ACTIONS(595),
    [anon_sym_DOT_STAR] = ACTIONS(595),
    [anon_sym_SLASH] = ACTIONS(595),
    [anon_sym_DOT_SLASH] = ACTIONS(595),
    [anon_sym_BSLASH] = ACTIONS(595),
    [anon_sym_DOT_BSLASH] = ACTIONS(595),
    [anon_sym_CARET] = ACTIONS(595),
    [anon_sym_DOT_CARET] = ACTIONS(595),
    [anon_sym_PIPE] = ACTIONS(595),
    [anon_sym_AMP] = ACTIONS(595),
    [anon_sym_TILDE] = ACTIONS(595),
    [anon_sym_QMARK] = ACTIONS(595),
    [anon_sym_AT] = ACTIONS(595),
    [anon_sym_LT] = ACTIONS(595),
    [anon_sym_LT_EQ] = ACTIONS(595),
    [anon_sym_EQ_EQ] = ACTIONS(595),
    [anon_sym_TILDE_EQ] = ACTIONS(595),
    [anon_sym_GT_EQ] = ACTIONS(595),
    [anon_sym_GT] = ACTIONS(595),
    [anon_sym_AMP_AMP] = ACTIONS(595),
    [anon_sym_PIPE_PIPE] = ACTIONS(595),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(595),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_LF] = ACTIONS(595),
    [anon_sym_SEMI] = ACTIONS(595),
    [anon_sym_LBRACE] = ACTIONS(595),
    [anon_sym_COLON] = ACTIONS(595),
    [anon_sym_return] = ACTIONS(595),
    [anon_sym_continue] = ACTIONS(595),
    [anon_sym_break] = ACTIONS(595),
    [anon_sym_elseif] = ACTIONS(595),
    [anon_sym_else] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_end] = ACTIONS(595),
    [anon_sym_for] = ACTIONS(595),
    [anon_sym_parfor] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(595),
    [anon_sym_switch] = ACTIONS(595),
    [anon_sym_global] = ACTIONS(595),
    [anon_sym_persistent] = ACTIONS(595),
    [anon_sym_arguments] = ACTIONS(595),
    [anon_sym_function] = ACTIONS(595),
    [anon_sym_properties] = ACTIONS(595),
    [anon_sym_get] = ACTIONS(595),
    [anon_sym_set] = ACTIONS(595),
    [anon_sym_methods] = ACTIONS(595),
    [anon_sym_events] = ACTIONS(595),
    [anon_sym_enumeration] = ACTIONS(595),
    [anon_sym_classdef] = ACTIONS(595),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_spmd] = ACTIONS(595),
    [aux_sym_number_token1] = ACTIONS(595),
    [aux_sym_number_token2] = ACTIONS(595),
    [aux_sym_number_token3] = ACTIONS(595),
    [anon_sym_CR] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(597),
    [sym__single_quote_string_start] = ACTIONS(597),
    [sym__double_quote_string_start] = ACTIONS(597),
    [sym__multioutput_variable_start] = ACTIONS(597),
    [sym__external_identifier] = ACTIONS(597),
  },
  [STATE(149)] = {
    [anon_sym_LPAREN] = ACTIONS(595),
    [anon_sym_PLUS] = ACTIONS(595),
    [anon_sym_DOT_PLUS] = ACTIONS(595),
    [anon_sym_DASH] = ACTIONS(595),
    [anon_sym_DOT_DASH] = ACTIONS(595),
    [anon_sym_STAR] = ACTIONS(595),
    [anon_sym_DOT_STAR] = ACTIONS(595),
    [anon_sym_SLASH] = ACTIONS(595),
    [anon_sym_DOT_SLASH] = ACTIONS(595),
    [anon_sym_BSLASH] = ACTIONS(595),
    [anon_sym_DOT_BSLASH] = ACTIONS(595),
    [anon_sym_CARET] = ACTIONS(595),
    [anon_sym_DOT_CARET] = ACTIONS(595),
    [anon_sym_PIPE] = ACTIONS(595),
    [anon_sym_AMP] = ACTIONS(595),
    [anon_sym_TILDE] = ACTIONS(595),
    [anon_sym_QMARK] = ACTIONS(595),
    [anon_sym_AT] = ACTIONS(595),
    [anon_sym_LT] = ACTIONS(595),
    [anon_sym_LT_EQ] = ACTIONS(595),
    [anon_sym_EQ_EQ] = ACTIONS(595),
    [anon_sym_TILDE_EQ] = ACTIONS(595),
    [anon_sym_GT_EQ] = ACTIONS(595),
    [anon_sym_GT] = ACTIONS(595),
    [anon_sym_AMP_AMP] = ACTIONS(595),
    [anon_sym_PIPE_PIPE] = ACTIONS(595),
    [anon_sym_DOT_SQUOTE] = ACTIONS(595),
    [anon_sym_SQUOTE] = ACTIONS(595),
    [anon_sym_COMMA] = ACTIONS(595),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_LF] = ACTIONS(595),
    [anon_sym_SEMI] = ACTIONS(595),
    [anon_sym_LBRACE] = ACTIONS(595),
    [anon_sym_COLON] = ACTIONS(595),
    [anon_sym_return] = ACTIONS(595),
    [anon_sym_continue] = ACTIONS(595),
    [anon_sym_break] = ACTIONS(595),
    [anon_sym_elseif] = ACTIONS(595),
    [anon_sym_else] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_end] = ACTIONS(595),
    [anon_sym_for] = ACTIONS(595),
    [anon_sym_parfor] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(595),
    [anon_sym_switch] = ACTIONS(595),
    [anon_sym_global] = ACTIONS(595),
    [anon_sym_persistent] = ACTIONS(595),
    [anon_sym_arguments] = ACTIONS(595),
    [anon_sym_function] = ACTIONS(595),
    [anon_sym_properties] = ACTIONS(595),
    [anon_sym_get] = ACTIONS(595),
    [anon_sym_set] = ACTIONS(595),
    [anon_sym_methods] = ACTIONS(595),
    [anon_sym_events] = ACTIONS(595),
    [anon_sym_enumeration] = ACTIONS(595),
    [anon_sym_classdef] = ACTIONS(595),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_spmd] = ACTIONS(595),
    [aux_sym_number_token1] = ACTIONS(595),
    [aux_sym_number_token2] = ACTIONS(595),
    [aux_sym_number_token3] = ACTIONS(595),
    [anon_sym_CR] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(597),
    [sym__single_quote_string_start] = ACTIONS(597),
    [sym__double_quote_string_start] = ACTIONS(597),
    [sym__multioutput_variable_start] = ACTIONS(597),
    [sym__external_identifier] = ACTIONS(597),
  },
  [STATE(150)] = {
    [anon_sym_LPAREN] = ACTIONS(595),
    [anon_sym_PLUS] = ACTIONS(595),
    [anon_sym_DOT_PLUS] = ACTIONS(595),
    [anon_sym_DASH] = ACTIONS(595),
    [anon_sym_DOT_DASH] = ACTIONS(595),
    [anon_sym_STAR] = ACTIONS(595),
    [anon_sym_DOT_STAR] = ACTIONS(595),
    [anon_sym_SLASH] = ACTIONS(595),
    [anon_sym_DOT_SLASH] = ACTIONS(595),
    [anon_sym_BSLASH] = ACTIONS(595),
    [anon_sym_DOT_BSLASH] = ACTIONS(595),
    [anon_sym_CARET] = ACTIONS(595),
    [anon_sym_DOT_CARET] = ACTIONS(595),
    [anon_sym_PIPE] = ACTIONS(595),
    [anon_sym_AMP] = ACTIONS(595),
    [anon_sym_TILDE] = ACTIONS(595),
    [anon_sym_QMARK] = ACTIONS(595),
    [anon_sym_AT] = ACTIONS(595),
    [anon_sym_LT] = ACTIONS(595),
    [anon_sym_LT_EQ] = ACTIONS(595),
    [anon_sym_EQ_EQ] = ACTIONS(595),
    [anon_sym_TILDE_EQ] = ACTIONS(595),
    [anon_sym_GT_EQ] = ACTIONS(595),
    [anon_sym_GT] = ACTIONS(595),
    [anon_sym_AMP_AMP] = ACTIONS(595),
    [anon_sym_PIPE_PIPE] = ACTIONS(595),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(595),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_LF] = ACTIONS(595),
    [anon_sym_SEMI] = ACTIONS(595),
    [anon_sym_LBRACE] = ACTIONS(595),
    [anon_sym_COLON] = ACTIONS(595),
    [anon_sym_return] = ACTIONS(595),
    [anon_sym_continue] = ACTIONS(595),
    [anon_sym_break] = ACTIONS(595),
    [anon_sym_elseif] = ACTIONS(595),
    [anon_sym_else] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_end] = ACTIONS(595),
    [anon_sym_for] = ACTIONS(595),
    [anon_sym_parfor] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(595),
    [anon_sym_switch] = ACTIONS(595),
    [anon_sym_global] = ACTIONS(595),
    [anon_sym_persistent] = ACTIONS(595),
    [anon_sym_arguments] = ACTIONS(595),
    [anon_sym_function] = ACTIONS(595),
    [anon_sym_properties] = ACTIONS(595),
    [anon_sym_get] = ACTIONS(595),
    [anon_sym_set] = ACTIONS(595),
    [anon_sym_methods] = ACTIONS(595),
    [anon_sym_events] = ACTIONS(595),
    [anon_sym_enumeration] = ACTIONS(595),
    [anon_sym_classdef] = ACTIONS(595),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_spmd] = ACTIONS(595),
    [aux_sym_number_token1] = ACTIONS(595),
    [aux_sym_number_token2] = ACTIONS(595),
    [aux_sym_number_token3] = ACTIONS(595),
    [anon_sym_CR] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(597),
    [sym__single_quote_string_start] = ACTIONS(597),
    [sym__double_quote_string_start] = ACTIONS(597),
    [sym__multioutput_variable_start] = ACTIONS(597),
    [sym__external_identifier] = ACTIONS(597),
  },
  [STATE(151)] = {
    [anon_sym_LPAREN] = ACTIONS(724),
    [anon_sym_PLUS] = ACTIONS(724),
    [anon_sym_DOT_PLUS] = ACTIONS(724),
    [anon_sym_DASH] = ACTIONS(724),
    [anon_sym_DOT_DASH] = ACTIONS(724),
    [anon_sym_STAR] = ACTIONS(724),
    [anon_sym_DOT_STAR] = ACTIONS(724),
    [anon_sym_SLASH] = ACTIONS(724),
    [anon_sym_DOT_SLASH] = ACTIONS(724),
    [anon_sym_BSLASH] = ACTIONS(724),
    [anon_sym_DOT_BSLASH] = ACTIONS(724),
    [anon_sym_CARET] = ACTIONS(724),
    [anon_sym_DOT_CARET] = ACTIONS(724),
    [anon_sym_PIPE] = ACTIONS(724),
    [anon_sym_AMP] = ACTIONS(724),
    [anon_sym_TILDE] = ACTIONS(724),
    [anon_sym_QMARK] = ACTIONS(724),
    [anon_sym_AT] = ACTIONS(724),
    [anon_sym_LT] = ACTIONS(726),
    [anon_sym_LT_EQ] = ACTIONS(726),
    [anon_sym_EQ_EQ] = ACTIONS(726),
    [anon_sym_TILDE_EQ] = ACTIONS(726),
    [anon_sym_GT_EQ] = ACTIONS(726),
    [anon_sym_GT] = ACTIONS(726),
    [anon_sym_AMP_AMP] = ACTIONS(724),
    [anon_sym_PIPE_PIPE] = ACTIONS(724),
    [anon_sym_DOT_SQUOTE] = ACTIONS(724),
    [anon_sym_SQUOTE] = ACTIONS(724),
    [anon_sym_COMMA] = ACTIONS(724),
    [anon_sym_LBRACK] = ACTIONS(724),
    [anon_sym_LF] = ACTIONS(724),
    [anon_sym_SEMI] = ACTIONS(724),
    [anon_sym_LBRACE] = ACTIONS(724),
    [anon_sym_COLON] = ACTIONS(724),
    [anon_sym_return] = ACTIONS(724),
    [anon_sym_continue] = ACTIONS(724),
    [anon_sym_break] = ACTIONS(724),
    [anon_sym_elseif] = ACTIONS(724),
    [anon_sym_else] = ACTIONS(724),
    [anon_sym_if] = ACTIONS(724),
    [anon_sym_end] = ACTIONS(724),
    [anon_sym_for] = ACTIONS(724),
    [anon_sym_parfor] = ACTIONS(724),
    [anon_sym_while] = ACTIONS(724),
    [anon_sym_switch] = ACTIONS(724),
    [anon_sym_global] = ACTIONS(724),
    [anon_sym_persistent] = ACTIONS(724),
    [anon_sym_arguments] = ACTIONS(724),
    [anon_sym_function] = ACTIONS(724),
    [anon_sym_properties] = ACTIONS(724),
    [anon_sym_get] = ACTIONS(724),
    [anon_sym_set] = ACTIONS(724),
    [anon_sym_methods] = ACTIONS(724),
    [anon_sym_events] = ACTIONS(724),
    [anon_sym_enumeration] = ACTIONS(724),
    [anon_sym_classdef] = ACTIONS(724),
    [anon_sym_try] = ACTIONS(724),
    [anon_sym_spmd] = ACTIONS(724),
    [aux_sym_number_token1] = ACTIONS(724),
    [aux_sym_number_token2] = ACTIONS(724),
    [aux_sym_number_token3] = ACTIONS(724),
    [anon_sym_CR] = ACTIONS(724),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(728),
    [sym__single_quote_string_start] = ACTIONS(728),
    [sym__double_quote_string_start] = ACTIONS(728),
    [sym__multioutput_variable_start] = ACTIONS(728),
    [sym__external_identifier] = ACTIONS(728),
  },
  [STATE(152)] = {
    [anon_sym_LPAREN] = ACTIONS(730),
    [anon_sym_PLUS] = ACTIONS(730),
    [anon_sym_DOT_PLUS] = ACTIONS(730),
    [anon_sym_DASH] = ACTIONS(730),
    [anon_sym_DOT_DASH] = ACTIONS(730),
    [anon_sym_STAR] = ACTIONS(730),
    [anon_sym_DOT_STAR] = ACTIONS(730),
    [anon_sym_SLASH] = ACTIONS(730),
    [anon_sym_DOT_SLASH] = ACTIONS(730),
    [anon_sym_BSLASH] = ACTIONS(730),
    [anon_sym_DOT_BSLASH] = ACTIONS(730),
    [anon_sym_CARET] = ACTIONS(730),
    [anon_sym_DOT_CARET] = ACTIONS(730),
    [anon_sym_PIPE] = ACTIONS(730),
    [anon_sym_AMP] = ACTIONS(730),
    [anon_sym_TILDE] = ACTIONS(730),
    [anon_sym_QMARK] = ACTIONS(730),
    [anon_sym_AT] = ACTIONS(730),
    [anon_sym_LT] = ACTIONS(730),
    [anon_sym_LT_EQ] = ACTIONS(730),
    [anon_sym_EQ_EQ] = ACTIONS(730),
    [anon_sym_TILDE_EQ] = ACTIONS(730),
    [anon_sym_GT_EQ] = ACTIONS(730),
    [anon_sym_GT] = ACTIONS(730),
    [anon_sym_AMP_AMP] = ACTIONS(730),
    [anon_sym_PIPE_PIPE] = ACTIONS(730),
    [anon_sym_DOT_SQUOTE] = ACTIONS(730),
    [anon_sym_SQUOTE] = ACTIONS(730),
    [anon_sym_COMMA] = ACTIONS(730),
    [anon_sym_LBRACK] = ACTIONS(730),
    [anon_sym_LF] = ACTIONS(730),
    [anon_sym_SEMI] = ACTIONS(730),
    [anon_sym_LBRACE] = ACTIONS(730),
    [anon_sym_COLON] = ACTIONS(730),
    [anon_sym_return] = ACTIONS(730),
    [anon_sym_continue] = ACTIONS(730),
    [anon_sym_break] = ACTIONS(730),
    [anon_sym_elseif] = ACTIONS(730),
    [anon_sym_else] = ACTIONS(730),
    [anon_sym_if] = ACTIONS(730),
    [anon_sym_end] = ACTIONS(730),
    [anon_sym_for] = ACTIONS(730),
    [anon_sym_parfor] = ACTIONS(730),
    [anon_sym_while] = ACTIONS(730),
    [anon_sym_switch] = ACTIONS(730),
    [anon_sym_global] = ACTIONS(730),
    [anon_sym_persistent] = ACTIONS(730),
    [anon_sym_arguments] = ACTIONS(730),
    [anon_sym_function] = ACTIONS(730),
    [anon_sym_properties] = ACTIONS(730),
    [anon_sym_get] = ACTIONS(730),
    [anon_sym_set] = ACTIONS(730),
    [anon_sym_methods] = ACTIONS(730),
    [anon_sym_events] = ACTIONS(730),
    [anon_sym_enumeration] = ACTIONS(730),
    [anon_sym_classdef] = ACTIONS(730),
    [anon_sym_try] = ACTIONS(730),
    [anon_sym_spmd] = ACTIONS(730),
    [aux_sym_number_token1] = ACTIONS(730),
    [aux_sym_number_token2] = ACTIONS(730),
    [aux_sym_number_token3] = ACTIONS(730),
    [anon_sym_CR] = ACTIONS(730),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(732),
    [sym__single_quote_string_start] = ACTIONS(732),
    [sym__double_quote_string_start] = ACTIONS(732),
    [sym__multioutput_variable_start] = ACTIONS(732),
    [sym__external_identifier] = ACTIONS(732),
  },
  [STATE(153)] = {
    [anon_sym_LPAREN] = ACTIONS(734),
    [anon_sym_PLUS] = ACTIONS(734),
    [anon_sym_DOT_PLUS] = ACTIONS(734),
    [anon_sym_DASH] = ACTIONS(734),
    [anon_sym_DOT_DASH] = ACTIONS(734),
    [anon_sym_STAR] = ACTIONS(734),
    [anon_sym_DOT_STAR] = ACTIONS(734),
    [anon_sym_SLASH] = ACTIONS(734),
    [anon_sym_DOT_SLASH] = ACTIONS(734),
    [anon_sym_BSLASH] = ACTIONS(734),
    [anon_sym_DOT_BSLASH] = ACTIONS(734),
    [anon_sym_CARET] = ACTIONS(734),
    [anon_sym_DOT_CARET] = ACTIONS(734),
    [anon_sym_PIPE] = ACTIONS(734),
    [anon_sym_AMP] = ACTIONS(734),
    [anon_sym_TILDE] = ACTIONS(734),
    [anon_sym_QMARK] = ACTIONS(734),
    [anon_sym_AT] = ACTIONS(734),
    [anon_sym_LT] = ACTIONS(734),
    [anon_sym_LT_EQ] = ACTIONS(734),
    [anon_sym_EQ_EQ] = ACTIONS(734),
    [anon_sym_TILDE_EQ] = ACTIONS(734),
    [anon_sym_GT_EQ] = ACTIONS(734),
    [anon_sym_GT] = ACTIONS(734),
    [anon_sym_AMP_AMP] = ACTIONS(734),
    [anon_sym_PIPE_PIPE] = ACTIONS(734),
    [anon_sym_DOT_SQUOTE] = ACTIONS(734),
    [anon_sym_SQUOTE] = ACTIONS(734),
    [anon_sym_COMMA] = ACTIONS(734),
    [anon_sym_LBRACK] = ACTIONS(734),
    [anon_sym_LF] = ACTIONS(734),
    [anon_sym_SEMI] = ACTIONS(734),
    [anon_sym_LBRACE] = ACTIONS(734),
    [anon_sym_COLON] = ACTIONS(734),
    [anon_sym_return] = ACTIONS(734),
    [anon_sym_continue] = ACTIONS(734),
    [anon_sym_break] = ACTIONS(734),
    [anon_sym_elseif] = ACTIONS(734),
    [anon_sym_else] = ACTIONS(734),
    [anon_sym_if] = ACTIONS(734),
    [anon_sym_end] = ACTIONS(734),
    [anon_sym_for] = ACTIONS(734),
    [anon_sym_parfor] = ACTIONS(734),
    [anon_sym_while] = ACTIONS(734),
    [anon_sym_switch] = ACTIONS(734),
    [anon_sym_global] = ACTIONS(734),
    [anon_sym_persistent] = ACTIONS(734),
    [anon_sym_arguments] = ACTIONS(734),
    [anon_sym_function] = ACTIONS(734),
    [anon_sym_properties] = ACTIONS(734),
    [anon_sym_get] = ACTIONS(734),
    [anon_sym_set] = ACTIONS(734),
    [anon_sym_methods] = ACTIONS(734),
    [anon_sym_events] = ACTIONS(734),
    [anon_sym_enumeration] = ACTIONS(734),
    [anon_sym_classdef] = ACTIONS(734),
    [anon_sym_try] = ACTIONS(734),
    [anon_sym_spmd] = ACTIONS(734),
    [aux_sym_number_token1] = ACTIONS(734),
    [aux_sym_number_token2] = ACTIONS(734),
    [aux_sym_number_token3] = ACTIONS(734),
    [anon_sym_CR] = ACTIONS(734),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(736),
    [sym__single_quote_string_start] = ACTIONS(736),
    [sym__double_quote_string_start] = ACTIONS(736),
    [sym__multioutput_variable_start] = ACTIONS(736),
    [sym__external_identifier] = ACTIONS(736),
  },
  [STATE(154)] = {
    [anon_sym_LPAREN] = ACTIONS(738),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_DOT_PLUS] = ACTIONS(738),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_DOT_DASH] = ACTIONS(738),
    [anon_sym_STAR] = ACTIONS(738),
    [anon_sym_DOT_STAR] = ACTIONS(738),
    [anon_sym_SLASH] = ACTIONS(738),
    [anon_sym_DOT_SLASH] = ACTIONS(738),
    [anon_sym_BSLASH] = ACTIONS(738),
    [anon_sym_DOT_BSLASH] = ACTIONS(738),
    [anon_sym_CARET] = ACTIONS(738),
    [anon_sym_DOT_CARET] = ACTIONS(738),
    [anon_sym_PIPE] = ACTIONS(738),
    [anon_sym_AMP] = ACTIONS(738),
    [anon_sym_TILDE] = ACTIONS(738),
    [anon_sym_QMARK] = ACTIONS(738),
    [anon_sym_AT] = ACTIONS(738),
    [anon_sym_LT] = ACTIONS(738),
    [anon_sym_LT_EQ] = ACTIONS(738),
    [anon_sym_EQ_EQ] = ACTIONS(738),
    [anon_sym_TILDE_EQ] = ACTIONS(738),
    [anon_sym_GT_EQ] = ACTIONS(738),
    [anon_sym_GT] = ACTIONS(738),
    [anon_sym_AMP_AMP] = ACTIONS(738),
    [anon_sym_PIPE_PIPE] = ACTIONS(738),
    [anon_sym_DOT_SQUOTE] = ACTIONS(738),
    [anon_sym_SQUOTE] = ACTIONS(738),
    [anon_sym_COMMA] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(738),
    [anon_sym_LF] = ACTIONS(738),
    [anon_sym_SEMI] = ACTIONS(738),
    [anon_sym_LBRACE] = ACTIONS(738),
    [anon_sym_COLON] = ACTIONS(738),
    [anon_sym_return] = ACTIONS(738),
    [anon_sym_continue] = ACTIONS(738),
    [anon_sym_break] = ACTIONS(738),
    [anon_sym_elseif] = ACTIONS(738),
    [anon_sym_else] = ACTIONS(738),
    [anon_sym_if] = ACTIONS(738),
    [anon_sym_end] = ACTIONS(738),
    [anon_sym_for] = ACTIONS(738),
    [anon_sym_parfor] = ACTIONS(738),
    [anon_sym_while] = ACTIONS(738),
    [anon_sym_switch] = ACTIONS(738),
    [anon_sym_global] = ACTIONS(738),
    [anon_sym_persistent] = ACTIONS(738),
    [anon_sym_arguments] = ACTIONS(738),
    [anon_sym_function] = ACTIONS(738),
    [anon_sym_properties] = ACTIONS(738),
    [anon_sym_get] = ACTIONS(738),
    [anon_sym_set] = ACTIONS(738),
    [anon_sym_methods] = ACTIONS(738),
    [anon_sym_events] = ACTIONS(738),
    [anon_sym_enumeration] = ACTIONS(738),
    [anon_sym_classdef] = ACTIONS(738),
    [anon_sym_try] = ACTIONS(738),
    [anon_sym_spmd] = ACTIONS(738),
    [aux_sym_number_token1] = ACTIONS(738),
    [aux_sym_number_token2] = ACTIONS(738),
    [aux_sym_number_token3] = ACTIONS(738),
    [anon_sym_CR] = ACTIONS(738),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(740),
    [sym__single_quote_string_start] = ACTIONS(740),
    [sym__double_quote_string_start] = ACTIONS(740),
    [sym__multioutput_variable_start] = ACTIONS(740),
    [sym__external_identifier] = ACTIONS(740),
  },
  [STATE(155)] = {
    [anon_sym_LPAREN] = ACTIONS(742),
    [anon_sym_PLUS] = ACTIONS(742),
    [anon_sym_DOT_PLUS] = ACTIONS(742),
    [anon_sym_DASH] = ACTIONS(742),
    [anon_sym_DOT_DASH] = ACTIONS(742),
    [anon_sym_STAR] = ACTIONS(742),
    [anon_sym_DOT_STAR] = ACTIONS(742),
    [anon_sym_SLASH] = ACTIONS(742),
    [anon_sym_DOT_SLASH] = ACTIONS(742),
    [anon_sym_BSLASH] = ACTIONS(742),
    [anon_sym_DOT_BSLASH] = ACTIONS(742),
    [anon_sym_CARET] = ACTIONS(742),
    [anon_sym_DOT_CARET] = ACTIONS(742),
    [anon_sym_PIPE] = ACTIONS(742),
    [anon_sym_AMP] = ACTIONS(742),
    [anon_sym_TILDE] = ACTIONS(742),
    [anon_sym_QMARK] = ACTIONS(742),
    [anon_sym_AT] = ACTIONS(742),
    [anon_sym_LT] = ACTIONS(742),
    [anon_sym_LT_EQ] = ACTIONS(742),
    [anon_sym_EQ_EQ] = ACTIONS(742),
    [anon_sym_TILDE_EQ] = ACTIONS(742),
    [anon_sym_GT_EQ] = ACTIONS(742),
    [anon_sym_GT] = ACTIONS(742),
    [anon_sym_AMP_AMP] = ACTIONS(742),
    [anon_sym_PIPE_PIPE] = ACTIONS(742),
    [anon_sym_DOT_SQUOTE] = ACTIONS(742),
    [anon_sym_SQUOTE] = ACTIONS(742),
    [anon_sym_COMMA] = ACTIONS(742),
    [anon_sym_LBRACK] = ACTIONS(742),
    [anon_sym_LF] = ACTIONS(742),
    [anon_sym_SEMI] = ACTIONS(742),
    [anon_sym_LBRACE] = ACTIONS(742),
    [anon_sym_COLON] = ACTIONS(742),
    [anon_sym_return] = ACTIONS(742),
    [anon_sym_continue] = ACTIONS(742),
    [anon_sym_break] = ACTIONS(742),
    [anon_sym_elseif] = ACTIONS(742),
    [anon_sym_else] = ACTIONS(742),
    [anon_sym_if] = ACTIONS(742),
    [anon_sym_end] = ACTIONS(742),
    [anon_sym_for] = ACTIONS(742),
    [anon_sym_parfor] = ACTIONS(742),
    [anon_sym_while] = ACTIONS(742),
    [anon_sym_switch] = ACTIONS(742),
    [anon_sym_global] = ACTIONS(742),
    [anon_sym_persistent] = ACTIONS(742),
    [anon_sym_arguments] = ACTIONS(742),
    [anon_sym_function] = ACTIONS(742),
    [anon_sym_properties] = ACTIONS(742),
    [anon_sym_get] = ACTIONS(742),
    [anon_sym_set] = ACTIONS(742),
    [anon_sym_methods] = ACTIONS(742),
    [anon_sym_events] = ACTIONS(742),
    [anon_sym_enumeration] = ACTIONS(742),
    [anon_sym_classdef] = ACTIONS(742),
    [anon_sym_try] = ACTIONS(742),
    [anon_sym_spmd] = ACTIONS(742),
    [aux_sym_number_token1] = ACTIONS(742),
    [aux_sym_number_token2] = ACTIONS(742),
    [aux_sym_number_token3] = ACTIONS(742),
    [anon_sym_CR] = ACTIONS(742),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(744),
    [sym__single_quote_string_start] = ACTIONS(744),
    [sym__double_quote_string_start] = ACTIONS(744),
    [sym__multioutput_variable_start] = ACTIONS(744),
    [sym__external_identifier] = ACTIONS(744),
  },
  [STATE(156)] = {
    [anon_sym_LPAREN] = ACTIONS(746),
    [anon_sym_PLUS] = ACTIONS(746),
    [anon_sym_DOT_PLUS] = ACTIONS(746),
    [anon_sym_DASH] = ACTIONS(746),
    [anon_sym_DOT_DASH] = ACTIONS(746),
    [anon_sym_STAR] = ACTIONS(746),
    [anon_sym_DOT_STAR] = ACTIONS(746),
    [anon_sym_SLASH] = ACTIONS(746),
    [anon_sym_DOT_SLASH] = ACTIONS(746),
    [anon_sym_BSLASH] = ACTIONS(746),
    [anon_sym_DOT_BSLASH] = ACTIONS(746),
    [anon_sym_CARET] = ACTIONS(746),
    [anon_sym_DOT_CARET] = ACTIONS(746),
    [anon_sym_PIPE] = ACTIONS(746),
    [anon_sym_AMP] = ACTIONS(746),
    [anon_sym_TILDE] = ACTIONS(746),
    [anon_sym_QMARK] = ACTIONS(746),
    [anon_sym_AT] = ACTIONS(746),
    [anon_sym_LT] = ACTIONS(746),
    [anon_sym_LT_EQ] = ACTIONS(746),
    [anon_sym_EQ_EQ] = ACTIONS(746),
    [anon_sym_TILDE_EQ] = ACTIONS(746),
    [anon_sym_GT_EQ] = ACTIONS(746),
    [anon_sym_GT] = ACTIONS(746),
    [anon_sym_AMP_AMP] = ACTIONS(746),
    [anon_sym_PIPE_PIPE] = ACTIONS(746),
    [anon_sym_DOT_SQUOTE] = ACTIONS(746),
    [anon_sym_SQUOTE] = ACTIONS(746),
    [anon_sym_COMMA] = ACTIONS(746),
    [anon_sym_LBRACK] = ACTIONS(746),
    [anon_sym_LF] = ACTIONS(746),
    [anon_sym_SEMI] = ACTIONS(746),
    [anon_sym_LBRACE] = ACTIONS(746),
    [anon_sym_COLON] = ACTIONS(746),
    [anon_sym_return] = ACTIONS(746),
    [anon_sym_continue] = ACTIONS(746),
    [anon_sym_break] = ACTIONS(746),
    [anon_sym_elseif] = ACTIONS(746),
    [anon_sym_else] = ACTIONS(746),
    [anon_sym_if] = ACTIONS(746),
    [anon_sym_end] = ACTIONS(746),
    [anon_sym_for] = ACTIONS(746),
    [anon_sym_parfor] = ACTIONS(746),
    [anon_sym_while] = ACTIONS(746),
    [anon_sym_switch] = ACTIONS(746),
    [anon_sym_global] = ACTIONS(746),
    [anon_sym_persistent] = ACTIONS(746),
    [anon_sym_arguments] = ACTIONS(746),
    [anon_sym_function] = ACTIONS(746),
    [anon_sym_properties] = ACTIONS(746),
    [anon_sym_get] = ACTIONS(746),
    [anon_sym_set] = ACTIONS(746),
    [anon_sym_methods] = ACTIONS(746),
    [anon_sym_events] = ACTIONS(746),
    [anon_sym_enumeration] = ACTIONS(746),
    [anon_sym_classdef] = ACTIONS(746),
    [anon_sym_try] = ACTIONS(746),
    [anon_sym_spmd] = ACTIONS(746),
    [aux_sym_number_token1] = ACTIONS(746),
    [aux_sym_number_token2] = ACTIONS(746),
    [aux_sym_number_token3] = ACTIONS(746),
    [anon_sym_CR] = ACTIONS(746),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(748),
    [sym__single_quote_string_start] = ACTIONS(748),
    [sym__double_quote_string_start] = ACTIONS(748),
    [sym__multioutput_variable_start] = ACTIONS(748),
    [sym__external_identifier] = ACTIONS(748),
  },
  [STATE(157)] = {
    [anon_sym_LPAREN] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(69),
    [anon_sym_DOT_PLUS] = ACTIONS(69),
    [anon_sym_DASH] = ACTIONS(69),
    [anon_sym_DOT_DASH] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(69),
    [anon_sym_DOT_STAR] = ACTIONS(69),
    [anon_sym_SLASH] = ACTIONS(69),
    [anon_sym_DOT_SLASH] = ACTIONS(69),
    [anon_sym_BSLASH] = ACTIONS(69),
    [anon_sym_DOT_BSLASH] = ACTIONS(69),
    [anon_sym_CARET] = ACTIONS(69),
    [anon_sym_DOT_CARET] = ACTIONS(69),
    [anon_sym_PIPE] = ACTIONS(69),
    [anon_sym_AMP] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(69),
    [anon_sym_QMARK] = ACTIONS(69),
    [anon_sym_AT] = ACTIONS(69),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(69),
    [anon_sym_PIPE_PIPE] = ACTIONS(69),
    [anon_sym_DOT_SQUOTE] = ACTIONS(69),
    [anon_sym_SQUOTE] = ACTIONS(69),
    [anon_sym_COMMA] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(69),
    [anon_sym_LF] = ACTIONS(69),
    [anon_sym_SEMI] = ACTIONS(69),
    [anon_sym_LBRACE] = ACTIONS(69),
    [anon_sym_COLON] = ACTIONS(69),
    [anon_sym_return] = ACTIONS(69),
    [anon_sym_continue] = ACTIONS(69),
    [anon_sym_break] = ACTIONS(69),
    [anon_sym_elseif] = ACTIONS(69),
    [anon_sym_else] = ACTIONS(69),
    [anon_sym_if] = ACTIONS(69),
    [anon_sym_end] = ACTIONS(69),
    [anon_sym_for] = ACTIONS(69),
    [anon_sym_parfor] = ACTIONS(69),
    [anon_sym_while] = ACTIONS(69),
    [anon_sym_switch] = ACTIONS(69),
    [anon_sym_global] = ACTIONS(69),
    [anon_sym_persistent] = ACTIONS(69),
    [anon_sym_arguments] = ACTIONS(69),
    [anon_sym_function] = ACTIONS(69),
    [anon_sym_properties] = ACTIONS(69),
    [anon_sym_get] = ACTIONS(69),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_methods] = ACTIONS(69),
    [anon_sym_events] = ACTIONS(69),
    [anon_sym_enumeration] = ACTIONS(69),
    [anon_sym_classdef] = ACTIONS(69),
    [anon_sym_try] = ACTIONS(69),
    [anon_sym_spmd] = ACTIONS(69),
    [aux_sym_number_token1] = ACTIONS(69),
    [aux_sym_number_token2] = ACTIONS(69),
    [aux_sym_number_token3] = ACTIONS(69),
    [anon_sym_CR] = ACTIONS(69),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(750),
    [sym__single_quote_string_start] = ACTIONS(750),
    [sym__double_quote_string_start] = ACTIONS(750),
    [sym__multioutput_variable_start] = ACTIONS(750),
    [sym__external_identifier] = ACTIONS(750),
  },
  [STATE(158)] = {
    [anon_sym_LPAREN] = ACTIONS(752),
    [anon_sym_PLUS] = ACTIONS(752),
    [anon_sym_DOT_PLUS] = ACTIONS(752),
    [anon_sym_DASH] = ACTIONS(752),
    [anon_sym_DOT_DASH] = ACTIONS(752),
    [anon_sym_STAR] = ACTIONS(752),
    [anon_sym_DOT_STAR] = ACTIONS(752),
    [anon_sym_SLASH] = ACTIONS(752),
    [anon_sym_DOT_SLASH] = ACTIONS(752),
    [anon_sym_BSLASH] = ACTIONS(752),
    [anon_sym_DOT_BSLASH] = ACTIONS(752),
    [anon_sym_CARET] = ACTIONS(752),
    [anon_sym_DOT_CARET] = ACTIONS(752),
    [anon_sym_PIPE] = ACTIONS(752),
    [anon_sym_AMP] = ACTIONS(752),
    [anon_sym_TILDE] = ACTIONS(752),
    [anon_sym_QMARK] = ACTIONS(752),
    [anon_sym_AT] = ACTIONS(752),
    [anon_sym_LT] = ACTIONS(752),
    [anon_sym_LT_EQ] = ACTIONS(752),
    [anon_sym_EQ_EQ] = ACTIONS(752),
    [anon_sym_TILDE_EQ] = ACTIONS(752),
    [anon_sym_GT_EQ] = ACTIONS(752),
    [anon_sym_GT] = ACTIONS(752),
    [anon_sym_AMP_AMP] = ACTIONS(752),
    [anon_sym_PIPE_PIPE] = ACTIONS(752),
    [anon_sym_DOT_SQUOTE] = ACTIONS(752),
    [anon_sym_SQUOTE] = ACTIONS(752),
    [anon_sym_COMMA] = ACTIONS(752),
    [anon_sym_LBRACK] = ACTIONS(752),
    [anon_sym_LF] = ACTIONS(752),
    [anon_sym_SEMI] = ACTIONS(752),
    [anon_sym_LBRACE] = ACTIONS(752),
    [anon_sym_COLON] = ACTIONS(752),
    [anon_sym_return] = ACTIONS(752),
    [anon_sym_continue] = ACTIONS(752),
    [anon_sym_break] = ACTIONS(752),
    [anon_sym_elseif] = ACTIONS(752),
    [anon_sym_else] = ACTIONS(752),
    [anon_sym_if] = ACTIONS(752),
    [anon_sym_end] = ACTIONS(752),
    [anon_sym_for] = ACTIONS(752),
    [anon_sym_parfor] = ACTIONS(752),
    [anon_sym_while] = ACTIONS(752),
    [anon_sym_switch] = ACTIONS(752),
    [anon_sym_global] = ACTIONS(752),
    [anon_sym_persistent] = ACTIONS(752),
    [anon_sym_arguments] = ACTIONS(752),
    [anon_sym_function] = ACTIONS(752),
    [anon_sym_properties] = ACTIONS(752),
    [anon_sym_get] = ACTIONS(752),
    [anon_sym_set] = ACTIONS(752),
    [anon_sym_methods] = ACTIONS(752),
    [anon_sym_events] = ACTIONS(752),
    [anon_sym_enumeration] = ACTIONS(752),
    [anon_sym_classdef] = ACTIONS(752),
    [anon_sym_try] = ACTIONS(752),
    [anon_sym_spmd] = ACTIONS(752),
    [aux_sym_number_token1] = ACTIONS(752),
    [aux_sym_number_token2] = ACTIONS(752),
    [aux_sym_number_token3] = ACTIONS(752),
    [anon_sym_CR] = ACTIONS(752),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(754),
    [sym__single_quote_string_start] = ACTIONS(754),
    [sym__double_quote_string_start] = ACTIONS(754),
    [sym__multioutput_variable_start] = ACTIONS(754),
    [sym__external_identifier] = ACTIONS(754),
  },
  [STATE(159)] = {
    [anon_sym_LPAREN] = ACTIONS(756),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DOT_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_DOT_DASH] = ACTIONS(756),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_DOT_STAR] = ACTIONS(756),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_DOT_SLASH] = ACTIONS(756),
    [anon_sym_BSLASH] = ACTIONS(756),
    [anon_sym_DOT_BSLASH] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(756),
    [anon_sym_DOT_CARET] = ACTIONS(756),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_AT] = ACTIONS(756),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_TILDE_EQ] = ACTIONS(756),
    [anon_sym_GT_EQ] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_AMP_AMP] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(756),
    [anon_sym_DOT_SQUOTE] = ACTIONS(756),
    [anon_sym_SQUOTE] = ACTIONS(756),
    [anon_sym_COMMA] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(756),
    [anon_sym_LF] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(756),
    [anon_sym_COLON] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_elseif] = ACTIONS(756),
    [anon_sym_else] = ACTIONS(756),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_end] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_parfor] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_switch] = ACTIONS(756),
    [anon_sym_global] = ACTIONS(756),
    [anon_sym_persistent] = ACTIONS(756),
    [anon_sym_arguments] = ACTIONS(756),
    [anon_sym_function] = ACTIONS(756),
    [anon_sym_properties] = ACTIONS(756),
    [anon_sym_get] = ACTIONS(756),
    [anon_sym_set] = ACTIONS(756),
    [anon_sym_methods] = ACTIONS(756),
    [anon_sym_events] = ACTIONS(756),
    [anon_sym_enumeration] = ACTIONS(756),
    [anon_sym_classdef] = ACTIONS(756),
    [anon_sym_try] = ACTIONS(756),
    [anon_sym_spmd] = ACTIONS(756),
    [aux_sym_number_token1] = ACTIONS(756),
    [aux_sym_number_token2] = ACTIONS(756),
    [aux_sym_number_token3] = ACTIONS(756),
    [anon_sym_CR] = ACTIONS(756),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(758),
    [sym__single_quote_string_start] = ACTIONS(758),
    [sym__double_quote_string_start] = ACTIONS(758),
    [sym__multioutput_variable_start] = ACTIONS(758),
    [sym__external_identifier] = ACTIONS(758),
  },
  [STATE(160)] = {
    [anon_sym_LPAREN] = ACTIONS(760),
    [anon_sym_PLUS] = ACTIONS(760),
    [anon_sym_DOT_PLUS] = ACTIONS(760),
    [anon_sym_DASH] = ACTIONS(760),
    [anon_sym_DOT_DASH] = ACTIONS(760),
    [anon_sym_STAR] = ACTIONS(760),
    [anon_sym_DOT_STAR] = ACTIONS(760),
    [anon_sym_SLASH] = ACTIONS(760),
    [anon_sym_DOT_SLASH] = ACTIONS(760),
    [anon_sym_BSLASH] = ACTIONS(760),
    [anon_sym_DOT_BSLASH] = ACTIONS(760),
    [anon_sym_CARET] = ACTIONS(760),
    [anon_sym_DOT_CARET] = ACTIONS(760),
    [anon_sym_PIPE] = ACTIONS(760),
    [anon_sym_AMP] = ACTIONS(760),
    [anon_sym_TILDE] = ACTIONS(760),
    [anon_sym_QMARK] = ACTIONS(760),
    [anon_sym_AT] = ACTIONS(760),
    [anon_sym_LT] = ACTIONS(760),
    [anon_sym_LT_EQ] = ACTIONS(760),
    [anon_sym_EQ_EQ] = ACTIONS(760),
    [anon_sym_TILDE_EQ] = ACTIONS(760),
    [anon_sym_GT_EQ] = ACTIONS(760),
    [anon_sym_GT] = ACTIONS(760),
    [anon_sym_AMP_AMP] = ACTIONS(760),
    [anon_sym_PIPE_PIPE] = ACTIONS(760),
    [anon_sym_DOT_SQUOTE] = ACTIONS(760),
    [anon_sym_SQUOTE] = ACTIONS(760),
    [anon_sym_COMMA] = ACTIONS(760),
    [anon_sym_LBRACK] = ACTIONS(760),
    [anon_sym_LF] = ACTIONS(760),
    [anon_sym_SEMI] = ACTIONS(760),
    [anon_sym_LBRACE] = ACTIONS(760),
    [anon_sym_COLON] = ACTIONS(760),
    [anon_sym_return] = ACTIONS(760),
    [anon_sym_continue] = ACTIONS(760),
    [anon_sym_break] = ACTIONS(760),
    [anon_sym_elseif] = ACTIONS(760),
    [anon_sym_else] = ACTIONS(760),
    [anon_sym_if] = ACTIONS(760),
    [anon_sym_end] = ACTIONS(760),
    [anon_sym_for] = ACTIONS(760),
    [anon_sym_parfor] = ACTIONS(760),
    [anon_sym_while] = ACTIONS(760),
    [anon_sym_switch] = ACTIONS(760),
    [anon_sym_global] = ACTIONS(760),
    [anon_sym_persistent] = ACTIONS(760),
    [anon_sym_arguments] = ACTIONS(760),
    [anon_sym_function] = ACTIONS(760),
    [anon_sym_properties] = ACTIONS(760),
    [anon_sym_get] = ACTIONS(760),
    [anon_sym_set] = ACTIONS(760),
    [anon_sym_methods] = ACTIONS(760),
    [anon_sym_events] = ACTIONS(760),
    [anon_sym_enumeration] = ACTIONS(760),
    [anon_sym_classdef] = ACTIONS(760),
    [anon_sym_try] = ACTIONS(760),
    [anon_sym_spmd] = ACTIONS(760),
    [aux_sym_number_token1] = ACTIONS(760),
    [aux_sym_number_token2] = ACTIONS(760),
    [aux_sym_number_token3] = ACTIONS(760),
    [anon_sym_CR] = ACTIONS(760),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(762),
    [sym__single_quote_string_start] = ACTIONS(762),
    [sym__double_quote_string_start] = ACTIONS(762),
    [sym__multioutput_variable_start] = ACTIONS(762),
    [sym__external_identifier] = ACTIONS(762),
  },
  [STATE(161)] = {
    [anon_sym_LPAREN] = ACTIONS(764),
    [anon_sym_PLUS] = ACTIONS(764),
    [anon_sym_DOT_PLUS] = ACTIONS(764),
    [anon_sym_DASH] = ACTIONS(764),
    [anon_sym_DOT_DASH] = ACTIONS(764),
    [anon_sym_STAR] = ACTIONS(766),
    [anon_sym_DOT_STAR] = ACTIONS(766),
    [anon_sym_SLASH] = ACTIONS(766),
    [anon_sym_DOT_SLASH] = ACTIONS(766),
    [anon_sym_BSLASH] = ACTIONS(766),
    [anon_sym_DOT_BSLASH] = ACTIONS(766),
    [anon_sym_CARET] = ACTIONS(768),
    [anon_sym_DOT_CARET] = ACTIONS(768),
    [anon_sym_PIPE] = ACTIONS(764),
    [anon_sym_AMP] = ACTIONS(764),
    [anon_sym_TILDE] = ACTIONS(764),
    [anon_sym_QMARK] = ACTIONS(764),
    [anon_sym_AT] = ACTIONS(764),
    [anon_sym_LT] = ACTIONS(764),
    [anon_sym_LT_EQ] = ACTIONS(764),
    [anon_sym_EQ_EQ] = ACTIONS(764),
    [anon_sym_TILDE_EQ] = ACTIONS(764),
    [anon_sym_GT_EQ] = ACTIONS(764),
    [anon_sym_GT] = ACTIONS(764),
    [anon_sym_AMP_AMP] = ACTIONS(764),
    [anon_sym_PIPE_PIPE] = ACTIONS(764),
    [anon_sym_DOT_SQUOTE] = ACTIONS(764),
    [anon_sym_SQUOTE] = ACTIONS(764),
    [anon_sym_COMMA] = ACTIONS(764),
    [anon_sym_LBRACK] = ACTIONS(764),
    [anon_sym_LF] = ACTIONS(764),
    [anon_sym_SEMI] = ACTIONS(764),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_COLON] = ACTIONS(764),
    [anon_sym_return] = ACTIONS(764),
    [anon_sym_continue] = ACTIONS(764),
    [anon_sym_break] = ACTIONS(764),
    [anon_sym_elseif] = ACTIONS(764),
    [anon_sym_else] = ACTIONS(764),
    [anon_sym_if] = ACTIONS(764),
    [anon_sym_end] = ACTIONS(764),
    [anon_sym_for] = ACTIONS(764),
    [anon_sym_parfor] = ACTIONS(764),
    [anon_sym_while] = ACTIONS(764),
    [anon_sym_switch] = ACTIONS(764),
    [anon_sym_global] = ACTIONS(764),
    [anon_sym_persistent] = ACTIONS(764),
    [anon_sym_arguments] = ACTIONS(764),
    [anon_sym_function] = ACTIONS(764),
    [anon_sym_properties] = ACTIONS(764),
    [anon_sym_get] = ACTIONS(764),
    [anon_sym_set] = ACTIONS(764),
    [anon_sym_methods] = ACTIONS(764),
    [anon_sym_events] = ACTIONS(764),
    [anon_sym_enumeration] = ACTIONS(764),
    [anon_sym_classdef] = ACTIONS(764),
    [anon_sym_try] = ACTIONS(764),
    [anon_sym_spmd] = ACTIONS(764),
    [aux_sym_number_token1] = ACTIONS(764),
    [aux_sym_number_token2] = ACTIONS(764),
    [aux_sym_number_token3] = ACTIONS(764),
    [anon_sym_CR] = ACTIONS(764),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(770),
    [sym__single_quote_string_start] = ACTIONS(770),
    [sym__double_quote_string_start] = ACTIONS(770),
    [sym__multioutput_variable_start] = ACTIONS(770),
    [sym__external_identifier] = ACTIONS(770),
  },
  [STATE(162)] = {
    [anon_sym_LPAREN] = ACTIONS(764),
    [anon_sym_PLUS] = ACTIONS(764),
    [anon_sym_DOT_PLUS] = ACTIONS(764),
    [anon_sym_DASH] = ACTIONS(764),
    [anon_sym_DOT_DASH] = ACTIONS(764),
    [anon_sym_STAR] = ACTIONS(764),
    [anon_sym_DOT_STAR] = ACTIONS(764),
    [anon_sym_SLASH] = ACTIONS(764),
    [anon_sym_DOT_SLASH] = ACTIONS(764),
    [anon_sym_BSLASH] = ACTIONS(764),
    [anon_sym_DOT_BSLASH] = ACTIONS(764),
    [anon_sym_CARET] = ACTIONS(768),
    [anon_sym_DOT_CARET] = ACTIONS(768),
    [anon_sym_PIPE] = ACTIONS(764),
    [anon_sym_AMP] = ACTIONS(764),
    [anon_sym_TILDE] = ACTIONS(764),
    [anon_sym_QMARK] = ACTIONS(764),
    [anon_sym_AT] = ACTIONS(764),
    [anon_sym_LT] = ACTIONS(764),
    [anon_sym_LT_EQ] = ACTIONS(764),
    [anon_sym_EQ_EQ] = ACTIONS(764),
    [anon_sym_TILDE_EQ] = ACTIONS(764),
    [anon_sym_GT_EQ] = ACTIONS(764),
    [anon_sym_GT] = ACTIONS(764),
    [anon_sym_AMP_AMP] = ACTIONS(764),
    [anon_sym_PIPE_PIPE] = ACTIONS(764),
    [anon_sym_DOT_SQUOTE] = ACTIONS(764),
    [anon_sym_SQUOTE] = ACTIONS(764),
    [anon_sym_COMMA] = ACTIONS(764),
    [anon_sym_LBRACK] = ACTIONS(764),
    [anon_sym_LF] = ACTIONS(764),
    [anon_sym_SEMI] = ACTIONS(764),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_COLON] = ACTIONS(764),
    [anon_sym_return] = ACTIONS(764),
    [anon_sym_continue] = ACTIONS(764),
    [anon_sym_break] = ACTIONS(764),
    [anon_sym_elseif] = ACTIONS(764),
    [anon_sym_else] = ACTIONS(764),
    [anon_sym_if] = ACTIONS(764),
    [anon_sym_end] = ACTIONS(764),
    [anon_sym_for] = ACTIONS(764),
    [anon_sym_parfor] = ACTIONS(764),
    [anon_sym_while] = ACTIONS(764),
    [anon_sym_switch] = ACTIONS(764),
    [anon_sym_global] = ACTIONS(764),
    [anon_sym_persistent] = ACTIONS(764),
    [anon_sym_arguments] = ACTIONS(764),
    [anon_sym_function] = ACTIONS(764),
    [anon_sym_properties] = ACTIONS(764),
    [anon_sym_get] = ACTIONS(764),
    [anon_sym_set] = ACTIONS(764),
    [anon_sym_methods] = ACTIONS(764),
    [anon_sym_events] = ACTIONS(764),
    [anon_sym_enumeration] = ACTIONS(764),
    [anon_sym_classdef] = ACTIONS(764),
    [anon_sym_try] = ACTIONS(764),
    [anon_sym_spmd] = ACTIONS(764),
    [aux_sym_number_token1] = ACTIONS(764),
    [aux_sym_number_token2] = ACTIONS(764),
    [aux_sym_number_token3] = ACTIONS(764),
    [anon_sym_CR] = ACTIONS(764),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(770),
    [sym__single_quote_string_start] = ACTIONS(770),
    [sym__double_quote_string_start] = ACTIONS(770),
    [sym__multioutput_variable_start] = ACTIONS(770),
    [sym__external_identifier] = ACTIONS(770),
  },
  [STATE(163)] = {
    [anon_sym_LPAREN] = ACTIONS(764),
    [anon_sym_PLUS] = ACTIONS(764),
    [anon_sym_DOT_PLUS] = ACTIONS(764),
    [anon_sym_DASH] = ACTIONS(764),
    [anon_sym_DOT_DASH] = ACTIONS(764),
    [anon_sym_STAR] = ACTIONS(764),
    [anon_sym_DOT_STAR] = ACTIONS(764),
    [anon_sym_SLASH] = ACTIONS(764),
    [anon_sym_DOT_SLASH] = ACTIONS(764),
    [anon_sym_BSLASH] = ACTIONS(764),
    [anon_sym_DOT_BSLASH] = ACTIONS(764),
    [anon_sym_CARET] = ACTIONS(768),
    [anon_sym_DOT_CARET] = ACTIONS(768),
    [anon_sym_PIPE] = ACTIONS(764),
    [anon_sym_AMP] = ACTIONS(764),
    [anon_sym_TILDE] = ACTIONS(764),
    [anon_sym_QMARK] = ACTIONS(764),
    [anon_sym_AT] = ACTIONS(764),
    [anon_sym_LT] = ACTIONS(764),
    [anon_sym_LT_EQ] = ACTIONS(764),
    [anon_sym_EQ_EQ] = ACTIONS(764),
    [anon_sym_TILDE_EQ] = ACTIONS(764),
    [anon_sym_GT_EQ] = ACTIONS(764),
    [anon_sym_GT] = ACTIONS(764),
    [anon_sym_AMP_AMP] = ACTIONS(764),
    [anon_sym_PIPE_PIPE] = ACTIONS(764),
    [anon_sym_DOT_SQUOTE] = ACTIONS(764),
    [anon_sym_SQUOTE] = ACTIONS(764),
    [anon_sym_COMMA] = ACTIONS(764),
    [anon_sym_LBRACK] = ACTIONS(764),
    [anon_sym_LF] = ACTIONS(764),
    [anon_sym_SEMI] = ACTIONS(764),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_COLON] = ACTIONS(764),
    [anon_sym_return] = ACTIONS(764),
    [anon_sym_continue] = ACTIONS(764),
    [anon_sym_break] = ACTIONS(764),
    [anon_sym_elseif] = ACTIONS(764),
    [anon_sym_else] = ACTIONS(764),
    [anon_sym_if] = ACTIONS(764),
    [anon_sym_end] = ACTIONS(764),
    [anon_sym_for] = ACTIONS(764),
    [anon_sym_parfor] = ACTIONS(764),
    [anon_sym_while] = ACTIONS(764),
    [anon_sym_switch] = ACTIONS(764),
    [anon_sym_global] = ACTIONS(764),
    [anon_sym_persistent] = ACTIONS(764),
    [anon_sym_arguments] = ACTIONS(764),
    [anon_sym_function] = ACTIONS(764),
    [anon_sym_properties] = ACTIONS(764),
    [anon_sym_get] = ACTIONS(764),
    [anon_sym_set] = ACTIONS(764),
    [anon_sym_methods] = ACTIONS(764),
    [anon_sym_events] = ACTIONS(764),
    [anon_sym_enumeration] = ACTIONS(764),
    [anon_sym_classdef] = ACTIONS(764),
    [anon_sym_try] = ACTIONS(764),
    [anon_sym_spmd] = ACTIONS(764),
    [aux_sym_number_token1] = ACTIONS(764),
    [aux_sym_number_token2] = ACTIONS(764),
    [aux_sym_number_token3] = ACTIONS(764),
    [anon_sym_CR] = ACTIONS(764),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(770),
    [sym__single_quote_string_start] = ACTIONS(770),
    [sym__double_quote_string_start] = ACTIONS(770),
    [sym__multioutput_variable_start] = ACTIONS(770),
    [sym__external_identifier] = ACTIONS(770),
  },
  [STATE(164)] = {
    [anon_sym_LPAREN] = ACTIONS(764),
    [anon_sym_PLUS] = ACTIONS(772),
    [anon_sym_DOT_PLUS] = ACTIONS(772),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_DOT_DASH] = ACTIONS(772),
    [anon_sym_STAR] = ACTIONS(766),
    [anon_sym_DOT_STAR] = ACTIONS(766),
    [anon_sym_SLASH] = ACTIONS(766),
    [anon_sym_DOT_SLASH] = ACTIONS(766),
    [anon_sym_BSLASH] = ACTIONS(766),
    [anon_sym_DOT_BSLASH] = ACTIONS(766),
    [anon_sym_CARET] = ACTIONS(768),
    [anon_sym_DOT_CARET] = ACTIONS(768),
    [anon_sym_PIPE] = ACTIONS(764),
    [anon_sym_AMP] = ACTIONS(764),
    [anon_sym_TILDE] = ACTIONS(764),
    [anon_sym_QMARK] = ACTIONS(764),
    [anon_sym_AT] = ACTIONS(764),
    [anon_sym_LT] = ACTIONS(764),
    [anon_sym_LT_EQ] = ACTIONS(764),
    [anon_sym_EQ_EQ] = ACTIONS(764),
    [anon_sym_TILDE_EQ] = ACTIONS(764),
    [anon_sym_GT_EQ] = ACTIONS(764),
    [anon_sym_GT] = ACTIONS(764),
    [anon_sym_AMP_AMP] = ACTIONS(764),
    [anon_sym_PIPE_PIPE] = ACTIONS(764),
    [anon_sym_DOT_SQUOTE] = ACTIONS(764),
    [anon_sym_SQUOTE] = ACTIONS(764),
    [anon_sym_COMMA] = ACTIONS(764),
    [anon_sym_LBRACK] = ACTIONS(764),
    [anon_sym_LF] = ACTIONS(764),
    [anon_sym_SEMI] = ACTIONS(764),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_COLON] = ACTIONS(764),
    [anon_sym_return] = ACTIONS(764),
    [anon_sym_continue] = ACTIONS(764),
    [anon_sym_break] = ACTIONS(764),
    [anon_sym_elseif] = ACTIONS(764),
    [anon_sym_else] = ACTIONS(764),
    [anon_sym_if] = ACTIONS(764),
    [anon_sym_end] = ACTIONS(764),
    [anon_sym_for] = ACTIONS(764),
    [anon_sym_parfor] = ACTIONS(764),
    [anon_sym_while] = ACTIONS(764),
    [anon_sym_switch] = ACTIONS(764),
    [anon_sym_global] = ACTIONS(764),
    [anon_sym_persistent] = ACTIONS(764),
    [anon_sym_arguments] = ACTIONS(764),
    [anon_sym_function] = ACTIONS(764),
    [anon_sym_properties] = ACTIONS(764),
    [anon_sym_get] = ACTIONS(764),
    [anon_sym_set] = ACTIONS(764),
    [anon_sym_methods] = ACTIONS(764),
    [anon_sym_events] = ACTIONS(764),
    [anon_sym_enumeration] = ACTIONS(764),
    [anon_sym_classdef] = ACTIONS(764),
    [anon_sym_try] = ACTIONS(764),
    [anon_sym_spmd] = ACTIONS(764),
    [aux_sym_number_token1] = ACTIONS(764),
    [aux_sym_number_token2] = ACTIONS(764),
    [aux_sym_number_token3] = ACTIONS(764),
    [anon_sym_CR] = ACTIONS(764),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(770),
    [sym__single_quote_string_start] = ACTIONS(770),
    [sym__double_quote_string_start] = ACTIONS(770),
    [sym__multioutput_variable_start] = ACTIONS(770),
    [sym__external_identifier] = ACTIONS(770),
  },
  [STATE(165)] = {
    [anon_sym_LPAREN] = ACTIONS(774),
    [anon_sym_PLUS] = ACTIONS(774),
    [anon_sym_DOT_PLUS] = ACTIONS(774),
    [anon_sym_DASH] = ACTIONS(774),
    [anon_sym_DOT_DASH] = ACTIONS(774),
    [anon_sym_STAR] = ACTIONS(774),
    [anon_sym_DOT_STAR] = ACTIONS(774),
    [anon_sym_SLASH] = ACTIONS(774),
    [anon_sym_DOT_SLASH] = ACTIONS(774),
    [anon_sym_BSLASH] = ACTIONS(774),
    [anon_sym_DOT_BSLASH] = ACTIONS(774),
    [anon_sym_CARET] = ACTIONS(774),
    [anon_sym_DOT_CARET] = ACTIONS(774),
    [anon_sym_PIPE] = ACTIONS(774),
    [anon_sym_AMP] = ACTIONS(774),
    [anon_sym_TILDE] = ACTIONS(774),
    [anon_sym_QMARK] = ACTIONS(774),
    [anon_sym_AT] = ACTIONS(774),
    [anon_sym_LT] = ACTIONS(774),
    [anon_sym_LT_EQ] = ACTIONS(774),
    [anon_sym_EQ_EQ] = ACTIONS(774),
    [anon_sym_TILDE_EQ] = ACTIONS(774),
    [anon_sym_GT_EQ] = ACTIONS(774),
    [anon_sym_GT] = ACTIONS(774),
    [anon_sym_AMP_AMP] = ACTIONS(774),
    [anon_sym_PIPE_PIPE] = ACTIONS(774),
    [anon_sym_DOT_SQUOTE] = ACTIONS(774),
    [anon_sym_SQUOTE] = ACTIONS(774),
    [anon_sym_COMMA] = ACTIONS(774),
    [anon_sym_LBRACK] = ACTIONS(774),
    [anon_sym_LF] = ACTIONS(774),
    [anon_sym_SEMI] = ACTIONS(774),
    [anon_sym_LBRACE] = ACTIONS(774),
    [anon_sym_COLON] = ACTIONS(776),
    [anon_sym_return] = ACTIONS(774),
    [anon_sym_continue] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(774),
    [anon_sym_elseif] = ACTIONS(774),
    [anon_sym_else] = ACTIONS(774),
    [anon_sym_if] = ACTIONS(774),
    [anon_sym_end] = ACTIONS(774),
    [anon_sym_for] = ACTIONS(774),
    [anon_sym_parfor] = ACTIONS(774),
    [anon_sym_while] = ACTIONS(774),
    [anon_sym_switch] = ACTIONS(774),
    [anon_sym_global] = ACTIONS(774),
    [anon_sym_persistent] = ACTIONS(774),
    [anon_sym_arguments] = ACTIONS(774),
    [anon_sym_function] = ACTIONS(774),
    [anon_sym_properties] = ACTIONS(774),
    [anon_sym_get] = ACTIONS(774),
    [anon_sym_set] = ACTIONS(774),
    [anon_sym_methods] = ACTIONS(774),
    [anon_sym_events] = ACTIONS(774),
    [anon_sym_enumeration] = ACTIONS(774),
    [anon_sym_classdef] = ACTIONS(774),
    [anon_sym_try] = ACTIONS(774),
    [anon_sym_spmd] = ACTIONS(774),
    [aux_sym_number_token1] = ACTIONS(774),
    [aux_sym_number_token2] = ACTIONS(774),
    [aux_sym_number_token3] = ACTIONS(774),
    [anon_sym_CR] = ACTIONS(774),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(778),
    [sym__single_quote_string_start] = ACTIONS(778),
    [sym__double_quote_string_start] = ACTIONS(778),
    [sym__multioutput_variable_start] = ACTIONS(778),
    [sym__external_identifier] = ACTIONS(778),
  },
  [STATE(166)] = {
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(780),
    [anon_sym_DOT_PLUS] = ACTIONS(780),
    [anon_sym_DASH] = ACTIONS(780),
    [anon_sym_DOT_DASH] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(780),
    [anon_sym_DOT_STAR] = ACTIONS(780),
    [anon_sym_SLASH] = ACTIONS(780),
    [anon_sym_DOT_SLASH] = ACTIONS(780),
    [anon_sym_BSLASH] = ACTIONS(780),
    [anon_sym_DOT_BSLASH] = ACTIONS(780),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_DOT_CARET] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(780),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_QMARK] = ACTIONS(780),
    [anon_sym_AT] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(780),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_EQ_EQ] = ACTIONS(780),
    [anon_sym_TILDE_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_GT] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_DOT_SQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_COMMA] = ACTIONS(780),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_LF] = ACTIONS(780),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_COLON] = ACTIONS(780),
    [anon_sym_return] = ACTIONS(780),
    [anon_sym_continue] = ACTIONS(780),
    [anon_sym_break] = ACTIONS(780),
    [anon_sym_elseif] = ACTIONS(780),
    [anon_sym_else] = ACTIONS(780),
    [anon_sym_if] = ACTIONS(780),
    [anon_sym_end] = ACTIONS(780),
    [anon_sym_for] = ACTIONS(780),
    [anon_sym_parfor] = ACTIONS(780),
    [anon_sym_while] = ACTIONS(780),
    [anon_sym_switch] = ACTIONS(780),
    [anon_sym_global] = ACTIONS(780),
    [anon_sym_persistent] = ACTIONS(780),
    [anon_sym_arguments] = ACTIONS(780),
    [anon_sym_function] = ACTIONS(780),
    [anon_sym_properties] = ACTIONS(780),
    [anon_sym_get] = ACTIONS(780),
    [anon_sym_set] = ACTIONS(780),
    [anon_sym_methods] = ACTIONS(780),
    [anon_sym_events] = ACTIONS(780),
    [anon_sym_enumeration] = ACTIONS(780),
    [anon_sym_classdef] = ACTIONS(780),
    [anon_sym_try] = ACTIONS(780),
    [anon_sym_spmd] = ACTIONS(780),
    [aux_sym_number_token1] = ACTIONS(780),
    [aux_sym_number_token2] = ACTIONS(780),
    [aux_sym_number_token3] = ACTIONS(780),
    [anon_sym_CR] = ACTIONS(780),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(782),
    [sym__single_quote_string_start] = ACTIONS(782),
    [sym__double_quote_string_start] = ACTIONS(782),
    [sym__multioutput_variable_start] = ACTIONS(782),
    [sym__external_identifier] = ACTIONS(782),
  },
  [STATE(167)] = {
    [anon_sym_LPAREN] = ACTIONS(784),
    [anon_sym_PLUS] = ACTIONS(784),
    [anon_sym_DOT_PLUS] = ACTIONS(784),
    [anon_sym_DASH] = ACTIONS(784),
    [anon_sym_DOT_DASH] = ACTIONS(784),
    [anon_sym_STAR] = ACTIONS(784),
    [anon_sym_DOT_STAR] = ACTIONS(784),
    [anon_sym_SLASH] = ACTIONS(784),
    [anon_sym_DOT_SLASH] = ACTIONS(784),
    [anon_sym_BSLASH] = ACTIONS(784),
    [anon_sym_DOT_BSLASH] = ACTIONS(784),
    [anon_sym_CARET] = ACTIONS(784),
    [anon_sym_DOT_CARET] = ACTIONS(784),
    [anon_sym_PIPE] = ACTIONS(784),
    [anon_sym_AMP] = ACTIONS(784),
    [anon_sym_TILDE] = ACTIONS(784),
    [anon_sym_QMARK] = ACTIONS(784),
    [anon_sym_AT] = ACTIONS(784),
    [anon_sym_LT] = ACTIONS(784),
    [anon_sym_LT_EQ] = ACTIONS(784),
    [anon_sym_EQ_EQ] = ACTIONS(784),
    [anon_sym_TILDE_EQ] = ACTIONS(784),
    [anon_sym_GT_EQ] = ACTIONS(784),
    [anon_sym_GT] = ACTIONS(784),
    [anon_sym_AMP_AMP] = ACTIONS(784),
    [anon_sym_PIPE_PIPE] = ACTIONS(784),
    [anon_sym_DOT_SQUOTE] = ACTIONS(784),
    [anon_sym_SQUOTE] = ACTIONS(784),
    [anon_sym_COMMA] = ACTIONS(784),
    [anon_sym_LBRACK] = ACTIONS(784),
    [anon_sym_LF] = ACTIONS(784),
    [anon_sym_SEMI] = ACTIONS(784),
    [anon_sym_LBRACE] = ACTIONS(784),
    [anon_sym_COLON] = ACTIONS(784),
    [anon_sym_return] = ACTIONS(784),
    [anon_sym_continue] = ACTIONS(784),
    [anon_sym_break] = ACTIONS(784),
    [anon_sym_elseif] = ACTIONS(784),
    [anon_sym_else] = ACTIONS(784),
    [anon_sym_if] = ACTIONS(784),
    [anon_sym_end] = ACTIONS(784),
    [anon_sym_for] = ACTIONS(784),
    [anon_sym_parfor] = ACTIONS(784),
    [anon_sym_while] = ACTIONS(784),
    [anon_sym_switch] = ACTIONS(784),
    [anon_sym_global] = ACTIONS(784),
    [anon_sym_persistent] = ACTIONS(784),
    [anon_sym_arguments] = ACTIONS(784),
    [anon_sym_function] = ACTIONS(784),
    [anon_sym_properties] = ACTIONS(784),
    [anon_sym_get] = ACTIONS(784),
    [anon_sym_set] = ACTIONS(784),
    [anon_sym_methods] = ACTIONS(784),
    [anon_sym_events] = ACTIONS(784),
    [anon_sym_enumeration] = ACTIONS(784),
    [anon_sym_classdef] = ACTIONS(784),
    [anon_sym_try] = ACTIONS(784),
    [anon_sym_spmd] = ACTIONS(784),
    [aux_sym_number_token1] = ACTIONS(784),
    [aux_sym_number_token2] = ACTIONS(784),
    [aux_sym_number_token3] = ACTIONS(784),
    [anon_sym_CR] = ACTIONS(784),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(786),
    [sym__single_quote_string_start] = ACTIONS(786),
    [sym__double_quote_string_start] = ACTIONS(786),
    [sym__multioutput_variable_start] = ACTIONS(786),
    [sym__external_identifier] = ACTIONS(786),
  },
  [STATE(168)] = {
    [anon_sym_LPAREN] = ACTIONS(788),
    [anon_sym_PLUS] = ACTIONS(788),
    [anon_sym_DOT_PLUS] = ACTIONS(788),
    [anon_sym_DASH] = ACTIONS(788),
    [anon_sym_DOT_DASH] = ACTIONS(788),
    [anon_sym_STAR] = ACTIONS(788),
    [anon_sym_DOT_STAR] = ACTIONS(788),
    [anon_sym_SLASH] = ACTIONS(788),
    [anon_sym_DOT_SLASH] = ACTIONS(788),
    [anon_sym_BSLASH] = ACTIONS(788),
    [anon_sym_DOT_BSLASH] = ACTIONS(788),
    [anon_sym_CARET] = ACTIONS(788),
    [anon_sym_DOT_CARET] = ACTIONS(788),
    [anon_sym_PIPE] = ACTIONS(788),
    [anon_sym_AMP] = ACTIONS(788),
    [anon_sym_TILDE] = ACTIONS(788),
    [anon_sym_QMARK] = ACTIONS(788),
    [anon_sym_AT] = ACTIONS(788),
    [anon_sym_LT] = ACTIONS(788),
    [anon_sym_LT_EQ] = ACTIONS(788),
    [anon_sym_EQ_EQ] = ACTIONS(788),
    [anon_sym_TILDE_EQ] = ACTIONS(788),
    [anon_sym_GT_EQ] = ACTIONS(788),
    [anon_sym_GT] = ACTIONS(788),
    [anon_sym_AMP_AMP] = ACTIONS(788),
    [anon_sym_PIPE_PIPE] = ACTIONS(788),
    [anon_sym_DOT_SQUOTE] = ACTIONS(788),
    [anon_sym_SQUOTE] = ACTIONS(788),
    [anon_sym_COMMA] = ACTIONS(788),
    [anon_sym_LBRACK] = ACTIONS(788),
    [anon_sym_LF] = ACTIONS(788),
    [anon_sym_SEMI] = ACTIONS(788),
    [anon_sym_LBRACE] = ACTIONS(788),
    [anon_sym_COLON] = ACTIONS(788),
    [anon_sym_return] = ACTIONS(788),
    [anon_sym_continue] = ACTIONS(788),
    [anon_sym_break] = ACTIONS(788),
    [anon_sym_elseif] = ACTIONS(788),
    [anon_sym_else] = ACTIONS(788),
    [anon_sym_if] = ACTIONS(788),
    [anon_sym_end] = ACTIONS(788),
    [anon_sym_for] = ACTIONS(788),
    [anon_sym_parfor] = ACTIONS(788),
    [anon_sym_while] = ACTIONS(788),
    [anon_sym_switch] = ACTIONS(788),
    [anon_sym_global] = ACTIONS(788),
    [anon_sym_persistent] = ACTIONS(788),
    [anon_sym_arguments] = ACTIONS(788),
    [anon_sym_function] = ACTIONS(788),
    [anon_sym_properties] = ACTIONS(788),
    [anon_sym_get] = ACTIONS(788),
    [anon_sym_set] = ACTIONS(788),
    [anon_sym_methods] = ACTIONS(788),
    [anon_sym_events] = ACTIONS(788),
    [anon_sym_enumeration] = ACTIONS(788),
    [anon_sym_classdef] = ACTIONS(788),
    [anon_sym_try] = ACTIONS(788),
    [anon_sym_spmd] = ACTIONS(788),
    [aux_sym_number_token1] = ACTIONS(788),
    [aux_sym_number_token2] = ACTIONS(788),
    [aux_sym_number_token3] = ACTIONS(788),
    [anon_sym_CR] = ACTIONS(788),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(790),
    [sym__single_quote_string_start] = ACTIONS(790),
    [sym__double_quote_string_start] = ACTIONS(790),
    [sym__multioutput_variable_start] = ACTIONS(790),
    [sym__external_identifier] = ACTIONS(790),
  },
  [STATE(169)] = {
    [anon_sym_LPAREN] = ACTIONS(792),
    [anon_sym_PLUS] = ACTIONS(792),
    [anon_sym_DOT_PLUS] = ACTIONS(792),
    [anon_sym_DASH] = ACTIONS(792),
    [anon_sym_DOT_DASH] = ACTIONS(792),
    [anon_sym_STAR] = ACTIONS(792),
    [anon_sym_DOT_STAR] = ACTIONS(792),
    [anon_sym_SLASH] = ACTIONS(792),
    [anon_sym_DOT_SLASH] = ACTIONS(792),
    [anon_sym_BSLASH] = ACTIONS(792),
    [anon_sym_DOT_BSLASH] = ACTIONS(792),
    [anon_sym_CARET] = ACTIONS(792),
    [anon_sym_DOT_CARET] = ACTIONS(792),
    [anon_sym_PIPE] = ACTIONS(792),
    [anon_sym_AMP] = ACTIONS(792),
    [anon_sym_TILDE] = ACTIONS(792),
    [anon_sym_QMARK] = ACTIONS(792),
    [anon_sym_AT] = ACTIONS(792),
    [anon_sym_LT] = ACTIONS(792),
    [anon_sym_LT_EQ] = ACTIONS(792),
    [anon_sym_EQ_EQ] = ACTIONS(792),
    [anon_sym_TILDE_EQ] = ACTIONS(792),
    [anon_sym_GT_EQ] = ACTIONS(792),
    [anon_sym_GT] = ACTIONS(792),
    [anon_sym_AMP_AMP] = ACTIONS(792),
    [anon_sym_PIPE_PIPE] = ACTIONS(792),
    [anon_sym_DOT_SQUOTE] = ACTIONS(792),
    [anon_sym_SQUOTE] = ACTIONS(792),
    [anon_sym_COMMA] = ACTIONS(792),
    [anon_sym_LBRACK] = ACTIONS(792),
    [anon_sym_LF] = ACTIONS(792),
    [anon_sym_SEMI] = ACTIONS(792),
    [anon_sym_LBRACE] = ACTIONS(792),
    [anon_sym_COLON] = ACTIONS(792),
    [anon_sym_return] = ACTIONS(792),
    [anon_sym_continue] = ACTIONS(792),
    [anon_sym_break] = ACTIONS(792),
    [anon_sym_elseif] = ACTIONS(792),
    [anon_sym_else] = ACTIONS(792),
    [anon_sym_if] = ACTIONS(792),
    [anon_sym_end] = ACTIONS(792),
    [anon_sym_for] = ACTIONS(792),
    [anon_sym_parfor] = ACTIONS(792),
    [anon_sym_while] = ACTIONS(792),
    [anon_sym_switch] = ACTIONS(792),
    [anon_sym_global] = ACTIONS(792),
    [anon_sym_persistent] = ACTIONS(792),
    [anon_sym_arguments] = ACTIONS(792),
    [anon_sym_function] = ACTIONS(792),
    [anon_sym_properties] = ACTIONS(792),
    [anon_sym_get] = ACTIONS(792),
    [anon_sym_set] = ACTIONS(792),
    [anon_sym_methods] = ACTIONS(792),
    [anon_sym_events] = ACTIONS(792),
    [anon_sym_enumeration] = ACTIONS(792),
    [anon_sym_classdef] = ACTIONS(792),
    [anon_sym_try] = ACTIONS(792),
    [anon_sym_spmd] = ACTIONS(792),
    [aux_sym_number_token1] = ACTIONS(792),
    [aux_sym_number_token2] = ACTIONS(792),
    [aux_sym_number_token3] = ACTIONS(792),
    [anon_sym_CR] = ACTIONS(792),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(794),
    [sym__single_quote_string_start] = ACTIONS(794),
    [sym__double_quote_string_start] = ACTIONS(794),
    [sym__multioutput_variable_start] = ACTIONS(794),
    [sym__external_identifier] = ACTIONS(794),
  },
  [STATE(170)] = {
    [anon_sym_LPAREN] = ACTIONS(796),
    [anon_sym_PLUS] = ACTIONS(796),
    [anon_sym_DOT_PLUS] = ACTIONS(796),
    [anon_sym_DASH] = ACTIONS(796),
    [anon_sym_DOT_DASH] = ACTIONS(796),
    [anon_sym_STAR] = ACTIONS(796),
    [anon_sym_DOT_STAR] = ACTIONS(796),
    [anon_sym_SLASH] = ACTIONS(796),
    [anon_sym_DOT_SLASH] = ACTIONS(796),
    [anon_sym_BSLASH] = ACTIONS(796),
    [anon_sym_DOT_BSLASH] = ACTIONS(796),
    [anon_sym_CARET] = ACTIONS(796),
    [anon_sym_DOT_CARET] = ACTIONS(796),
    [anon_sym_PIPE] = ACTIONS(796),
    [anon_sym_AMP] = ACTIONS(796),
    [anon_sym_TILDE] = ACTIONS(796),
    [anon_sym_QMARK] = ACTIONS(796),
    [anon_sym_AT] = ACTIONS(796),
    [anon_sym_LT] = ACTIONS(798),
    [anon_sym_LT_EQ] = ACTIONS(798),
    [anon_sym_EQ_EQ] = ACTIONS(798),
    [anon_sym_TILDE_EQ] = ACTIONS(798),
    [anon_sym_GT_EQ] = ACTIONS(798),
    [anon_sym_GT] = ACTIONS(798),
    [anon_sym_AMP_AMP] = ACTIONS(798),
    [anon_sym_PIPE_PIPE] = ACTIONS(798),
    [anon_sym_DOT_SQUOTE] = ACTIONS(796),
    [anon_sym_SQUOTE] = ACTIONS(796),
    [anon_sym_COMMA] = ACTIONS(796),
    [anon_sym_LBRACK] = ACTIONS(796),
    [anon_sym_LF] = ACTIONS(796),
    [anon_sym_SEMI] = ACTIONS(796),
    [anon_sym_LBRACE] = ACTIONS(796),
    [anon_sym_COLON] = ACTIONS(801),
    [anon_sym_return] = ACTIONS(796),
    [anon_sym_continue] = ACTIONS(796),
    [anon_sym_break] = ACTIONS(796),
    [anon_sym_elseif] = ACTIONS(796),
    [anon_sym_else] = ACTIONS(796),
    [anon_sym_if] = ACTIONS(796),
    [anon_sym_end] = ACTIONS(796),
    [anon_sym_for] = ACTIONS(796),
    [anon_sym_parfor] = ACTIONS(796),
    [anon_sym_while] = ACTIONS(796),
    [anon_sym_switch] = ACTIONS(796),
    [anon_sym_global] = ACTIONS(796),
    [anon_sym_persistent] = ACTIONS(796),
    [anon_sym_arguments] = ACTIONS(796),
    [anon_sym_function] = ACTIONS(796),
    [anon_sym_properties] = ACTIONS(796),
    [anon_sym_get] = ACTIONS(796),
    [anon_sym_set] = ACTIONS(796),
    [anon_sym_methods] = ACTIONS(796),
    [anon_sym_events] = ACTIONS(796),
    [anon_sym_enumeration] = ACTIONS(796),
    [anon_sym_classdef] = ACTIONS(796),
    [anon_sym_try] = ACTIONS(796),
    [anon_sym_spmd] = ACTIONS(796),
    [aux_sym_number_token1] = ACTIONS(796),
    [aux_sym_number_token2] = ACTIONS(796),
    [aux_sym_number_token3] = ACTIONS(796),
    [anon_sym_CR] = ACTIONS(796),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(803),
    [sym__single_quote_string_start] = ACTIONS(803),
    [sym__double_quote_string_start] = ACTIONS(803),
    [sym__multioutput_variable_start] = ACTIONS(803),
    [sym__external_identifier] = ACTIONS(803),
  },
  [STATE(171)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(711),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(172)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(590),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(173)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(805),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(174)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(582),
    [anon_sym_SQUOTE] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(590),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(175)] = {
    [anon_sym_LPAREN] = ACTIONS(578),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(578),
    [anon_sym_QMARK] = ACTIONS(578),
    [anon_sym_AT] = ACTIONS(578),
    [anon_sym_LT] = ACTIONS(578),
    [anon_sym_LT_EQ] = ACTIONS(578),
    [anon_sym_EQ_EQ] = ACTIONS(578),
    [anon_sym_TILDE_EQ] = ACTIONS(578),
    [anon_sym_GT_EQ] = ACTIONS(578),
    [anon_sym_GT] = ACTIONS(578),
    [anon_sym_AMP_AMP] = ACTIONS(578),
    [anon_sym_PIPE_PIPE] = ACTIONS(578),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(578),
    [anon_sym_LBRACK] = ACTIONS(578),
    [anon_sym_LF] = ACTIONS(578),
    [anon_sym_SEMI] = ACTIONS(578),
    [anon_sym_LBRACE] = ACTIONS(578),
    [anon_sym_COLON] = ACTIONS(578),
    [anon_sym_return] = ACTIONS(578),
    [anon_sym_continue] = ACTIONS(578),
    [anon_sym_break] = ACTIONS(578),
    [anon_sym_elseif] = ACTIONS(578),
    [anon_sym_else] = ACTIONS(578),
    [anon_sym_if] = ACTIONS(578),
    [anon_sym_end] = ACTIONS(578),
    [anon_sym_for] = ACTIONS(578),
    [anon_sym_parfor] = ACTIONS(578),
    [anon_sym_while] = ACTIONS(578),
    [anon_sym_switch] = ACTIONS(578),
    [anon_sym_global] = ACTIONS(578),
    [anon_sym_persistent] = ACTIONS(578),
    [anon_sym_arguments] = ACTIONS(578),
    [anon_sym_function] = ACTIONS(578),
    [anon_sym_properties] = ACTIONS(578),
    [anon_sym_get] = ACTIONS(578),
    [anon_sym_set] = ACTIONS(578),
    [anon_sym_methods] = ACTIONS(578),
    [anon_sym_events] = ACTIONS(578),
    [anon_sym_enumeration] = ACTIONS(578),
    [anon_sym_classdef] = ACTIONS(578),
    [anon_sym_try] = ACTIONS(578),
    [anon_sym_spmd] = ACTIONS(578),
    [aux_sym_number_token1] = ACTIONS(578),
    [aux_sym_number_token2] = ACTIONS(578),
    [aux_sym_number_token3] = ACTIONS(578),
    [anon_sym_CR] = ACTIONS(578),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(601),
    [sym__single_quote_string_start] = ACTIONS(601),
    [sym__double_quote_string_start] = ACTIONS(601),
    [sym__multioutput_variable_start] = ACTIONS(601),
    [sym__external_identifier] = ACTIONS(601),
  },
  [STATE(176)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(713),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(177)] = {
    [anon_sym_LPAREN] = ACTIONS(578),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(578),
    [anon_sym_QMARK] = ACTIONS(578),
    [anon_sym_AT] = ACTIONS(578),
    [anon_sym_LT] = ACTIONS(578),
    [anon_sym_LT_EQ] = ACTIONS(578),
    [anon_sym_EQ_EQ] = ACTIONS(578),
    [anon_sym_TILDE_EQ] = ACTIONS(578),
    [anon_sym_GT_EQ] = ACTIONS(578),
    [anon_sym_GT] = ACTIONS(578),
    [anon_sym_AMP_AMP] = ACTIONS(578),
    [anon_sym_PIPE_PIPE] = ACTIONS(578),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(578),
    [anon_sym_LBRACK] = ACTIONS(578),
    [anon_sym_LF] = ACTIONS(578),
    [anon_sym_SEMI] = ACTIONS(578),
    [anon_sym_LBRACE] = ACTIONS(578),
    [anon_sym_COLON] = ACTIONS(578),
    [anon_sym_return] = ACTIONS(578),
    [anon_sym_continue] = ACTIONS(578),
    [anon_sym_break] = ACTIONS(578),
    [anon_sym_elseif] = ACTIONS(578),
    [anon_sym_else] = ACTIONS(578),
    [anon_sym_if] = ACTIONS(578),
    [anon_sym_end] = ACTIONS(578),
    [anon_sym_for] = ACTIONS(578),
    [anon_sym_parfor] = ACTIONS(578),
    [anon_sym_while] = ACTIONS(578),
    [anon_sym_switch] = ACTIONS(578),
    [anon_sym_global] = ACTIONS(578),
    [anon_sym_persistent] = ACTIONS(578),
    [anon_sym_arguments] = ACTIONS(578),
    [anon_sym_function] = ACTIONS(578),
    [anon_sym_properties] = ACTIONS(578),
    [anon_sym_get] = ACTIONS(578),
    [anon_sym_set] = ACTIONS(578),
    [anon_sym_methods] = ACTIONS(578),
    [anon_sym_events] = ACTIONS(578),
    [anon_sym_enumeration] = ACTIONS(578),
    [anon_sym_classdef] = ACTIONS(578),
    [anon_sym_try] = ACTIONS(578),
    [anon_sym_spmd] = ACTIONS(578),
    [aux_sym_number_token1] = ACTIONS(578),
    [aux_sym_number_token2] = ACTIONS(578),
    [aux_sym_number_token3] = ACTIONS(578),
    [anon_sym_CR] = ACTIONS(578),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(601),
    [sym__single_quote_string_start] = ACTIONS(601),
    [sym__double_quote_string_start] = ACTIONS(601),
    [sym__multioutput_variable_start] = ACTIONS(601),
    [sym__external_identifier] = ACTIONS(601),
  },
  [STATE(178)] = {
    [anon_sym_LPAREN] = ACTIONS(578),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(578),
    [anon_sym_QMARK] = ACTIONS(578),
    [anon_sym_AT] = ACTIONS(578),
    [anon_sym_LT] = ACTIONS(578),
    [anon_sym_LT_EQ] = ACTIONS(578),
    [anon_sym_EQ_EQ] = ACTIONS(578),
    [anon_sym_TILDE_EQ] = ACTIONS(578),
    [anon_sym_GT_EQ] = ACTIONS(578),
    [anon_sym_GT] = ACTIONS(578),
    [anon_sym_AMP_AMP] = ACTIONS(578),
    [anon_sym_PIPE_PIPE] = ACTIONS(578),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(578),
    [anon_sym_LBRACK] = ACTIONS(578),
    [anon_sym_LF] = ACTIONS(578),
    [anon_sym_SEMI] = ACTIONS(578),
    [anon_sym_LBRACE] = ACTIONS(578),
    [anon_sym_COLON] = ACTIONS(578),
    [anon_sym_return] = ACTIONS(578),
    [anon_sym_continue] = ACTIONS(578),
    [anon_sym_break] = ACTIONS(578),
    [anon_sym_elseif] = ACTIONS(578),
    [anon_sym_else] = ACTIONS(578),
    [anon_sym_if] = ACTIONS(578),
    [anon_sym_end] = ACTIONS(578),
    [anon_sym_for] = ACTIONS(578),
    [anon_sym_parfor] = ACTIONS(578),
    [anon_sym_while] = ACTIONS(578),
    [anon_sym_switch] = ACTIONS(578),
    [anon_sym_global] = ACTIONS(578),
    [anon_sym_persistent] = ACTIONS(578),
    [anon_sym_arguments] = ACTIONS(578),
    [anon_sym_function] = ACTIONS(578),
    [anon_sym_properties] = ACTIONS(578),
    [anon_sym_get] = ACTIONS(578),
    [anon_sym_set] = ACTIONS(578),
    [anon_sym_methods] = ACTIONS(578),
    [anon_sym_events] = ACTIONS(578),
    [anon_sym_enumeration] = ACTIONS(578),
    [anon_sym_classdef] = ACTIONS(578),
    [anon_sym_try] = ACTIONS(578),
    [anon_sym_spmd] = ACTIONS(578),
    [aux_sym_number_token1] = ACTIONS(578),
    [aux_sym_number_token2] = ACTIONS(578),
    [aux_sym_number_token3] = ACTIONS(578),
    [anon_sym_CR] = ACTIONS(578),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(601),
    [sym__single_quote_string_start] = ACTIONS(601),
    [sym__double_quote_string_start] = ACTIONS(601),
    [sym__multioutput_variable_start] = ACTIONS(601),
    [sym__external_identifier] = ACTIONS(601),
  },
  [STATE(179)] = {
    [anon_sym_LPAREN] = ACTIONS(599),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(599),
    [anon_sym_QMARK] = ACTIONS(599),
    [anon_sym_AT] = ACTIONS(599),
    [anon_sym_LT] = ACTIONS(590),
    [anon_sym_LT_EQ] = ACTIONS(590),
    [anon_sym_EQ_EQ] = ACTIONS(590),
    [anon_sym_TILDE_EQ] = ACTIONS(590),
    [anon_sym_GT_EQ] = ACTIONS(590),
    [anon_sym_GT] = ACTIONS(590),
    [anon_sym_AMP_AMP] = ACTIONS(590),
    [anon_sym_PIPE_PIPE] = ACTIONS(590),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(599),
    [anon_sym_LBRACK] = ACTIONS(599),
    [anon_sym_LF] = ACTIONS(599),
    [anon_sym_SEMI] = ACTIONS(599),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_COLON] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(599),
    [anon_sym_continue] = ACTIONS(599),
    [anon_sym_break] = ACTIONS(599),
    [anon_sym_elseif] = ACTIONS(599),
    [anon_sym_else] = ACTIONS(599),
    [anon_sym_if] = ACTIONS(599),
    [anon_sym_end] = ACTIONS(599),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_parfor] = ACTIONS(599),
    [anon_sym_while] = ACTIONS(599),
    [anon_sym_switch] = ACTIONS(599),
    [anon_sym_global] = ACTIONS(599),
    [anon_sym_persistent] = ACTIONS(599),
    [anon_sym_arguments] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(599),
    [anon_sym_properties] = ACTIONS(599),
    [anon_sym_get] = ACTIONS(599),
    [anon_sym_set] = ACTIONS(599),
    [anon_sym_methods] = ACTIONS(599),
    [anon_sym_events] = ACTIONS(599),
    [anon_sym_enumeration] = ACTIONS(599),
    [anon_sym_classdef] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(599),
    [anon_sym_spmd] = ACTIONS(599),
    [aux_sym_number_token1] = ACTIONS(599),
    [aux_sym_number_token2] = ACTIONS(599),
    [aux_sym_number_token3] = ACTIONS(599),
    [anon_sym_CR] = ACTIONS(599),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(603),
    [sym__single_quote_string_start] = ACTIONS(603),
    [sym__double_quote_string_start] = ACTIONS(603),
    [sym__multioutput_variable_start] = ACTIONS(603),
    [sym__external_identifier] = ACTIONS(603),
  },
  [STATE(180)] = {
    [anon_sym_LPAREN] = ACTIONS(718),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(718),
    [anon_sym_QMARK] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(718),
    [anon_sym_LT] = ACTIONS(805),
    [anon_sym_LT_EQ] = ACTIONS(805),
    [anon_sym_EQ_EQ] = ACTIONS(805),
    [anon_sym_TILDE_EQ] = ACTIONS(805),
    [anon_sym_GT_EQ] = ACTIONS(805),
    [anon_sym_GT] = ACTIONS(805),
    [anon_sym_AMP_AMP] = ACTIONS(805),
    [anon_sym_PIPE_PIPE] = ACTIONS(805),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(718),
    [anon_sym_LBRACK] = ACTIONS(718),
    [anon_sym_LF] = ACTIONS(718),
    [anon_sym_SEMI] = ACTIONS(718),
    [anon_sym_LBRACE] = ACTIONS(718),
    [anon_sym_COLON] = ACTIONS(718),
    [anon_sym_return] = ACTIONS(718),
    [anon_sym_continue] = ACTIONS(718),
    [anon_sym_break] = ACTIONS(718),
    [anon_sym_elseif] = ACTIONS(718),
    [anon_sym_else] = ACTIONS(718),
    [anon_sym_if] = ACTIONS(718),
    [anon_sym_end] = ACTIONS(718),
    [anon_sym_for] = ACTIONS(718),
    [anon_sym_parfor] = ACTIONS(718),
    [anon_sym_while] = ACTIONS(718),
    [anon_sym_switch] = ACTIONS(718),
    [anon_sym_global] = ACTIONS(718),
    [anon_sym_persistent] = ACTIONS(718),
    [anon_sym_arguments] = ACTIONS(718),
    [anon_sym_function] = ACTIONS(718),
    [anon_sym_properties] = ACTIONS(718),
    [anon_sym_get] = ACTIONS(718),
    [anon_sym_set] = ACTIONS(718),
    [anon_sym_methods] = ACTIONS(718),
    [anon_sym_events] = ACTIONS(718),
    [anon_sym_enumeration] = ACTIONS(718),
    [anon_sym_classdef] = ACTIONS(718),
    [anon_sym_try] = ACTIONS(718),
    [anon_sym_spmd] = ACTIONS(718),
    [aux_sym_number_token1] = ACTIONS(718),
    [aux_sym_number_token2] = ACTIONS(718),
    [aux_sym_number_token3] = ACTIONS(718),
    [anon_sym_CR] = ACTIONS(718),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(808),
    [sym__single_quote_string_start] = ACTIONS(808),
    [sym__double_quote_string_start] = ACTIONS(808),
    [sym__multioutput_variable_start] = ACTIONS(808),
    [sym__external_identifier] = ACTIONS(808),
  },
  [STATE(181)] = {
    [anon_sym_LPAREN] = ACTIONS(599),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(599),
    [anon_sym_QMARK] = ACTIONS(599),
    [anon_sym_AT] = ACTIONS(599),
    [anon_sym_LT] = ACTIONS(590),
    [anon_sym_LT_EQ] = ACTIONS(590),
    [anon_sym_EQ_EQ] = ACTIONS(590),
    [anon_sym_TILDE_EQ] = ACTIONS(590),
    [anon_sym_GT_EQ] = ACTIONS(590),
    [anon_sym_GT] = ACTIONS(590),
    [anon_sym_AMP_AMP] = ACTIONS(590),
    [anon_sym_PIPE_PIPE] = ACTIONS(590),
    [anon_sym_DOT_SQUOTE] = ACTIONS(599),
    [anon_sym_SQUOTE] = ACTIONS(599),
    [anon_sym_COMMA] = ACTIONS(599),
    [anon_sym_LBRACK] = ACTIONS(599),
    [anon_sym_LF] = ACTIONS(599),
    [anon_sym_SEMI] = ACTIONS(599),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_COLON] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(599),
    [anon_sym_continue] = ACTIONS(599),
    [anon_sym_break] = ACTIONS(599),
    [anon_sym_elseif] = ACTIONS(599),
    [anon_sym_else] = ACTIONS(599),
    [anon_sym_if] = ACTIONS(599),
    [anon_sym_end] = ACTIONS(599),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_parfor] = ACTIONS(599),
    [anon_sym_while] = ACTIONS(599),
    [anon_sym_switch] = ACTIONS(599),
    [anon_sym_global] = ACTIONS(599),
    [anon_sym_persistent] = ACTIONS(599),
    [anon_sym_arguments] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(599),
    [anon_sym_properties] = ACTIONS(599),
    [anon_sym_get] = ACTIONS(599),
    [anon_sym_set] = ACTIONS(599),
    [anon_sym_methods] = ACTIONS(599),
    [anon_sym_events] = ACTIONS(599),
    [anon_sym_enumeration] = ACTIONS(599),
    [anon_sym_classdef] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(599),
    [anon_sym_spmd] = ACTIONS(599),
    [aux_sym_number_token1] = ACTIONS(599),
    [aux_sym_number_token2] = ACTIONS(599),
    [aux_sym_number_token3] = ACTIONS(599),
    [anon_sym_CR] = ACTIONS(599),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(603),
    [sym__single_quote_string_start] = ACTIONS(603),
    [sym__double_quote_string_start] = ACTIONS(603),
    [sym__multioutput_variable_start] = ACTIONS(603),
    [sym__external_identifier] = ACTIONS(603),
  },
  [STATE(182)] = {
    [anon_sym_LPAREN] = ACTIONS(578),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(578),
    [anon_sym_QMARK] = ACTIONS(578),
    [anon_sym_AT] = ACTIONS(578),
    [anon_sym_LT] = ACTIONS(578),
    [anon_sym_LT_EQ] = ACTIONS(578),
    [anon_sym_EQ_EQ] = ACTIONS(578),
    [anon_sym_TILDE_EQ] = ACTIONS(578),
    [anon_sym_GT_EQ] = ACTIONS(578),
    [anon_sym_GT] = ACTIONS(578),
    [anon_sym_AMP_AMP] = ACTIONS(578),
    [anon_sym_PIPE_PIPE] = ACTIONS(578),
    [anon_sym_DOT_SQUOTE] = ACTIONS(586),
    [anon_sym_SQUOTE] = ACTIONS(586),
    [anon_sym_COMMA] = ACTIONS(578),
    [anon_sym_LBRACK] = ACTIONS(578),
    [anon_sym_LF] = ACTIONS(578),
    [anon_sym_SEMI] = ACTIONS(578),
    [anon_sym_LBRACE] = ACTIONS(578),
    [anon_sym_COLON] = ACTIONS(578),
    [anon_sym_return] = ACTIONS(578),
    [anon_sym_continue] = ACTIONS(578),
    [anon_sym_break] = ACTIONS(578),
    [anon_sym_elseif] = ACTIONS(578),
    [anon_sym_else] = ACTIONS(578),
    [anon_sym_if] = ACTIONS(578),
    [anon_sym_end] = ACTIONS(578),
    [anon_sym_for] = ACTIONS(578),
    [anon_sym_parfor] = ACTIONS(578),
    [anon_sym_while] = ACTIONS(578),
    [anon_sym_switch] = ACTIONS(578),
    [anon_sym_global] = ACTIONS(578),
    [anon_sym_persistent] = ACTIONS(578),
    [anon_sym_arguments] = ACTIONS(578),
    [anon_sym_function] = ACTIONS(578),
    [anon_sym_properties] = ACTIONS(578),
    [anon_sym_get] = ACTIONS(578),
    [anon_sym_set] = ACTIONS(578),
    [anon_sym_methods] = ACTIONS(578),
    [anon_sym_events] = ACTIONS(578),
    [anon_sym_enumeration] = ACTIONS(578),
    [anon_sym_classdef] = ACTIONS(578),
    [anon_sym_try] = ACTIONS(578),
    [anon_sym_spmd] = ACTIONS(578),
    [aux_sym_number_token1] = ACTIONS(578),
    [aux_sym_number_token2] = ACTIONS(578),
    [aux_sym_number_token3] = ACTIONS(578),
    [anon_sym_CR] = ACTIONS(578),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(601),
    [sym__single_quote_string_start] = ACTIONS(601),
    [sym__double_quote_string_start] = ACTIONS(601),
    [sym__multioutput_variable_start] = ACTIONS(601),
    [sym__external_identifier] = ACTIONS(601),
  },
  [STATE(183)] = {
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_PLUS] = ACTIONS(810),
    [anon_sym_DOT_PLUS] = ACTIONS(810),
    [anon_sym_DASH] = ACTIONS(810),
    [anon_sym_DOT_DASH] = ACTIONS(810),
    [anon_sym_STAR] = ACTIONS(810),
    [anon_sym_DOT_STAR] = ACTIONS(810),
    [anon_sym_SLASH] = ACTIONS(810),
    [anon_sym_DOT_SLASH] = ACTIONS(810),
    [anon_sym_BSLASH] = ACTIONS(810),
    [anon_sym_DOT_BSLASH] = ACTIONS(810),
    [anon_sym_CARET] = ACTIONS(810),
    [anon_sym_DOT_CARET] = ACTIONS(810),
    [anon_sym_PIPE] = ACTIONS(810),
    [anon_sym_AMP] = ACTIONS(810),
    [anon_sym_TILDE] = ACTIONS(810),
    [anon_sym_QMARK] = ACTIONS(810),
    [anon_sym_AT] = ACTIONS(810),
    [anon_sym_LT] = ACTIONS(726),
    [anon_sym_LT_EQ] = ACTIONS(726),
    [anon_sym_EQ_EQ] = ACTIONS(726),
    [anon_sym_TILDE_EQ] = ACTIONS(726),
    [anon_sym_GT_EQ] = ACTIONS(726),
    [anon_sym_GT] = ACTIONS(726),
    [anon_sym_AMP_AMP] = ACTIONS(810),
    [anon_sym_PIPE_PIPE] = ACTIONS(810),
    [anon_sym_DOT_SQUOTE] = ACTIONS(810),
    [anon_sym_SQUOTE] = ACTIONS(810),
    [anon_sym_COMMA] = ACTIONS(810),
    [anon_sym_LBRACK] = ACTIONS(810),
    [anon_sym_LF] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(810),
    [anon_sym_LBRACE] = ACTIONS(810),
    [anon_sym_COLON] = ACTIONS(810),
    [anon_sym_return] = ACTIONS(810),
    [anon_sym_continue] = ACTIONS(810),
    [anon_sym_break] = ACTIONS(810),
    [anon_sym_elseif] = ACTIONS(810),
    [anon_sym_else] = ACTIONS(810),
    [anon_sym_if] = ACTIONS(810),
    [anon_sym_end] = ACTIONS(810),
    [anon_sym_for] = ACTIONS(810),
    [anon_sym_parfor] = ACTIONS(810),
    [anon_sym_while] = ACTIONS(810),
    [anon_sym_switch] = ACTIONS(810),
    [anon_sym_global] = ACTIONS(810),
    [anon_sym_persistent] = ACTIONS(810),
    [anon_sym_arguments] = ACTIONS(810),
    [anon_sym_function] = ACTIONS(810),
    [anon_sym_properties] = ACTIONS(810),
    [anon_sym_get] = ACTIONS(810),
    [anon_sym_set] = ACTIONS(810),
    [anon_sym_methods] = ACTIONS(810),
    [anon_sym_events] = ACTIONS(810),
    [anon_sym_enumeration] = ACTIONS(810),
    [anon_sym_classdef] = ACTIONS(810),
    [anon_sym_try] = ACTIONS(810),
    [anon_sym_spmd] = ACTIONS(810),
    [aux_sym_number_token1] = ACTIONS(810),
    [aux_sym_number_token2] = ACTIONS(810),
    [aux_sym_number_token3] = ACTIONS(810),
    [anon_sym_CR] = ACTIONS(810),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(812),
    [sym__single_quote_string_start] = ACTIONS(812),
    [sym__double_quote_string_start] = ACTIONS(812),
    [sym__multioutput_variable_start] = ACTIONS(812),
    [sym__external_identifier] = ACTIONS(812),
  },
  [STATE(184)] = {
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_PLUS] = ACTIONS(810),
    [anon_sym_DOT_PLUS] = ACTIONS(810),
    [anon_sym_DASH] = ACTIONS(810),
    [anon_sym_DOT_DASH] = ACTIONS(810),
    [anon_sym_STAR] = ACTIONS(810),
    [anon_sym_DOT_STAR] = ACTIONS(810),
    [anon_sym_SLASH] = ACTIONS(810),
    [anon_sym_DOT_SLASH] = ACTIONS(810),
    [anon_sym_BSLASH] = ACTIONS(810),
    [anon_sym_DOT_BSLASH] = ACTIONS(810),
    [anon_sym_CARET] = ACTIONS(810),
    [anon_sym_DOT_CARET] = ACTIONS(810),
    [anon_sym_PIPE] = ACTIONS(810),
    [anon_sym_AMP] = ACTIONS(810),
    [anon_sym_TILDE] = ACTIONS(810),
    [anon_sym_QMARK] = ACTIONS(810),
    [anon_sym_AT] = ACTIONS(810),
    [anon_sym_LT] = ACTIONS(726),
    [anon_sym_LT_EQ] = ACTIONS(726),
    [anon_sym_EQ_EQ] = ACTIONS(726),
    [anon_sym_TILDE_EQ] = ACTIONS(726),
    [anon_sym_GT_EQ] = ACTIONS(726),
    [anon_sym_GT] = ACTIONS(726),
    [anon_sym_AMP_AMP] = ACTIONS(814),
    [anon_sym_PIPE_PIPE] = ACTIONS(810),
    [anon_sym_DOT_SQUOTE] = ACTIONS(810),
    [anon_sym_SQUOTE] = ACTIONS(810),
    [anon_sym_COMMA] = ACTIONS(810),
    [anon_sym_LBRACK] = ACTIONS(810),
    [anon_sym_LF] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(810),
    [anon_sym_LBRACE] = ACTIONS(810),
    [anon_sym_COLON] = ACTIONS(810),
    [anon_sym_return] = ACTIONS(810),
    [anon_sym_continue] = ACTIONS(810),
    [anon_sym_break] = ACTIONS(810),
    [anon_sym_elseif] = ACTIONS(810),
    [anon_sym_else] = ACTIONS(810),
    [anon_sym_if] = ACTIONS(810),
    [anon_sym_end] = ACTIONS(810),
    [anon_sym_for] = ACTIONS(810),
    [anon_sym_parfor] = ACTIONS(810),
    [anon_sym_while] = ACTIONS(810),
    [anon_sym_switch] = ACTIONS(810),
    [anon_sym_global] = ACTIONS(810),
    [anon_sym_persistent] = ACTIONS(810),
    [anon_sym_arguments] = ACTIONS(810),
    [anon_sym_function] = ACTIONS(810),
    [anon_sym_properties] = ACTIONS(810),
    [anon_sym_get] = ACTIONS(810),
    [anon_sym_set] = ACTIONS(810),
    [anon_sym_methods] = ACTIONS(810),
    [anon_sym_events] = ACTIONS(810),
    [anon_sym_enumeration] = ACTIONS(810),
    [anon_sym_classdef] = ACTIONS(810),
    [anon_sym_try] = ACTIONS(810),
    [anon_sym_spmd] = ACTIONS(810),
    [aux_sym_number_token1] = ACTIONS(810),
    [aux_sym_number_token2] = ACTIONS(810),
    [aux_sym_number_token3] = ACTIONS(810),
    [anon_sym_CR] = ACTIONS(810),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(812),
    [sym__single_quote_string_start] = ACTIONS(812),
    [sym__double_quote_string_start] = ACTIONS(812),
    [sym__multioutput_variable_start] = ACTIONS(812),
    [sym__external_identifier] = ACTIONS(812),
  },
  [STATE(185)] = {
    [anon_sym_LPAREN] = ACTIONS(816),
    [anon_sym_PLUS] = ACTIONS(816),
    [anon_sym_DOT_PLUS] = ACTIONS(816),
    [anon_sym_DASH] = ACTIONS(816),
    [anon_sym_DOT_DASH] = ACTIONS(816),
    [anon_sym_STAR] = ACTIONS(816),
    [anon_sym_DOT_STAR] = ACTIONS(816),
    [anon_sym_SLASH] = ACTIONS(816),
    [anon_sym_DOT_SLASH] = ACTIONS(816),
    [anon_sym_BSLASH] = ACTIONS(816),
    [anon_sym_DOT_BSLASH] = ACTIONS(816),
    [anon_sym_CARET] = ACTIONS(816),
    [anon_sym_DOT_CARET] = ACTIONS(816),
    [anon_sym_PIPE] = ACTIONS(816),
    [anon_sym_AMP] = ACTIONS(816),
    [anon_sym_TILDE] = ACTIONS(816),
    [anon_sym_QMARK] = ACTIONS(816),
    [anon_sym_AT] = ACTIONS(816),
    [anon_sym_LT] = ACTIONS(726),
    [anon_sym_LT_EQ] = ACTIONS(726),
    [anon_sym_EQ_EQ] = ACTIONS(726),
    [anon_sym_TILDE_EQ] = ACTIONS(726),
    [anon_sym_GT_EQ] = ACTIONS(726),
    [anon_sym_GT] = ACTIONS(726),
    [anon_sym_AMP_AMP] = ACTIONS(814),
    [anon_sym_PIPE_PIPE] = ACTIONS(818),
    [anon_sym_DOT_SQUOTE] = ACTIONS(816),
    [anon_sym_SQUOTE] = ACTIONS(816),
    [anon_sym_COMMA] = ACTIONS(816),
    [anon_sym_LBRACK] = ACTIONS(816),
    [anon_sym_LF] = ACTIONS(816),
    [anon_sym_SEMI] = ACTIONS(816),
    [anon_sym_LBRACE] = ACTIONS(816),
    [anon_sym_COLON] = ACTIONS(816),
    [anon_sym_return] = ACTIONS(816),
    [anon_sym_continue] = ACTIONS(816),
    [anon_sym_break] = ACTIONS(816),
    [anon_sym_elseif] = ACTIONS(816),
    [anon_sym_else] = ACTIONS(816),
    [anon_sym_if] = ACTIONS(816),
    [anon_sym_end] = ACTIONS(816),
    [anon_sym_for] = ACTIONS(816),
    [anon_sym_parfor] = ACTIONS(816),
    [anon_sym_while] = ACTIONS(816),
    [anon_sym_switch] = ACTIONS(816),
    [anon_sym_global] = ACTIONS(816),
    [anon_sym_persistent] = ACTIONS(816),
    [anon_sym_arguments] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(816),
    [anon_sym_properties] = ACTIONS(816),
    [anon_sym_get] = ACTIONS(816),
    [anon_sym_set] = ACTIONS(816),
    [anon_sym_methods] = ACTIONS(816),
    [anon_sym_events] = ACTIONS(816),
    [anon_sym_enumeration] = ACTIONS(816),
    [anon_sym_classdef] = ACTIONS(816),
    [anon_sym_try] = ACTIONS(816),
    [anon_sym_spmd] = ACTIONS(816),
    [aux_sym_number_token1] = ACTIONS(816),
    [aux_sym_number_token2] = ACTIONS(816),
    [aux_sym_number_token3] = ACTIONS(816),
    [anon_sym_CR] = ACTIONS(816),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(820),
    [sym__single_quote_string_start] = ACTIONS(820),
    [sym__double_quote_string_start] = ACTIONS(820),
    [sym__multioutput_variable_start] = ACTIONS(820),
    [sym__external_identifier] = ACTIONS(820),
  },
  [STATE(186)] = {
    [anon_sym_LPAREN] = ACTIONS(822),
    [anon_sym_PLUS] = ACTIONS(822),
    [anon_sym_DOT_PLUS] = ACTIONS(822),
    [anon_sym_DASH] = ACTIONS(822),
    [anon_sym_DOT_DASH] = ACTIONS(822),
    [anon_sym_STAR] = ACTIONS(822),
    [anon_sym_DOT_STAR] = ACTIONS(822),
    [anon_sym_SLASH] = ACTIONS(822),
    [anon_sym_DOT_SLASH] = ACTIONS(822),
    [anon_sym_BSLASH] = ACTIONS(822),
    [anon_sym_DOT_BSLASH] = ACTIONS(822),
    [anon_sym_CARET] = ACTIONS(822),
    [anon_sym_DOT_CARET] = ACTIONS(822),
    [anon_sym_PIPE] = ACTIONS(822),
    [anon_sym_AMP] = ACTIONS(822),
    [anon_sym_TILDE] = ACTIONS(822),
    [anon_sym_QMARK] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(822),
    [anon_sym_LT] = ACTIONS(726),
    [anon_sym_LT_EQ] = ACTIONS(726),
    [anon_sym_EQ_EQ] = ACTIONS(726),
    [anon_sym_TILDE_EQ] = ACTIONS(726),
    [anon_sym_GT_EQ] = ACTIONS(726),
    [anon_sym_GT] = ACTIONS(726),
    [anon_sym_AMP_AMP] = ACTIONS(814),
    [anon_sym_PIPE_PIPE] = ACTIONS(818),
    [anon_sym_DOT_SQUOTE] = ACTIONS(822),
    [anon_sym_SQUOTE] = ACTIONS(822),
    [anon_sym_COMMA] = ACTIONS(822),
    [anon_sym_LBRACK] = ACTIONS(822),
    [anon_sym_LF] = ACTIONS(822),
    [anon_sym_SEMI] = ACTIONS(822),
    [anon_sym_LBRACE] = ACTIONS(822),
    [anon_sym_COLON] = ACTIONS(822),
    [anon_sym_return] = ACTIONS(822),
    [anon_sym_continue] = ACTIONS(822),
    [anon_sym_break] = ACTIONS(822),
    [anon_sym_elseif] = ACTIONS(822),
    [anon_sym_else] = ACTIONS(822),
    [anon_sym_if] = ACTIONS(822),
    [anon_sym_end] = ACTIONS(822),
    [anon_sym_for] = ACTIONS(822),
    [anon_sym_parfor] = ACTIONS(822),
    [anon_sym_while] = ACTIONS(822),
    [anon_sym_switch] = ACTIONS(822),
    [anon_sym_global] = ACTIONS(822),
    [anon_sym_persistent] = ACTIONS(822),
    [anon_sym_arguments] = ACTIONS(822),
    [anon_sym_function] = ACTIONS(822),
    [anon_sym_properties] = ACTIONS(822),
    [anon_sym_get] = ACTIONS(822),
    [anon_sym_set] = ACTIONS(822),
    [anon_sym_methods] = ACTIONS(822),
    [anon_sym_events] = ACTIONS(822),
    [anon_sym_enumeration] = ACTIONS(822),
    [anon_sym_classdef] = ACTIONS(822),
    [anon_sym_try] = ACTIONS(822),
    [anon_sym_spmd] = ACTIONS(822),
    [aux_sym_number_token1] = ACTIONS(822),
    [aux_sym_number_token2] = ACTIONS(822),
    [aux_sym_number_token3] = ACTIONS(822),
    [anon_sym_CR] = ACTIONS(822),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(824),
    [sym__single_quote_string_start] = ACTIONS(824),
    [sym__double_quote_string_start] = ACTIONS(824),
    [sym__multioutput_variable_start] = ACTIONS(824),
    [sym__external_identifier] = ACTIONS(824),
  },
  [STATE(187)] = {
    [anon_sym_LPAREN] = ACTIONS(764),
    [anon_sym_PLUS] = ACTIONS(772),
    [anon_sym_DOT_PLUS] = ACTIONS(772),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_DOT_DASH] = ACTIONS(772),
    [anon_sym_STAR] = ACTIONS(766),
    [anon_sym_DOT_STAR] = ACTIONS(766),
    [anon_sym_SLASH] = ACTIONS(766),
    [anon_sym_DOT_SLASH] = ACTIONS(766),
    [anon_sym_BSLASH] = ACTIONS(766),
    [anon_sym_DOT_BSLASH] = ACTIONS(766),
    [anon_sym_CARET] = ACTIONS(768),
    [anon_sym_DOT_CARET] = ACTIONS(768),
    [anon_sym_PIPE] = ACTIONS(764),
    [anon_sym_AMP] = ACTIONS(826),
    [anon_sym_TILDE] = ACTIONS(764),
    [anon_sym_QMARK] = ACTIONS(764),
    [anon_sym_AT] = ACTIONS(764),
    [anon_sym_LT] = ACTIONS(764),
    [anon_sym_LT_EQ] = ACTIONS(764),
    [anon_sym_EQ_EQ] = ACTIONS(764),
    [anon_sym_TILDE_EQ] = ACTIONS(764),
    [anon_sym_GT_EQ] = ACTIONS(764),
    [anon_sym_GT] = ACTIONS(764),
    [anon_sym_AMP_AMP] = ACTIONS(764),
    [anon_sym_PIPE_PIPE] = ACTIONS(764),
    [anon_sym_DOT_SQUOTE] = ACTIONS(764),
    [anon_sym_SQUOTE] = ACTIONS(764),
    [anon_sym_COMMA] = ACTIONS(764),
    [anon_sym_LBRACK] = ACTIONS(764),
    [anon_sym_LF] = ACTIONS(764),
    [anon_sym_SEMI] = ACTIONS(764),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_COLON] = ACTIONS(764),
    [anon_sym_return] = ACTIONS(764),
    [anon_sym_continue] = ACTIONS(764),
    [anon_sym_break] = ACTIONS(764),
    [anon_sym_elseif] = ACTIONS(764),
    [anon_sym_else] = ACTIONS(764),
    [anon_sym_if] = ACTIONS(764),
    [anon_sym_end] = ACTIONS(764),
    [anon_sym_for] = ACTIONS(764),
    [anon_sym_parfor] = ACTIONS(764),
    [anon_sym_while] = ACTIONS(764),
    [anon_sym_switch] = ACTIONS(764),
    [anon_sym_global] = ACTIONS(764),
    [anon_sym_persistent] = ACTIONS(764),
    [anon_sym_arguments] = ACTIONS(764),
    [anon_sym_function] = ACTIONS(764),
    [anon_sym_properties] = ACTIONS(764),
    [anon_sym_get] = ACTIONS(764),
    [anon_sym_set] = ACTIONS(764),
    [anon_sym_methods] = ACTIONS(764),
    [anon_sym_events] = ACTIONS(764),
    [anon_sym_enumeration] = ACTIONS(764),
    [anon_sym_classdef] = ACTIONS(764),
    [anon_sym_try] = ACTIONS(764),
    [anon_sym_spmd] = ACTIONS(764),
    [aux_sym_number_token1] = ACTIONS(764),
    [aux_sym_number_token2] = ACTIONS(764),
    [aux_sym_number_token3] = ACTIONS(764),
    [anon_sym_CR] = ACTIONS(764),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(770),
    [sym__single_quote_string_start] = ACTIONS(770),
    [sym__double_quote_string_start] = ACTIONS(770),
    [sym__multioutput_variable_start] = ACTIONS(770),
    [sym__external_identifier] = ACTIONS(770),
  },
  [STATE(188)] = {
    [sym_identifier] = STATE(444),
    [sym__expression] = STATE(976),
    [sym_parenthesis] = STATE(636),
    [sym__binary_expression] = STATE(982),
    [sym_binary_operator] = STATE(612),
    [sym_unary_operator] = STATE(637),
    [sym_indirect_access] = STATE(1557),
    [sym_field_expression] = STATE(645),
    [sym_not_operator] = STATE(713),
    [sym_metaclass_operator] = STATE(976),
    [sym_handle_operator] = STATE(976),
    [sym_comparison_operator] = STATE(638),
    [sym_boolean_operator] = STATE(638),
    [sym_postfix_operator] = STATE(636),
    [sym_string] = STATE(645),
    [sym_row] = STATE(1541),
    [sym_matrix] = STATE(636),
    [sym_cell] = STATE(659),
    [sym_ignored_argument] = STATE(1262),
    [sym__index_boolean_operator] = STATE(676),
    [sym__index_comparison_operator] = STATE(687),
    [sym__index_not_operator] = STATE(688),
    [sym__index_unary_operator] = STATE(690),
    [sym__index_postfix_operator] = STATE(697),
    [sym__index_row] = STATE(1498),
    [sym__index_matrix] = STATE(647),
    [sym__index_range_element] = STATE(1734),
    [sym__index_range] = STATE(665),
    [sym__index_parenthesis] = STATE(647),
    [sym__index_expression] = STATE(1005),
    [sym__index_binary_expression] = STATE(968),
    [sym__index_binary_operator] = STATE(675),
    [sym_function_call] = STATE(444),
    [sym__range_element] = STATE(1759),
    [sym_range] = STATE(976),
    [sym_lambda] = STATE(976),
    [sym_number] = STATE(645),
    [sym_end_keyword] = STATE(494),
    [sym__keywords] = STATE(480),
    [aux_sym_matrix_repeat1] = STATE(189),
    [anon_sym_LPAREN] = ACTIONS(828),
    [anon_sym_PLUS] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(830),
    [anon_sym_TILDE] = ACTIONS(832),
    [anon_sym_QMARK] = ACTIONS(834),
    [anon_sym_AT] = ACTIONS(836),
    [anon_sym_COMMA] = ACTIONS(838),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_LF] = ACTIONS(842),
    [anon_sym_RBRACK] = ACTIONS(844),
    [anon_sym_LBRACE] = ACTIONS(846),
    [anon_sym_end] = ACTIONS(848),
    [anon_sym_arguments] = ACTIONS(850),
    [anon_sym_properties] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_methods] = ACTIONS(850),
    [anon_sym_events] = ACTIONS(850),
    [anon_sym_enumeration] = ACTIONS(850),
    [aux_sym_number_token1] = ACTIONS(852),
    [aux_sym_number_token2] = ACTIONS(854),
    [aux_sym_number_token3] = ACTIONS(854),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(856),
    [sym__double_quote_string_start] = ACTIONS(858),
    [sym__external_identifier] = ACTIONS(860),
  },
  [STATE(189)] = {
    [sym_identifier] = STATE(444),
    [sym__expression] = STATE(976),
    [sym_parenthesis] = STATE(636),
    [sym__binary_expression] = STATE(982),
    [sym_binary_operator] = STATE(612),
    [sym_unary_operator] = STATE(637),
    [sym_indirect_access] = STATE(1557),
    [sym_field_expression] = STATE(645),
    [sym_not_operator] = STATE(713),
    [sym_metaclass_operator] = STATE(976),
    [sym_handle_operator] = STATE(976),
    [sym_comparison_operator] = STATE(638),
    [sym_boolean_operator] = STATE(638),
    [sym_postfix_operator] = STATE(636),
    [sym_string] = STATE(645),
    [sym_row] = STATE(1546),
    [sym_matrix] = STATE(636),
    [sym_cell] = STATE(659),
    [sym_ignored_argument] = STATE(1262),
    [sym__index_boolean_operator] = STATE(676),
    [sym__index_comparison_operator] = STATE(687),
    [sym__index_not_operator] = STATE(688),
    [sym__index_unary_operator] = STATE(690),
    [sym__index_postfix_operator] = STATE(697),
    [sym__index_row] = STATE(1502),
    [sym__index_matrix] = STATE(647),
    [sym__index_range_element] = STATE(1734),
    [sym__index_range] = STATE(665),
    [sym__index_parenthesis] = STATE(647),
    [sym__index_expression] = STATE(1005),
    [sym__index_binary_expression] = STATE(968),
    [sym__index_binary_operator] = STATE(675),
    [sym_function_call] = STATE(444),
    [sym__range_element] = STATE(1759),
    [sym_range] = STATE(976),
    [sym_lambda] = STATE(976),
    [sym_number] = STATE(645),
    [sym_end_keyword] = STATE(494),
    [sym__keywords] = STATE(480),
    [aux_sym_matrix_repeat1] = STATE(810),
    [anon_sym_LPAREN] = ACTIONS(828),
    [anon_sym_PLUS] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(830),
    [anon_sym_TILDE] = ACTIONS(832),
    [anon_sym_QMARK] = ACTIONS(834),
    [anon_sym_AT] = ACTIONS(836),
    [anon_sym_COMMA] = ACTIONS(838),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_LF] = ACTIONS(862),
    [anon_sym_RBRACK] = ACTIONS(864),
    [anon_sym_LBRACE] = ACTIONS(846),
    [anon_sym_end] = ACTIONS(848),
    [anon_sym_arguments] = ACTIONS(850),
    [anon_sym_properties] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_methods] = ACTIONS(850),
    [anon_sym_events] = ACTIONS(850),
    [anon_sym_enumeration] = ACTIONS(850),
    [aux_sym_number_token1] = ACTIONS(852),
    [aux_sym_number_token2] = ACTIONS(854),
    [aux_sym_number_token3] = ACTIONS(854),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(856),
    [sym__double_quote_string_start] = ACTIONS(858),
    [sym__external_identifier] = ACTIONS(860),
  },
  [STATE(190)] = {
    [sym_identifier] = STATE(444),
    [sym__expression] = STATE(976),
    [sym_parenthesis] = STATE(636),
    [sym__binary_expression] = STATE(982),
    [sym_binary_operator] = STATE(612),
    [sym_unary_operator] = STATE(637),
    [sym_indirect_access] = STATE(1557),
    [sym_field_expression] = STATE(645),
    [sym_not_operator] = STATE(713),
    [sym_metaclass_operator] = STATE(976),
    [sym_handle_operator] = STATE(976),
    [sym_comparison_operator] = STATE(638),
    [sym_boolean_operator] = STATE(638),
    [sym_postfix_operator] = STATE(636),
    [sym_string] = STATE(645),
    [sym_row] = STATE(1479),
    [sym_matrix] = STATE(636),
    [sym_cell] = STATE(659),
    [sym_ignored_argument] = STATE(1262),
    [sym__index_boolean_operator] = STATE(676),
    [sym__index_comparison_operator] = STATE(687),
    [sym__index_not_operator] = STATE(688),
    [sym__index_unary_operator] = STATE(690),
    [sym__index_postfix_operator] = STATE(697),
    [sym__index_row] = STATE(1407),
    [sym__index_matrix] = STATE(647),
    [sym__index_range_element] = STATE(1734),
    [sym__index_range] = STATE(665),
    [sym__index_parenthesis] = STATE(647),
    [sym__index_expression] = STATE(1005),
    [sym__index_binary_expression] = STATE(968),
    [sym__index_binary_operator] = STATE(675),
    [sym_function_call] = STATE(444),
    [sym__range_element] = STATE(1759),
    [sym_range] = STATE(976),
    [sym_lambda] = STATE(976),
    [sym_number] = STATE(645),
    [sym_end_keyword] = STATE(494),
    [sym__keywords] = STATE(480),
    [aux_sym_matrix_repeat1] = STATE(193),
    [anon_sym_LPAREN] = ACTIONS(828),
    [anon_sym_PLUS] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(830),
    [anon_sym_TILDE] = ACTIONS(832),
    [anon_sym_QMARK] = ACTIONS(834),
    [anon_sym_AT] = ACTIONS(836),
    [anon_sym_COMMA] = ACTIONS(838),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_LF] = ACTIONS(866),
    [anon_sym_RBRACK] = ACTIONS(868),
    [anon_sym_LBRACE] = ACTIONS(846),
    [anon_sym_end] = ACTIONS(848),
    [anon_sym_arguments] = ACTIONS(850),
    [anon_sym_properties] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_methods] = ACTIONS(850),
    [anon_sym_events] = ACTIONS(850),
    [anon_sym_enumeration] = ACTIONS(850),
    [aux_sym_number_token1] = ACTIONS(852),
    [aux_sym_number_token2] = ACTIONS(854),
    [aux_sym_number_token3] = ACTIONS(854),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(856),
    [sym__double_quote_string_start] = ACTIONS(858),
    [sym__external_identifier] = ACTIONS(860),
  },
  [STATE(191)] = {
    [sym_identifier] = STATE(444),
    [sym__expression] = STATE(976),
    [sym_parenthesis] = STATE(636),
    [sym__binary_expression] = STATE(982),
    [sym_binary_operator] = STATE(612),
    [sym_unary_operator] = STATE(637),
    [sym_indirect_access] = STATE(1557),
    [sym_field_expression] = STATE(645),
    [sym_not_operator] = STATE(713),
    [sym_metaclass_operator] = STATE(976),
    [sym_handle_operator] = STATE(976),
    [sym_comparison_operator] = STATE(638),
    [sym_boolean_operator] = STATE(638),
    [sym_postfix_operator] = STATE(636),
    [sym_string] = STATE(645),
    [sym_row] = STATE(1486),
    [sym_matrix] = STATE(636),
    [sym_cell] = STATE(659),
    [sym_ignored_argument] = STATE(1262),
    [sym__index_boolean_operator] = STATE(676),
    [sym__index_comparison_operator] = STATE(687),
    [sym__index_not_operator] = STATE(688),
    [sym__index_unary_operator] = STATE(690),
    [sym__index_postfix_operator] = STATE(697),
    [sym__index_row] = STATE(1426),
    [sym__index_matrix] = STATE(647),
    [sym__index_range_element] = STATE(1734),
    [sym__index_range] = STATE(665),
    [sym__index_parenthesis] = STATE(647),
    [sym__index_expression] = STATE(1005),
    [sym__index_binary_expression] = STATE(968),
    [sym__index_binary_operator] = STATE(675),
    [sym_function_call] = STATE(444),
    [sym__range_element] = STATE(1759),
    [sym_range] = STATE(976),
    [sym_lambda] = STATE(976),
    [sym_number] = STATE(645),
    [sym_end_keyword] = STATE(494),
    [sym__keywords] = STATE(480),
    [aux_sym_matrix_repeat1] = STATE(810),
    [anon_sym_LPAREN] = ACTIONS(828),
    [anon_sym_PLUS] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(830),
    [anon_sym_TILDE] = ACTIONS(832),
    [anon_sym_QMARK] = ACTIONS(834),
    [anon_sym_AT] = ACTIONS(836),
    [anon_sym_COMMA] = ACTIONS(838),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_LF] = ACTIONS(862),
    [anon_sym_RBRACK] = ACTIONS(870),
    [anon_sym_LBRACE] = ACTIONS(846),
    [anon_sym_end] = ACTIONS(848),
    [anon_sym_arguments] = ACTIONS(850),
    [anon_sym_properties] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_methods] = ACTIONS(850),
    [anon_sym_events] = ACTIONS(850),
    [anon_sym_enumeration] = ACTIONS(850),
    [aux_sym_number_token1] = ACTIONS(852),
    [aux_sym_number_token2] = ACTIONS(854),
    [aux_sym_number_token3] = ACTIONS(854),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(856),
    [sym__double_quote_string_start] = ACTIONS(858),
    [sym__external_identifier] = ACTIONS(860),
  },
  [STATE(192)] = {
    [anon_sym_LPAREN] = ACTIONS(582),
    [anon_sym_PLUS] = ACTIONS(578),
    [anon_sym_DOT_PLUS] = ACTIONS(578),
    [anon_sym_DASH] = ACTIONS(578),
    [anon_sym_DOT_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(578),
    [anon_sym_DOT_STAR] = ACTIONS(578),
    [anon_sym_SLASH] = ACTIONS(578),
    [anon_sym_DOT_SLASH] = ACTIONS(578),
    [anon_sym_BSLASH] = ACTIONS(578),
    [anon_sym_DOT_BSLASH] = ACTIONS(578),
    [anon_sym_CARET] = ACTIONS(578),
    [anon_sym_DOT_CARET] = ACTIONS(578),
    [anon_sym_PIPE] = ACTIONS(578),
    [anon_sym_AMP] = ACTIONS(578),
    [anon_sym_TILDE] = ACTIONS(582),
    [anon_sym_QMARK] = ACTIONS(582),
    [anon_sym_AT] = ACTIONS(582),
    [anon_sym_LT] = ACTIONS(582),
    [anon_sym_LT_EQ] = ACTIONS(582),
    [anon_sym_EQ_EQ] = ACTIONS(582),
    [anon_sym_TILDE_EQ] = ACTIONS(582),
    [anon_sym_GT_EQ] = ACTIONS(582),
    [anon_sym_GT] = ACTIONS(582),
    [anon_sym_AMP_AMP] = ACTIONS(582),
    [anon_sym_PIPE_PIPE] = ACTIONS(582),
    [anon_sym_COMMA] = ACTIONS(582),
    [anon_sym_LBRACK] = ACTIONS(582),
    [anon_sym_LF] = ACTIONS(582),
    [anon_sym_SEMI] = ACTIONS(582),
    [anon_sym_LBRACE] = ACTIONS(582),
    [anon_sym_COLON] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(582),
    [anon_sym_continue] = ACTIONS(582),
    [anon_sym_break] = ACTIONS(582),
    [anon_sym_elseif] = ACTIONS(582),
    [anon_sym_else] = ACTIONS(582),
    [anon_sym_if] = ACTIONS(582),
    [anon_sym_end] = ACTIONS(582),
    [anon_sym_for] = ACTIONS(582),
    [anon_sym_parfor] = ACTIONS(582),
    [anon_sym_while] = ACTIONS(582),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_global] = ACTIONS(582),
    [anon_sym_persistent] = ACTIONS(582),
    [anon_sym_arguments] = ACTIONS(582),
    [anon_sym_function] = ACTIONS(582),
    [anon_sym_properties] = ACTIONS(582),
    [anon_sym_get] = ACTIONS(582),
    [anon_sym_set] = ACTIONS(582),
    [anon_sym_methods] = ACTIONS(582),
    [anon_sym_events] = ACTIONS(582),
    [anon_sym_enumeration] = ACTIONS(582),
    [anon_sym_classdef] = ACTIONS(582),
    [anon_sym_try] = ACTIONS(582),
    [anon_sym_spmd] = ACTIONS(582),
    [aux_sym_number_token1] = ACTIONS(582),
    [aux_sym_number_token2] = ACTIONS(582),
    [aux_sym_number_token3] = ACTIONS(582),
    [anon_sym_CR] = ACTIONS(582),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(193)] = {
    [sym_identifier] = STATE(444),
    [sym__expression] = STATE(976),
    [sym_parenthesis] = STATE(636),
    [sym__binary_expression] = STATE(982),
    [sym_binary_operator] = STATE(612),
    [sym_unary_operator] = STATE(637),
    [sym_indirect_access] = STATE(1557),
    [sym_field_expression] = STATE(645),
    [sym_not_operator] = STATE(713),
    [sym_metaclass_operator] = STATE(976),
    [sym_handle_operator] = STATE(976),
    [sym_comparison_operator] = STATE(638),
    [sym_boolean_operator] = STATE(638),
    [sym_postfix_operator] = STATE(636),
    [sym_string] = STATE(645),
    [sym_row] = STATE(1486),
    [sym_matrix] = STATE(636),
    [sym_cell] = STATE(659),
    [sym_ignored_argument] = STATE(1262),
    [sym__index_boolean_operator] = STATE(676),
    [sym__index_comparison_operator] = STATE(687),
    [sym__index_not_operator] = STATE(688),
    [sym__index_unary_operator] = STATE(690),
    [sym__index_postfix_operator] = STATE(697),
    [sym__index_row] = STATE(1426),
    [sym__index_matrix] = STATE(647),
    [sym__index_range_element] = STATE(1734),
    [sym__index_range] = STATE(665),
    [sym__index_parenthesis] = STATE(647),
    [sym__index_expression] = STATE(1005),
    [sym__index_binary_expression] = STATE(968),
    [sym__index_binary_operator] = STATE(675),
    [sym_function_call] = STATE(444),
    [sym__range_element] = STATE(1759),
    [sym_range] = STATE(976),
    [sym_lambda] = STATE(976),
    [sym_number] = STATE(645),
    [sym_end_keyword] = STATE(494),
    [sym__keywords] = STATE(480),
    [aux_sym_matrix_repeat1] = STATE(810),
    [anon_sym_LPAREN] = ACTIONS(828),
    [anon_sym_PLUS] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(830),
    [anon_sym_TILDE] = ACTIONS(832),
    [anon_sym_QMARK] = ACTIONS(834),
    [anon_sym_AT] = ACTIONS(836),
    [anon_sym_COMMA] = ACTIONS(838),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_LF] = ACTIONS(862),
    [anon_sym_RBRACK] = ACTIONS(872),
    [anon_sym_LBRACE] = ACTIONS(846),
    [anon_sym_end] = ACTIONS(848),
    [anon_sym_arguments] = ACTIONS(850),
    [anon_sym_properties] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_methods] = ACTIONS(850),
    [anon_sym_events] = ACTIONS(850),
    [anon_sym_enumeration] = ACTIONS(850),
    [aux_sym_number_token1] = ACTIONS(852),
    [aux_sym_number_token2] = ACTIONS(854),
    [aux_sym_number_token3] = ACTIONS(854),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(856),
    [sym__double_quote_string_start] = ACTIONS(858),
    [sym__external_identifier] = ACTIONS(860),
  },
  [STATE(194)] = {
    [sym_identifier] = STATE(444),
    [sym__expression] = STATE(976),
    [sym_parenthesis] = STATE(636),
    [sym__binary_expression] = STATE(982),
    [sym_binary_operator] = STATE(612),
    [sym_unary_operator] = STATE(637),
    [sym_indirect_access] = STATE(1557),
    [sym_field_expression] = STATE(645),
    [sym_not_operator] = STATE(713),
    [sym_metaclass_operator] = STATE(976),
    [sym_handle_operator] = STATE(976),
    [sym_comparison_operator] = STATE(638),
    [sym_boolean_operator] = STATE(638),
    [sym_postfix_operator] = STATE(636),
    [sym_string] = STATE(645),
    [sym_row] = STATE(1479),
    [sym_matrix] = STATE(636),
    [sym_cell] = STATE(659),
    [sym_ignored_argument] = STATE(1262),
    [sym__index_boolean_operator] = STATE(676),
    [sym__index_comparison_operator] = STATE(687),
    [sym__index_not_operator] = STATE(688),
    [sym__index_unary_operator] = STATE(690),
    [sym__index_postfix_operator] = STATE(697),
    [sym__index_row] = STATE(1407),
    [sym__index_matrix] = STATE(647),
    [sym__index_range_element] = STATE(1734),
    [sym__index_range] = STATE(665),
    [sym__index_parenthesis] = STATE(647),
    [sym__index_expression] = STATE(1005),
    [sym__index_binary_expression] = STATE(968),
    [sym__index_binary_operator] = STATE(675),
    [sym_function_call] = STATE(444),
    [sym__range_element] = STATE(1759),
    [sym_range] = STATE(976),
    [sym_lambda] = STATE(976),
    [sym_number] = STATE(645),
    [sym_end_keyword] = STATE(494),
    [sym__keywords] = STATE(480),
    [aux_sym_matrix_repeat1] = STATE(191),
    [anon_sym_LPAREN] = ACTIONS(828),
    [anon_sym_PLUS] = ACTIONS(830),
    [anon_sym_DASH] = ACTIONS(830),
    [anon_sym_TILDE] = ACTIONS(832),
    [anon_sym_QMARK] = ACTIONS(834),
    [anon_sym_AT] = ACTIONS(836),
    [anon_sym_COMMA] = ACTIONS(838),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_LF] = ACTIONS(874),
    [anon_sym_RBRACK] = ACTIONS(876),
    [anon_sym_LBRACE] = ACTIONS(846),
    [anon_sym_end] = ACTIONS(848),
    [anon_sym_arguments] = ACTIONS(850),
    [anon_sym_properties] = ACTIONS(850),
    [anon_sym_get] = ACTIONS(850),
    [anon_sym_set] = ACTIONS(850),
    [anon_sym_methods] = ACTIONS(850),
    [anon_sym_events] = ACTIONS(850),
    [anon_sym_enumeration] = ACTIONS(850),
    [aux_sym_number_token1] = ACTIONS(852),
    [aux_sym_number_token2] = ACTIONS(854),
    [aux_sym_number_token3] = ACTIONS(854),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(856),
    [sym__double_quote_string_start] = ACTIONS(858),
    [sym__external_identifier] = ACTIONS(860),
  },
  [STATE(195)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1729),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_RBRACE] = ACTIONS(892),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(196)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1728),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_RBRACE] = ACTIONS(906),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(197)] = {
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_PLUS] = ACTIONS(810),
    [anon_sym_DOT_PLUS] = ACTIONS(810),
    [anon_sym_DASH] = ACTIONS(810),
    [anon_sym_DOT_DASH] = ACTIONS(810),
    [anon_sym_STAR] = ACTIONS(810),
    [anon_sym_DOT_STAR] = ACTIONS(810),
    [anon_sym_SLASH] = ACTIONS(810),
    [anon_sym_DOT_SLASH] = ACTIONS(810),
    [anon_sym_BSLASH] = ACTIONS(810),
    [anon_sym_DOT_BSLASH] = ACTIONS(810),
    [anon_sym_CARET] = ACTIONS(810),
    [anon_sym_DOT_CARET] = ACTIONS(810),
    [anon_sym_PIPE] = ACTIONS(810),
    [anon_sym_AMP] = ACTIONS(810),
    [anon_sym_TILDE] = ACTIONS(810),
    [anon_sym_QMARK] = ACTIONS(810),
    [anon_sym_AT] = ACTIONS(810),
    [anon_sym_LT] = ACTIONS(117),
    [anon_sym_LT_EQ] = ACTIONS(117),
    [anon_sym_EQ_EQ] = ACTIONS(117),
    [anon_sym_TILDE_EQ] = ACTIONS(117),
    [anon_sym_GT_EQ] = ACTIONS(117),
    [anon_sym_GT] = ACTIONS(117),
    [anon_sym_AMP_AMP] = ACTIONS(119),
    [anon_sym_PIPE_PIPE] = ACTIONS(810),
    [anon_sym_COMMA] = ACTIONS(810),
    [anon_sym_LBRACK] = ACTIONS(810),
    [anon_sym_LF] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(810),
    [anon_sym_LBRACE] = ACTIONS(810),
    [anon_sym_return] = ACTIONS(810),
    [anon_sym_continue] = ACTIONS(810),
    [anon_sym_break] = ACTIONS(810),
    [anon_sym_elseif] = ACTIONS(810),
    [anon_sym_else] = ACTIONS(810),
    [anon_sym_if] = ACTIONS(810),
    [anon_sym_end] = ACTIONS(810),
    [anon_sym_for] = ACTIONS(810),
    [anon_sym_parfor] = ACTIONS(810),
    [anon_sym_while] = ACTIONS(810),
    [anon_sym_switch] = ACTIONS(810),
    [anon_sym_global] = ACTIONS(810),
    [anon_sym_persistent] = ACTIONS(810),
    [anon_sym_arguments] = ACTIONS(810),
    [anon_sym_function] = ACTIONS(810),
    [anon_sym_properties] = ACTIONS(810),
    [anon_sym_get] = ACTIONS(810),
    [anon_sym_set] = ACTIONS(810),
    [anon_sym_methods] = ACTIONS(810),
    [anon_sym_events] = ACTIONS(810),
    [anon_sym_enumeration] = ACTIONS(810),
    [anon_sym_classdef] = ACTIONS(810),
    [anon_sym_try] = ACTIONS(810),
    [anon_sym_spmd] = ACTIONS(810),
    [aux_sym_number_token1] = ACTIONS(810),
    [aux_sym_number_token2] = ACTIONS(810),
    [aux_sym_number_token3] = ACTIONS(810),
    [anon_sym_CR] = ACTIONS(810),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(812),
    [sym__single_quote_string_start] = ACTIONS(812),
    [sym__double_quote_string_start] = ACTIONS(812),
    [sym__multioutput_variable_start] = ACTIONS(812),
    [sym__external_identifier] = ACTIONS(812),
  },
  [STATE(198)] = {
    [sym_identifier] = STATE(461),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(815),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(817),
    [sym_unary_operator] = STATE(818),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(808),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(815),
    [sym_string] = STATE(808),
    [sym_matrix] = STATE(815),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1738),
    [sym_function_call] = STATE(498),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(808),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_RPAREN] = ACTIONS(908),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(199)] = {
    [anon_sym_LPAREN] = ACTIONS(822),
    [anon_sym_PLUS] = ACTIONS(822),
    [anon_sym_DOT_PLUS] = ACTIONS(822),
    [anon_sym_DASH] = ACTIONS(822),
    [anon_sym_DOT_DASH] = ACTIONS(822),
    [anon_sym_STAR] = ACTIONS(822),
    [anon_sym_DOT_STAR] = ACTIONS(822),
    [anon_sym_SLASH] = ACTIONS(822),
    [anon_sym_DOT_SLASH] = ACTIONS(822),
    [anon_sym_BSLASH] = ACTIONS(822),
    [anon_sym_DOT_BSLASH] = ACTIONS(822),
    [anon_sym_CARET] = ACTIONS(822),
    [anon_sym_DOT_CARET] = ACTIONS(822),
    [anon_sym_PIPE] = ACTIONS(822),
    [anon_sym_AMP] = ACTIONS(822),
    [anon_sym_TILDE] = ACTIONS(822),
    [anon_sym_QMARK] = ACTIONS(822),
    [anon_sym_AT] = ACTIONS(822),
    [anon_sym_LT] = ACTIONS(117),
    [anon_sym_LT_EQ] = ACTIONS(117),
    [anon_sym_EQ_EQ] = ACTIONS(117),
    [anon_sym_TILDE_EQ] = ACTIONS(117),
    [anon_sym_GT_EQ] = ACTIONS(117),
    [anon_sym_GT] = ACTIONS(117),
    [anon_sym_AMP_AMP] = ACTIONS(119),
    [anon_sym_PIPE_PIPE] = ACTIONS(121),
    [anon_sym_COMMA] = ACTIONS(822),
    [anon_sym_LBRACK] = ACTIONS(822),
    [anon_sym_LF] = ACTIONS(822),
    [anon_sym_SEMI] = ACTIONS(822),
    [anon_sym_LBRACE] = ACTIONS(822),
    [anon_sym_return] = ACTIONS(822),
    [anon_sym_continue] = ACTIONS(822),
    [anon_sym_break] = ACTIONS(822),
    [anon_sym_elseif] = ACTIONS(822),
    [anon_sym_else] = ACTIONS(822),
    [anon_sym_if] = ACTIONS(822),
    [anon_sym_end] = ACTIONS(822),
    [anon_sym_for] = ACTIONS(822),
    [anon_sym_parfor] = ACTIONS(822),
    [anon_sym_while] = ACTIONS(822),
    [anon_sym_switch] = ACTIONS(822),
    [anon_sym_global] = ACTIONS(822),
    [anon_sym_persistent] = ACTIONS(822),
    [anon_sym_arguments] = ACTIONS(822),
    [anon_sym_function] = ACTIONS(822),
    [anon_sym_properties] = ACTIONS(822),
    [anon_sym_get] = ACTIONS(822),
    [anon_sym_set] = ACTIONS(822),
    [anon_sym_methods] = ACTIONS(822),
    [anon_sym_events] = ACTIONS(822),
    [anon_sym_enumeration] = ACTIONS(822),
    [anon_sym_classdef] = ACTIONS(822),
    [anon_sym_try] = ACTIONS(822),
    [anon_sym_spmd] = ACTIONS(822),
    [aux_sym_number_token1] = ACTIONS(822),
    [aux_sym_number_token2] = ACTIONS(822),
    [aux_sym_number_token3] = ACTIONS(822),
    [anon_sym_CR] = ACTIONS(822),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(824),
    [sym__single_quote_string_start] = ACTIONS(824),
    [sym__double_quote_string_start] = ACTIONS(824),
    [sym__multioutput_variable_start] = ACTIONS(824),
    [sym__external_identifier] = ACTIONS(824),
  },
  [STATE(200)] = {
    [anon_sym_LPAREN] = ACTIONS(810),
    [anon_sym_PLUS] = ACTIONS(810),
    [anon_sym_DOT_PLUS] = ACTIONS(810),
    [anon_sym_DASH] = ACTIONS(810),
    [anon_sym_DOT_DASH] = ACTIONS(810),
    [anon_sym_STAR] = ACTIONS(810),
    [anon_sym_DOT_STAR] = ACTIONS(810),
    [anon_sym_SLASH] = ACTIONS(810),
    [anon_sym_DOT_SLASH] = ACTIONS(810),
    [anon_sym_BSLASH] = ACTIONS(810),
    [anon_sym_DOT_BSLASH] = ACTIONS(810),
    [anon_sym_CARET] = ACTIONS(810),
    [anon_sym_DOT_CARET] = ACTIONS(810),
    [anon_sym_PIPE] = ACTIONS(810),
    [anon_sym_AMP] = ACTIONS(810),
    [anon_sym_TILDE] = ACTIONS(810),
    [anon_sym_QMARK] = ACTIONS(810),
    [anon_sym_AT] = ACTIONS(810),
    [anon_sym_LT] = ACTIONS(117),
    [anon_sym_LT_EQ] = ACTIONS(117),
    [anon_sym_EQ_EQ] = ACTIONS(117),
    [anon_sym_TILDE_EQ] = ACTIONS(117),
    [anon_sym_GT_EQ] = ACTIONS(117),
    [anon_sym_GT] = ACTIONS(117),
    [anon_sym_AMP_AMP] = ACTIONS(810),
    [anon_sym_PIPE_PIPE] = ACTIONS(810),
    [anon_sym_COMMA] = ACTIONS(810),
    [anon_sym_LBRACK] = ACTIONS(810),
    [anon_sym_LF] = ACTIONS(810),
    [anon_sym_SEMI] = ACTIONS(810),
    [anon_sym_LBRACE] = ACTIONS(810),
    [anon_sym_return] = ACTIONS(810),
    [anon_sym_continue] = ACTIONS(810),
    [anon_sym_break] = ACTIONS(810),
    [anon_sym_elseif] = ACTIONS(810),
    [anon_sym_else] = ACTIONS(810),
    [anon_sym_if] = ACTIONS(810),
    [anon_sym_end] = ACTIONS(810),
    [anon_sym_for] = ACTIONS(810),
    [anon_sym_parfor] = ACTIONS(810),
    [anon_sym_while] = ACTIONS(810),
    [anon_sym_switch] = ACTIONS(810),
    [anon_sym_global] = ACTIONS(810),
    [anon_sym_persistent] = ACTIONS(810),
    [anon_sym_arguments] = ACTIONS(810),
    [anon_sym_function] = ACTIONS(810),
    [anon_sym_properties] = ACTIONS(810),
    [anon_sym_get] = ACTIONS(810),
    [anon_sym_set] = ACTIONS(810),
    [anon_sym_methods] = ACTIONS(810),
    [anon_sym_events] = ACTIONS(810),
    [anon_sym_enumeration] = ACTIONS(810),
    [anon_sym_classdef] = ACTIONS(810),
    [anon_sym_try] = ACTIONS(810),
    [anon_sym_spmd] = ACTIONS(810),
    [aux_sym_number_token1] = ACTIONS(810),
    [aux_sym_number_token2] = ACTIONS(810),
    [aux_sym_number_token3] = ACTIONS(810),
    [anon_sym_CR] = ACTIONS(810),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(812),
    [sym__single_quote_string_start] = ACTIONS(812),
    [sym__double_quote_string_start] = ACTIONS(812),
    [sym__multioutput_variable_start] = ACTIONS(812),
    [sym__external_identifier] = ACTIONS(812),
  },
  [STATE(201)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1760),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_RPAREN] = ACTIONS(892),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(202)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1744),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_RBRACE] = ACTIONS(908),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(203)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1738),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_RPAREN] = ACTIONS(908),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(204)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1777),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(205)] = {
    [anon_sym_LPAREN] = ACTIONS(816),
    [anon_sym_PLUS] = ACTIONS(816),
    [anon_sym_DOT_PLUS] = ACTIONS(816),
    [anon_sym_DASH] = ACTIONS(816),
    [anon_sym_DOT_DASH] = ACTIONS(816),
    [anon_sym_STAR] = ACTIONS(816),
    [anon_sym_DOT_STAR] = ACTIONS(816),
    [anon_sym_SLASH] = ACTIONS(816),
    [anon_sym_DOT_SLASH] = ACTIONS(816),
    [anon_sym_BSLASH] = ACTIONS(816),
    [anon_sym_DOT_BSLASH] = ACTIONS(816),
    [anon_sym_CARET] = ACTIONS(816),
    [anon_sym_DOT_CARET] = ACTIONS(816),
    [anon_sym_PIPE] = ACTIONS(816),
    [anon_sym_AMP] = ACTIONS(816),
    [anon_sym_TILDE] = ACTIONS(816),
    [anon_sym_QMARK] = ACTIONS(816),
    [anon_sym_AT] = ACTIONS(816),
    [anon_sym_LT] = ACTIONS(117),
    [anon_sym_LT_EQ] = ACTIONS(117),
    [anon_sym_EQ_EQ] = ACTIONS(117),
    [anon_sym_TILDE_EQ] = ACTIONS(117),
    [anon_sym_GT_EQ] = ACTIONS(117),
    [anon_sym_GT] = ACTIONS(117),
    [anon_sym_AMP_AMP] = ACTIONS(119),
    [anon_sym_PIPE_PIPE] = ACTIONS(121),
    [anon_sym_COMMA] = ACTIONS(816),
    [anon_sym_LBRACK] = ACTIONS(816),
    [anon_sym_LF] = ACTIONS(816),
    [anon_sym_SEMI] = ACTIONS(816),
    [anon_sym_LBRACE] = ACTIONS(816),
    [anon_sym_return] = ACTIONS(816),
    [anon_sym_continue] = ACTIONS(816),
    [anon_sym_break] = ACTIONS(816),
    [anon_sym_elseif] = ACTIONS(816),
    [anon_sym_else] = ACTIONS(816),
    [anon_sym_if] = ACTIONS(816),
    [anon_sym_end] = ACTIONS(816),
    [anon_sym_for] = ACTIONS(816),
    [anon_sym_parfor] = ACTIONS(816),
    [anon_sym_while] = ACTIONS(816),
    [anon_sym_switch] = ACTIONS(816),
    [anon_sym_global] = ACTIONS(816),
    [anon_sym_persistent] = ACTIONS(816),
    [anon_sym_arguments] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(816),
    [anon_sym_properties] = ACTIONS(816),
    [anon_sym_get] = ACTIONS(816),
    [anon_sym_set] = ACTIONS(816),
    [anon_sym_methods] = ACTIONS(816),
    [anon_sym_events] = ACTIONS(816),
    [anon_sym_enumeration] = ACTIONS(816),
    [anon_sym_classdef] = ACTIONS(816),
    [anon_sym_try] = ACTIONS(816),
    [anon_sym_spmd] = ACTIONS(816),
    [aux_sym_number_token1] = ACTIONS(816),
    [aux_sym_number_token2] = ACTIONS(816),
    [aux_sym_number_token3] = ACTIONS(816),
    [anon_sym_CR] = ACTIONS(816),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(820),
    [sym__single_quote_string_start] = ACTIONS(820),
    [sym__double_quote_string_start] = ACTIONS(820),
    [sym__multioutput_variable_start] = ACTIONS(820),
    [sym__external_identifier] = ACTIONS(820),
  },
  [STATE(206)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1758),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(207)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1710),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_RPAREN] = ACTIONS(912),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(208)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1711),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_RBRACE] = ACTIONS(912),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
  [STATE(209)] = {
    [sym_identifier] = STATE(453),
    [sym__expression] = STATE(1050),
    [sym_parenthesis] = STATE(804),
    [sym__binary_expression] = STATE(980),
    [sym_binary_operator] = STATE(749),
    [sym_unary_operator] = STATE(805),
    [sym_indirect_access] = STATE(1535),
    [sym_field_expression] = STATE(794),
    [sym_not_operator] = STATE(839),
    [sym_metaclass_operator] = STATE(1050),
    [sym_handle_operator] = STATE(1050),
    [sym_comparison_operator] = STATE(704),
    [sym_boolean_operator] = STATE(704),
    [sym_postfix_operator] = STATE(804),
    [sym_string] = STATE(794),
    [sym_matrix] = STATE(804),
    [sym_cell] = STATE(795),
    [sym_spread_operator] = STATE(1428),
    [sym__index_boolean_operator] = STATE(796),
    [sym__index_comparison_operator] = STATE(798),
    [sym__index_not_operator] = STATE(799),
    [sym__index_unary_operator] = STATE(801),
    [sym__index_postfix_operator] = STATE(802),
    [sym__index_matrix] = STATE(743),
    [sym__index_range_element] = STATE(1713),
    [sym__index_range] = STATE(707),
    [sym__index_parenthesis] = STATE(743),
    [sym__index_expression] = STATE(1059),
    [sym__index_binary_expression] = STATE(971),
    [sym__index_binary_operator] = STATE(791),
    [sym__index_argument] = STATE(1428),
    [sym__index_arguments] = STATE(1624),
    [sym_arguments] = STATE(1727),
    [sym_function_call] = STATE(487),
    [sym__range_element] = STATE(1762),
    [sym_range] = STATE(1050),
    [sym_lambda] = STATE(1050),
    [sym_number] = STATE(794),
    [sym_end_keyword] = STATE(556),
    [sym__keywords] = STATE(503),
    [anon_sym_LPAREN] = ACTIONS(878),
    [anon_sym_RPAREN] = ACTIONS(906),
    [anon_sym_PLUS] = ACTIONS(880),
    [anon_sym_DASH] = ACTIONS(880),
    [anon_sym_TILDE] = ACTIONS(882),
    [anon_sym_QMARK] = ACTIONS(884),
    [anon_sym_AT] = ACTIONS(886),
    [anon_sym_LBRACK] = ACTIONS(888),
    [anon_sym_LBRACE] = ACTIONS(890),
    [anon_sym_COLON] = ACTIONS(894),
    [anon_sym_end] = ACTIONS(29),
    [anon_sym_arguments] = ACTIONS(896),
    [anon_sym_properties] = ACTIONS(896),
    [anon_sym_get] = ACTIONS(896),
    [anon_sym_set] = ACTIONS(896),
    [anon_sym_methods] = ACTIONS(896),
    [anon_sym_events] = ACTIONS(896),
    [anon_sym_enumeration] = ACTIONS(896),
    [aux_sym_number_token1] = ACTIONS(898),
    [aux_sym_number_token2] = ACTIONS(900),
    [aux_sym_number_token3] = ACTIONS(900),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__single_quote_string_start] = ACTIONS(902),
    [sym__double_quote_string_start] = ACTIONS(904),
    [sym__external_identifier] = ACTIONS(896),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 42,
    ACTIONS(828), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_LBRACK,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(914), 1,
      anon_sym_TILDE,
    ACTIONS(916), 1,
      anon_sym_QMARK,
    ACTIONS(918), 1,
      anon_sym_AT,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_not_operator,
    STATE(614), 1,
      sym_binary_operator,
    STATE(659), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(673), 1,
      sym__index_expression,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(920), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(922), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    STATE(444), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(647), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(585), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(645), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(641), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [149] = 43,
    ACTIONS(828), 1,
      anon_sym_LPAREN,
    ACTIONS(832), 1,
      anon_sym_TILDE,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(840), 1,
      anon_sym_LBRACK,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(927), 1,
      aux_sym_matrix_token1,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(659), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(713), 1,
      sym_not_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1028), 1,
      sym__index_expression,
    STATE(1537), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(924), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(444), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(647), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(636), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(645), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(1002), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [300] = 43,
    ACTIONS(828), 1,
      anon_sym_LPAREN,
    ACTIONS(832), 1,
      anon_sym_TILDE,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(840), 1,
      anon_sym_LBRACK,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(933), 1,
      aux_sym_matrix_token1,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(659), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(713), 1,
      sym_not_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1028), 1,
      sym__index_expression,
    STATE(1537), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(830), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(930), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(444), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(647), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(636), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(645), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(1002), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [451] = 41,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(878), 1,
      anon_sym_LPAREN,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(888), 1,
      anon_sym_LBRACK,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(894), 1,
      anon_sym_COLON,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(749), 1,
      sym_binary_operator,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(795), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1059), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(880), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(487), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(743), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(1610), 2,
      sym_spread_operator,
      sym__index_argument,
    STATE(794), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(804), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(1050), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [597] = 40,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(936), 1,
      anon_sym_LPAREN,
    ACTIONS(940), 1,
      anon_sym_TILDE,
    ACTIONS(942), 1,
      anon_sym_QMARK,
    ACTIONS(944), 1,
      anon_sym_AT,
    ACTIONS(946), 1,
      anon_sym_LBRACK,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(659), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(713), 1,
      sym_not_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1009), 1,
      sym__index_expression,
    STATE(1344), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(938), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(444), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(647), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(636), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(645), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(998), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [739] = 39,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(878), 1,
      anon_sym_LPAREN,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(888), 1,
      anon_sym_LBRACK,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(706), 1,
      sym_unary_operator,
    STATE(707), 1,
      sym__index_range,
    STATE(708), 1,
      sym_not_operator,
    STATE(735), 1,
      sym_cell,
    STATE(739), 1,
      sym__index_not_operator,
    STATE(741), 1,
      sym__index_unary_operator,
    STATE(742), 1,
      sym__index_postfix_operator,
    STATE(749), 1,
      sym_binary_operator,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(880), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(468), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(754), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(730), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(792), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [878] = 39,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(878), 1,
      anon_sym_LPAREN,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(956), 1,
      anon_sym_TILDE,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(960), 1,
      anon_sym_AT,
    ACTIONS(962), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(729), 1,
      sym_unary_operator,
    STATE(757), 1,
      sym_not_operator,
    STATE(759), 1,
      sym__index_expression,
    STATE(778), 1,
      sym_binary_operator,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(828), 1,
      sym_cell,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(954), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(542), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(743), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(727), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(819), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(714), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1017] = 39,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(936), 1,
      anon_sym_LPAREN,
    ACTIONS(946), 1,
      anon_sym_LBRACK,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(964), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(613), 1,
      sym_not_operator,
    STATE(620), 1,
      sym_unary_operator,
    STATE(661), 1,
      sym_cell,
    STATE(662), 1,
      sym__index_not_operator,
    STATE(663), 1,
      sym__index_unary_operator,
    STATE(664), 1,
      sym__index_postfix_operator,
    STATE(707), 1,
      sym__index_range,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(813), 1,
      sym_end_keyword,
    STATE(846), 1,
      sym_binary_operator,
    STATE(850), 1,
      sym__index_binary_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(938), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(449), 2,
      sym_identifier,
      sym_function_call,
    STATE(666), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(615), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(660), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1156] = 39,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(878), 1,
      anon_sym_LPAREN,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(888), 1,
      anon_sym_LBRACK,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(956), 1,
      anon_sym_TILDE,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(828), 1,
      sym_cell,
    STATE(830), 1,
      sym_binary_operator,
    STATE(831), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1130), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(880), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(522), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(743), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(834), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(841), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1295] = 39,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(878), 1,
      anon_sym_LPAREN,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(888), 1,
      anon_sym_LBRACK,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(956), 1,
      anon_sym_TILDE,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(828), 1,
      sym_cell,
    STATE(830), 1,
      sym_binary_operator,
    STATE(831), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1145), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(880), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(522), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(743), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(834), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(841), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1434] = 39,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(878), 1,
      anon_sym_LPAREN,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(888), 1,
      anon_sym_LBRACK,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(960), 1,
      anon_sym_AT,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(729), 1,
      sym_unary_operator,
    STATE(757), 1,
      sym_not_operator,
    STATE(759), 1,
      sym__index_expression,
    STATE(778), 1,
      sym_binary_operator,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(795), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(880), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(489), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(743), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(727), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(794), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(714), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1573] = 39,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(936), 1,
      anon_sym_LPAREN,
    ACTIONS(946), 1,
      anon_sym_LBRACK,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(964), 1,
      anon_sym_TILDE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_not_operator,
    STATE(614), 1,
      sym_binary_operator,
    STATE(659), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(673), 1,
      sym__index_expression,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(938), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(444), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(647), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(585), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(645), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(641), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1712] = 39,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(878), 1,
      anon_sym_LPAREN,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(888), 1,
      anon_sym_LBRACK,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(795), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(817), 1,
      sym_binary_operator,
    STATE(818), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1145), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(880), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(565), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(743), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(808), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(815), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(1128), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1851] = 39,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(878), 1,
      anon_sym_LPAREN,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(956), 1,
      anon_sym_TILDE,
    ACTIONS(962), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(706), 1,
      sym_unary_operator,
    STATE(707), 1,
      sym__index_range,
    STATE(708), 1,
      sym_not_operator,
    STATE(735), 1,
      sym_cell,
    STATE(739), 1,
      sym__index_not_operator,
    STATE(741), 1,
      sym__index_unary_operator,
    STATE(742), 1,
      sym__index_postfix_operator,
    STATE(749), 1,
      sym_binary_operator,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(954), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(468), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(754), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(730), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(792), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [1990] = 39,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(878), 1,
      anon_sym_LPAREN,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(888), 1,
      anon_sym_LBRACK,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(795), 1,
      sym_cell,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(817), 1,
      sym_binary_operator,
    STATE(818), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1130), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(880), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(565), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(743), 2,
      sym__index_matrix,
      sym__index_parenthesis,
    STATE(808), 3,
      sym_field_expression,
      sym_string,
      sym_number,
    STATE(815), 3,
      sym_parenthesis,
      sym_postfix_operator,
      sym_matrix,
    STATE(1134), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2129] = 5,
    ACTIONS(970), 1,
      anon_sym_DOT,
    STATE(229), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(655), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(653), 47,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_CR,
  [2196] = 5,
    ACTIONS(970), 1,
      anon_sym_DOT,
    STATE(229), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(635), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(631), 47,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_CR,
  [2263] = 5,
    ACTIONS(970), 1,
      anon_sym_DOT,
    STATE(226), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(639), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(637), 47,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_CR,
  [2330] = 5,
    ACTIONS(970), 1,
      anon_sym_DOT,
    STATE(225), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(659), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(657), 47,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_CR,
  [2397] = 5,
    ACTIONS(972), 1,
      anon_sym_DOT,
    STATE(229), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(629), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(624), 47,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_CR,
  [2464] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(697), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(695), 48,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_CR,
  [2526] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(629), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(624), 48,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_CR,
  [2588] = 33,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(987), 1,
      aux_sym_matrix_token1,
    ACTIONS(989), 1,
      anon_sym_end,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1555), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(985), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2710] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(991), 1,
      anon_sym_RBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1567), 1,
      sym_row,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2833] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(993), 1,
      anon_sym_RBRACE,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1500), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [2956] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(995), 1,
      anon_sym_RBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1486), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3079] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(997), 1,
      anon_sym_RBRACE,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1488), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3202] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(999), 1,
      anon_sym_RBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1489), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3325] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1001), 1,
      anon_sym_LF,
    ACTIONS(1003), 1,
      anon_sym_RBRACE,
    STATE(234), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1554), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3448] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1005), 1,
      anon_sym_LF,
    ACTIONS(1007), 1,
      anon_sym_RBRACK,
    STATE(241), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1541), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3571] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1009), 1,
      anon_sym_LF,
    ACTIONS(1011), 1,
      anon_sym_RBRACE,
    STATE(242), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1543), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3694] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1013), 1,
      anon_sym_RBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1546), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3817] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1015), 1,
      anon_sym_RBRACE,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1548), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [3940] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1017), 1,
      anon_sym_LF,
    ACTIONS(1019), 1,
      anon_sym_RBRACK,
    STATE(233), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1562), 1,
      sym_row,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4063] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1021), 1,
      anon_sym_LF,
    ACTIONS(1023), 1,
      anon_sym_RBRACK,
    STATE(237), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1575), 1,
      sym_row,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4186] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1025), 1,
      anon_sym_LF,
    ACTIONS(1027), 1,
      anon_sym_RBRACE,
    STATE(246), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1563), 1,
      sym_row,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4309] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1029), 1,
      anon_sym_RBRACE,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1569), 1,
      sym_row,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4432] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1031), 1,
      anon_sym_LF,
    ACTIONS(1033), 1,
      anon_sym_RBRACK,
    STATE(235), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1479), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4555] = 34,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(981), 1,
      anon_sym_COMMA,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1035), 1,
      anon_sym_LF,
    ACTIONS(1037), 1,
      anon_sym_RBRACE,
    STATE(236), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1281), 1,
      sym_ignored_argument,
    STATE(1480), 1,
      sym_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(976), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4678] = 30,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(916), 1,
      anon_sym_QMARK,
    ACTIONS(918), 1,
      anon_sym_AT,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1039), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_not_operator,
    STATE(614), 1,
      sym_binary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(922), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(438), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(920), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(641), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(585), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4792] = 31,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1043), 1,
      aux_sym_matrix_token1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1359), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(1041), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(1002), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [4908] = 31,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1047), 1,
      aux_sym_matrix_token1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1359), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(1045), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(1002), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5024] = 31,
    ACTIONS(834), 1,
      anon_sym_QMARK,
    ACTIONS(836), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(975), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_TILDE,
    ACTIONS(983), 1,
      anon_sym_LBRACK,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1051), 1,
      aux_sym_matrix_token1,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1359), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(977), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(1049), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(1002), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5140] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(253), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1057), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1053), 6,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
    ACTIONS(1055), 38,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [5203] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(253), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(139), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1060), 6,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
    ACTIONS(1062), 38,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [5266] = 6,
    ACTIONS(119), 1,
      anon_sym_AMP_AMP,
    ACTIONS(121), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1066), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(117), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(1064), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
      anon_sym_CR,
  [5331] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(253), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(139), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(211), 6,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
    ACTIONS(243), 38,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [5394] = 35,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1072), 1,
      anon_sym_TILDE,
    ACTIONS(1074), 1,
      anon_sym_COMMA,
    ACTIONS(1076), 1,
      anon_sym_LBRACK,
    ACTIONS(1078), 1,
      anon_sym_RBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1005), 1,
      sym__index_expression,
    STATE(1354), 1,
      sym_ignored_argument,
    STATE(1502), 1,
      sym__index_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1070), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5514] = 34,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1072), 1,
      anon_sym_TILDE,
    ACTIONS(1074), 1,
      anon_sym_COMMA,
    ACTIONS(1076), 1,
      anon_sym_LBRACK,
    ACTIONS(1082), 1,
      aux_sym_matrix_token1,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1005), 1,
      sym__index_expression,
    STATE(1354), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1604), 1,
      sym__index_row,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1070), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1080), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5632] = 35,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1072), 1,
      anon_sym_TILDE,
    ACTIONS(1074), 1,
      anon_sym_COMMA,
    ACTIONS(1076), 1,
      anon_sym_LBRACK,
    ACTIONS(1084), 1,
      anon_sym_LF,
    ACTIONS(1086), 1,
      anon_sym_RBRACK,
    STATE(257), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1005), 1,
      sym__index_expression,
    STATE(1354), 1,
      sym_ignored_argument,
    STATE(1498), 1,
      sym__index_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1070), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5752] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1090), 1,
      anon_sym_RPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(817), 1,
      sym_binary_operator,
    STATE(818), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(499), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1099), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(815), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5858] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(942), 1,
      anon_sym_QMARK,
    ACTIONS(944), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1102), 1,
      anon_sym_TILDE,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1323), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(998), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [5964] = 35,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1072), 1,
      anon_sym_TILDE,
    ACTIONS(1074), 1,
      anon_sym_COMMA,
    ACTIONS(1076), 1,
      anon_sym_LBRACK,
    ACTIONS(1106), 1,
      anon_sym_LF,
    ACTIONS(1108), 1,
      anon_sym_RBRACK,
    STATE(263), 1,
      aux_sym_matrix_repeat1,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1005), 1,
      sym__index_expression,
    STATE(1354), 1,
      sym_ignored_argument,
    STATE(1407), 1,
      sym__index_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1070), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6084] = 35,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(862), 1,
      anon_sym_LF,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1072), 1,
      anon_sym_TILDE,
    ACTIONS(1074), 1,
      anon_sym_COMMA,
    ACTIONS(1076), 1,
      anon_sym_LBRACK,
    ACTIONS(1110), 1,
      anon_sym_RBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1005), 1,
      sym__index_expression,
    STATE(1354), 1,
      sym_ignored_argument,
    STATE(1426), 1,
      sym__index_row,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1070), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6204] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(942), 1,
      anon_sym_QMARK,
    ACTIONS(944), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1102), 1,
      anon_sym_TILDE,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1359), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1002), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6310] = 28,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(922), 1,
      anon_sym_EQ,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(530), 1,
      sym_cell,
    STATE(568), 1,
      sym_unary_operator,
    STATE(578), 1,
      sym_binary_operator,
    STATE(579), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(577), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(560), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6416] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(960), 1,
      anon_sym_AT,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(729), 1,
      sym_unary_operator,
    STATE(757), 1,
      sym_not_operator,
    STATE(778), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(481), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(773), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(727), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6519] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1126), 1,
      anon_sym_AT,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(199), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6622] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1023), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6725] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1013), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6828] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1033), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [6931] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(657), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7034] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1032), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7137] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1142), 1,
      anon_sym_QMARK,
    ACTIONS(1144), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(5), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7240] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1091), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7343] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(706), 1,
      sym_unary_operator,
    STATE(708), 1,
      sym_not_operator,
    STATE(709), 1,
      sym_cell,
    STATE(749), 1,
      sym_binary_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(463), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(792), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7446] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(872), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7549] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(530), 1,
      sym_cell,
    STATE(568), 1,
      sym_unary_operator,
    STATE(578), 1,
      sym_binary_operator,
    STATE(579), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(577), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(560), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7652] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(571), 1,
      sym_unary_operator,
    STATE(573), 1,
      sym_not_operator,
    STATE(574), 1,
      sym_cell,
    STATE(847), 1,
      sym_binary_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(422), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(570), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7755] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(817), 1,
      sym_binary_operator,
    STATE(818), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(499), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1132), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(815), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [7858] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(320), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1146), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(211), 6,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
    ACTIONS(243), 34,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [7917] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    ACTIONS(1148), 1,
      anon_sym_AT,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(718), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8020] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    ACTIONS(1148), 1,
      anon_sym_AT,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(845), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8123] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    ACTIONS(1148), 1,
      anon_sym_AT,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(849), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8226] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(721), 1,
      sym_unary_operator,
    STATE(732), 1,
      sym_binary_operator,
    STATE(781), 1,
      sym_cell,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(485), 2,
      sym_identifier,
      sym_function_call,
    STATE(768), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1161), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(719), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8325] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(721), 1,
      sym_unary_operator,
    STATE(732), 1,
      sym_binary_operator,
    STATE(781), 1,
      sym_cell,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(485), 2,
      sym_identifier,
      sym_function_call,
    STATE(772), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1161), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(719), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8424] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(721), 1,
      sym_unary_operator,
    STATE(732), 1,
      sym_binary_operator,
    STATE(781), 1,
      sym_cell,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(485), 2,
      sym_identifier,
      sym_function_call,
    STATE(774), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1161), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(719), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8523] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(721), 1,
      sym_unary_operator,
    STATE(732), 1,
      sym_binary_operator,
    STATE(781), 1,
      sym_cell,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(485), 2,
      sym_identifier,
      sym_function_call,
    STATE(775), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1161), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(719), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8622] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(721), 1,
      sym_unary_operator,
    STATE(732), 1,
      sym_binary_operator,
    STATE(781), 1,
      sym_cell,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(485), 2,
      sym_identifier,
      sym_function_call,
    STATE(776), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1161), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(719), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8721] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(724), 1,
      sym_unary_operator,
    STATE(725), 1,
      sym_not_operator,
    STATE(737), 1,
      sym_binary_operator,
    STATE(777), 1,
      sym__range_element,
    STATE(783), 1,
      sym_cell,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(486), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(722), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8824] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(320), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1146), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1060), 6,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
    ACTIONS(1062), 34,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [8883] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(851), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [8986] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(852), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9089] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(724), 1,
      sym_unary_operator,
    STATE(725), 1,
      sym_not_operator,
    STATE(737), 1,
      sym_binary_operator,
    STATE(779), 1,
      sym__range_element,
    STATE(783), 1,
      sym_cell,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(486), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(722), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9192] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1142), 1,
      anon_sym_QMARK,
    ACTIONS(1144), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(3), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9295] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    ACTIONS(1152), 1,
      anon_sym_AT,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(590), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9398] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    ACTIONS(1152), 1,
      anon_sym_AT,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(816), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9501] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    ACTIONS(1152), 1,
      anon_sym_AT,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(814), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9604] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(611), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(625), 1,
      sym_binary_operator,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(436), 2,
      sym_identifier,
      sym_function_call,
    STATE(591), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1160), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(619), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9703] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(611), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(625), 1,
      sym_binary_operator,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(436), 2,
      sym_identifier,
      sym_function_call,
    STATE(592), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1160), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(619), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9802] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(611), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(625), 1,
      sym_binary_operator,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(436), 2,
      sym_identifier,
      sym_function_call,
    STATE(593), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1160), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(619), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [9901] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(611), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(625), 1,
      sym_binary_operator,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(436), 2,
      sym_identifier,
      sym_function_call,
    STATE(594), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1160), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(619), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10000] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(611), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(625), 1,
      sym_binary_operator,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(436), 2,
      sym_identifier,
      sym_function_call,
    STATE(595), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1160), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(619), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10099] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(597), 1,
      sym__range_element,
    STATE(623), 1,
      sym_unary_operator,
    STATE(624), 1,
      sym_not_operator,
    STATE(626), 1,
      sym_binary_operator,
    STATE(857), 1,
      sym_cell,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(437), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(622), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10202] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(530), 1,
      sym_cell,
    STATE(568), 1,
      sym_unary_operator,
    STATE(578), 1,
      sym_binary_operator,
    STATE(579), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(566), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(560), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10305] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(530), 1,
      sym_cell,
    STATE(568), 1,
      sym_unary_operator,
    STATE(578), 1,
      sym_binary_operator,
    STATE(579), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(567), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(560), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10408] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(610), 1,
      sym__range_element,
    STATE(623), 1,
      sym_unary_operator,
    STATE(624), 1,
      sym_not_operator,
    STATE(626), 1,
      sym_binary_operator,
    STATE(857), 1,
      sym_cell,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(437), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(622), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10511] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1098), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10614] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1129), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10717] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1126), 1,
      anon_sym_AT,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(160), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10820] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1126), 1,
      anon_sym_AT,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(200), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [10923] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1126), 1,
      anon_sym_AT,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(197), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11026] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(175), 1,
      sym_cell,
    STATE(178), 1,
      sym_unary_operator,
    STATE(182), 1,
      sym_binary_operator,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(112), 2,
      sym_identifier,
      sym_function_call,
    STATE(161), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1152), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(177), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11125] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(175), 1,
      sym_cell,
    STATE(178), 1,
      sym_unary_operator,
    STATE(182), 1,
      sym_binary_operator,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(112), 2,
      sym_identifier,
      sym_function_call,
    STATE(162), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1152), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(177), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11224] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(175), 1,
      sym_cell,
    STATE(178), 1,
      sym_unary_operator,
    STATE(182), 1,
      sym_binary_operator,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(112), 2,
      sym_identifier,
      sym_function_call,
    STATE(163), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1152), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(177), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11323] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(175), 1,
      sym_cell,
    STATE(178), 1,
      sym_unary_operator,
    STATE(182), 1,
      sym_binary_operator,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(112), 2,
      sym_identifier,
      sym_function_call,
    STATE(187), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1152), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(177), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11422] = 25,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(175), 1,
      sym_cell,
    STATE(178), 1,
      sym_unary_operator,
    STATE(182), 1,
      sym_binary_operator,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(112), 2,
      sym_identifier,
      sym_function_call,
    STATE(164), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1152), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(177), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11521] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(140), 1,
      sym_binary_operator,
    STATE(165), 1,
      sym__range_element,
    STATE(180), 1,
      sym_unary_operator,
    STATE(181), 1,
      sym_not_operator,
    STATE(858), 1,
      sym_cell,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(113), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(179), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11624] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1016), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11727] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(942), 1,
      anon_sym_QMARK,
    ACTIONS(944), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(809), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11830] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(320), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1154), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1053), 6,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
    ACTIONS(1055), 34,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [11889] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1020), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [11992] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(942), 1,
      anon_sym_QMARK,
    ACTIONS(944), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(811), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12095] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(140), 1,
      sym_binary_operator,
    STATE(170), 1,
      sym__range_element,
    STATE(180), 1,
      sym_unary_operator,
    STATE(181), 1,
      sym_not_operator,
    STATE(858), 1,
      sym_cell,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(113), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(179), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12198] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(548), 1,
      sym_not_operator,
    STATE(553), 1,
      sym_binary_operator,
    STATE(561), 1,
      sym__range_element,
    STATE(580), 1,
      sym_unary_operator,
    STATE(853), 1,
      sym_cell,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(416), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(547), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12301] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1142), 1,
      anon_sym_QMARK,
    ACTIONS(1144), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(205), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12404] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1157), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(557), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12507] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1157), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(670), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12610] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1157), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(658), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12713] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(517), 1,
      sym_cell,
    STATE(544), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_binary_operator,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(505), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1156), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(543), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12812] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(517), 1,
      sym_cell,
    STATE(544), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_binary_operator,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(513), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1156), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(543), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [12911] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(517), 1,
      sym_cell,
    STATE(544), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_binary_operator,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(520), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1156), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(543), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13010] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(517), 1,
      sym_cell,
    STATE(544), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_binary_operator,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(529), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1156), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(543), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13109] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1142), 1,
      anon_sym_QMARK,
    ACTIONS(1144), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(199), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13212] = 25,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(517), 1,
      sym_cell,
    STATE(544), 1,
      sym_unary_operator,
    STATE(551), 1,
      sym_binary_operator,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(418), 2,
      sym_identifier,
      sym_function_call,
    STATE(538), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1156), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(543), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13311] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(548), 1,
      sym_not_operator,
    STATE(549), 1,
      sym__range_element,
    STATE(553), 1,
      sym_binary_operator,
    STATE(580), 1,
      sym_unary_operator,
    STATE(853), 1,
      sym_cell,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(416), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(547), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13414] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13517] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(830), 1,
      sym_binary_operator,
    STATE(831), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(558), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(841), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13620] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1142), 1,
      anon_sym_QMARK,
    ACTIONS(1144), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(4), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13723] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(960), 1,
      anon_sym_AT,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(729), 1,
      sym_unary_operator,
    STATE(757), 1,
      sym_not_operator,
    STATE(778), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(481), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(714), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(727), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13826] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1142), 1,
      anon_sym_QMARK,
    ACTIONS(1144), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(255), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [13929] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(839), 1,
      sym_not_operator,
    STATE(843), 1,
      sym_binary_operator,
    STATE(844), 1,
      sym_unary_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(528), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(842), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14032] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1159), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(145), 1,
      sym_cell,
    STATE(173), 1,
      sym_unary_operator,
    STATE(174), 1,
      sym_not_operator,
    STATE(176), 1,
      sym_binary_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(109), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(151), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(172), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14135] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(530), 1,
      sym_cell,
    STATE(568), 1,
      sym_unary_operator,
    STATE(578), 1,
      sym_binary_operator,
    STATE(579), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(557), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(560), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14238] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(530), 1,
      sym_cell,
    STATE(568), 1,
      sym_unary_operator,
    STATE(578), 1,
      sym_binary_operator,
    STATE(579), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(563), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(560), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14341] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1116), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(530), 1,
      sym_cell,
    STATE(568), 1,
      sym_unary_operator,
    STATE(578), 1,
      sym_binary_operator,
    STATE(579), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(415), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(564), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(560), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14444] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1103), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14547] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_QMARK,
    ACTIONS(15), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(981), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14650] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(588), 1,
      sym_cell,
    STATE(613), 1,
      sym_not_operator,
    STATE(620), 1,
      sym_unary_operator,
    STATE(846), 1,
      sym_binary_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(441), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(615), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14753] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(960), 1,
      anon_sym_AT,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(729), 1,
      sym_unary_operator,
    STATE(757), 1,
      sym_not_operator,
    STATE(778), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(481), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(718), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(727), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14856] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(960), 1,
      anon_sym_AT,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(729), 1,
      sym_unary_operator,
    STATE(757), 1,
      sym_not_operator,
    STATE(778), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(481), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(769), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(727), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [14959] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(960), 1,
      anon_sym_AT,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(729), 1,
      sym_unary_operator,
    STATE(757), 1,
      sym_not_operator,
    STATE(778), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(481), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(770), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(727), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15062] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(960), 1,
      anon_sym_AT,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(729), 1,
      sym_unary_operator,
    STATE(757), 1,
      sym_not_operator,
    STATE(778), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(481), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(771), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(727), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15165] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(817), 1,
      sym_binary_operator,
    STATE(818), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(499), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1138), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(815), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15268] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_not_operator,
    STATE(614), 1,
      sym_binary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(438), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(590), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(585), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15371] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_not_operator,
    STATE(614), 1,
      sym_binary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(438), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(631), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(585), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15474] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_not_operator,
    STATE(614), 1,
      sym_binary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(438), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(632), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(585), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15577] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1157), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15680] = 27,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(53), 1,
      aux_sym_number_token1,
    ACTIONS(59), 1,
      sym__single_quote_string_start,
    ACTIONS(61), 1,
      sym__double_quote_string_start,
    ACTIONS(1112), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_QMARK,
    ACTIONS(1157), 1,
      anon_sym_AT,
    STATE(412), 1,
      sym__keywords,
    STATE(514), 1,
      sym_binary_operator,
    STATE(515), 1,
      sym_unary_operator,
    STATE(530), 1,
      sym_cell,
    STATE(596), 1,
      sym_not_operator,
    STATE(993), 1,
      sym__binary_expression,
    STATE(1463), 1,
      sym_end_keyword,
    STATE(1516), 1,
      sym_indirect_access,
    STATE(1721), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(9), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(419), 2,
      sym_identifier,
      sym_function_call,
    STATE(526), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(657), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(510), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15783] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1159), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(145), 1,
      sym_cell,
    STATE(173), 1,
      sym_unary_operator,
    STATE(174), 1,
      sym_not_operator,
    STATE(176), 1,
      sym_binary_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(109), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(160), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(172), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15886] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1159), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(145), 1,
      sym_cell,
    STATE(173), 1,
      sym_unary_operator,
    STATE(174), 1,
      sym_not_operator,
    STATE(176), 1,
      sym_binary_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(109), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(183), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(172), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [15989] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1159), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(145), 1,
      sym_cell,
    STATE(173), 1,
      sym_unary_operator,
    STATE(174), 1,
      sym_not_operator,
    STATE(176), 1,
      sym_binary_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(109), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(184), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(172), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16092] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_not_operator,
    STATE(614), 1,
      sym_binary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(438), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(585), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16195] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_not_operator,
    STATE(614), 1,
      sym_binary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(438), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(585), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16298] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1159), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(145), 1,
      sym_cell,
    STATE(173), 1,
      sym_unary_operator,
    STATE(174), 1,
      sym_not_operator,
    STATE(176), 1,
      sym_binary_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(109), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(185), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(172), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16401] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    ACTIONS(1159), 1,
      anon_sym_AT,
    STATE(135), 1,
      sym__keywords,
    STATE(145), 1,
      sym_cell,
    STATE(173), 1,
      sym_unary_operator,
    STATE(174), 1,
      sym_not_operator,
    STATE(176), 1,
      sym_binary_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(109), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(186), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(172), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16504] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(829), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(840), 1,
      sym_binary_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(519), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(837), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16607] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(601), 1,
      sym_unary_operator,
    STATE(607), 1,
      sym_not_operator,
    STATE(614), 1,
      sym_binary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(438), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(641), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(585), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16710] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(148), 1,
      sym_unary_operator,
    STATE(149), 1,
      sym_not_operator,
    STATE(150), 1,
      sym_cell,
    STATE(848), 1,
      sym_binary_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(110), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(147), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16813] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(822), 1,
      sym_binary_operator,
    STATE(836), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(518), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(835), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [16916] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(824), 1,
      sym_binary_operator,
    STATE(827), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(504), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(820), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17019] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(817), 1,
      sym_binary_operator,
    STATE(818), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(499), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1128), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(815), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17122] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    ACTIONS(1148), 1,
      anon_sym_AT,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(851), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17225] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(958), 1,
      anon_sym_QMARK,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    ACTIONS(1148), 1,
      anon_sym_AT,
    STATE(503), 1,
      sym__keywords,
    STATE(749), 1,
      sym_binary_operator,
    STATE(783), 1,
      sym_cell,
    STATE(805), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(484), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(852), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(804), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17328] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    ACTIONS(1152), 1,
      anon_sym_AT,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(809), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17431] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(1098), 1,
      anon_sym_LPAREN,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1150), 1,
      anon_sym_TILDE,
    ACTIONS(1152), 1,
      anon_sym_AT,
    STATE(480), 1,
      sym__keywords,
    STATE(612), 1,
      sym_binary_operator,
    STATE(637), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_cell,
    STATE(713), 1,
      sym_not_operator,
    STATE(982), 1,
      sym__binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1558), 1,
      sym_end_keyword,
    STATE(1759), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1100), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(440), 2,
      sym_identifier,
      sym_function_call,
    STATE(638), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(811), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(636), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17534] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1118), 1,
      anon_sym_LPAREN,
    ACTIONS(1122), 1,
      anon_sym_TILDE,
    ACTIONS(1124), 1,
      anon_sym_QMARK,
    ACTIONS(1126), 1,
      anon_sym_AT,
    ACTIONS(1128), 1,
      anon_sym_LBRACK,
    ACTIONS(1130), 1,
      anon_sym_LBRACE,
    ACTIONS(1134), 1,
      aux_sym_number_token1,
    ACTIONS(1138), 1,
      sym__single_quote_string_start,
    ACTIONS(1140), 1,
      sym__double_quote_string_start,
    STATE(135), 1,
      sym__keywords,
    STATE(143), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_cell,
    STATE(171), 1,
      sym_binary_operator,
    STATE(192), 1,
      sym_not_operator,
    STATE(986), 1,
      sym__binary_expression,
    STATE(1573), 1,
      sym_indirect_access,
    STATE(1574), 1,
      sym_end_keyword,
    STATE(1751), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1120), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1136), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(111), 2,
      sym_identifier,
      sym_function_call,
    STATE(144), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(205), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(142), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17637] = 27,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(884), 1,
      anon_sym_QMARK,
    ACTIONS(886), 1,
      anon_sym_AT,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1088), 1,
      anon_sym_LPAREN,
    ACTIONS(1094), 1,
      anon_sym_TILDE,
    ACTIONS(1096), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(783), 1,
      sym_cell,
    STATE(817), 1,
      sym_binary_operator,
    STATE(818), 1,
      sym_unary_operator,
    STATE(839), 1,
      sym_not_operator,
    STATE(980), 1,
      sym__binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1762), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1092), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(499), 2,
      sym_identifier,
      sym_function_call,
    STATE(704), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(1134), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(815), 6,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17740] = 32,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1072), 1,
      anon_sym_TILDE,
    ACTIONS(1076), 1,
      anon_sym_LBRACK,
    ACTIONS(1163), 1,
      aux_sym_matrix_token1,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1028), 1,
      sym__index_expression,
    STATE(1521), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1070), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1161), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17852] = 32,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1072), 1,
      anon_sym_TILDE,
    ACTIONS(1076), 1,
      anon_sym_LBRACK,
    ACTIONS(1167), 1,
      aux_sym_matrix_token1,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1028), 1,
      sym__index_expression,
    STATE(1521), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1070), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1165), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [17964] = 31,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1076), 1,
      anon_sym_LBRACK,
    ACTIONS(1169), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(673), 1,
      sym__index_expression,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(920), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(922), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1070), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18074] = 32,
    ACTIONS(846), 1,
      anon_sym_LBRACE,
    ACTIONS(848), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(860), 1,
      sym__external_identifier,
    ACTIONS(1068), 1,
      anon_sym_LPAREN,
    ACTIONS(1072), 1,
      anon_sym_TILDE,
    ACTIONS(1076), 1,
      anon_sym_LBRACK,
    ACTIONS(1173), 1,
      aux_sym_matrix_token1,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1028), 1,
      sym__index_expression,
    STATE(1521), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(854), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1070), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1171), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(850), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18186] = 29,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1179), 1,
      anon_sym_TILDE,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1009), 1,
      sym__index_expression,
    STATE(1376), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18289] = 29,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1179), 1,
      anon_sym_TILDE,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1028), 1,
      sym__index_expression,
    STATE(1521), 1,
      sym_ignored_argument,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18392] = 5,
    ACTIONS(1187), 1,
      anon_sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1185), 2,
      anon_sym_end,
      aux_sym_number_token1,
    STATE(384), 2,
      sym_arguments_statement,
      aux_sym_function_definition_repeat1,
    ACTIONS(1183), 37,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [18447] = 28,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(501), 1,
      sym_end_keyword,
    STATE(649), 1,
      sym__index_not_operator,
    STATE(652), 1,
      sym__index_unary_operator,
    STATE(654), 1,
      sym__index_postfix_operator,
    STATE(656), 1,
      sym__index_binary_operator,
    STATE(695), 1,
      sym__index_range_element,
    STATE(707), 1,
      sym__index_range,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(855), 1,
      sym_cell,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1557), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(455), 2,
      sym_identifier,
      sym_function_call,
    STATE(655), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18547] = 26,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(562), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(734), 1,
      sym__index_postfix_operator,
    STATE(763), 1,
      sym__index_binary_operator,
    STATE(764), 1,
      sym__index_unary_operator,
    STATE(766), 1,
      sym_cell,
    STATE(785), 1,
      sym__index_boolean_operator,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(467), 2,
      sym_identifier,
      sym_function_call,
    STATE(753), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(760), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18643] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(550), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(726), 1,
      sym__index_binary_operator,
    STATE(744), 1,
      sym_cell,
    STATE(765), 1,
      sym__index_range_element,
    STATE(780), 1,
      sym__index_postfix_operator,
    STATE(787), 1,
      sym__index_not_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(800), 1,
      sym__index_unary_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(488), 2,
      sym_identifier,
      sym_function_call,
    STATE(723), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18743] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(739), 1,
      sym__index_not_operator,
    STATE(741), 1,
      sym__index_unary_operator,
    STATE(742), 1,
      sym__index_postfix_operator,
    STATE(761), 1,
      sym_cell,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(483), 2,
      sym_identifier,
      sym_function_call,
    STATE(754), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18843] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(744), 1,
      sym_cell,
    STATE(759), 1,
      sym__index_expression,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(490), 2,
      sym_identifier,
      sym_function_call,
    STATE(743), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [18943] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(662), 1,
      sym__index_not_operator,
    STATE(663), 1,
      sym__index_unary_operator,
    STATE(664), 1,
      sym__index_postfix_operator,
    STATE(692), 1,
      sym_cell,
    STATE(707), 1,
      sym__index_range,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(813), 1,
      sym_end_keyword,
    STATE(850), 1,
      sym__index_binary_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(459), 2,
      sym_identifier,
      sym_function_call,
    STATE(666), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19043] = 28,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(501), 1,
      sym_end_keyword,
    STATE(649), 1,
      sym__index_not_operator,
    STATE(652), 1,
      sym__index_unary_operator,
    STATE(654), 1,
      sym__index_postfix_operator,
    STATE(656), 1,
      sym__index_binary_operator,
    STATE(678), 1,
      sym__index_range_element,
    STATE(707), 1,
      sym__index_range,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(855), 1,
      sym_cell,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1557), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(455), 2,
      sym_identifier,
      sym_function_call,
    STATE(655), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19143] = 28,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(679), 1,
      sym__index_expression,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19243] = 28,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(680), 1,
      sym__index_expression,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19343] = 28,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(681), 1,
      sym__index_expression,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19443] = 26,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(502), 1,
      sym_end_keyword,
    STATE(648), 1,
      sym__index_boolean_operator,
    STATE(668), 1,
      sym_cell,
    STATE(698), 1,
      sym__index_unary_operator,
    STATE(699), 1,
      sym__index_postfix_operator,
    STATE(701), 1,
      sym__index_binary_operator,
    STATE(707), 1,
      sym__index_range,
    STATE(1149), 1,
      sym__index_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(450), 2,
      sym_identifier,
      sym_function_call,
    STATE(683), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(700), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19539] = 26,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(502), 1,
      sym_end_keyword,
    STATE(648), 1,
      sym__index_boolean_operator,
    STATE(668), 1,
      sym_cell,
    STATE(698), 1,
      sym__index_unary_operator,
    STATE(699), 1,
      sym__index_postfix_operator,
    STATE(701), 1,
      sym__index_binary_operator,
    STATE(707), 1,
      sym__index_range,
    STATE(1149), 1,
      sym__index_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(450), 2,
      sym_identifier,
      sym_function_call,
    STATE(684), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(700), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19635] = 26,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(502), 1,
      sym_end_keyword,
    STATE(648), 1,
      sym__index_boolean_operator,
    STATE(668), 1,
      sym_cell,
    STATE(698), 1,
      sym__index_unary_operator,
    STATE(699), 1,
      sym__index_postfix_operator,
    STATE(701), 1,
      sym__index_binary_operator,
    STATE(707), 1,
      sym__index_range,
    STATE(1149), 1,
      sym__index_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(450), 2,
      sym_identifier,
      sym_function_call,
    STATE(685), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(700), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19731] = 26,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(502), 1,
      sym_end_keyword,
    STATE(648), 1,
      sym__index_boolean_operator,
    STATE(668), 1,
      sym_cell,
    STATE(698), 1,
      sym__index_unary_operator,
    STATE(699), 1,
      sym__index_postfix_operator,
    STATE(701), 1,
      sym__index_binary_operator,
    STATE(707), 1,
      sym__index_range,
    STATE(1149), 1,
      sym__index_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(450), 2,
      sym_identifier,
      sym_function_call,
    STATE(689), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(700), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19827] = 26,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(502), 1,
      sym_end_keyword,
    STATE(648), 1,
      sym__index_boolean_operator,
    STATE(668), 1,
      sym_cell,
    STATE(698), 1,
      sym__index_unary_operator,
    STATE(699), 1,
      sym__index_postfix_operator,
    STATE(701), 1,
      sym__index_binary_operator,
    STATE(707), 1,
      sym__index_range,
    STATE(1149), 1,
      sym__index_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(450), 2,
      sym_identifier,
      sym_function_call,
    STATE(682), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(700), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [19923] = 26,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(562), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(734), 1,
      sym__index_postfix_operator,
    STATE(763), 1,
      sym__index_binary_operator,
    STATE(764), 1,
      sym__index_unary_operator,
    STATE(766), 1,
      sym_cell,
    STATE(785), 1,
      sym__index_boolean_operator,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(467), 2,
      sym_identifier,
      sym_function_call,
    STATE(758), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(760), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20019] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(550), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(726), 1,
      sym__index_binary_operator,
    STATE(744), 1,
      sym_cell,
    STATE(745), 1,
      sym__index_range_element,
    STATE(780), 1,
      sym__index_postfix_operator,
    STATE(787), 1,
      sym__index_not_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(800), 1,
      sym__index_unary_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(488), 2,
      sym_identifier,
      sym_function_call,
    STATE(723), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20119] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(744), 1,
      sym_cell,
    STATE(746), 1,
      sym__index_expression,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(490), 2,
      sym_identifier,
      sym_function_call,
    STATE(743), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20219] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(744), 1,
      sym_cell,
    STATE(747), 1,
      sym__index_expression,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(490), 2,
      sym_identifier,
      sym_function_call,
    STATE(743), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20319] = 28,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(556), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(744), 1,
      sym_cell,
    STATE(748), 1,
      sym__index_expression,
    STATE(791), 1,
      sym__index_binary_operator,
    STATE(796), 1,
      sym__index_boolean_operator,
    STATE(798), 1,
      sym__index_comparison_operator,
    STATE(799), 1,
      sym__index_not_operator,
    STATE(801), 1,
      sym__index_unary_operator,
    STATE(802), 1,
      sym__index_postfix_operator,
    STATE(971), 1,
      sym__index_binary_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(490), 2,
      sym_identifier,
      sym_function_call,
    STATE(743), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20419] = 26,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(562), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(734), 1,
      sym__index_postfix_operator,
    STATE(763), 1,
      sym__index_binary_operator,
    STATE(764), 1,
      sym__index_unary_operator,
    STATE(766), 1,
      sym_cell,
    STATE(785), 1,
      sym__index_boolean_operator,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(467), 2,
      sym_identifier,
      sym_function_call,
    STATE(750), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(760), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20515] = 28,
    ACTIONS(852), 1,
      aux_sym_number_token1,
    ACTIONS(856), 1,
      sym__single_quote_string_start,
    ACTIONS(858), 1,
      sym__double_quote_string_start,
    ACTIONS(948), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_end,
    ACTIONS(1175), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACK,
    ACTIONS(1190), 1,
      anon_sym_TILDE,
    STATE(480), 1,
      sym__keywords,
    STATE(494), 1,
      sym_end_keyword,
    STATE(646), 1,
      sym_cell,
    STATE(665), 1,
      sym__index_range,
    STATE(673), 1,
      sym__index_expression,
    STATE(675), 1,
      sym__index_binary_operator,
    STATE(676), 1,
      sym__index_boolean_operator,
    STATE(687), 1,
      sym__index_comparison_operator,
    STATE(688), 1,
      sym__index_not_operator,
    STATE(690), 1,
      sym__index_unary_operator,
    STATE(697), 1,
      sym__index_postfix_operator,
    STATE(968), 1,
      sym__index_binary_expression,
    STATE(1557), 1,
      sym_indirect_access,
    STATE(1734), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(952), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1177), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(460), 2,
      sym_identifier,
      sym_function_call,
    STATE(647), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20615] = 26,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(562), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(734), 1,
      sym__index_postfix_operator,
    STATE(763), 1,
      sym__index_binary_operator,
    STATE(764), 1,
      sym__index_unary_operator,
    STATE(766), 1,
      sym_cell,
    STATE(785), 1,
      sym__index_boolean_operator,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(467), 2,
      sym_identifier,
      sym_function_call,
    STATE(751), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(760), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20711] = 26,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(890), 1,
      anon_sym_LBRACE,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1192), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_TILDE,
    ACTIONS(1198), 1,
      anon_sym_LBRACK,
    STATE(503), 1,
      sym__keywords,
    STATE(562), 1,
      sym_end_keyword,
    STATE(707), 1,
      sym__index_range,
    STATE(734), 1,
      sym__index_postfix_operator,
    STATE(763), 1,
      sym__index_binary_operator,
    STATE(764), 1,
      sym__index_unary_operator,
    STATE(766), 1,
      sym_cell,
    STATE(785), 1,
      sym__index_boolean_operator,
    STATE(1154), 1,
      sym__index_expression,
    STATE(1535), 1,
      sym_indirect_access,
    STATE(1713), 1,
      sym__index_range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    ACTIONS(1194), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(467), 2,
      sym_identifier,
      sym_function_call,
    STATE(752), 3,
      sym__index_comparison_operator,
      sym__index_not_operator,
      sym__index_binary_expression,
    STATE(760), 5,
      sym_field_expression,
      sym_string,
      sym__index_matrix,
      sym__index_parenthesis,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [20807] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1202), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1200), 38,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [20856] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1206), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1204), 38,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [20905] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1210), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1208), 38,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [20954] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(695), 40,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_vector,
      anon_sym_matrix,
      anon_sym_scalar,
      anon_sym_CR,
  [21001] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1214), 2,
      anon_sym_end,
      aux_sym_number_token1,
    ACTIONS(1212), 38,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [21050] = 4,
    ACTIONS(1216), 1,
      anon_sym_DOT,
    STATE(420), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(647), 36,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21099] = 11,
    ACTIONS(590), 1,
      anon_sym_COLON,
    ACTIONS(1218), 1,
      anon_sym_LPAREN,
    ACTIONS(1220), 1,
      anon_sym_DOT,
    ACTIONS(1222), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    STATE(427), 1,
      sym__args,
    STATE(443), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21162] = 11,
    ACTIONS(1218), 1,
      anon_sym_LPAREN,
    ACTIONS(1220), 1,
      anon_sym_DOT,
    ACTIONS(1222), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    STATE(427), 1,
      sym__args,
    STATE(443), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(590), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(599), 8,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [21225] = 5,
    ACTIONS(1218), 1,
      anon_sym_LPAREN,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    STATE(432), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(620), 35,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21276] = 9,
    ACTIONS(1218), 1,
      anon_sym_LPAREN,
    ACTIONS(1220), 1,
      anon_sym_DOT,
    ACTIONS(1222), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    STATE(427), 1,
      sym__args,
    STATE(443), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21335] = 11,
    ACTIONS(599), 1,
      anon_sym_COLON,
    ACTIONS(1218), 1,
      anon_sym_LPAREN,
    ACTIONS(1220), 1,
      anon_sym_DOT,
    ACTIONS(1222), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    STATE(427), 1,
      sym__args,
    STATE(443), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21398] = 4,
    ACTIONS(1228), 1,
      anon_sym_DOT,
    STATE(420), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 36,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21447] = 6,
    ACTIONS(1218), 1,
      anon_sym_LPAREN,
    ACTIONS(1222), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    STATE(427), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(612), 34,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21500] = 9,
    ACTIONS(1218), 1,
      anon_sym_LPAREN,
    ACTIONS(1220), 1,
      anon_sym_DOT,
    ACTIONS(1222), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    STATE(427), 1,
      sym__args,
    STATE(443), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21559] = 4,
    ACTIONS(1231), 1,
      anon_sym_DOT,
    STATE(414), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(641), 36,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21608] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(665), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21652] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(677), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21696] = 6,
    ACTIONS(1233), 1,
      anon_sym_LPAREN,
    STATE(1320), 1,
      sym__argument_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(859), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1237), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1235), 29,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
  [21748] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(673), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21792] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(707), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21836] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(699), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21880] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(687), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21924] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21968] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(691), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22012] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(669), 34,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22058] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22102] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(703), 37,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22146] = 10,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(601), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22205] = 12,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(603), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(599), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(590), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22268] = 12,
    ACTIONS(590), 1,
      anon_sym_COLON,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22331] = 12,
    ACTIONS(599), 1,
      anon_sym_COLON,
    ACTIONS(1218), 1,
      anon_sym_LPAREN,
    ACTIONS(1220), 1,
      anon_sym_DOT,
    ACTIONS(1222), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1251), 1,
      anon_sym_EQ,
    STATE(427), 1,
      sym__args,
    STATE(443), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 12,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22394] = 12,
    ACTIONS(599), 1,
      anon_sym_COLON,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22457] = 10,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(597), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22516] = 10,
    ACTIONS(1253), 1,
      anon_sym_LPAREN,
    ACTIONS(1257), 1,
      anon_sym_else,
    ACTIONS(1259), 1,
      anon_sym_end,
    STATE(480), 1,
      sym__keywords,
    STATE(584), 1,
      sym__extended_keywords,
    STATE(1558), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(446), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1255), 18,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [22574] = 4,
    ACTIONS(1220), 1,
      anon_sym_DOT,
    STATE(448), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(616), 33,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22620] = 12,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    ACTIONS(1271), 1,
      anon_sym_COLON,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1266), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1263), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22682] = 10,
    ACTIONS(1273), 1,
      anon_sym_LPAREN,
    ACTIONS(1277), 1,
      anon_sym_else,
    ACTIONS(1279), 1,
      anon_sym_end,
    STATE(908), 1,
      sym__keywords,
    STATE(957), 1,
      sym__extended_keywords,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(896), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1275), 18,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [22740] = 7,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(614), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(612), 29,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22792] = 6,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(491), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(620), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22842] = 4,
    ACTIONS(1283), 1,
      anon_sym_DOT,
    STATE(448), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(605), 33,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22888] = 10,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1266), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1288), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1286), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [22946] = 10,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1292), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1261), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [23004] = 5,
    ACTIONS(1294), 1,
      anon_sym_DOT,
    STATE(454), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(651), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(647), 31,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23052] = 5,
    ACTIONS(1296), 1,
      anon_sym_DOT,
    STATE(451), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(645), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(641), 31,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23100] = 14,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1308), 1,
      anon_sym_EQ,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23166] = 5,
    ACTIONS(1312), 1,
      anon_sym_DOT,
    STATE(454), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(629), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(624), 31,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23214] = 11,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1310), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1271), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23274] = 10,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1319), 1,
      anon_sym_else,
    ACTIONS(1321), 1,
      anon_sym_end,
    STATE(503), 1,
      sym__keywords,
    STATE(644), 1,
      sym__extended_keywords,
    STATE(1536), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(493), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1317), 18,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [23332] = 10,
    ACTIONS(1323), 1,
      anon_sym_LPAREN,
    ACTIONS(1327), 1,
      anon_sym_else,
    ACTIONS(1329), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(470), 1,
      sym__extended_keywords,
    STATE(1463), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(421), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1325), 18,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [23390] = 10,
    ACTIONS(1331), 1,
      anon_sym_LPAREN,
    ACTIONS(1335), 1,
      anon_sym_else,
    ACTIONS(1337), 1,
      anon_sym_end,
    STATE(130), 1,
      sym__extended_keywords,
    STATE(135), 1,
      sym__keywords,
    STATE(1574), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(115), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
    ACTIONS(1333), 18,
      anon_sym_return,
      anon_sym_continue,
      anon_sym_break,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
  [23448] = 10,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1288), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1286), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [23506] = 12,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    ACTIONS(1245), 1,
      anon_sym_AT,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    ACTIONS(1271), 1,
      anon_sym_COLON,
    STATE(469), 1,
      sym__args,
    STATE(546), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1341), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1339), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23568] = 14,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1308), 1,
      anon_sym_EQ,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 8,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23633] = 4,
    ACTIONS(1343), 1,
      anon_sym_DOT,
    STATE(466), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(657), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23678] = 10,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(597), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23735] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(669), 34,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23776] = 4,
    ACTIONS(1343), 1,
      anon_sym_DOT,
    STATE(420), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(631), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23821] = 4,
    ACTIONS(1343), 1,
      anon_sym_DOT,
    STATE(420), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(653), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23866] = 10,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1261), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1292), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23923] = 10,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1286), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1288), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23980] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(675), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(673), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24023] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(612), 34,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24064] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(663), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(661), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24107] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(679), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(677), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24150] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(665), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24193] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(671), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(669), 29,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24238] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(687), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24281] = 4,
    ACTIONS(1343), 1,
      anon_sym_DOT,
    STATE(465), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24326] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(709), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(707), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24369] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(705), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(703), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24412] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(701), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(699), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24455] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(697), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(695), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24498] = 13,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1349), 1,
      anon_sym_COLON,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24561] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(629), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(624), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24604] = 10,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1286), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1288), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24661] = 13,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24724] = 10,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24781] = 13,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(590), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(603), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1349), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24844] = 13,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    STATE(509), 1,
      sym__args,
    STATE(598), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24907] = 12,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1271), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1310), 10,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24968] = 13,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25031] = 13,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1339), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1341), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25094] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(691), 32,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25137] = 5,
    ACTIONS(1352), 1,
      anon_sym_DOT,
    STATE(492), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(629), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25183] = 7,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(612), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(614), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25233] = 9,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    ACTIONS(1271), 1,
      anon_sym_COLON,
    ACTIONS(1355), 1,
      anon_sym_AT,
    STATE(471), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1341), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1339), 12,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [25287] = 5,
    ACTIONS(1357), 1,
      anon_sym_DOT,
    STATE(497), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(641), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(645), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25333] = 6,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(575), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(620), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(622), 25,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25381] = 5,
    ACTIONS(1359), 1,
      anon_sym_DOT,
    STATE(492), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(647), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(651), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25427] = 13,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    STATE(509), 1,
      sym__args,
    STATE(598), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 8,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25489] = 13,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 8,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25551] = 3,
    ACTIONS(1361), 1,
      sym_number_size,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(681), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [25593] = 8,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    ACTIONS(1355), 1,
      anon_sym_AT,
    STATE(471), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1310), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1271), 13,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [25645] = 7,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1249), 1,
      anon_sym_LBRACE,
    ACTIONS(1355), 1,
      anon_sym_AT,
    STATE(471), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1292), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1261), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [25695] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(695), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
    ACTIONS(697), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25737] = 14,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1363), 1,
      anon_sym_RPAREN,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25800] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1365), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(764), 24,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [25843] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(681), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [25882] = 5,
    ACTIONS(1369), 1,
      anon_sym_DOT,
    STATE(507), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(610), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(605), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25927] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(707), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(709), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25968] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(673), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(675), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26009] = 5,
    ACTIONS(599), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26054] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(738), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26093] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(730), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26132] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(764), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26173] = 5,
    ACTIONS(711), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26218] = 5,
    ACTIONS(718), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26263] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(742), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26302] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26343] = 14,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1372), 1,
      anon_sym_RPAREN,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26406] = 14,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1374), 1,
      anon_sym_RPAREN,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26469] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(764), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26510] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(665), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(667), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26551] = 14,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26614] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26653] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(792), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26692] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(780), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26731] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 18,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26772] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(746), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26811] = 14,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1376), 1,
      anon_sym_RPAREN,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26874] = 6,
    ACTIONS(1380), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1378), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1365), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(764), 19,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26921] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 16,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26964] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(677), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27005] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(69), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27044] = 5,
    ACTIONS(1382), 1,
      anon_sym_DOT,
    STATE(535), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(639), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(637), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27089] = 5,
    ACTIONS(1382), 1,
      anon_sym_DOT,
    STATE(536), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(659), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(657), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27134] = 5,
    ACTIONS(1382), 1,
      anon_sym_DOT,
    STATE(454), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(635), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(631), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27179] = 5,
    ACTIONS(1382), 1,
      anon_sym_DOT,
    STATE(454), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(655), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(653), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27224] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(629), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27265] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1378), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1365), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(764), 20,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27310] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27349] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(752), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27388] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(756), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27427] = 14,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27490] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27531] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27572] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(784), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27611] = 5,
    ACTIONS(1243), 1,
      anon_sym_DOT,
    STATE(507), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(618), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(616), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27656] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(590), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(599), 8,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27701] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(590), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(599), 10,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27744] = 3,
    ACTIONS(1384), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(774), 31,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27785] = 9,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1386), 1,
      anon_sym_AT,
    STATE(555), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1271), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1310), 12,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27838] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27879] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(669), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(671), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27922] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(711), 8,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(713), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27967] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(734), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28006] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(663), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28047] = 10,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(1386), 1,
      anon_sym_AT,
    STATE(555), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1339), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1341), 11,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28102] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(760), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28141] = 14,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1390), 1,
      anon_sym_RPAREN,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28204] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(687), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(689), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28245] = 5,
    ACTIONS(590), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28290] = 4,
    ACTIONS(801), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(798), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(796), 23,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28333] = 7,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1386), 1,
      anon_sym_AT,
    STATE(555), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1292), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28382] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1392), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(810), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28423] = 4,
    ACTIONS(1394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1392), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(810), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28466] = 13,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    STATE(509), 1,
      sym__args,
    STATE(602), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 7,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28527] = 5,
    ACTIONS(1394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1396), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1392), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(816), 24,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28572] = 5,
    ACTIONS(1394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1396), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1392), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(822), 24,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28617] = 5,
    ACTIONS(805), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28662] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(703), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(705), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28703] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28744] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28785] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(699), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(701), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28826] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 32,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28865] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 30,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [28906] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(691), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(693), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28947] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1388), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1239), 30,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
  [28988] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1392), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(724), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29029] = 5,
    ACTIONS(713), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29074] = 4,
    ACTIONS(590), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 17,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29117] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(718), 8,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(805), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29162] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1388), 27,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29202] = 4,
    ACTIONS(1398), 1,
      sym_number_size,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(685), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(681), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29244] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(671), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(669), 29,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29284] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(614), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(612), 29,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29324] = 6,
    ACTIONS(590), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29369] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(740), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(738), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29408] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(742), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29447] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(597), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29488] = 5,
    ACTIONS(1400), 1,
      anon_sym_DOT,
    STATE(589), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(605), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(610), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29531] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(762), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(760), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29570] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(770), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1405), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1403), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(764), 20,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29613] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(770), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1405), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(764), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29654] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(770), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1405), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(764), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29695] = 7,
    ACTIONS(1409), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(770), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1405), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1407), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1403), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(764), 15,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29742] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(770), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1405), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1407), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1403), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(764), 16,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29787] = 4,
    ACTIONS(599), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [29828] = 4,
    ACTIONS(1411), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(778), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(774), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [29869] = 5,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    STATE(589), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(616), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(618), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29912] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(780), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29951] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(786), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(784), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29990] = 6,
    ACTIONS(805), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30035] = 5,
    ACTIONS(1300), 1,
      anon_sym_DOT,
    STATE(589), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(616), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(618), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30078] = 5,
    ACTIONS(1413), 1,
      anon_sym_DOT,
    STATE(605), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(639), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30121] = 5,
    ACTIONS(1413), 1,
      anon_sym_DOT,
    STATE(606), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(657), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(659), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30164] = 5,
    ACTIONS(1413), 1,
      anon_sym_DOT,
    STATE(492), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(631), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(635), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30207] = 5,
    ACTIONS(1413), 1,
      anon_sym_DOT,
    STATE(492), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(653), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(655), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30250] = 5,
    ACTIONS(590), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(582), 13,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30293] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(790), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(788), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30332] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(794), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(792), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30371] = 5,
    ACTIONS(801), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(803), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(798), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(796), 19,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30414] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(601), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30455] = 6,
    ACTIONS(711), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30500] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(597), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(595), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30539] = 6,
    ACTIONS(713), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30584] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(597), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30625] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(748), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(746), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30664] = 6,
    ACTIONS(599), 1,
      anon_sym_COLON,
    ACTIONS(1251), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1224), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 12,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30709] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(750), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(69), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30748] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(601), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30789] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(597), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30830] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(601), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30871] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(603), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(599), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(590), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30916] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(808), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(718), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(805), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [30961] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(603), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(599), 6,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(590), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31004] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(601), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31045] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(716), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(711), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(713), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31090] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(732), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(730), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31129] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(754), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(752), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31168] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(758), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31207] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(734), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31246] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(812), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1415), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(810), 22,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31287] = 5,
    ACTIONS(1417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(812), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1415), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(810), 21,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31330] = 6,
    ACTIONS(1417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1419), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(820), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1415), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(816), 20,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31375] = 6,
    ACTIONS(1417), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1419), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(824), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1415), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(822), 20,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31420] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(685), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(681), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31459] = 6,
    ACTIONS(599), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31504] = 6,
    ACTIONS(718), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31549] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 14,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31590] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1247), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(582), 12,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31633] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(722), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(720), 28,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31672] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(728), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1415), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(724), 22,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31713] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1421), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [31751] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(669), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(671), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31789] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(612), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(614), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31827] = 6,
    ACTIONS(1271), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1266), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1263), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31871] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1341), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1339), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31913] = 6,
    ACTIONS(1271), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1341), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1339), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31957] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1427), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1425), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [31995] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1310), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1271), 13,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32035] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1421), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32073] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1421), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32111] = 6,
    ACTIONS(1433), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1435), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1437), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1431), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1429), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32155] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1441), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1439), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32193] = 6,
    ACTIONS(1445), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1447), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1449), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1443), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1429), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32237] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1310), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1271), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32279] = 6,
    ACTIONS(1453), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1455), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1457), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1451), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1425), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32323] = 5,
    ACTIONS(1461), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1463), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(822), 21,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [32365] = 4,
    ACTIONS(1461), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(810), 22,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [32405] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1266), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1263), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [32447] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1266), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1288), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1286), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32487] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1266), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1288), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1286), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32527] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1288), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1286), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32565] = 5,
    ACTIONS(1433), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1435), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1467), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1465), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32607] = 5,
    ACTIONS(1445), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1447), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1467), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1465), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32649] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1341), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1339), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32687] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1288), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1286), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32727] = 4,
    ACTIONS(1469), 1,
      sym_number_size,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(681), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(685), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32767] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1292), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1261), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32807] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1473), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1471), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32845] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(810), 23,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [32883] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1477), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1475), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32921] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1481), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1479), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32959] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1485), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(1483), 21,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [32999] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1492), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1489), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33037] = 7,
    ACTIONS(1451), 1,
      anon_sym_COLON,
    ACTIONS(1453), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1455), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1497), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1495), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1425), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33083] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1497), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1495), 13,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1425), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33123] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1502), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1499), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33161] = 4,
    ACTIONS(1509), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1507), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1505), 26,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [33201] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1513), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1511), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33239] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1517), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1485), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(1515), 21,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33279] = 5,
    ACTIONS(1519), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1517), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1485), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(1515), 20,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33321] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1525), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1527), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1523), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1521), 19,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33363] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1525), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1527), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1521), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33403] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1525), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1527), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1521), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33443] = 7,
    ACTIONS(1531), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1525), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1527), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1529), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1523), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1521), 14,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33489] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1441), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1439), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33527] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1341), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1339), 13,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33567] = 5,
    ACTIONS(1271), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1341), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1339), 12,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1261), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33609] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1525), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1527), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1529), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1523), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1521), 15,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33653] = 7,
    ACTIONS(1431), 1,
      anon_sym_COLON,
    ACTIONS(1433), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1435), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1533), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1429), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33699] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1539), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1537), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33737] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1288), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1286), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33777] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1543), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1541), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33815] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1545), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [33853] = 5,
    ACTIONS(1556), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1554), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1551), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1549), 18,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [33895] = 5,
    ACTIONS(1461), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1463), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(816), 21,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [33937] = 7,
    ACTIONS(1443), 1,
      anon_sym_COLON,
    ACTIONS(1445), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1447), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1533), 10,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1429), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [33983] = 5,
    ACTIONS(1433), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1435), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1429), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [34025] = 5,
    ACTIONS(1445), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1447), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1429), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [34067] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1292), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1261), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [34107] = 5,
    ACTIONS(1453), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1455), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1427), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1425), 25,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [34149] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1421), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [34187] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1473), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1471), 27,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [34225] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(593), 12,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34266] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1439), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1441), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34303] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(597), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34342] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1339), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1341), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34379] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(597), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34416] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(597), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34455] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(780), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(782), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34492] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(738), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(740), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34529] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(784), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(786), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34566] = 5,
    ACTIONS(599), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(582), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(578), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [34607] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(724), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1560), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1562), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(728), 20,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34648] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1537), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1539), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34685] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1475), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1477), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34722] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(742), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(744), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34759] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(760), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(762), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34796] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34835] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1479), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1481), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34872] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [34911] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(590), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(603), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1349), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34956] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1271), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1310), 10,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [34999] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(805), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(808), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1564), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35044] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(590), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(603), 6,
      anon_sym_RPAREN,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1349), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35087] = 7,
    ACTIONS(1567), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1569), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1425), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1451), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1457), 10,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1427), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35132] = 7,
    ACTIONS(1349), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35177] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1471), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1473), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35214] = 7,
    ACTIONS(1564), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35259] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1286), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1288), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35298] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1471), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1473), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35335] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35374] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(756), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(758), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35411] = 5,
    ACTIONS(1571), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1573), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1429), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1558), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35452] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1286), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1288), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35491] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(730), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(732), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35528] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(713), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(716), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1575), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35573] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1499), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1502), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35610] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1286), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1288), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35647] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(681), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(685), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35684] = 5,
    ACTIONS(1578), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1580), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1465), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1467), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35725] = 5,
    ACTIONS(1571), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1573), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1465), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1467), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35766] = 7,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1339), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1341), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35811] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1339), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1341), 10,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [35854] = 4,
    ACTIONS(1582), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1505), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1507), 23,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [35893] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1511), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1513), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35930] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1515), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1584), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1586), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1517), 20,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [35971] = 6,
    ACTIONS(1588), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1515), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1584), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1586), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1517), 19,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36014] = 7,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [36059] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1592), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1521), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1590), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1527), 16,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36100] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1592), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1521), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1527), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36139] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1592), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1521), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1527), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36178] = 7,
    ACTIONS(1596), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1592), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1521), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1594), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1590), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1527), 12,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36223] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1286), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1288), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36262] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(790), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36299] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(792), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(794), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36336] = 6,
    ACTIONS(1349), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(593), 11,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [36379] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1592), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1521), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1594), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1590), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1527), 12,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36422] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1483), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1584), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1586), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1487), 20,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36463] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1261), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1292), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36502] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1286), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1288), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36541] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1541), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1543), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36578] = 5,
    ACTIONS(1567), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1569), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1425), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1427), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36619] = 5,
    ACTIONS(1578), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1580), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1429), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1558), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36660] = 6,
    ACTIONS(1582), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1549), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1551), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1598), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1554), 17,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [36703] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1347), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1261), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1292), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36742] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1439), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1441), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36779] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1603), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(764), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1601), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(770), 16,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36820] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1560), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1562), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(812), 20,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36861] = 6,
    ACTIONS(1605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1560), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1562), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(812), 19,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36904] = 7,
    ACTIONS(1605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1607), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(816), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1560), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1562), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(820), 18,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36949] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1603), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(764), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(770), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [36988] = 7,
    ACTIONS(1605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1607), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(822), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1560), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1562), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(824), 18,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37033] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1603), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(764), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(770), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37072] = 7,
    ACTIONS(1611), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1603), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(764), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1609), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1601), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(770), 12,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37117] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1603), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(764), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1609), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1601), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(770), 12,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37160] = 4,
    ACTIONS(1613), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(774), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(778), 23,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [37199] = 7,
    ACTIONS(1575), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37244] = 6,
    ACTIONS(1613), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(796), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(798), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1615), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(803), 17,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [37287] = 7,
    ACTIONS(1571), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1573), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1429), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1443), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1449), 10,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1558), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37332] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(578), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37371] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(722), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37408] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 10,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37451] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(746), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(748), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37488] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1425), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1427), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37525] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1421), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1423), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37562] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1271), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1310), 12,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37603] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1421), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1423), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37640] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(69), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(750), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37677] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1489), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1492), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37714] = 8,
    ACTIONS(1457), 1,
      anon_sym_COLON,
    ACTIONS(1567), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1569), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1425), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1495), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1497), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1427), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37761] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(595), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(597), 22,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37800] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(752), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(754), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37837] = 7,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37882] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 10,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [37925] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1425), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1495), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1427), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1497), 12,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [37966] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1421), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1423), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [38003] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1339), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1341), 12,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [38044] = 6,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1339), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1341), 11,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38087] = 7,
    ACTIONS(1578), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1580), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1429), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1431), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1437), 10,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1558), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38132] = 8,
    ACTIONS(1437), 1,
      anon_sym_COLON,
    ACTIONS(1578), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1580), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1429), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1533), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1535), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1558), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38179] = 8,
    ACTIONS(1449), 1,
      anon_sym_COLON,
    ACTIONS(1571), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1573), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1429), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1533), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1535), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1558), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38226] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1421), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1423), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [38263] = 7,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38308] = 7,
    ACTIONS(808), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38353] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(734), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(736), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [38390] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1545), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1547), 24,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [38427] = 7,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 8,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38471] = 6,
    ACTIONS(1620), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1622), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(820), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1618), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(816), 17,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38513] = 5,
    ACTIONS(1626), 1,
      anon_sym_LF,
    STATE(810), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1629), 3,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__external_identifier,
    ACTIONS(1624), 22,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      aux_sym_number_token1,
      aux_sym_number_token2,
      aux_sym_number_token3,
  [38553] = 6,
    ACTIONS(1620), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1622), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(824), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1618), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(822), 17,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38595] = 18,
    ACTIONS(1631), 1,
      anon_sym_LPAREN,
    ACTIONS(1633), 1,
      anon_sym_DOT,
    ACTIONS(1635), 1,
      anon_sym_AT,
    ACTIONS(1639), 1,
      anon_sym_LBRACE,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    ACTIONS(1643), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(1647), 1,
      sym__external_identifier,
    STATE(870), 1,
      sym_dimensions,
    STATE(878), 1,
      sym__keywords,
    STATE(890), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(1015), 1,
      sym_identifier,
    STATE(1102), 1,
      sym_property_name,
    STATE(1162), 1,
      sym_validation_functions,
    STATE(1225), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(940), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1637), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1645), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38661] = 10,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(1649), 1,
      anon_sym_LPAREN,
    ACTIONS(1651), 1,
      anon_sym_AT,
    ACTIONS(1653), 1,
      anon_sym_LBRACE,
    STATE(471), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1339), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1341), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38711] = 5,
    ACTIONS(1620), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(812), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1618), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(810), 18,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38751] = 7,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 8,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38795] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(812), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1618), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(810), 19,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38833] = 7,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 8,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38877] = 7,
    ACTIONS(808), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 8,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38921] = 8,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [38966] = 8,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1363), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39011] = 4,
    ACTIONS(1481), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1499), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1502), 21,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
  [39048] = 8,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(1372), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39093] = 4,
    ACTIONS(1543), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1489), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1492), 21,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
  [39130] = 8,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(1363), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39175] = 17,
    ACTIONS(1631), 1,
      anon_sym_LPAREN,
    ACTIONS(1633), 1,
      anon_sym_DOT,
    ACTIONS(1635), 1,
      anon_sym_AT,
    ACTIONS(1639), 1,
      anon_sym_LBRACE,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    ACTIONS(1647), 1,
      sym__external_identifier,
    STATE(870), 1,
      sym_dimensions,
    STATE(878), 1,
      sym__keywords,
    STATE(890), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(1015), 1,
      sym_identifier,
    STATE(1102), 1,
      sym_property_name,
    STATE(1162), 1,
      sym_validation_functions,
    STATE(1225), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(940), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1637), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1645), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39238] = 16,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(107), 1,
      anon_sym_function,
    ACTIONS(1657), 1,
      anon_sym_end,
    ACTIONS(1665), 1,
      sym__external_identifier,
    STATE(503), 1,
      sym__keywords,
    STATE(873), 1,
      aux_sym_methods_repeat1,
    STATE(1253), 1,
      sym_function_output,
    STATE(1272), 1,
      sym__function_definition_with_end,
    STATE(1278), 1,
      sym_function_signature,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1661), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(882), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    STATE(1712), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(1659), 3,
      anon_sym_arguments,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1655), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1663), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39299] = 8,
    ACTIONS(808), 1,
      anon_sym_COLON,
    ACTIONS(1363), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39344] = 7,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 7,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39387] = 8,
    ACTIONS(808), 1,
      anon_sym_COLON,
    ACTIONS(1374), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39432] = 8,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(1390), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39477] = 8,
    ACTIONS(808), 1,
      anon_sym_COLON,
    ACTIONS(1390), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39522] = 17,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1667), 1,
      anon_sym_LPAREN,
    ACTIONS(1669), 1,
      anon_sym_DOT,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    ACTIONS(1673), 1,
      anon_sym_AT,
    ACTIONS(1675), 1,
      anon_sym_COMMA,
    ACTIONS(1677), 1,
      anon_sym_RBRACK,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    STATE(904), 1,
      sym__args,
    STATE(908), 1,
      sym__keywords,
    STATE(948), 1,
      aux_sym_field_expression_repeat1,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(892), 2,
      sym_identifier,
      sym_function_call,
    STATE(871), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39585] = 17,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1667), 1,
      anon_sym_LPAREN,
    ACTIONS(1669), 1,
      anon_sym_DOT,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    ACTIONS(1673), 1,
      anon_sym_AT,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1681), 1,
      anon_sym_COMMA,
    ACTIONS(1683), 1,
      anon_sym_RBRACK,
    STATE(904), 1,
      sym__args,
    STATE(908), 1,
      sym__keywords,
    STATE(948), 1,
      aux_sym_field_expression_repeat1,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(892), 2,
      sym_identifier,
      sym_function_call,
    STATE(869), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39648] = 8,
    ACTIONS(1310), 1,
      anon_sym_COLON,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1263), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1304), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1268), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39693] = 8,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1372), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39738] = 8,
    ACTIONS(808), 1,
      anon_sym_COLON,
    ACTIONS(1372), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39783] = 8,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1374), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39828] = 16,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(107), 1,
      anon_sym_function,
    ACTIONS(1665), 1,
      sym__external_identifier,
    ACTIONS(1685), 1,
      anon_sym_end,
    STATE(503), 1,
      sym__keywords,
    STATE(876), 1,
      aux_sym_methods_repeat1,
    STATE(1253), 1,
      sym_function_output,
    STATE(1272), 1,
      sym__function_definition_with_end,
    STATE(1278), 1,
      sym_function_signature,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1661), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(882), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    STATE(1712), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(1659), 3,
      anon_sym_arguments,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1655), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1663), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39889] = 6,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(593), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39930] = 8,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(1374), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [39975] = 8,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1390), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40020] = 8,
    ACTIONS(603), 1,
      anon_sym_COLON,
    ACTIONS(1376), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40065] = 8,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(1376), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40110] = 8,
    ACTIONS(808), 1,
      anon_sym_COLON,
    ACTIONS(1376), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1345), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40155] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(812), 17,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [40193] = 7,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1691), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40235] = 7,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1693), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40277] = 7,
    ACTIONS(716), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1695), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40319] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(812), 16,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [40359] = 8,
    ACTIONS(1457), 1,
      anon_sym_COLON,
    ACTIONS(1699), 1,
      anon_sym_DOT_SQUOTE,
    ACTIONS(1701), 1,
      anon_sym_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1425), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1495), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1497), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1427), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40403] = 7,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(816), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(820), 15,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [40445] = 7,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(822), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(824), 15,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [40487] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1693), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40526] = 16,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1667), 1,
      anon_sym_LPAREN,
    ACTIONS(1669), 1,
      anon_sym_DOT,
    ACTIONS(1673), 1,
      anon_sym_AT,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1705), 1,
      anon_sym_COMMA,
    ACTIONS(1707), 1,
      anon_sym_RBRACE,
    STATE(904), 1,
      sym__args,
    STATE(908), 1,
      sym__keywords,
    STATE(948), 1,
      aux_sym_field_expression_repeat1,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(886), 2,
      sym_field_expression,
      aux_sym_validation_functions_repeat1,
    STATE(933), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40585] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1261), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1339), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1709), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1341), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1292), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40624] = 15,
    ACTIONS(1631), 1,
      anon_sym_LPAREN,
    ACTIONS(1635), 1,
      anon_sym_AT,
    ACTIONS(1639), 1,
      anon_sym_LBRACE,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    ACTIONS(1647), 1,
      sym__external_identifier,
    STATE(870), 1,
      sym_dimensions,
    STATE(878), 1,
      sym__keywords,
    STATE(1015), 1,
      sym_identifier,
    STATE(1102), 1,
      sym_property_name,
    STATE(1162), 1,
      sym_validation_functions,
    STATE(1225), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(940), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1637), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1645), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40681] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1691), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40720] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1695), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(593), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(601), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [40759] = 12,
    ACTIONS(1711), 1,
      anon_sym_TILDE,
    ACTIONS(1715), 1,
      anon_sym_end,
    ACTIONS(1719), 1,
      sym__external_identifier,
    STATE(812), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    STATE(1333), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(905), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1717), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40809] = 14,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(902), 1,
      sym__single_quote_string_start,
    ACTIONS(904), 1,
      sym__double_quote_string_start,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1536), 1,
      sym_end_keyword,
    STATE(1579), 1,
      sym_indirect_access,
    STATE(1772), 1,
      sym_parfor_options,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(1380), 2,
      sym_identifier,
      sym_function_call,
    STATE(1753), 2,
      sym_string,
      sym_number,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40863] = 12,
    ACTIONS(1711), 1,
      anon_sym_TILDE,
    ACTIONS(1719), 1,
      sym__external_identifier,
    ACTIONS(1721), 1,
      anon_sym_end,
    STATE(812), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    STATE(1333), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(916), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1717), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40913] = 11,
    ACTIONS(1711), 1,
      anon_sym_TILDE,
    ACTIONS(1719), 1,
      sym__external_identifier,
    ACTIONS(1723), 1,
      anon_sym_end,
    STATE(825), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(935), 2,
      sym_property,
      aux_sym_properties_repeat1,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1717), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [40960] = 11,
    ACTIONS(1711), 1,
      anon_sym_TILDE,
    ACTIONS(1719), 1,
      sym__external_identifier,
    ACTIONS(1725), 1,
      anon_sym_end,
    STATE(825), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(939), 2,
      sym_property,
      aux_sym_properties_repeat1,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1717), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41007] = 12,
    ACTIONS(1727), 1,
      anon_sym_LPAREN,
    ACTIONS(1730), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      anon_sym_COMMA,
    ACTIONS(1736), 1,
      anon_sym_RBRACK,
    ACTIONS(1738), 1,
      anon_sym_end,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(892), 2,
      sym_identifier,
      sym_function_call,
    STATE(864), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1741), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41055] = 12,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    ACTIONS(1681), 1,
      anon_sym_COMMA,
    ACTIONS(1683), 1,
      anon_sym_RBRACK,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(892), 2,
      sym_identifier,
      sym_function_call,
    STATE(869), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41103] = 14,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1281), 1,
      sym__external_identifier,
    ACTIONS(1744), 1,
      anon_sym_LPAREN,
    ACTIONS(1746), 1,
      anon_sym_TILDE,
    ACTIONS(1748), 1,
      anon_sym_LF,
    ACTIONS(1750), 1,
      anon_sym_RBRACK,
    STATE(908), 1,
      sym__keywords,
    STATE(978), 1,
      aux_sym_matrix_repeat1,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(832), 2,
      sym_identifier,
      sym_function_call,
    STATE(867), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1752), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41155] = 12,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    ACTIONS(1675), 1,
      anon_sym_COMMA,
    ACTIONS(1677), 1,
      anon_sym_RBRACK,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(892), 2,
      sym_identifier,
      sym_function_call,
    STATE(871), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41203] = 14,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(1281), 1,
      sym__external_identifier,
    ACTIONS(1744), 1,
      anon_sym_LPAREN,
    ACTIONS(1746), 1,
      anon_sym_TILDE,
    ACTIONS(1754), 1,
      anon_sym_LF,
    ACTIONS(1756), 1,
      anon_sym_RBRACK,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(833), 2,
      sym_identifier,
      sym_function_call,
    STATE(865), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1752), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41255] = 12,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    ACTIONS(1675), 1,
      anon_sym_COMMA,
    ACTIONS(1677), 1,
      anon_sym_RBRACK,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(892), 2,
      sym_identifier,
      sym_function_call,
    STATE(864), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41303] = 12,
    ACTIONS(1639), 1,
      anon_sym_LBRACE,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    ACTIONS(1647), 1,
      sym__external_identifier,
    STATE(878), 1,
      sym__keywords,
    STATE(1014), 1,
      sym_identifier,
    STATE(1105), 1,
      sym_property_name,
    STATE(1151), 1,
      sym_validation_functions,
    STATE(1229), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(944), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1758), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1645), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41351] = 12,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    ACTIONS(1760), 1,
      anon_sym_COMMA,
    ACTIONS(1762), 1,
      anon_sym_RBRACK,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(892), 2,
      sym_identifier,
      sym_function_call,
    STATE(864), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41399] = 11,
    ACTIONS(1461), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1463), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1766), 1,
      anon_sym_end,
    ACTIONS(1768), 1,
      anon_sym_case,
    ACTIONS(1770), 1,
      anon_sym_otherwise,
    STATE(1775), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1017), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    STATE(1240), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1764), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [41444] = 15,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(308), 1,
      anon_sym_function,
    ACTIONS(1665), 1,
      sym__external_identifier,
    ACTIONS(1772), 1,
      anon_sym_end,
    ACTIONS(1774), 1,
      anon_sym_arguments,
    STATE(503), 1,
      sym__keywords,
    STATE(874), 1,
      aux_sym_methods_repeat1,
    STATE(1253), 1,
      sym_function_output,
    STATE(1272), 1,
      sym__function_definition_with_end,
    STATE(1278), 1,
      sym_function_signature,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1659), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1776), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(1712), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(896), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41497] = 15,
    ACTIONS(1778), 1,
      anon_sym_end,
    ACTIONS(1780), 1,
      anon_sym_arguments,
    ACTIONS(1783), 1,
      anon_sym_function,
    ACTIONS(1795), 1,
      sym__multioutput_variable_start,
    ACTIONS(1798), 1,
      sym__external_identifier,
    STATE(503), 1,
      sym__keywords,
    STATE(874), 1,
      aux_sym_methods_repeat1,
    STATE(1253), 1,
      sym_function_output,
    STATE(1272), 1,
      sym__function_definition_with_end,
    STATE(1278), 1,
      sym_function_signature,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1786), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(1792), 2,
      anon_sym_get,
      anon_sym_set,
    STATE(1712), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(1789), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41550] = 4,
    ACTIONS(1801), 1,
      anon_sym_DOT,
    STATE(875), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 18,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [41581] = 15,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(308), 1,
      anon_sym_function,
    ACTIONS(1665), 1,
      sym__external_identifier,
    ACTIONS(1774), 1,
      anon_sym_arguments,
    ACTIONS(1804), 1,
      anon_sym_end,
    STATE(503), 1,
      sym__keywords,
    STATE(874), 1,
      aux_sym_methods_repeat1,
    STATE(1253), 1,
      sym_function_output,
    STATE(1272), 1,
      sym__function_definition_with_end,
    STATE(1278), 1,
      sym_function_signature,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1659), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1776), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(1712), 2,
      sym_identifier,
      sym_multioutput_variable,
    ACTIONS(896), 4,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41634] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1778), 2,
      sym__multioutput_variable_start,
      sym__external_identifier,
    STATE(882), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1655), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1806), 11,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41666] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(695), 19,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [41692] = 11,
    ACTIONS(1808), 1,
      anon_sym_LPAREN,
    ACTIONS(1811), 1,
      anon_sym_COMMA,
    ACTIONS(1814), 1,
      anon_sym_RBRACE,
    ACTIONS(1816), 1,
      anon_sym_end,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(879), 2,
      sym_field_expression,
      aux_sym_validation_functions_repeat1,
    STATE(933), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1819), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41736] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1824), 2,
      sym__multioutput_variable_start,
      sym__external_identifier,
    STATE(882), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1655), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1822), 11,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41768] = 11,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    ACTIONS(1677), 1,
      anon_sym_RBRACK,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(901), 2,
      sym_identifier,
      sym_function_call,
    STATE(1008), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41812] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      sym__multioutput_variable_start,
      sym__external_identifier,
    STATE(882), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1826), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1055), 11,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41844] = 11,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    ACTIONS(1762), 1,
      anon_sym_RBRACK,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(901), 2,
      sym_identifier,
      sym_function_call,
    STATE(1008), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41888] = 11,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1705), 1,
      anon_sym_COMMA,
    ACTIONS(1707), 1,
      anon_sym_RBRACE,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(886), 2,
      sym_field_expression,
      aux_sym_validation_functions_repeat1,
    STATE(933), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41932] = 11,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    ACTIONS(1829), 1,
      anon_sym_RBRACK,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(901), 2,
      sym_identifier,
      sym_function_call,
    STATE(1008), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [41976] = 11,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1705), 1,
      anon_sym_COMMA,
    ACTIONS(1831), 1,
      anon_sym_RBRACE,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(879), 2,
      sym_field_expression,
      aux_sym_validation_functions_repeat1,
    STATE(933), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42020] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 19,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [42046] = 9,
    ACTIONS(43), 1,
      sym__external_identifier,
    ACTIONS(1835), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1394), 1,
      sym_identifier,
    STATE(1395), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(900), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1833), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42085] = 4,
    ACTIONS(1837), 1,
      anon_sym_DOT,
    STATE(891), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(645), 16,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42114] = 5,
    ACTIONS(651), 1,
      sym__external_identifier,
    ACTIONS(1839), 1,
      anon_sym_DOT,
    STATE(893), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(647), 15,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [42145] = 4,
    ACTIONS(1841), 1,
      anon_sym_DOT,
    STATE(894), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(651), 16,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42174] = 8,
    ACTIONS(1669), 1,
      anon_sym_DOT,
    ACTIONS(1673), 1,
      anon_sym_AT,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1843), 1,
      anon_sym_LPAREN,
    STATE(904), 1,
      sym__args,
    STATE(948), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1845), 12,
      sym__external_identifier,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42211] = 5,
    ACTIONS(629), 1,
      sym__external_identifier,
    ACTIONS(1847), 1,
      anon_sym_DOT,
    STATE(893), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 15,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [42242] = 4,
    ACTIONS(1850), 1,
      anon_sym_DOT,
    STATE(894), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(629), 16,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42271] = 9,
    ACTIONS(43), 1,
      sym__external_identifier,
    ACTIONS(1855), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1394), 1,
      sym_identifier,
    STATE(1395), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(888), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1853), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42310] = 6,
    ACTIONS(1673), 1,
      anon_sym_AT,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1843), 1,
      anon_sym_LPAREN,
    STATE(904), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(614), 14,
      sym__external_identifier,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42343] = 5,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1843), 1,
      anon_sym_LPAREN,
    STATE(930), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 15,
      sym__external_identifier,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42374] = 3,
    ACTIONS(697), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(695), 17,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DOT_QMARK,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [42401] = 9,
    ACTIONS(43), 1,
      sym__external_identifier,
    ACTIONS(1857), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1394), 1,
      sym_identifier,
    STATE(1395), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(900), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1833), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42440] = 9,
    ACTIONS(1862), 1,
      anon_sym_end,
    ACTIONS(1867), 1,
      sym__external_identifier,
    STATE(412), 1,
      sym__keywords,
    STATE(1394), 1,
      sym_identifier,
    STATE(1395), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(900), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1859), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1864), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42479] = 8,
    ACTIONS(1669), 1,
      anon_sym_DOT,
    ACTIONS(1673), 1,
      anon_sym_AT,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1843), 1,
      anon_sym_LPAREN,
    STATE(904), 1,
      sym__args,
    STATE(948), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1736), 12,
      sym__external_identifier,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42516] = 10,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    ACTIONS(1671), 1,
      anon_sym_TILDE,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(901), 2,
      sym_identifier,
      sym_function_call,
    STATE(1008), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42557] = 9,
    ACTIONS(43), 1,
      sym__external_identifier,
    ACTIONS(1835), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1394), 1,
      sym_identifier,
    STATE(1395), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(899), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1870), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42596] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(675), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42620] = 9,
    ACTIONS(1872), 1,
      anon_sym_TILDE,
    ACTIONS(1874), 1,
      anon_sym_end,
    STATE(812), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    STATE(1333), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(907), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1719), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42658] = 8,
    ACTIONS(1669), 1,
      anon_sym_DOT,
    ACTIONS(1673), 1,
      anon_sym_AT,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1843), 1,
      anon_sym_LPAREN,
    STATE(904), 1,
      sym__args,
    STATE(948), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1814), 11,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42694] = 9,
    ACTIONS(1876), 1,
      anon_sym_TILDE,
    ACTIONS(1879), 1,
      anon_sym_end,
    STATE(812), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    STATE(1333), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(907), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1881), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42732] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(697), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42756] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(629), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42780] = 11,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(975), 1,
      sym_function_output,
    STATE(1159), 1,
      sym_identifier,
    STATE(1183), 1,
      sym_end_keyword,
    STATE(1712), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1886), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(43), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42822] = 8,
    ACTIONS(43), 1,
      sym__external_identifier,
    ACTIONS(1890), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1387), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(913), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1888), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42858] = 8,
    ACTIONS(43), 1,
      sym__external_identifier,
    ACTIONS(1892), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1387), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(913), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1888), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42894] = 8,
    ACTIONS(1897), 1,
      anon_sym_end,
    ACTIONS(1902), 1,
      sym__external_identifier,
    STATE(412), 1,
      sym__keywords,
    STATE(1387), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(913), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1894), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1899), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42930] = 8,
    ACTIONS(43), 1,
      sym__external_identifier,
    ACTIONS(1890), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1387), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(912), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1905), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [42966] = 11,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(977), 1,
      sym_function_output,
    STATE(1150), 1,
      sym_identifier,
    STATE(1219), 1,
      sym_end_keyword,
    STATE(1712), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1907), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(43), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43008] = 9,
    ACTIONS(1872), 1,
      anon_sym_TILDE,
    ACTIONS(1909), 1,
      anon_sym_end,
    STATE(812), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    STATE(1333), 1,
      sym_class_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(907), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1719), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43046] = 3,
    ACTIONS(629), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 16,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [43072] = 4,
    ACTIONS(1911), 1,
      anon_sym_DOT,
    STATE(875), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(631), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [43100] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(663), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43124] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(667), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43148] = 8,
    ACTIONS(43), 1,
      sym__external_identifier,
    ACTIONS(1915), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1387), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(911), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1913), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43184] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1388), 2,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(671), 15,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43210] = 4,
    ACTIONS(1911), 1,
      anon_sym_DOT,
    STATE(918), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [43238] = 4,
    ACTIONS(1911), 1,
      anon_sym_DOT,
    STATE(925), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(657), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [43266] = 4,
    ACTIONS(1911), 1,
      anon_sym_DOT,
    STATE(875), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(653), 15,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [43294] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(679), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43318] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(705), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43342] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(701), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43366] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43390] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43414] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(709), 17,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43438] = 11,
    ACTIONS(63), 1,
      sym__multioutput_variable_start,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(974), 1,
      sym_function_output,
    STATE(1157), 1,
      sym_identifier,
    STATE(1198), 1,
      sym_end_keyword,
    STATE(1712), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1917), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(43), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43480] = 8,
    ACTIONS(1669), 1,
      anon_sym_DOT,
    ACTIONS(1673), 1,
      anon_sym_AT,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1843), 1,
      anon_sym_LPAREN,
    STATE(904), 1,
      sym__args,
    STATE(948), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1919), 11,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43516] = 5,
    ACTIONS(1921), 1,
      anon_sym_DOT,
    STATE(934), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(629), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [43545] = 8,
    ACTIONS(1872), 1,
      anon_sym_TILDE,
    ACTIONS(1924), 1,
      anon_sym_end,
    STATE(825), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(946), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1719), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43580] = 4,
    ACTIONS(1926), 1,
      anon_sym_DOT,
    STATE(936), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(610), 14,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43607] = 5,
    ACTIONS(1879), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1929), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43636] = 5,
    ACTIONS(1933), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1931), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43665] = 8,
    ACTIONS(1872), 1,
      anon_sym_TILDE,
    ACTIONS(1935), 1,
      anon_sym_end,
    STATE(825), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(946), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1719), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43700] = 5,
    ACTIONS(1939), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1937), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43729] = 3,
    ACTIONS(922), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(920), 15,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [43754] = 9,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    STATE(884), 1,
      sym_field_expression,
    STATE(908), 1,
      sym__keywords,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(854), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43791] = 5,
    ACTIONS(1053), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1941), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1055), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43820] = 5,
    ACTIONS(1946), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1944), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43849] = 5,
    ACTIONS(1950), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1948), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43878] = 8,
    ACTIONS(1952), 1,
      anon_sym_TILDE,
    ACTIONS(1955), 1,
      anon_sym_end,
    STATE(825), 1,
      sym_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(856), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(946), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1957), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43913] = 3,
    ACTIONS(705), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(703), 15,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [43938] = 4,
    ACTIONS(1669), 1,
      anon_sym_DOT,
    STATE(936), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(618), 14,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [43965] = 3,
    ACTIONS(701), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(699), 15,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [43990] = 7,
    ACTIONS(43), 1,
      sym__external_identifier,
    STATE(412), 1,
      sym__keywords,
    STATE(1301), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(18), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1960), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(105), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44023] = 5,
    ACTIONS(1964), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(943), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1962), 9,
      anon_sym_TILDE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44052] = 9,
    ACTIONS(29), 1,
      anon_sym_end,
    ACTIONS(1315), 1,
      anon_sym_LPAREN,
    STATE(908), 1,
      sym__keywords,
    STATE(1024), 1,
      sym_field_expression,
    STATE(1474), 1,
      sym_indirect_access,
    STATE(1475), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(906), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44089] = 5,
    ACTIONS(1966), 1,
      anon_sym_DOT,
    STATE(959), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(659), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(657), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [44117] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(671), 15,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44139] = 5,
    ACTIONS(1966), 1,
      anon_sym_DOT,
    STATE(965), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(635), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(631), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [44167] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(695), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(697), 13,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [44191] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(614), 15,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44213] = 5,
    ACTIONS(1966), 1,
      anon_sym_DOT,
    STATE(955), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(639), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(637), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [44241] = 5,
    ACTIONS(1966), 1,
      anon_sym_DOT,
    STATE(965), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(655), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(653), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [44269] = 6,
    ACTIONS(1719), 1,
      sym__external_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(964), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1968), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1717), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44299] = 6,
    ACTIONS(1719), 1,
      sym__external_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(963), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1970), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1717), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44329] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(629), 13,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [44353] = 6,
    ACTIONS(1719), 1,
      sym__external_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(966), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1972), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1717), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44383] = 6,
    ACTIONS(1719), 1,
      sym__external_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(966), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1974), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1717), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44413] = 5,
    ACTIONS(1976), 1,
      anon_sym_DOT,
    STATE(965), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(629), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(624), 11,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [44441] = 6,
    ACTIONS(1984), 1,
      sym__external_identifier,
    STATE(898), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(966), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1979), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1981), 7,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44471] = 7,
    ACTIONS(1987), 1,
      anon_sym_RPAREN,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    STATE(503), 1,
      sym__keywords,
    STATE(1703), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44502] = 6,
    ACTIONS(1997), 1,
      anon_sym_PIPE,
    ACTIONS(1999), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1995), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1991), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1993), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44531] = 6,
    ACTIONS(1461), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1463), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(256), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2001), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [44560] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(629), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(624), 12,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [44583] = 6,
    ACTIONS(2003), 1,
      anon_sym_PIPE,
    ACTIONS(2005), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1592), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1594), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1590), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44612] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(697), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(695), 12,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [44635] = 3,
    ACTIONS(2009), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2007), 13,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [44658] = 8,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1203), 1,
      sym_identifier,
    STATE(1216), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(2011), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(43), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44691] = 8,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1193), 1,
      sym_end_keyword,
    STATE(1211), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(2013), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(43), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44724] = 8,
    ACTIONS(1620), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1622), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2017), 1,
      aux_sym_matrix_token1,
    ACTIONS(2019), 1,
      sym__entry_delimiter,
    STATE(1235), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2015), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1618), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [44757] = 8,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1199), 1,
      sym_identifier,
    STATE(1204), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(105), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(2021), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(43), 6,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44790] = 5,
    ACTIONS(1629), 1,
      sym__external_identifier,
    ACTIONS(2023), 1,
      anon_sym_LF,
    STATE(978), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1624), 11,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44817] = 6,
    ACTIONS(1461), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1463), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(280), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2026), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [44846] = 6,
    ACTIONS(2028), 1,
      anon_sym_PIPE,
    ACTIONS(2030), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1603), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1609), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1601), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44875] = 6,
    ACTIONS(1461), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1463), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(10), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2032), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [44904] = 6,
    ACTIONS(2040), 1,
      anon_sym_PIPE,
    ACTIONS(2042), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2038), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(2034), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(2036), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [44933] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2044), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1719), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44964] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2046), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1715), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [44995] = 3,
    ACTIONS(2050), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2048), 13,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [45018] = 6,
    ACTIONS(2058), 1,
      anon_sym_PIPE,
    ACTIONS(2060), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2056), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(2052), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(2054), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [45047] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2062), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1705), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45078] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2064), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1726), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45109] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2066), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1737), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45140] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2068), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1709), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45171] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2070), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1746), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45202] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2072), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1750), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45233] = 6,
    ACTIONS(2080), 1,
      anon_sym_PIPE,
    ACTIONS(2082), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2078), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(2074), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(2076), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [45262] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2084), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1774), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45293] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2086), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1767), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45324] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2088), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1769), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45355] = 7,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    ACTIONS(2090), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(1771), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1649), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45386] = 8,
    ACTIONS(1043), 1,
      aux_sym_matrix_token1,
    ACTIONS(1620), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1622), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2092), 1,
      sym__entry_delimiter,
    STATE(1237), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1041), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1618), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45419] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(922), 13,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45439] = 5,
    ACTIONS(2094), 1,
      anon_sym_DOT,
    STATE(1001), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(657), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(659), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [45465] = 5,
    ACTIONS(2094), 1,
      anon_sym_DOT,
    STATE(934), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(653), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(655), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [45491] = 6,
    ACTIONS(1620), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1622), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2098), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(2096), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1618), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45519] = 3,
    ACTIONS(2100), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1897), 12,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [45541] = 5,
    ACTIONS(2094), 1,
      anon_sym_DOT,
    STATE(934), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(631), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(635), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [45567] = 8,
    ACTIONS(1519), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2102), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2106), 1,
      aux_sym_matrix_token1,
    ACTIONS(2108), 1,
      sym__entry_delimiter,
    STATE(1364), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2104), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1485), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45599] = 5,
    ACTIONS(2094), 1,
      anon_sym_DOT,
    STATE(1004), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(639), 9,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [45625] = 3,
    ACTIONS(2110), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1862), 12,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
      anon_sym_CR,
  [45647] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1736), 13,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45667] = 8,
    ACTIONS(1167), 1,
      aux_sym_matrix_token1,
    ACTIONS(1519), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2102), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2112), 1,
      sym__entry_delimiter,
    STATE(1350), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1165), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(1485), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45699] = 6,
    ACTIONS(2114), 1,
      anon_sym_LPAREN,
    STATE(412), 1,
      sym__keywords,
    STATE(1106), 1,
      sym_attributes,
    STATE(1167), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45726] = 6,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1203), 1,
      sym_identifier,
    STATE(1216), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45753] = 6,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1180), 1,
      sym_identifier,
    STATE(1181), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45780] = 5,
    ACTIONS(1461), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1463), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2116), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45805] = 9,
    ACTIONS(1639), 1,
      anon_sym_LBRACE,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    ACTIONS(2118), 1,
      anon_sym_DOT,
    STATE(1135), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(1158), 1,
      sym_validation_functions,
    STATE(1312), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(951), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2120), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [45838] = 9,
    ACTIONS(1639), 1,
      anon_sym_LBRACE,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    ACTIONS(2118), 1,
      anon_sym_DOT,
    STATE(1135), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(1151), 1,
      sym_validation_functions,
    STATE(1229), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(944), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1758), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [45871] = 5,
    ACTIONS(1461), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1463), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2122), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
    ACTIONS(1459), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [45896] = 8,
    ACTIONS(1768), 1,
      anon_sym_case,
    ACTIONS(1770), 1,
      anon_sym_otherwise,
    ACTIONS(2126), 1,
      anon_sym_end,
    STATE(1768), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1125), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    STATE(1273), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(2124), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [45927] = 6,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1188), 1,
      sym_identifier,
    STATE(1192), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45954] = 6,
    ACTIONS(2128), 1,
      anon_sym_LPAREN,
    STATE(11), 1,
      sym_iterator,
    STATE(503), 1,
      sym__keywords,
    STATE(1743), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [45981] = 8,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2132), 1,
      anon_sym_COMMA,
    STATE(1531), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2130), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [46012] = 6,
    ACTIONS(2134), 1,
      anon_sym_LPAREN,
    STATE(11), 1,
      sym_iterator,
    STATE(503), 1,
      sym__keywords,
    STATE(1743), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46039] = 5,
    ACTIONS(1989), 1,
      anon_sym_TILDE,
    STATE(503), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1682), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46064] = 8,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2132), 1,
      anon_sym_COMMA,
    STATE(1542), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2136), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [46095] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1814), 12,
      sym__external_identifier,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46114] = 6,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1220), 1,
      sym_end_keyword,
    STATE(1221), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46141] = 6,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1199), 1,
      sym_identifier,
    STATE(1204), 1,
      sym_end_keyword,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46168] = 6,
    ACTIONS(1884), 1,
      anon_sym_end,
    STATE(412), 1,
      sym__keywords,
    STATE(1193), 1,
      sym_end_keyword,
    STATE(1211), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46195] = 6,
    ACTIONS(1519), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2102), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2138), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(2140), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1485), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [46222] = 8,
    ACTIONS(2142), 1,
      anon_sym_SEMI,
    ACTIONS(2144), 1,
      anon_sym_end,
    ACTIONS(2146), 1,
      anon_sym_properties,
    ACTIONS(2148), 1,
      anon_sym_methods,
    ACTIONS(2150), 1,
      anon_sym_events,
    ACTIONS(2152), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1034), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [46252] = 8,
    ACTIONS(2146), 1,
      anon_sym_properties,
    ACTIONS(2148), 1,
      anon_sym_methods,
    ACTIONS(2150), 1,
      anon_sym_events,
    ACTIONS(2152), 1,
      anon_sym_enumeration,
    ACTIONS(2154), 1,
      anon_sym_SEMI,
    ACTIONS(2156), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1060), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [46282] = 5,
    STATE(889), 1,
      sym_identifier,
    STATE(897), 1,
      sym_property_name,
    STATE(908), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46306] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2158), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [46332] = 8,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2160), 1,
      anon_sym_RPAREN,
    ACTIONS(2162), 1,
      anon_sym_COMMA,
    STATE(1644), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [46362] = 8,
    ACTIONS(2146), 1,
      anon_sym_properties,
    ACTIONS(2148), 1,
      anon_sym_methods,
    ACTIONS(2150), 1,
      anon_sym_events,
    ACTIONS(2152), 1,
      anon_sym_enumeration,
    ACTIONS(2164), 1,
      anon_sym_SEMI,
    ACTIONS(2166), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1075), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [46392] = 5,
    STATE(503), 1,
      sym__keywords,
    STATE(1664), 1,
      sym_iterator,
    STATE(1754), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46416] = 5,
    ACTIONS(2168), 1,
      anon_sym_STAR,
    STATE(503), 1,
      sym__keywords,
    STATE(537), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46440] = 5,
    STATE(412), 1,
      sym__keywords,
    STATE(417), 1,
      sym_property_name,
    STATE(423), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46464] = 5,
    ACTIONS(2170), 1,
      anon_sym_STAR,
    STATE(503), 1,
      sym__keywords,
    STATE(537), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46488] = 5,
    STATE(503), 1,
      sym__keywords,
    STATE(1606), 1,
      sym_attribute,
    STATE(1635), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46512] = 5,
    STATE(117), 1,
      sym_property_name,
    STATE(121), 1,
      sym_identifier,
    STATE(135), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46536] = 5,
    ACTIONS(2172), 1,
      anon_sym_STAR,
    STATE(412), 1,
      sym__keywords,
    STATE(431), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46560] = 5,
    STATE(956), 1,
      sym__keywords,
    STATE(1295), 1,
      sym_identifier,
    STATE(1602), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46584] = 5,
    ACTIONS(2176), 1,
      anon_sym_LPAREN,
    STATE(878), 1,
      sym__keywords,
    STATE(924), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1647), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46608] = 5,
    ACTIONS(2168), 1,
      anon_sym_STAR,
    STATE(956), 1,
      sym__keywords,
    STATE(962), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46632] = 5,
    ACTIONS(2178), 1,
      anon_sym_STAR,
    STATE(908), 1,
      sym__keywords,
    STATE(909), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46656] = 5,
    STATE(495), 1,
      sym_identifier,
    STATE(496), 1,
      sym_property_name,
    STATE(503), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46680] = 5,
    STATE(447), 1,
      sym_property_name,
    STATE(452), 1,
      sym_identifier,
    STATE(480), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46704] = 5,
    STATE(956), 1,
      sym__keywords,
    STATE(1295), 1,
      sym_identifier,
    STATE(1641), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46728] = 5,
    ACTIONS(2180), 1,
      anon_sym_LPAREN,
    STATE(953), 1,
      sym_identifier,
    STATE(972), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2182), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46752] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2184), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [46778] = 5,
    ACTIONS(2186), 1,
      anon_sym_STAR,
    STATE(412), 1,
      sym__keywords,
    STATE(431), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46802] = 5,
    STATE(878), 1,
      sym__keywords,
    STATE(1168), 1,
      sym_identifier,
    STATE(1319), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1647), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46826] = 5,
    ACTIONS(2188), 1,
      anon_sym_LPAREN,
    STATE(412), 1,
      sym__keywords,
    STATE(462), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46850] = 5,
    STATE(878), 1,
      sym__keywords,
    STATE(1168), 1,
      sym_identifier,
    STATE(1381), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1647), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46874] = 5,
    ACTIONS(2190), 1,
      anon_sym_STAR,
    STATE(480), 1,
      sym__keywords,
    STATE(482), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46898] = 5,
    ACTIONS(2192), 1,
      anon_sym_STAR,
    STATE(480), 1,
      sym__keywords,
    STATE(482), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46922] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2196), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(2194), 9,
      sym__external_identifier,
      anon_sym_end,
      anon_sym_arguments,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46942] = 5,
    ACTIONS(2198), 1,
      anon_sym_LPAREN,
    STATE(228), 1,
      sym_identifier,
    STATE(230), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2200), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [46966] = 6,
    ACTIONS(1588), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2204), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1584), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2202), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1586), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [46992] = 8,
    ACTIONS(2146), 1,
      anon_sym_properties,
    ACTIONS(2148), 1,
      anon_sym_methods,
    ACTIONS(2150), 1,
      anon_sym_events,
    ACTIONS(2152), 1,
      anon_sym_enumeration,
    ACTIONS(2164), 1,
      anon_sym_SEMI,
    ACTIONS(2206), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1075), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [47022] = 5,
    ACTIONS(2170), 1,
      anon_sym_STAR,
    STATE(956), 1,
      sym__keywords,
    STATE(962), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47046] = 5,
    ACTIONS(2208), 1,
      anon_sym_STAR,
    STATE(135), 1,
      sym__keywords,
    STATE(138), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47070] = 5,
    ACTIONS(2210), 1,
      anon_sym_STAR,
    STATE(135), 1,
      sym__keywords,
    STATE(138), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47094] = 5,
    ACTIONS(2212), 1,
      anon_sym_LPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(604), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47118] = 8,
    ACTIONS(2146), 1,
      anon_sym_properties,
    ACTIONS(2148), 1,
      anon_sym_methods,
    ACTIONS(2150), 1,
      anon_sym_events,
    ACTIONS(2152), 1,
      anon_sym_enumeration,
    ACTIONS(2214), 1,
      anon_sym_SEMI,
    ACTIONS(2216), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1082), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [47148] = 5,
    ACTIONS(2218), 1,
      anon_sym_STAR,
    STATE(898), 1,
      sym__keywords,
    STATE(917), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1719), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47172] = 5,
    ACTIONS(2220), 1,
      anon_sym_STAR,
    STATE(898), 1,
      sym__keywords,
    STATE(917), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1719), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47196] = 5,
    ACTIONS(2222), 1,
      anon_sym_LPAREN,
    STATE(480), 1,
      sym__keywords,
    STATE(534), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47220] = 5,
    STATE(503), 1,
      sym__keywords,
    STATE(1635), 1,
      sym_identifier,
    STATE(1702), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47244] = 5,
    ACTIONS(2224), 1,
      anon_sym_LPAREN,
    STATE(124), 1,
      sym_identifier,
    STATE(135), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47268] = 5,
    STATE(503), 1,
      sym__keywords,
    STATE(1740), 1,
      sym_iterator,
    STATE(1754), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47292] = 5,
    ACTIONS(2226), 1,
      anon_sym_LPAREN,
    STATE(503), 1,
      sym__keywords,
    STATE(604), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47316] = 5,
    ACTIONS(2228), 1,
      anon_sym_STAR,
    STATE(908), 1,
      sym__keywords,
    STATE(909), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47340] = 5,
    ACTIONS(2230), 1,
      anon_sym_LPAREN,
    STATE(480), 1,
      sym__keywords,
    STATE(534), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47364] = 8,
    ACTIONS(2232), 1,
      anon_sym_SEMI,
    ACTIONS(2235), 1,
      anon_sym_end,
    ACTIONS(2237), 1,
      anon_sym_properties,
    ACTIONS(2240), 1,
      anon_sym_methods,
    ACTIONS(2243), 1,
      anon_sym_events,
    ACTIONS(2246), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1075), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [47394] = 5,
    ACTIONS(2249), 1,
      anon_sym_LPAREN,
    STATE(124), 1,
      sym_identifier,
    STATE(135), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47418] = 8,
    ACTIONS(2146), 1,
      anon_sym_properties,
    ACTIONS(2148), 1,
      anon_sym_methods,
    ACTIONS(2150), 1,
      anon_sym_events,
    ACTIONS(2152), 1,
      anon_sym_enumeration,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(2253), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1080), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [47448] = 5,
    STATE(503), 1,
      sym__keywords,
    STATE(1635), 1,
      sym_identifier,
    STATE(1639), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47472] = 5,
    STATE(956), 1,
      sym__keywords,
    STATE(1295), 1,
      sym_identifier,
    STATE(1645), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47496] = 8,
    ACTIONS(2144), 1,
      anon_sym_end,
    ACTIONS(2146), 1,
      anon_sym_properties,
    ACTIONS(2148), 1,
      anon_sym_methods,
    ACTIONS(2150), 1,
      anon_sym_events,
    ACTIONS(2152), 1,
      anon_sym_enumeration,
    ACTIONS(2164), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1075), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [47526] = 5,
    ACTIONS(2255), 1,
      anon_sym_LPAREN,
    STATE(412), 1,
      sym__keywords,
    STATE(462), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47550] = 8,
    ACTIONS(2146), 1,
      anon_sym_properties,
    ACTIONS(2148), 1,
      anon_sym_methods,
    ACTIONS(2150), 1,
      anon_sym_events,
    ACTIONS(2152), 1,
      anon_sym_enumeration,
    ACTIONS(2156), 1,
      anon_sym_end,
    ACTIONS(2164), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1075), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [47580] = 5,
    ACTIONS(2172), 1,
      anon_sym_STAR,
    STATE(878), 1,
      sym__keywords,
    STATE(887), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1647), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47604] = 5,
    ACTIONS(2257), 1,
      anon_sym_LPAREN,
    STATE(956), 1,
      sym__keywords,
    STATE(1000), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47628] = 6,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    STATE(1312), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(951), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2259), 3,
      anon_sym_vector,
      anon_sym_matrix,
      anon_sym_scalar,
    ACTIONS(2120), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [47654] = 5,
    ACTIONS(2186), 1,
      anon_sym_STAR,
    STATE(878), 1,
      sym__keywords,
    STATE(887), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1647), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47678] = 5,
    STATE(956), 1,
      sym__keywords,
    STATE(1295), 1,
      sym_identifier,
    STATE(1620), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47702] = 5,
    STATE(956), 1,
      sym__keywords,
    STATE(1295), 1,
      sym_identifier,
    STATE(1634), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47726] = 5,
    STATE(496), 1,
      sym_property_name,
    STATE(956), 1,
      sym__keywords,
    STATE(1295), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47750] = 4,
    STATE(503), 1,
      sym__keywords,
    STATE(537), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47771] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2261), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47796] = 4,
    STATE(412), 1,
      sym__keywords,
    STATE(476), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47817] = 4,
    STATE(503), 1,
      sym__keywords,
    STATE(1717), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47838] = 4,
    STATE(503), 1,
      sym__keywords,
    STATE(1618), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47859] = 4,
    STATE(878), 1,
      sym__keywords,
    STATE(887), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1647), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47880] = 4,
    STATE(412), 1,
      sym__keywords,
    STATE(431), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47901] = 4,
    STATE(878), 1,
      sym__keywords,
    STATE(923), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1647), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47922] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2263), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47947] = 7,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2265), 1,
      anon_sym_RPAREN,
    ACTIONS(2267), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [47974] = 4,
    STATE(956), 1,
      sym__keywords,
    STATE(1006), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [47995] = 4,
    STATE(956), 1,
      sym__keywords,
    STATE(962), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48016] = 7,
    ACTIONS(1639), 1,
      anon_sym_LBRACE,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    STATE(1151), 1,
      sym_validation_functions,
    STATE(1229), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(944), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1758), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [48043] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1066), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48068] = 4,
    STATE(503), 1,
      sym__keywords,
    STATE(1687), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48089] = 7,
    ACTIONS(1639), 1,
      anon_sym_LBRACE,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    STATE(1158), 1,
      sym_validation_functions,
    STATE(1312), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(951), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2120), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [48116] = 4,
    STATE(412), 1,
      sym__keywords,
    STATE(1186), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48137] = 4,
    STATE(958), 1,
      sym_identifier,
    STATE(972), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2182), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48158] = 4,
    STATE(970), 1,
      sym_identifier,
    STATE(972), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2182), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48179] = 4,
    STATE(227), 1,
      sym_identifier,
    STATE(230), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2200), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48200] = 4,
    STATE(503), 1,
      sym__keywords,
    STATE(1722), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48221] = 4,
    STATE(230), 1,
      sym__keywords,
    STATE(231), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2200), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48242] = 4,
    STATE(412), 1,
      sym__keywords,
    STATE(1085), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(43), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48263] = 4,
    STATE(503), 1,
      sym__keywords,
    STATE(603), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(896), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48284] = 4,
    STATE(480), 1,
      sym__keywords,
    STATE(533), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48305] = 4,
    STATE(480), 1,
      sym__keywords,
    STATE(482), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(860), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48326] = 4,
    STATE(120), 1,
      sym_identifier,
    STATE(135), 1,
      sym__keywords,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48347] = 4,
    STATE(878), 1,
      sym__keywords,
    STATE(1227), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1647), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48368] = 4,
    STATE(135), 1,
      sym__keywords,
    STATE(138), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1132), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48389] = 4,
    STATE(908), 1,
      sym__keywords,
    STATE(909), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1281), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48410] = 4,
    STATE(898), 1,
      sym__keywords,
    STATE(917), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1719), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [48431] = 6,
    ACTIONS(2269), 1,
      ts_builtin_sym_end,
    ACTIONS(2273), 1,
      anon_sym_SEMI,
    ACTIONS(2275), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2271), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48455] = 6,
    ACTIONS(453), 1,
      ts_builtin_sym_end,
    ACTIONS(2279), 1,
      anon_sym_SEMI,
    ACTIONS(2281), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2277), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48479] = 6,
    ACTIONS(371), 1,
      ts_builtin_sym_end,
    ACTIONS(2285), 1,
      anon_sym_SEMI,
    ACTIONS(2287), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2283), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48503] = 6,
    ACTIONS(459), 1,
      ts_builtin_sym_end,
    ACTIONS(2291), 1,
      anon_sym_SEMI,
    ACTIONS(2293), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2289), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48527] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1125), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1055), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
    ACTIONS(2295), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [48547] = 6,
    ACTIONS(423), 1,
      ts_builtin_sym_end,
    ACTIONS(2300), 1,
      anon_sym_SEMI,
    ACTIONS(2302), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2298), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48571] = 6,
    ACTIONS(395), 1,
      ts_builtin_sym_end,
    ACTIONS(2306), 1,
      anon_sym_SEMI,
    ACTIONS(2308), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2304), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48595] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2310), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48619] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2312), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48643] = 6,
    ACTIONS(1588), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2204), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2314), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1584), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1586), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48667] = 6,
    ACTIONS(2316), 1,
      ts_builtin_sym_end,
    ACTIONS(2320), 1,
      anon_sym_SEMI,
    ACTIONS(2322), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2318), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48691] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2324), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48715] = 6,
    ACTIONS(2326), 1,
      ts_builtin_sym_end,
    ACTIONS(2330), 1,
      anon_sym_SEMI,
    ACTIONS(2332), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2328), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48739] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2334), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48763] = 4,
    ACTIONS(2336), 1,
      anon_sym_DOT,
    STATE(875), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(647), 7,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [48783] = 6,
    ACTIONS(401), 1,
      ts_builtin_sym_end,
    ACTIONS(2340), 1,
      anon_sym_SEMI,
    ACTIONS(2342), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2338), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48807] = 6,
    ACTIONS(407), 1,
      ts_builtin_sym_end,
    ACTIONS(2346), 1,
      anon_sym_SEMI,
    ACTIONS(2348), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2344), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48831] = 6,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2350), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [48855] = 6,
    ACTIONS(377), 1,
      ts_builtin_sym_end,
    ACTIONS(2354), 1,
      anon_sym_SEMI,
    ACTIONS(2356), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2352), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48879] = 6,
    ACTIONS(2358), 1,
      ts_builtin_sym_end,
    ACTIONS(2362), 1,
      anon_sym_SEMI,
    ACTIONS(2364), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2360), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48903] = 6,
    ACTIONS(343), 1,
      ts_builtin_sym_end,
    ACTIONS(2368), 1,
      anon_sym_SEMI,
    ACTIONS(2370), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2366), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48927] = 6,
    ACTIONS(2372), 1,
      ts_builtin_sym_end,
    ACTIONS(2376), 1,
      anon_sym_SEMI,
    ACTIONS(2378), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2374), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48951] = 6,
    ACTIONS(349), 1,
      ts_builtin_sym_end,
    ACTIONS(2382), 1,
      anon_sym_SEMI,
    ACTIONS(2384), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2380), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48975] = 6,
    ACTIONS(355), 1,
      ts_builtin_sym_end,
    ACTIONS(2388), 1,
      anon_sym_SEMI,
    ACTIONS(2390), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2386), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [48999] = 6,
    ACTIONS(1588), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2204), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2392), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1584), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1586), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [49023] = 6,
    ACTIONS(417), 1,
      ts_builtin_sym_end,
    ACTIONS(2396), 1,
      anon_sym_SEMI,
    ACTIONS(2398), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2394), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49047] = 6,
    ACTIONS(2400), 1,
      ts_builtin_sym_end,
    ACTIONS(2404), 1,
      anon_sym_SEMI,
    ACTIONS(2406), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2402), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49071] = 5,
    ACTIONS(1697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1703), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1687), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1689), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [49092] = 5,
    ACTIONS(2410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2412), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2408), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [49113] = 6,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2418), 1,
      anon_sym_EQ,
    STATE(56), 1,
      sym__end_of_line,
    STATE(1368), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2416), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49136] = 5,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    STATE(1312), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(951), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2120), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49157] = 5,
    ACTIONS(2422), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2424), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(726), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2420), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [49178] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2426), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49193] = 5,
    ACTIONS(1588), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2204), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1584), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1586), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [49214] = 5,
    ACTIONS(2428), 1,
      anon_sym_LPAREN,
    STATE(1263), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(838), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2430), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49235] = 5,
    ACTIONS(2434), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2436), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1392), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2432), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [49256] = 6,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2418), 1,
      anon_sym_EQ,
    STATE(84), 1,
      sym__end_of_line,
    STATE(1385), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2438), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49279] = 5,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    STATE(1340), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(945), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2440), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49300] = 6,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2418), 1,
      anon_sym_EQ,
    STATE(33), 1,
      sym__end_of_line,
    STATE(1372), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2442), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49323] = 5,
    ACTIONS(2446), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2448), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1415), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2444), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [49344] = 5,
    ACTIONS(1605), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1607), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1560), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1562), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [49365] = 5,
    ACTIONS(1641), 1,
      anon_sym_EQ,
    STATE(1229), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(944), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1758), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49386] = 5,
    ACTIONS(1233), 1,
      anon_sym_LPAREN,
    STATE(1320), 1,
      sym__argument_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(859), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1237), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49407] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2450), 8,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_properties,
      anon_sym_get,
      anon_sym_set,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [49422] = 5,
    ACTIONS(2428), 1,
      anon_sym_LPAREN,
    STATE(1259), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(863), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2452), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49443] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2454), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49459] = 5,
    ACTIONS(2456), 1,
      anon_sym_LT,
    STATE(1065), 1,
      sym__end_of_line,
    STATE(1403), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2458), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49479] = 4,
    ACTIONS(2118), 1,
      anon_sym_DOT,
    STATE(1135), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(641), 5,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49497] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2460), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49513] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2462), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49529] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2464), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49545] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2466), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49561] = 5,
    ACTIONS(2428), 1,
      anon_sym_LPAREN,
    STATE(921), 1,
      sym__end_of_line,
    STATE(1348), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49581] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2470), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49597] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2472), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49613] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2474), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49629] = 4,
    ACTIONS(2476), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2271), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49647] = 4,
    ACTIONS(2478), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2318), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49665] = 4,
    ACTIONS(2480), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2277), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49683] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(32), 1,
      sym__end_of_line,
    STATE(1361), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2482), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49703] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(67), 1,
      sym__end_of_line,
    STATE(1362), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49723] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2486), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49739] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(34), 1,
      sym__end_of_line,
    STATE(1373), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49759] = 4,
    ACTIONS(2490), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2352), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49777] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2492), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49793] = 5,
    ACTIONS(2456), 1,
      anon_sym_LT,
    STATE(1077), 1,
      sym__end_of_line,
    STATE(1383), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2494), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49813] = 4,
    ACTIONS(2496), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2289), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49831] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(88), 1,
      sym__end_of_line,
    STATE(1401), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2498), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49851] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2500), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49867] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2502), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49883] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2504), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49899] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(94), 1,
      sym__end_of_line,
    STATE(1402), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2506), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49919] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(48), 1,
      sym__end_of_line,
    STATE(1371), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49939] = 4,
    ACTIONS(2510), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2394), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [49957] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2512), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49973] = 5,
    ACTIONS(1235), 1,
      anon_sym_EQ,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(1438), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2514), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [49993] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2516), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50009] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(93), 1,
      sym__end_of_line,
    STATE(1391), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2518), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50029] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(36), 1,
      sym__end_of_line,
    STATE(1367), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2520), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50049] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2522), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50065] = 4,
    ACTIONS(2524), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2380), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50083] = 5,
    ACTIONS(2428), 1,
      anon_sym_LPAREN,
    STATE(895), 1,
      sym__end_of_line,
    STATE(1351), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2526), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50103] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(102), 1,
      sym__end_of_line,
    STATE(1357), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2528), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50123] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(37), 1,
      sym__end_of_line,
    STATE(1369), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2530), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50143] = 4,
    ACTIONS(2532), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2338), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50161] = 4,
    ACTIONS(2534), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2344), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50179] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2536), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50195] = 4,
    ACTIONS(2538), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2386), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50213] = 4,
    ACTIONS(2540), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2374), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50231] = 4,
    ACTIONS(2542), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2360), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50249] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(47), 1,
      sym__end_of_line,
    STATE(1370), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2544), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50269] = 4,
    ACTIONS(2546), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2298), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50287] = 4,
    ACTIONS(2548), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2402), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50305] = 4,
    ACTIONS(2550), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2328), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50323] = 5,
    ACTIONS(695), 1,
      anon_sym_EQ,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(1438), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2514), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50343] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(103), 1,
      sym__end_of_line,
    STATE(1358), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2552), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50363] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2554), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50379] = 4,
    ACTIONS(2556), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2366), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50397] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(71), 1,
      sym__end_of_line,
    STATE(1374), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2558), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50417] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(44), 1,
      sym__end_of_line,
    STATE(1388), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2560), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50437] = 5,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(43), 1,
      sym__end_of_line,
    STATE(1386), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2562), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50457] = 4,
    ACTIONS(2564), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2283), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50475] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2566), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50491] = 4,
    ACTIONS(2568), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
    ACTIONS(2304), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50509] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(944), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(1758), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50524] = 4,
    ACTIONS(2570), 1,
      ts_builtin_sym_end,
    ACTIONS(2574), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2572), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50541] = 4,
    ACTIONS(1911), 1,
      anon_sym_DOT,
    STATE(1321), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2576), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50558] = 5,
    ACTIONS(2358), 1,
      ts_builtin_sym_end,
    ACTIONS(2362), 1,
      anon_sym_SEMI,
    ACTIONS(2364), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2360), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50577] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(951), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2120), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50592] = 5,
    ACTIONS(2570), 1,
      ts_builtin_sym_end,
    ACTIONS(2574), 1,
      anon_sym_function,
    ACTIONS(2578), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2572), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50611] = 5,
    ACTIONS(371), 1,
      ts_builtin_sym_end,
    ACTIONS(2285), 1,
      anon_sym_SEMI,
    ACTIONS(2287), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2283), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50630] = 4,
    ACTIONS(2580), 1,
      ts_builtin_sym_end,
    ACTIONS(2584), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2582), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50647] = 4,
    ACTIONS(371), 1,
      ts_builtin_sym_end,
    ACTIONS(2287), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2283), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50664] = 5,
    ACTIONS(2580), 1,
      ts_builtin_sym_end,
    ACTIONS(2584), 1,
      anon_sym_function,
    ACTIONS(2586), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2582), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50683] = 5,
    ACTIONS(1043), 1,
      aux_sym_matrix_token1,
    ACTIONS(2092), 1,
      sym__entry_delimiter,
    STATE(1241), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1041), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [50702] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2588), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [50715] = 5,
    ACTIONS(1051), 1,
      aux_sym_matrix_token1,
    ACTIONS(2590), 1,
      sym__entry_delimiter,
    STATE(1241), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1049), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [50734] = 4,
    ACTIONS(2400), 1,
      ts_builtin_sym_end,
    ACTIONS(2406), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2402), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50751] = 5,
    ACTIONS(2400), 1,
      ts_builtin_sym_end,
    ACTIONS(2404), 1,
      anon_sym_SEMI,
    ACTIONS(2406), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2402), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50770] = 6,
    ACTIONS(2592), 1,
      anon_sym_end,
    ACTIONS(2594), 1,
      anon_sym_case,
    ACTIONS(2596), 1,
      anon_sym_otherwise,
    STATE(1768), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1366), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [50791] = 5,
    ACTIONS(2098), 1,
      aux_sym_matrix_token1,
    ACTIONS(2598), 1,
      sym__entry_delimiter,
    STATE(1241), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2096), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [50810] = 4,
    ACTIONS(2326), 1,
      ts_builtin_sym_end,
    ACTIONS(2332), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2328), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50827] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2601), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [50840] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2603), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [50853] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2605), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [50866] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2607), 1,
      anon_sym_elseif,
    ACTIONS(2609), 1,
      anon_sym_end,
    STATE(1733), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1365), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [50887] = 4,
    ACTIONS(453), 1,
      ts_builtin_sym_end,
    ACTIONS(2281), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2277), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [50904] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2607), 1,
      anon_sym_elseif,
    ACTIONS(2609), 1,
      anon_sym_end,
    STATE(1733), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1343), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [50925] = 5,
    ACTIONS(343), 1,
      ts_builtin_sym_end,
    ACTIONS(2368), 1,
      anon_sym_SEMI,
    ACTIONS(2370), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2366), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50944] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2607), 1,
      anon_sym_elseif,
    ACTIONS(2611), 1,
      anon_sym_end,
    STATE(1730), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1246), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [50965] = 5,
    ACTIONS(2326), 1,
      ts_builtin_sym_end,
    ACTIONS(2330), 1,
      anon_sym_SEMI,
    ACTIONS(2332), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2328), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [50984] = 4,
    ACTIONS(2613), 1,
      anon_sym_AMP,
    STATE(1335), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2615), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51001] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2617), 2,
      sym__external_identifier,
      anon_sym_arguments,
    ACTIONS(2619), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    ACTIONS(2621), 2,
      anon_sym_get,
      anon_sym_set,
  [51018] = 4,
    ACTIONS(2623), 1,
      ts_builtin_sym_end,
    ACTIONS(2627), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2625), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51035] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2629), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [51048] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2631), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [51061] = 4,
    ACTIONS(2633), 1,
      anon_sym_DOT,
    STATE(934), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(651), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51078] = 4,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(1582), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2635), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51095] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(862), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2637), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51110] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2639), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [51123] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2641), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [51136] = 6,
    ACTIONS(2646), 1,
      aux_sym_matrix_token1,
    ACTIONS(2649), 1,
      sym__entry_delimiter,
    STATE(1235), 1,
      aux_sym_row_repeat1,
    STATE(1364), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2643), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [51157] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(826), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2651), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51172] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(254), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2653), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51187] = 4,
    ACTIONS(2655), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(377), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51204] = 4,
    ACTIONS(2659), 1,
      sym_command_argument,
    STATE(1313), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2657), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51221] = 4,
    ACTIONS(2661), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(355), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51238] = 4,
    ACTIONS(2663), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(401), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51255] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2665), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [51268] = 4,
    ACTIONS(2667), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(407), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51285] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2669), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [51298] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(880), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2671), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51313] = 6,
    ACTIONS(2594), 1,
      anon_sym_case,
    ACTIONS(2596), 1,
      anon_sym_otherwise,
    ACTIONS(2673), 1,
      anon_sym_end,
    STATE(1736), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1366), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [51334] = 4,
    ACTIONS(2675), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51351] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2607), 1,
      anon_sym_elseif,
    ACTIONS(2611), 1,
      anon_sym_end,
    STATE(1730), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1365), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [51372] = 4,
    ACTIONS(2677), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2372), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51389] = 5,
    ACTIONS(423), 1,
      ts_builtin_sym_end,
    ACTIONS(2300), 1,
      anon_sym_SEMI,
    ACTIONS(2302), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2298), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51408] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(877), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2679), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51423] = 4,
    ACTIONS(2681), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(417), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51440] = 5,
    ACTIONS(401), 1,
      ts_builtin_sym_end,
    ACTIONS(2340), 1,
      anon_sym_SEMI,
    ACTIONS(2342), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2338), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51459] = 5,
    ACTIONS(2017), 1,
      aux_sym_matrix_token1,
    ACTIONS(2019), 1,
      sym__entry_delimiter,
    STATE(1235), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2015), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [51478] = 4,
    ACTIONS(2683), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(371), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51495] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(256), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2001), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51510] = 4,
    ACTIONS(2685), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2269), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51527] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(280), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2026), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51542] = 5,
    ACTIONS(894), 1,
      anon_sym_COLON,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(1646), 2,
      sym_spread_operator,
      sym_number,
  [51561] = 4,
    ACTIONS(2358), 1,
      ts_builtin_sym_end,
    ACTIONS(2364), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2360), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51578] = 4,
    ACTIONS(401), 1,
      ts_builtin_sym_end,
    ACTIONS(2342), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2338), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51595] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2687), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [51608] = 4,
    ACTIONS(2689), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(423), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51625] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(290), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2691), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51640] = 5,
    ACTIONS(349), 1,
      ts_builtin_sym_end,
    ACTIONS(2382), 1,
      anon_sym_SEMI,
    ACTIONS(2384), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2380), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51659] = 4,
    ACTIONS(2693), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(453), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51676] = 5,
    ACTIONS(407), 1,
      ts_builtin_sym_end,
    ACTIONS(2346), 1,
      anon_sym_SEMI,
    ACTIONS(2348), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2344), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51695] = 4,
    ACTIONS(2695), 1,
      anon_sym_DOT,
    STATE(1257), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(645), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51712] = 4,
    ACTIONS(407), 1,
      ts_builtin_sym_end,
    ACTIONS(2348), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2344), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51729] = 4,
    ACTIONS(2697), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2358), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51746] = 4,
    ACTIONS(2699), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(343), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51763] = 4,
    ACTIONS(2701), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(459), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [51780] = 4,
    ACTIONS(2703), 1,
      ts_builtin_sym_end,
    ACTIONS(2707), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2705), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51797] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(20), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2709), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51812] = 4,
    ACTIONS(2711), 1,
      ts_builtin_sym_end,
    ACTIONS(2715), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51829] = 4,
    ACTIONS(2372), 1,
      ts_builtin_sym_end,
    ACTIONS(2378), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2374), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51846] = 4,
    ACTIONS(2717), 1,
      ts_builtin_sym_end,
    ACTIONS(2721), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2719), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51863] = 5,
    ACTIONS(2372), 1,
      ts_builtin_sym_end,
    ACTIONS(2376), 1,
      anon_sym_SEMI,
    ACTIONS(2378), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2374), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51882] = 4,
    ACTIONS(2723), 1,
      ts_builtin_sym_end,
    ACTIONS(2727), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2725), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51899] = 4,
    ACTIONS(2731), 1,
      sym_command_argument,
    STATE(1266), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2729), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51916] = 4,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    STATE(1515), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2733), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [51933] = 5,
    ACTIONS(894), 1,
      anon_sym_COLON,
    ACTIONS(898), 1,
      aux_sym_number_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(900), 2,
      aux_sym_number_token2,
      aux_sym_number_token3,
    STATE(1662), 2,
      sym_spread_operator,
      sym_number,
  [51952] = 5,
    ACTIONS(355), 1,
      ts_builtin_sym_end,
    ACTIONS(2388), 1,
      anon_sym_SEMI,
    ACTIONS(2390), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2386), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51971] = 5,
    ACTIONS(2723), 1,
      ts_builtin_sym_end,
    ACTIONS(2727), 1,
      anon_sym_function,
    ACTIONS(2735), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2725), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [51990] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(945), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2440), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52005] = 4,
    ACTIONS(2739), 1,
      sym_command_argument,
    STATE(1313), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2737), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52022] = 4,
    ACTIONS(355), 1,
      ts_builtin_sym_end,
    ACTIONS(2390), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2386), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52039] = 5,
    ACTIONS(395), 1,
      ts_builtin_sym_end,
    ACTIONS(2306), 1,
      anon_sym_SEMI,
    ACTIONS(2308), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2304), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52058] = 5,
    ACTIONS(459), 1,
      ts_builtin_sym_end,
    ACTIONS(2291), 1,
      anon_sym_SEMI,
    ACTIONS(2293), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52077] = 4,
    ACTIONS(2742), 1,
      ts_builtin_sym_end,
    ACTIONS(2746), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2744), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52094] = 4,
    ACTIONS(2269), 1,
      ts_builtin_sym_end,
    ACTIONS(2275), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2271), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52111] = 4,
    ACTIONS(2613), 1,
      anon_sym_AMP,
    STATE(1252), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2748), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52128] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(861), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2750), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52143] = 4,
    ACTIONS(1911), 1,
      anon_sym_DOT,
    STATE(875), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2752), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52160] = 4,
    ACTIONS(2754), 1,
      ts_builtin_sym_end,
    ACTIONS(2758), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2756), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52177] = 5,
    ACTIONS(1043), 1,
      aux_sym_matrix_token1,
    ACTIONS(2092), 1,
      sym__entry_delimiter,
    STATE(1237), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1041), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [52196] = 5,
    ACTIONS(2754), 1,
      ts_builtin_sym_end,
    ACTIONS(2758), 1,
      anon_sym_function,
    ACTIONS(2760), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2756), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52215] = 4,
    ACTIONS(2762), 1,
      ts_builtin_sym_end,
    ACTIONS(2766), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2764), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52232] = 4,
    ACTIONS(459), 1,
      ts_builtin_sym_end,
    ACTIONS(2293), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52249] = 5,
    ACTIONS(2762), 1,
      ts_builtin_sym_end,
    ACTIONS(2766), 1,
      anon_sym_function,
    ACTIONS(2768), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2764), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52268] = 4,
    ACTIONS(2770), 1,
      ts_builtin_sym_end,
    ACTIONS(2774), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2772), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52285] = 5,
    ACTIONS(2770), 1,
      ts_builtin_sym_end,
    ACTIONS(2774), 1,
      anon_sym_function,
    ACTIONS(2776), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2772), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52304] = 5,
    ACTIONS(377), 1,
      ts_builtin_sym_end,
    ACTIONS(2354), 1,
      anon_sym_SEMI,
    ACTIONS(2356), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2352), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52323] = 4,
    ACTIONS(2778), 1,
      ts_builtin_sym_end,
    ACTIONS(2782), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2780), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52340] = 5,
    ACTIONS(2269), 1,
      ts_builtin_sym_end,
    ACTIONS(2273), 1,
      anon_sym_SEMI,
    ACTIONS(2275), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2271), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52359] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(937), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2784), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52374] = 4,
    ACTIONS(2786), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2400), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [52391] = 4,
    ACTIONS(2788), 1,
      anon_sym_AMP,
    STATE(1335), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2791), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52408] = 4,
    ACTIONS(2316), 1,
      ts_builtin_sym_end,
    ACTIONS(2322), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2318), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52425] = 5,
    ACTIONS(453), 1,
      ts_builtin_sym_end,
    ACTIONS(2279), 1,
      anon_sym_SEMI,
    ACTIONS(2281), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2277), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52444] = 4,
    ACTIONS(2793), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [52461] = 5,
    ACTIONS(2316), 1,
      ts_builtin_sym_end,
    ACTIONS(2320), 1,
      anon_sym_SEMI,
    ACTIONS(2322), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2318), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52480] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(938), 2,
      sym__end_of_line,
      aux_sym__block_repeat1,
    ACTIONS(2795), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52495] = 5,
    ACTIONS(417), 1,
      ts_builtin_sym_end,
    ACTIONS(2396), 1,
      anon_sym_SEMI,
    ACTIONS(2398), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2394), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [52514] = 4,
    ACTIONS(2797), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(349), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [52531] = 6,
    ACTIONS(127), 1,
      anon_sym_else,
    ACTIONS(2607), 1,
      anon_sym_elseif,
    ACTIONS(2799), 1,
      anon_sym_end,
    STATE(1756), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1365), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [52552] = 6,
    ACTIONS(927), 1,
      aux_sym_matrix_token1,
    ACTIONS(2801), 1,
      sym__entry_delimiter,
    STATE(1237), 1,
      aux_sym_row_repeat1,
    STATE(1350), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(924), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [52573] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2803), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [52586] = 4,
    ACTIONS(2805), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2316), 2,
      ts_builtin_sym_end,
      anon_sym_function,
    ACTIONS(1388), 3,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
  [52603] = 4,
    ACTIONS(2807), 1,
      sym__single_quote_string_end,
    STATE(1384), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2809), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [52619] = 3,
    STATE(914), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2811), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52633] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2813), 5,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_CR,
  [52645] = 5,
    ACTIONS(1173), 1,
      aux_sym_matrix_token1,
    ACTIONS(2815), 1,
      sym__entry_delimiter,
    STATE(1352), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1171), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [52663] = 3,
    STATE(903), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2817), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52677] = 5,
    ACTIONS(2140), 1,
      aux_sym_matrix_token1,
    ACTIONS(2819), 1,
      sym__entry_delimiter,
    STATE(1352), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2138), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [52695] = 4,
    ACTIONS(2822), 1,
      sym__double_quote_string_end,
    STATE(1363), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2824), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [52711] = 5,
    ACTIONS(2106), 1,
      aux_sym_matrix_token1,
    ACTIONS(2108), 1,
      sym__entry_delimiter,
    STATE(1364), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2104), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [52729] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1239), 5,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52741] = 4,
    ACTIONS(2826), 1,
      sym__single_quote_string_end,
    STATE(1375), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2828), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [52757] = 3,
    STATE(104), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2830), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52771] = 3,
    STATE(83), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2832), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52785] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2098), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(2096), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [52799] = 5,
    ACTIONS(2834), 1,
      anon_sym_SEMI,
    ACTIONS(2837), 1,
      aux_sym_matrix_token1,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2840), 2,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [52817] = 3,
    STATE(74), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2842), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52831] = 3,
    STATE(76), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2844), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52845] = 4,
    ACTIONS(2846), 1,
      sym__double_quote_string_end,
    STATE(1363), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2848), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [52861] = 5,
    ACTIONS(1167), 1,
      aux_sym_matrix_token1,
    ACTIONS(2112), 1,
      sym__entry_delimiter,
    STATE(1352), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1165), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [52879] = 5,
    ACTIONS(2851), 1,
      anon_sym_elseif,
    ACTIONS(2854), 1,
      anon_sym_else,
    ACTIONS(2856), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1365), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [52897] = 4,
    ACTIONS(2860), 1,
      anon_sym_case,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2858), 2,
      anon_sym_end,
      anon_sym_otherwise,
    STATE(1366), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [52913] = 3,
    STATE(38), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2863), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52927] = 3,
    STATE(46), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2865), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52941] = 3,
    STATE(40), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2867), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52955] = 3,
    STATE(61), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2869), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52969] = 3,
    STATE(63), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2871), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52983] = 3,
    STATE(49), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2873), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [52997] = 3,
    STATE(51), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2875), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53011] = 3,
    STATE(60), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2877), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53025] = 4,
    ACTIONS(2822), 1,
      sym__single_quote_string_end,
    STATE(1384), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2809), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53041] = 5,
    ACTIONS(1167), 1,
      aux_sym_matrix_token1,
    ACTIONS(2112), 1,
      sym__entry_delimiter,
    STATE(1350), 1,
      aux_sym__index_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1165), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [53059] = 4,
    ACTIONS(2879), 1,
      sym__single_quote_string_end,
    STATE(1347), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2881), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53075] = 4,
    ACTIONS(2879), 1,
      sym__double_quote_string_end,
    STATE(1379), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2883), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53091] = 4,
    ACTIONS(2807), 1,
      sym__double_quote_string_end,
    STATE(1363), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2824), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53107] = 6,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(2885), 1,
      anon_sym_RPAREN,
    ACTIONS(2887), 1,
      anon_sym_AT,
    STATE(509), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53127] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2791), 5,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53139] = 4,
    ACTIONS(2826), 1,
      sym__double_quote_string_end,
    STATE(1353), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2889), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53155] = 3,
    STATE(1029), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2891), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53169] = 4,
    ACTIONS(2846), 1,
      sym__single_quote_string_end,
    STATE(1384), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2893), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53185] = 3,
    STATE(96), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2896), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53199] = 3,
    STATE(80), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2898), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53213] = 3,
    STATE(1003), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2900), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53227] = 3,
    STATE(58), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2902), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53241] = 4,
    ACTIONS(2904), 1,
      sym__single_quote_string_end,
    STATE(1392), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2906), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53257] = 4,
    ACTIONS(2904), 1,
      sym__double_quote_string_end,
    STATE(1393), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2908), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53273] = 3,
    STATE(98), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2910), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53287] = 4,
    ACTIONS(2912), 1,
      sym__single_quote_string_end,
    STATE(1384), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2809), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53303] = 4,
    ACTIONS(2912), 1,
      sym__double_quote_string_end,
    STATE(1363), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2824), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53319] = 3,
    ACTIONS(2914), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2916), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53333] = 3,
    STATE(1007), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2918), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53347] = 4,
    ACTIONS(2920), 1,
      sym__single_quote_string_end,
    STATE(1398), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2922), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53363] = 4,
    ACTIONS(2920), 1,
      sym__double_quote_string_end,
    STATE(1399), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2924), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53379] = 4,
    ACTIONS(2926), 1,
      sym__single_quote_string_end,
    STATE(1384), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2809), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53395] = 4,
    ACTIONS(2926), 1,
      sym__double_quote_string_end,
    STATE(1363), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2824), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [53411] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2928), 5,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_CR,
  [53423] = 3,
    STATE(89), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2930), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53437] = 3,
    STATE(91), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2932), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53451] = 3,
    STATE(1030), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2934), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53465] = 4,
    ACTIONS(2936), 1,
      anon_sym_end,
    ACTIONS(2938), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53480] = 4,
    ACTIONS(439), 1,
      anon_sym_endfunction,
    ACTIONS(2940), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(349), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53495] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2942), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53506] = 5,
    ACTIONS(1110), 1,
      anon_sym_RBRACK,
    ACTIONS(2944), 1,
      anon_sym_SEMI,
    ACTIONS(2946), 1,
      aux_sym_matrix_token1,
    STATE(1425), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53523] = 4,
    ACTIONS(443), 1,
      anon_sym_endfunction,
    ACTIONS(2948), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(355), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53538] = 3,
    ACTIONS(2568), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2304), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [53551] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2713), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53562] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(2954), 1,
      anon_sym_RBRACE,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53579] = 4,
    ACTIONS(451), 1,
      anon_sym_endfunction,
    ACTIONS(2956), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(371), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53594] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2958), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53605] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2960), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53616] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2566), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53627] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2512), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53638] = 4,
    ACTIONS(2962), 1,
      anon_sym_end,
    ACTIONS(2964), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2269), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53653] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2462), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53664] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2719), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53675] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2966), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53686] = 4,
    ACTIONS(2968), 1,
      anon_sym_end,
    ACTIONS(2970), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2316), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53701] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2756), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53712] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2972), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53723] = 3,
    ACTIONS(2974), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2756), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [53736] = 5,
    ACTIONS(2944), 1,
      anon_sym_SEMI,
    ACTIONS(2946), 1,
      aux_sym_matrix_token1,
    ACTIONS(2976), 1,
      anon_sym_RBRACK,
    STATE(1518), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53753] = 5,
    ACTIONS(2944), 1,
      anon_sym_SEMI,
    ACTIONS(2946), 1,
      aux_sym_matrix_token1,
    ACTIONS(2976), 1,
      anon_sym_RBRACK,
    STATE(1526), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [53770] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2454), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53781] = 4,
    ACTIONS(2980), 1,
      anon_sym_COMMA,
    STATE(1430), 1,
      aux_sym__index_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2978), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53796] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2470), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53807] = 4,
    ACTIONS(2985), 1,
      anon_sym_COMMA,
    STATE(1436), 1,
      aux_sym__index_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2983), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53822] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2988), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53833] = 4,
    ACTIONS(457), 1,
      anon_sym_endfunction,
    ACTIONS(2990), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(453), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53848] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2764), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53859] = 3,
    ACTIONS(2992), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2764), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [53872] = 4,
    ACTIONS(463), 1,
      anon_sym_endfunction,
    ACTIONS(2994), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(459), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53887] = 4,
    ACTIONS(2998), 1,
      anon_sym_COMMA,
    STATE(1436), 1,
      aux_sym__index_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2996), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53902] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3001), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53913] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3003), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53924] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3005), 4,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_get,
      anon_sym_set,
  [53935] = 4,
    ACTIONS(393), 1,
      anon_sym_endfunction,
    ACTIONS(3007), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(377), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53950] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3009), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53961] = 4,
    ACTIONS(399), 1,
      anon_sym_endfunction,
    ACTIONS(3011), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [53976] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3013), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [53987] = 3,
    ACTIONS(2532), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2338), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [54000] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54011] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2338), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54022] = 3,
    ACTIONS(2534), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2344), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [54035] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54046] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2344), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54057] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2374), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54068] = 3,
    ACTIONS(2540), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2374), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [54081] = 4,
    ACTIONS(381), 1,
      anon_sym_endfunction,
    ACTIONS(3017), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(377), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54096] = 3,
    ACTIONS(2510), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2394), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [54109] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3019), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54120] = 3,
    ACTIONS(2546), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2298), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [54133] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2360), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54144] = 3,
    ACTIONS(2542), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2360), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [54157] = 4,
    ACTIONS(405), 1,
      anon_sym_endfunction,
    ACTIONS(3021), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(401), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54172] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3023), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54183] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2466), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54194] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3025), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54205] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2705), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54216] = 5,
    ACTIONS(3027), 1,
      anon_sym_LPAREN,
    ACTIONS(3029), 1,
      anon_sym_AT,
    ACTIONS(3031), 1,
      anon_sym_LBRACE,
    STATE(434), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54233] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2744), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54244] = 4,
    ACTIONS(411), 1,
      anon_sym_endfunction,
    ACTIONS(3033), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(407), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54259] = 4,
    ACTIONS(3037), 1,
      anon_sym_COMMA,
    STATE(1466), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3035), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54274] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3040), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54285] = 4,
    ACTIONS(471), 1,
      anon_sym_endfunction,
    ACTIONS(3042), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(401), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54300] = 4,
    ACTIONS(565), 1,
      ts_builtin_sym_end,
    ACTIONS(3044), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1503), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [54315] = 4,
    ACTIONS(431), 1,
      anon_sym_endfunction,
    ACTIONS(3046), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54330] = 4,
    ACTIONS(475), 1,
      anon_sym_endfunction,
    ACTIONS(3048), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(407), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54345] = 4,
    ACTIONS(3050), 1,
      anon_sym_end,
    ACTIONS(3052), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2372), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54360] = 4,
    ACTIONS(3054), 1,
      anon_sym_end,
    ACTIONS(3056), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2372), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54375] = 5,
    ACTIONS(1673), 1,
      anon_sym_AT,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1843), 1,
      anon_sym_LPAREN,
    STATE(904), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54392] = 5,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1843), 1,
      anon_sym_LPAREN,
    ACTIONS(3058), 1,
      anon_sym_AT,
    STATE(919), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54409] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3060), 1,
      anon_sym_RBRACK,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54426] = 4,
    ACTIONS(479), 1,
      anon_sym_endfunction,
    ACTIONS(3062), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(417), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54441] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2502), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54452] = 5,
    ACTIONS(995), 1,
      anon_sym_RBRACK,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    STATE(1485), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54469] = 5,
    ACTIONS(997), 1,
      anon_sym_RBRACE,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    STATE(1487), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54486] = 4,
    ACTIONS(483), 1,
      anon_sym_endfunction,
    ACTIONS(3064), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(423), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54501] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3066), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54512] = 4,
    ACTIONS(3068), 1,
      anon_sym_end,
    ACTIONS(3070), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2358), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54527] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2486), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54538] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3072), 1,
      anon_sym_RBRACK,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54555] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3072), 1,
      anon_sym_RBRACK,
    STATE(1495), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54572] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3074), 1,
      anon_sym_RBRACE,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54589] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3074), 1,
      anon_sym_RBRACE,
    STATE(1496), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54606] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3060), 1,
      anon_sym_RBRACK,
    STATE(1512), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54623] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3076), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54634] = 4,
    ACTIONS(421), 1,
      anon_sym_endfunction,
    ACTIONS(3078), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(417), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54649] = 4,
    ACTIONS(3044), 1,
      anon_sym_function,
    ACTIONS(3080), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1503), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [54664] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3082), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54675] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3084), 1,
      anon_sym_RBRACE,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54692] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3086), 1,
      anon_sym_RBRACK,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54709] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3088), 1,
      anon_sym_RBRACE,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54726] = 4,
    ACTIONS(427), 1,
      anon_sym_endfunction,
    ACTIONS(3090), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(423), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54741] = 5,
    ACTIONS(1078), 1,
      anon_sym_RBRACK,
    ACTIONS(2944), 1,
      anon_sym_SEMI,
    ACTIONS(2946), 1,
      aux_sym_matrix_token1,
    STATE(1501), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54758] = 4,
    ACTIONS(347), 1,
      anon_sym_endfunction,
    ACTIONS(3092), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(343), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54773] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3084), 1,
      anon_sym_RBRACE,
    STATE(1411), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54790] = 5,
    ACTIONS(2944), 1,
      anon_sym_SEMI,
    ACTIONS(2946), 1,
      aux_sym_matrix_token1,
    ACTIONS(3094), 1,
      anon_sym_RBRACK,
    STATE(1518), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54807] = 5,
    ACTIONS(2944), 1,
      anon_sym_SEMI,
    ACTIONS(2946), 1,
      aux_sym_matrix_token1,
    ACTIONS(3094), 1,
      anon_sym_RBRACK,
    STATE(1506), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54824] = 4,
    ACTIONS(3096), 1,
      ts_builtin_sym_end,
    ACTIONS(3098), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1503), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [54839] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3101), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54850] = 4,
    ACTIONS(3103), 1,
      anon_sym_end,
    ACTIONS(3105), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2358), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54865] = 5,
    ACTIONS(2944), 1,
      anon_sym_SEMI,
    ACTIONS(2946), 1,
      aux_sym_matrix_token1,
    ACTIONS(3107), 1,
      anon_sym_RBRACK,
    STATE(1518), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54882] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3109), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54893] = 4,
    ACTIONS(353), 1,
      anon_sym_endfunction,
    ACTIONS(3111), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(349), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54908] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2536), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54919] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3113), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54930] = 4,
    ACTIONS(3115), 1,
      anon_sym_end,
    ACTIONS(3117), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2400), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54945] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3119), 1,
      anon_sym_RBRACK,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [54962] = 4,
    ACTIONS(3121), 1,
      anon_sym_end,
    ACTIONS(3123), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [54977] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2617), 4,
      sym__external_identifier,
      anon_sym_arguments,
      anon_sym_get,
      anon_sym_set,
  [54988] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3125), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [54999] = 5,
    ACTIONS(3027), 1,
      anon_sym_LPAREN,
    ACTIONS(3031), 1,
      anon_sym_LBRACE,
    ACTIONS(3127), 1,
      anon_sym_AT,
    STATE(427), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55016] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2474), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55027] = 5,
    ACTIONS(3129), 1,
      anon_sym_SEMI,
    ACTIONS(3132), 1,
      aux_sym_matrix_token1,
    ACTIONS(3135), 1,
      anon_sym_RBRACK,
    STATE(1518), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55044] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2271), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55055] = 3,
    ACTIONS(2476), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2271), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55068] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2138), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(2140), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
  [55081] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2318), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55092] = 3,
    ACTIONS(2478), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2318), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55105] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2572), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55116] = 3,
    ACTIONS(3137), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2572), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55129] = 5,
    ACTIONS(2944), 1,
      anon_sym_SEMI,
    ACTIONS(2946), 1,
      aux_sym_matrix_token1,
    ACTIONS(3139), 1,
      anon_sym_RBRACK,
    STATE(1518), 1,
      aux_sym__index_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55146] = 3,
    ACTIONS(2480), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2277), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55159] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3141), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55170] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2277), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55181] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2522), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55192] = 4,
    ACTIONS(2132), 1,
      anon_sym_COMMA,
    STATE(1466), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3143), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55207] = 3,
    ACTIONS(2496), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55220] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55231] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2582), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55242] = 5,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1302), 1,
      anon_sym_AT,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(509), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55259] = 5,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(1386), 1,
      anon_sym_AT,
    STATE(555), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55276] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3145), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    ACTIONS(3148), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
  [55289] = 3,
    ACTIONS(3151), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2582), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55302] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2500), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55313] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2516), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55324] = 5,
    ACTIONS(1013), 1,
      anon_sym_RBRACK,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    STATE(1545), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55341] = 4,
    ACTIONS(2132), 1,
      anon_sym_COMMA,
    STATE(1466), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3153), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55356] = 5,
    ACTIONS(1015), 1,
      anon_sym_RBRACE,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    STATE(1547), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55373] = 4,
    ACTIONS(3155), 1,
      anon_sym_end,
    ACTIONS(3157), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2269), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [55388] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3159), 1,
      anon_sym_RBRACK,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55405] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3159), 1,
      anon_sym_RBRACK,
    STATE(1549), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55422] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3161), 1,
      anon_sym_RBRACE,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55439] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3161), 1,
      anon_sym_RBRACE,
    STATE(1550), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55456] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3163), 1,
      anon_sym_RBRACK,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55473] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3165), 1,
      anon_sym_RBRACE,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55490] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3167), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55501] = 4,
    ACTIONS(3169), 1,
      anon_sym_end,
    ACTIONS(3171), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2316), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [55516] = 4,
    ACTIONS(375), 1,
      anon_sym_endfunction,
    ACTIONS(3173), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(371), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [55531] = 5,
    ACTIONS(993), 1,
      anon_sym_RBRACE,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    STATE(1494), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55548] = 3,
    ACTIONS(3175), 1,
      aux_sym_matrix_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2840), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [55561] = 4,
    ACTIONS(487), 1,
      anon_sym_endfunction,
    ACTIONS(3177), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(453), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [55576] = 5,
    ACTIONS(1649), 1,
      anon_sym_LPAREN,
    ACTIONS(1653), 1,
      anon_sym_LBRACE,
    ACTIONS(3179), 1,
      anon_sym_AT,
    STATE(469), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55593] = 5,
    ACTIONS(1649), 1,
      anon_sym_LPAREN,
    ACTIONS(1651), 1,
      anon_sym_AT,
    ACTIONS(1653), 1,
      anon_sym_LBRACE,
    STATE(471), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55610] = 3,
    ACTIONS(2490), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2352), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55623] = 4,
    ACTIONS(491), 1,
      anon_sym_endfunction,
    ACTIONS(3181), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(459), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [55638] = 3,
    ACTIONS(2556), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2366), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55651] = 5,
    ACTIONS(991), 1,
      anon_sym_RBRACK,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    STATE(1566), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55668] = 5,
    ACTIONS(1029), 1,
      anon_sym_RBRACE,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    STATE(1568), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55685] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3183), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55696] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3185), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55707] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3187), 1,
      anon_sym_RBRACK,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55724] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3187), 1,
      anon_sym_RBRACK,
    STATE(1570), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55741] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3189), 1,
      anon_sym_RBRACE,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55758] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3189), 1,
      anon_sym_RBRACE,
    STATE(1571), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55775] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3191), 1,
      anon_sym_RBRACK,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55792] = 5,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    ACTIONS(3193), 1,
      anon_sym_RBRACE,
    STATE(1360), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55809] = 3,
    ACTIONS(2524), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2380), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55822] = 5,
    ACTIONS(3195), 1,
      anon_sym_LPAREN,
    ACTIONS(3197), 1,
      anon_sym_AT,
    ACTIONS(3199), 1,
      anon_sym_LBRACE,
    STATE(129), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55839] = 5,
    ACTIONS(3195), 1,
      anon_sym_LPAREN,
    ACTIONS(3199), 1,
      anon_sym_LBRACE,
    ACTIONS(3201), 1,
      anon_sym_AT,
    STATE(125), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55856] = 5,
    ACTIONS(999), 1,
      anon_sym_RBRACK,
    ACTIONS(2950), 1,
      anon_sym_SEMI,
    ACTIONS(2952), 1,
      aux_sym_matrix_token1,
    STATE(1476), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55873] = 3,
    ACTIONS(2538), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2386), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55886] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2386), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55897] = 4,
    ACTIONS(435), 1,
      anon_sym_endfunction,
    ACTIONS(3203), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(343), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [55912] = 5,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    ACTIONS(2887), 1,
      anon_sym_AT,
    STATE(509), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [55929] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3205), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55940] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3207), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55951] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3209), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55962] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3211), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55973] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2725), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [55984] = 3,
    ACTIONS(3213), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2725), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [55997] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2772), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [56008] = 3,
    ACTIONS(3215), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2772), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [56021] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2780), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [56032] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2402), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [56043] = 3,
    ACTIONS(2548), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2402), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [56056] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2328), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [56067] = 3,
    ACTIONS(2550), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2328), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [56080] = 3,
    ACTIONS(2564), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2283), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [56093] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2625), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [56104] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3217), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [56115] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3219), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [56126] = 4,
    ACTIONS(3221), 1,
      anon_sym_end,
    ACTIONS(3223), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2400), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56141] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2283), 4,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_SEMI,
      anon_sym_CR,
  [56152] = 4,
    ACTIONS(359), 1,
      anon_sym_endfunction,
    ACTIONS(3225), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(355), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56167] = 4,
    ACTIONS(3227), 1,
      anon_sym_RPAREN,
    ACTIONS(3229), 1,
      anon_sym_COMMA,
    STATE(1600), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56181] = 4,
    ACTIONS(3232), 1,
      anon_sym_RPAREN,
    ACTIONS(3234), 1,
      anon_sym_COMMA,
    STATE(1601), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56195] = 4,
    ACTIONS(3027), 1,
      anon_sym_LPAREN,
    ACTIONS(3031), 1,
      anon_sym_LBRACE,
    STATE(428), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56209] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3237), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
  [56219] = 3,
    ACTIONS(3239), 1,
      aux_sym_matrix_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3135), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [56231] = 4,
    ACTIONS(3241), 1,
      anon_sym_end,
    ACTIONS(3243), 1,
      anon_sym_catch,
    STATE(1716), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56245] = 4,
    ACTIONS(3245), 1,
      anon_sym_RPAREN,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    STATE(1648), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56259] = 3,
    ACTIONS(2683), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(371), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56271] = 4,
    ACTIONS(2261), 1,
      anon_sym_RPAREN,
    ACTIONS(3249), 1,
      anon_sym_COMMA,
    STATE(1608), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56285] = 3,
    ACTIONS(151), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3252), 2,
      anon_sym_elseif,
      anon_sym_end,
  [56297] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3254), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [56307] = 4,
    ACTIONS(3256), 1,
      anon_sym_RPAREN,
    ACTIONS(3258), 1,
      anon_sym_COMMA,
    STATE(1611), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56321] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3261), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [56331] = 3,
    ACTIONS(2663), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(401), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56343] = 3,
    ACTIONS(2667), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(407), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56355] = 3,
    ACTIONS(3263), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2754), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56367] = 3,
    ACTIONS(2685), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2269), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56379] = 3,
    ACTIONS(2677), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2372), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56391] = 4,
    ACTIONS(3265), 1,
      anon_sym_RPAREN,
    ACTIONS(3267), 1,
      anon_sym_COMMA,
    STATE(1627), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56405] = 3,
    ACTIONS(2797), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(349), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56417] = 4,
    ACTIONS(1298), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_LBRACE,
    STATE(508), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56431] = 3,
    ACTIONS(2805), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2316), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56443] = 3,
    ACTIONS(3269), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2570), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56455] = 4,
    ACTIONS(3271), 1,
      anon_sym_RPAREN,
    ACTIONS(3273), 1,
      anon_sym_COMMA,
    STATE(1601), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56469] = 3,
    ACTIONS(3277), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3275), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56481] = 3,
    ACTIONS(2693), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(453), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56493] = 3,
    ACTIONS(2655), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(377), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56505] = 4,
    ACTIONS(3267), 1,
      anon_sym_COMMA,
    ACTIONS(3279), 1,
      anon_sym_RPAREN,
    STATE(1600), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56519] = 3,
    ACTIONS(2701), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(459), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56531] = 3,
    ACTIONS(2689), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(423), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56543] = 3,
    ACTIONS(3281), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2762), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56555] = 3,
    ACTIONS(3283), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2580), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56567] = 3,
    ACTIONS(2697), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2358), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56579] = 3,
    ACTIONS(2661), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(355), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56591] = 4,
    ACTIONS(1649), 1,
      anon_sym_LPAREN,
    ACTIONS(1653), 1,
      anon_sym_LBRACE,
    STATE(477), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56605] = 3,
    ACTIONS(3287), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3285), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [56617] = 3,
    ACTIONS(2675), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56629] = 4,
    ACTIONS(3289), 1,
      anon_sym_RPAREN,
    ACTIONS(3291), 1,
      anon_sym_COMMA,
    STATE(1611), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56643] = 4,
    ACTIONS(3293), 1,
      anon_sym_RPAREN,
    ACTIONS(3295), 1,
      anon_sym_COMMA,
    STATE(1638), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56657] = 4,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3298), 1,
      anon_sym_RPAREN,
    STATE(1647), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56671] = 3,
    ACTIONS(2699), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(343), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56683] = 4,
    ACTIONS(3195), 1,
      anon_sym_LPAREN,
    ACTIONS(3199), 1,
      anon_sym_LBRACE,
    STATE(139), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56697] = 4,
    ACTIONS(3243), 1,
      anon_sym_catch,
    ACTIONS(3300), 1,
      anon_sym_end,
    STATE(1741), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56711] = 3,
    ACTIONS(3304), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3302), 2,
      anon_sym_elseif,
      anon_sym_end,
  [56723] = 4,
    ACTIONS(2162), 1,
      anon_sym_COMMA,
    ACTIONS(3306), 1,
      anon_sym_RPAREN,
    STATE(1608), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56737] = 4,
    ACTIONS(1679), 1,
      anon_sym_LBRACE,
    ACTIONS(1843), 1,
      anon_sym_LPAREN,
    STATE(931), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56751] = 4,
    ACTIONS(3291), 1,
      anon_sym_COMMA,
    ACTIONS(3308), 1,
      anon_sym_RPAREN,
    STATE(1637), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56765] = 4,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3310), 1,
      anon_sym_RPAREN,
    STATE(1638), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56779] = 4,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3312), 1,
      anon_sym_RPAREN,
    STATE(1638), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56793] = 4,
    ACTIONS(3273), 1,
      anon_sym_COMMA,
    ACTIONS(3314), 1,
      anon_sym_RPAREN,
    STATE(1623), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56807] = 3,
    ACTIONS(3316), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2723), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56819] = 3,
    ACTIONS(3318), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2770), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56831] = 3,
    ACTIONS(2786), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2400), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56843] = 3,
    ACTIONS(2793), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56855] = 3,
    ACTIONS(2681), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(417), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56867] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2358), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56876] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2703), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56885] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2742), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56894] = 3,
    ACTIONS(547), 1,
      anon_sym_endfunction,
    ACTIONS(3320), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56905] = 3,
    ACTIONS(527), 1,
      anon_sym_endfunction,
    ACTIONS(3322), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56916] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(407), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56925] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2269), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56934] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3256), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [56943] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2372), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56952] = 3,
    ACTIONS(3324), 1,
      anon_sym_RPAREN,
    ACTIONS(3326), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56963] = 3,
    ACTIONS(3328), 1,
      anon_sym_end,
    ACTIONS(3330), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [56974] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2762), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56983] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2316), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [56992] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2570), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57001] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(355), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57010] = 3,
    ACTIONS(3332), 1,
      anon_sym_end,
    ACTIONS(3334), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57021] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(453), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57030] = 3,
    ACTIONS(3336), 1,
      anon_sym_end,
    ACTIONS(3338), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57041] = 3,
    ACTIONS(543), 1,
      anon_sym_endfunction,
    ACTIONS(3340), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57052] = 3,
    ACTIONS(523), 1,
      anon_sym_endfunction,
    ACTIONS(3342), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57063] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(459), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57072] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2580), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57081] = 3,
    ACTIONS(3344), 1,
      anon_sym_end,
    ACTIONS(3346), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57092] = 3,
    ACTIONS(499), 1,
      anon_sym_endfunction,
    ACTIONS(3348), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57103] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(371), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57112] = 3,
    ACTIONS(551), 1,
      anon_sym_endfunction,
    ACTIONS(3350), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57123] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(922), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [57132] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3232), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [57141] = 3,
    ACTIONS(503), 1,
      anon_sym_endfunction,
    ACTIONS(3352), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57152] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2711), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57161] = 3,
    ACTIONS(511), 1,
      anon_sym_endfunction,
    ACTIONS(3354), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57172] = 3,
    ACTIONS(555), 1,
      anon_sym_endfunction,
    ACTIONS(3356), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57183] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3358), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [57192] = 3,
    ACTIONS(515), 1,
      anon_sym_endfunction,
    ACTIONS(3360), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57203] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2623), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57212] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2717), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57221] = 3,
    ACTIONS(3362), 1,
      anon_sym_end,
    ACTIONS(3364), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57232] = 3,
    ACTIONS(3366), 1,
      anon_sym_end,
    ACTIONS(3368), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57243] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(401), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57252] = 3,
    ACTIONS(539), 1,
      anon_sym_endfunction,
    ACTIONS(3370), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57263] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2723), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57272] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2770), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57281] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2754), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57290] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2778), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57299] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2400), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57308] = 3,
    ACTIONS(495), 1,
      anon_sym_endfunction,
    ACTIONS(3372), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57319] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [57328] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3293), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [57337] = 2,
    ACTIONS(3374), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57345] = 2,
    ACTIONS(3376), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57353] = 2,
    ACTIONS(3378), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57361] = 2,
    ACTIONS(3380), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57369] = 2,
    ACTIONS(3382), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57377] = 2,
    ACTIONS(3384), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57385] = 2,
    ACTIONS(3386), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57393] = 2,
    ACTIONS(3388), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57401] = 2,
    ACTIONS(3388), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57409] = 2,
    ACTIONS(3390), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57417] = 2,
    ACTIONS(3392), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57425] = 2,
    ACTIONS(2611), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57433] = 2,
    ACTIONS(3394), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57441] = 2,
    ACTIONS(3396), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57449] = 2,
    ACTIONS(3398), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57457] = 2,
    ACTIONS(3400), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57465] = 2,
    ACTIONS(3402), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57473] = 2,
    ACTIONS(3404), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57481] = 2,
    ACTIONS(3406), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57489] = 2,
    ACTIONS(3408), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57497] = 2,
    ACTIONS(3410), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57505] = 2,
    ACTIONS(3412), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57513] = 2,
    ACTIONS(3414), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57521] = 2,
    ACTIONS(3416), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57529] = 2,
    ACTIONS(3418), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57537] = 2,
    ACTIONS(3418), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57545] = 2,
    ACTIONS(3420), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57553] = 2,
    ACTIONS(2609), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57561] = 2,
    ACTIONS(3422), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57569] = 2,
    ACTIONS(3424), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57577] = 2,
    ACTIONS(2799), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57585] = 2,
    ACTIONS(3426), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57593] = 2,
    ACTIONS(3428), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57601] = 2,
    ACTIONS(3430), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57609] = 2,
    ACTIONS(3432), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57617] = 2,
    ACTIONS(3434), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57625] = 2,
    ACTIONS(3300), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57633] = 2,
    ACTIONS(3324), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57641] = 2,
    ACTIONS(3241), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57649] = 2,
    ACTIONS(3436), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57657] = 2,
    ACTIONS(3438), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57665] = 2,
    ACTIONS(3434), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57673] = 2,
    ACTIONS(3440), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57681] = 2,
    ACTIONS(3442), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57689] = 2,
    ACTIONS(3444), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57697] = 2,
    ACTIONS(3446), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57705] = 2,
    ACTIONS(3448), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57713] = 2,
    ACTIONS(3450), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57721] = 2,
    ACTIONS(3452), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57729] = 2,
    ACTIONS(3454), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57737] = 2,
    ACTIONS(2885), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57745] = 2,
    ACTIONS(3456), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57753] = 2,
    ACTIONS(3458), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57761] = 2,
    ACTIONS(3460), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57769] = 2,
    ACTIONS(3462), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57777] = 2,
    ACTIONS(3464), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57785] = 2,
    ACTIONS(3466), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57793] = 2,
    ACTIONS(3420), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57801] = 2,
    ACTIONS(3468), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57809] = 2,
    ACTIONS(3470), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57817] = 2,
    ACTIONS(3472), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57825] = 2,
    ACTIONS(3474), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57833] = 2,
    ACTIONS(3476), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57841] = 2,
    ACTIONS(3478), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57849] = 2,
    ACTIONS(3480), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57857] = 2,
    ACTIONS(2673), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57865] = 2,
    ACTIONS(3482), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57873] = 2,
    ACTIONS(3484), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57881] = 2,
    ACTIONS(3486), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57889] = 2,
    ACTIONS(3488), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57897] = 2,
    ACTIONS(3490), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57905] = 2,
    ACTIONS(3492), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57913] = 2,
    ACTIONS(2592), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57921] = 2,
    ACTIONS(3494), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [57929] = 2,
    ACTIONS(3464), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(210)] = 0,
  [SMALL_STATE(211)] = 149,
  [SMALL_STATE(212)] = 300,
  [SMALL_STATE(213)] = 451,
  [SMALL_STATE(214)] = 597,
  [SMALL_STATE(215)] = 739,
  [SMALL_STATE(216)] = 878,
  [SMALL_STATE(217)] = 1017,
  [SMALL_STATE(218)] = 1156,
  [SMALL_STATE(219)] = 1295,
  [SMALL_STATE(220)] = 1434,
  [SMALL_STATE(221)] = 1573,
  [SMALL_STATE(222)] = 1712,
  [SMALL_STATE(223)] = 1851,
  [SMALL_STATE(224)] = 1990,
  [SMALL_STATE(225)] = 2129,
  [SMALL_STATE(226)] = 2196,
  [SMALL_STATE(227)] = 2263,
  [SMALL_STATE(228)] = 2330,
  [SMALL_STATE(229)] = 2397,
  [SMALL_STATE(230)] = 2464,
  [SMALL_STATE(231)] = 2526,
  [SMALL_STATE(232)] = 2588,
  [SMALL_STATE(233)] = 2710,
  [SMALL_STATE(234)] = 2833,
  [SMALL_STATE(235)] = 2956,
  [SMALL_STATE(236)] = 3079,
  [SMALL_STATE(237)] = 3202,
  [SMALL_STATE(238)] = 3325,
  [SMALL_STATE(239)] = 3448,
  [SMALL_STATE(240)] = 3571,
  [SMALL_STATE(241)] = 3694,
  [SMALL_STATE(242)] = 3817,
  [SMALL_STATE(243)] = 3940,
  [SMALL_STATE(244)] = 4063,
  [SMALL_STATE(245)] = 4186,
  [SMALL_STATE(246)] = 4309,
  [SMALL_STATE(247)] = 4432,
  [SMALL_STATE(248)] = 4555,
  [SMALL_STATE(249)] = 4678,
  [SMALL_STATE(250)] = 4792,
  [SMALL_STATE(251)] = 4908,
  [SMALL_STATE(252)] = 5024,
  [SMALL_STATE(253)] = 5140,
  [SMALL_STATE(254)] = 5203,
  [SMALL_STATE(255)] = 5266,
  [SMALL_STATE(256)] = 5331,
  [SMALL_STATE(257)] = 5394,
  [SMALL_STATE(258)] = 5514,
  [SMALL_STATE(259)] = 5632,
  [SMALL_STATE(260)] = 5752,
  [SMALL_STATE(261)] = 5858,
  [SMALL_STATE(262)] = 5964,
  [SMALL_STATE(263)] = 6084,
  [SMALL_STATE(264)] = 6204,
  [SMALL_STATE(265)] = 6310,
  [SMALL_STATE(266)] = 6416,
  [SMALL_STATE(267)] = 6519,
  [SMALL_STATE(268)] = 6622,
  [SMALL_STATE(269)] = 6725,
  [SMALL_STATE(270)] = 6828,
  [SMALL_STATE(271)] = 6931,
  [SMALL_STATE(272)] = 7034,
  [SMALL_STATE(273)] = 7137,
  [SMALL_STATE(274)] = 7240,
  [SMALL_STATE(275)] = 7343,
  [SMALL_STATE(276)] = 7446,
  [SMALL_STATE(277)] = 7549,
  [SMALL_STATE(278)] = 7652,
  [SMALL_STATE(279)] = 7755,
  [SMALL_STATE(280)] = 7858,
  [SMALL_STATE(281)] = 7917,
  [SMALL_STATE(282)] = 8020,
  [SMALL_STATE(283)] = 8123,
  [SMALL_STATE(284)] = 8226,
  [SMALL_STATE(285)] = 8325,
  [SMALL_STATE(286)] = 8424,
  [SMALL_STATE(287)] = 8523,
  [SMALL_STATE(288)] = 8622,
  [SMALL_STATE(289)] = 8721,
  [SMALL_STATE(290)] = 8824,
  [SMALL_STATE(291)] = 8883,
  [SMALL_STATE(292)] = 8986,
  [SMALL_STATE(293)] = 9089,
  [SMALL_STATE(294)] = 9192,
  [SMALL_STATE(295)] = 9295,
  [SMALL_STATE(296)] = 9398,
  [SMALL_STATE(297)] = 9501,
  [SMALL_STATE(298)] = 9604,
  [SMALL_STATE(299)] = 9703,
  [SMALL_STATE(300)] = 9802,
  [SMALL_STATE(301)] = 9901,
  [SMALL_STATE(302)] = 10000,
  [SMALL_STATE(303)] = 10099,
  [SMALL_STATE(304)] = 10202,
  [SMALL_STATE(305)] = 10305,
  [SMALL_STATE(306)] = 10408,
  [SMALL_STATE(307)] = 10511,
  [SMALL_STATE(308)] = 10614,
  [SMALL_STATE(309)] = 10717,
  [SMALL_STATE(310)] = 10820,
  [SMALL_STATE(311)] = 10923,
  [SMALL_STATE(312)] = 11026,
  [SMALL_STATE(313)] = 11125,
  [SMALL_STATE(314)] = 11224,
  [SMALL_STATE(315)] = 11323,
  [SMALL_STATE(316)] = 11422,
  [SMALL_STATE(317)] = 11521,
  [SMALL_STATE(318)] = 11624,
  [SMALL_STATE(319)] = 11727,
  [SMALL_STATE(320)] = 11830,
  [SMALL_STATE(321)] = 11889,
  [SMALL_STATE(322)] = 11992,
  [SMALL_STATE(323)] = 12095,
  [SMALL_STATE(324)] = 12198,
  [SMALL_STATE(325)] = 12301,
  [SMALL_STATE(326)] = 12404,
  [SMALL_STATE(327)] = 12507,
  [SMALL_STATE(328)] = 12610,
  [SMALL_STATE(329)] = 12713,
  [SMALL_STATE(330)] = 12812,
  [SMALL_STATE(331)] = 12911,
  [SMALL_STATE(332)] = 13010,
  [SMALL_STATE(333)] = 13109,
  [SMALL_STATE(334)] = 13212,
  [SMALL_STATE(335)] = 13311,
  [SMALL_STATE(336)] = 13414,
  [SMALL_STATE(337)] = 13517,
  [SMALL_STATE(338)] = 13620,
  [SMALL_STATE(339)] = 13723,
  [SMALL_STATE(340)] = 13826,
  [SMALL_STATE(341)] = 13929,
  [SMALL_STATE(342)] = 14032,
  [SMALL_STATE(343)] = 14135,
  [SMALL_STATE(344)] = 14238,
  [SMALL_STATE(345)] = 14341,
  [SMALL_STATE(346)] = 14444,
  [SMALL_STATE(347)] = 14547,
  [SMALL_STATE(348)] = 14650,
  [SMALL_STATE(349)] = 14753,
  [SMALL_STATE(350)] = 14856,
  [SMALL_STATE(351)] = 14959,
  [SMALL_STATE(352)] = 15062,
  [SMALL_STATE(353)] = 15165,
  [SMALL_STATE(354)] = 15268,
  [SMALL_STATE(355)] = 15371,
  [SMALL_STATE(356)] = 15474,
  [SMALL_STATE(357)] = 15577,
  [SMALL_STATE(358)] = 15680,
  [SMALL_STATE(359)] = 15783,
  [SMALL_STATE(360)] = 15886,
  [SMALL_STATE(361)] = 15989,
  [SMALL_STATE(362)] = 16092,
  [SMALL_STATE(363)] = 16195,
  [SMALL_STATE(364)] = 16298,
  [SMALL_STATE(365)] = 16401,
  [SMALL_STATE(366)] = 16504,
  [SMALL_STATE(367)] = 16607,
  [SMALL_STATE(368)] = 16710,
  [SMALL_STATE(369)] = 16813,
  [SMALL_STATE(370)] = 16916,
  [SMALL_STATE(371)] = 17019,
  [SMALL_STATE(372)] = 17122,
  [SMALL_STATE(373)] = 17225,
  [SMALL_STATE(374)] = 17328,
  [SMALL_STATE(375)] = 17431,
  [SMALL_STATE(376)] = 17534,
  [SMALL_STATE(377)] = 17637,
  [SMALL_STATE(378)] = 17740,
  [SMALL_STATE(379)] = 17852,
  [SMALL_STATE(380)] = 17964,
  [SMALL_STATE(381)] = 18074,
  [SMALL_STATE(382)] = 18186,
  [SMALL_STATE(383)] = 18289,
  [SMALL_STATE(384)] = 18392,
  [SMALL_STATE(385)] = 18447,
  [SMALL_STATE(386)] = 18547,
  [SMALL_STATE(387)] = 18643,
  [SMALL_STATE(388)] = 18743,
  [SMALL_STATE(389)] = 18843,
  [SMALL_STATE(390)] = 18943,
  [SMALL_STATE(391)] = 19043,
  [SMALL_STATE(392)] = 19143,
  [SMALL_STATE(393)] = 19243,
  [SMALL_STATE(394)] = 19343,
  [SMALL_STATE(395)] = 19443,
  [SMALL_STATE(396)] = 19539,
  [SMALL_STATE(397)] = 19635,
  [SMALL_STATE(398)] = 19731,
  [SMALL_STATE(399)] = 19827,
  [SMALL_STATE(400)] = 19923,
  [SMALL_STATE(401)] = 20019,
  [SMALL_STATE(402)] = 20119,
  [SMALL_STATE(403)] = 20219,
  [SMALL_STATE(404)] = 20319,
  [SMALL_STATE(405)] = 20419,
  [SMALL_STATE(406)] = 20515,
  [SMALL_STATE(407)] = 20615,
  [SMALL_STATE(408)] = 20711,
  [SMALL_STATE(409)] = 20807,
  [SMALL_STATE(410)] = 20856,
  [SMALL_STATE(411)] = 20905,
  [SMALL_STATE(412)] = 20954,
  [SMALL_STATE(413)] = 21001,
  [SMALL_STATE(414)] = 21050,
  [SMALL_STATE(415)] = 21099,
  [SMALL_STATE(416)] = 21162,
  [SMALL_STATE(417)] = 21225,
  [SMALL_STATE(418)] = 21276,
  [SMALL_STATE(419)] = 21335,
  [SMALL_STATE(420)] = 21398,
  [SMALL_STATE(421)] = 21447,
  [SMALL_STATE(422)] = 21500,
  [SMALL_STATE(423)] = 21559,
  [SMALL_STATE(424)] = 21608,
  [SMALL_STATE(425)] = 21652,
  [SMALL_STATE(426)] = 21696,
  [SMALL_STATE(427)] = 21748,
  [SMALL_STATE(428)] = 21792,
  [SMALL_STATE(429)] = 21836,
  [SMALL_STATE(430)] = 21880,
  [SMALL_STATE(431)] = 21924,
  [SMALL_STATE(432)] = 21968,
  [SMALL_STATE(433)] = 22012,
  [SMALL_STATE(434)] = 22058,
  [SMALL_STATE(435)] = 22102,
  [SMALL_STATE(436)] = 22146,
  [SMALL_STATE(437)] = 22205,
  [SMALL_STATE(438)] = 22268,
  [SMALL_STATE(439)] = 22331,
  [SMALL_STATE(440)] = 22394,
  [SMALL_STATE(441)] = 22457,
  [SMALL_STATE(442)] = 22516,
  [SMALL_STATE(443)] = 22574,
  [SMALL_STATE(444)] = 22620,
  [SMALL_STATE(445)] = 22682,
  [SMALL_STATE(446)] = 22740,
  [SMALL_STATE(447)] = 22792,
  [SMALL_STATE(448)] = 22842,
  [SMALL_STATE(449)] = 22888,
  [SMALL_STATE(450)] = 22946,
  [SMALL_STATE(451)] = 23004,
  [SMALL_STATE(452)] = 23052,
  [SMALL_STATE(453)] = 23100,
  [SMALL_STATE(454)] = 23166,
  [SMALL_STATE(455)] = 23214,
  [SMALL_STATE(456)] = 23274,
  [SMALL_STATE(457)] = 23332,
  [SMALL_STATE(458)] = 23390,
  [SMALL_STATE(459)] = 23448,
  [SMALL_STATE(460)] = 23506,
  [SMALL_STATE(461)] = 23568,
  [SMALL_STATE(462)] = 23633,
  [SMALL_STATE(463)] = 23678,
  [SMALL_STATE(464)] = 23735,
  [SMALL_STATE(465)] = 23776,
  [SMALL_STATE(466)] = 23821,
  [SMALL_STATE(467)] = 23866,
  [SMALL_STATE(468)] = 23923,
  [SMALL_STATE(469)] = 23980,
  [SMALL_STATE(470)] = 24023,
  [SMALL_STATE(471)] = 24064,
  [SMALL_STATE(472)] = 24107,
  [SMALL_STATE(473)] = 24150,
  [SMALL_STATE(474)] = 24193,
  [SMALL_STATE(475)] = 24238,
  [SMALL_STATE(476)] = 24281,
  [SMALL_STATE(477)] = 24326,
  [SMALL_STATE(478)] = 24369,
  [SMALL_STATE(479)] = 24412,
  [SMALL_STATE(480)] = 24455,
  [SMALL_STATE(481)] = 24498,
  [SMALL_STATE(482)] = 24561,
  [SMALL_STATE(483)] = 24604,
  [SMALL_STATE(484)] = 24661,
  [SMALL_STATE(485)] = 24724,
  [SMALL_STATE(486)] = 24781,
  [SMALL_STATE(487)] = 24844,
  [SMALL_STATE(488)] = 24907,
  [SMALL_STATE(489)] = 24968,
  [SMALL_STATE(490)] = 25031,
  [SMALL_STATE(491)] = 25094,
  [SMALL_STATE(492)] = 25137,
  [SMALL_STATE(493)] = 25183,
  [SMALL_STATE(494)] = 25233,
  [SMALL_STATE(495)] = 25287,
  [SMALL_STATE(496)] = 25333,
  [SMALL_STATE(497)] = 25381,
  [SMALL_STATE(498)] = 25427,
  [SMALL_STATE(499)] = 25489,
  [SMALL_STATE(500)] = 25551,
  [SMALL_STATE(501)] = 25593,
  [SMALL_STATE(502)] = 25645,
  [SMALL_STATE(503)] = 25695,
  [SMALL_STATE(504)] = 25737,
  [SMALL_STATE(505)] = 25800,
  [SMALL_STATE(506)] = 25843,
  [SMALL_STATE(507)] = 25882,
  [SMALL_STATE(508)] = 25927,
  [SMALL_STATE(509)] = 25968,
  [SMALL_STATE(510)] = 26009,
  [SMALL_STATE(511)] = 26054,
  [SMALL_STATE(512)] = 26093,
  [SMALL_STATE(513)] = 26132,
  [SMALL_STATE(514)] = 26173,
  [SMALL_STATE(515)] = 26218,
  [SMALL_STATE(516)] = 26263,
  [SMALL_STATE(517)] = 26302,
  [SMALL_STATE(518)] = 26343,
  [SMALL_STATE(519)] = 26406,
  [SMALL_STATE(520)] = 26469,
  [SMALL_STATE(521)] = 26510,
  [SMALL_STATE(522)] = 26551,
  [SMALL_STATE(523)] = 26614,
  [SMALL_STATE(524)] = 26653,
  [SMALL_STATE(525)] = 26692,
  [SMALL_STATE(526)] = 26731,
  [SMALL_STATE(527)] = 26772,
  [SMALL_STATE(528)] = 26811,
  [SMALL_STATE(529)] = 26874,
  [SMALL_STATE(530)] = 26921,
  [SMALL_STATE(531)] = 26964,
  [SMALL_STATE(532)] = 27005,
  [SMALL_STATE(533)] = 27044,
  [SMALL_STATE(534)] = 27089,
  [SMALL_STATE(535)] = 27134,
  [SMALL_STATE(536)] = 27179,
  [SMALL_STATE(537)] = 27224,
  [SMALL_STATE(538)] = 27265,
  [SMALL_STATE(539)] = 27310,
  [SMALL_STATE(540)] = 27349,
  [SMALL_STATE(541)] = 27388,
  [SMALL_STATE(542)] = 27427,
  [SMALL_STATE(543)] = 27490,
  [SMALL_STATE(544)] = 27531,
  [SMALL_STATE(545)] = 27572,
  [SMALL_STATE(546)] = 27611,
  [SMALL_STATE(547)] = 27656,
  [SMALL_STATE(548)] = 27701,
  [SMALL_STATE(549)] = 27744,
  [SMALL_STATE(550)] = 27785,
  [SMALL_STATE(551)] = 27838,
  [SMALL_STATE(552)] = 27879,
  [SMALL_STATE(553)] = 27922,
  [SMALL_STATE(554)] = 27967,
  [SMALL_STATE(555)] = 28006,
  [SMALL_STATE(556)] = 28047,
  [SMALL_STATE(557)] = 28102,
  [SMALL_STATE(558)] = 28141,
  [SMALL_STATE(559)] = 28204,
  [SMALL_STATE(560)] = 28245,
  [SMALL_STATE(561)] = 28290,
  [SMALL_STATE(562)] = 28333,
  [SMALL_STATE(563)] = 28382,
  [SMALL_STATE(564)] = 28423,
  [SMALL_STATE(565)] = 28466,
  [SMALL_STATE(566)] = 28527,
  [SMALL_STATE(567)] = 28572,
  [SMALL_STATE(568)] = 28617,
  [SMALL_STATE(569)] = 28662,
  [SMALL_STATE(570)] = 28703,
  [SMALL_STATE(571)] = 28744,
  [SMALL_STATE(572)] = 28785,
  [SMALL_STATE(573)] = 28826,
  [SMALL_STATE(574)] = 28865,
  [SMALL_STATE(575)] = 28906,
  [SMALL_STATE(576)] = 28947,
  [SMALL_STATE(577)] = 28988,
  [SMALL_STATE(578)] = 29029,
  [SMALL_STATE(579)] = 29074,
  [SMALL_STATE(580)] = 29117,
  [SMALL_STATE(581)] = 29162,
  [SMALL_STATE(582)] = 29202,
  [SMALL_STATE(583)] = 29244,
  [SMALL_STATE(584)] = 29284,
  [SMALL_STATE(585)] = 29324,
  [SMALL_STATE(586)] = 29369,
  [SMALL_STATE(587)] = 29408,
  [SMALL_STATE(588)] = 29447,
  [SMALL_STATE(589)] = 29488,
  [SMALL_STATE(590)] = 29531,
  [SMALL_STATE(591)] = 29570,
  [SMALL_STATE(592)] = 29613,
  [SMALL_STATE(593)] = 29654,
  [SMALL_STATE(594)] = 29695,
  [SMALL_STATE(595)] = 29742,
  [SMALL_STATE(596)] = 29787,
  [SMALL_STATE(597)] = 29828,
  [SMALL_STATE(598)] = 29869,
  [SMALL_STATE(599)] = 29912,
  [SMALL_STATE(600)] = 29951,
  [SMALL_STATE(601)] = 29990,
  [SMALL_STATE(602)] = 30035,
  [SMALL_STATE(603)] = 30078,
  [SMALL_STATE(604)] = 30121,
  [SMALL_STATE(605)] = 30164,
  [SMALL_STATE(606)] = 30207,
  [SMALL_STATE(607)] = 30250,
  [SMALL_STATE(608)] = 30293,
  [SMALL_STATE(609)] = 30332,
  [SMALL_STATE(610)] = 30371,
  [SMALL_STATE(611)] = 30414,
  [SMALL_STATE(612)] = 30455,
  [SMALL_STATE(613)] = 30500,
  [SMALL_STATE(614)] = 30539,
  [SMALL_STATE(615)] = 30584,
  [SMALL_STATE(616)] = 30625,
  [SMALL_STATE(617)] = 30664,
  [SMALL_STATE(618)] = 30709,
  [SMALL_STATE(619)] = 30748,
  [SMALL_STATE(620)] = 30789,
  [SMALL_STATE(621)] = 30830,
  [SMALL_STATE(622)] = 30871,
  [SMALL_STATE(623)] = 30916,
  [SMALL_STATE(624)] = 30961,
  [SMALL_STATE(625)] = 31004,
  [SMALL_STATE(626)] = 31045,
  [SMALL_STATE(627)] = 31090,
  [SMALL_STATE(628)] = 31129,
  [SMALL_STATE(629)] = 31168,
  [SMALL_STATE(630)] = 31207,
  [SMALL_STATE(631)] = 31246,
  [SMALL_STATE(632)] = 31287,
  [SMALL_STATE(633)] = 31330,
  [SMALL_STATE(634)] = 31375,
  [SMALL_STATE(635)] = 31420,
  [SMALL_STATE(636)] = 31459,
  [SMALL_STATE(637)] = 31504,
  [SMALL_STATE(638)] = 31549,
  [SMALL_STATE(639)] = 31590,
  [SMALL_STATE(640)] = 31633,
  [SMALL_STATE(641)] = 31672,
  [SMALL_STATE(642)] = 31713,
  [SMALL_STATE(643)] = 31751,
  [SMALL_STATE(644)] = 31789,
  [SMALL_STATE(645)] = 31827,
  [SMALL_STATE(646)] = 31871,
  [SMALL_STATE(647)] = 31913,
  [SMALL_STATE(648)] = 31957,
  [SMALL_STATE(649)] = 31995,
  [SMALL_STATE(650)] = 32035,
  [SMALL_STATE(651)] = 32073,
  [SMALL_STATE(652)] = 32111,
  [SMALL_STATE(653)] = 32155,
  [SMALL_STATE(654)] = 32193,
  [SMALL_STATE(655)] = 32237,
  [SMALL_STATE(656)] = 32279,
  [SMALL_STATE(657)] = 32323,
  [SMALL_STATE(658)] = 32365,
  [SMALL_STATE(659)] = 32405,
  [SMALL_STATE(660)] = 32447,
  [SMALL_STATE(661)] = 32487,
  [SMALL_STATE(662)] = 32527,
  [SMALL_STATE(663)] = 32565,
  [SMALL_STATE(664)] = 32607,
  [SMALL_STATE(665)] = 32649,
  [SMALL_STATE(666)] = 32687,
  [SMALL_STATE(667)] = 32727,
  [SMALL_STATE(668)] = 32767,
  [SMALL_STATE(669)] = 32807,
  [SMALL_STATE(670)] = 32845,
  [SMALL_STATE(671)] = 32883,
  [SMALL_STATE(672)] = 32921,
  [SMALL_STATE(673)] = 32959,
  [SMALL_STATE(674)] = 32999,
  [SMALL_STATE(675)] = 33037,
  [SMALL_STATE(676)] = 33083,
  [SMALL_STATE(677)] = 33123,
  [SMALL_STATE(678)] = 33161,
  [SMALL_STATE(679)] = 33201,
  [SMALL_STATE(680)] = 33239,
  [SMALL_STATE(681)] = 33279,
  [SMALL_STATE(682)] = 33321,
  [SMALL_STATE(683)] = 33363,
  [SMALL_STATE(684)] = 33403,
  [SMALL_STATE(685)] = 33443,
  [SMALL_STATE(686)] = 33489,
  [SMALL_STATE(687)] = 33527,
  [SMALL_STATE(688)] = 33567,
  [SMALL_STATE(689)] = 33609,
  [SMALL_STATE(690)] = 33653,
  [SMALL_STATE(691)] = 33699,
  [SMALL_STATE(692)] = 33737,
  [SMALL_STATE(693)] = 33777,
  [SMALL_STATE(694)] = 33815,
  [SMALL_STATE(695)] = 33853,
  [SMALL_STATE(696)] = 33895,
  [SMALL_STATE(697)] = 33937,
  [SMALL_STATE(698)] = 33983,
  [SMALL_STATE(699)] = 34025,
  [SMALL_STATE(700)] = 34067,
  [SMALL_STATE(701)] = 34107,
  [SMALL_STATE(702)] = 34149,
  [SMALL_STATE(703)] = 34187,
  [SMALL_STATE(704)] = 34225,
  [SMALL_STATE(705)] = 34266,
  [SMALL_STATE(706)] = 34303,
  [SMALL_STATE(707)] = 34342,
  [SMALL_STATE(708)] = 34379,
  [SMALL_STATE(709)] = 34416,
  [SMALL_STATE(710)] = 34455,
  [SMALL_STATE(711)] = 34492,
  [SMALL_STATE(712)] = 34529,
  [SMALL_STATE(713)] = 34566,
  [SMALL_STATE(714)] = 34607,
  [SMALL_STATE(715)] = 34648,
  [SMALL_STATE(716)] = 34685,
  [SMALL_STATE(717)] = 34722,
  [SMALL_STATE(718)] = 34759,
  [SMALL_STATE(719)] = 34796,
  [SMALL_STATE(720)] = 34835,
  [SMALL_STATE(721)] = 34872,
  [SMALL_STATE(722)] = 34911,
  [SMALL_STATE(723)] = 34956,
  [SMALL_STATE(724)] = 34999,
  [SMALL_STATE(725)] = 35044,
  [SMALL_STATE(726)] = 35087,
  [SMALL_STATE(727)] = 35132,
  [SMALL_STATE(728)] = 35177,
  [SMALL_STATE(729)] = 35214,
  [SMALL_STATE(730)] = 35259,
  [SMALL_STATE(731)] = 35298,
  [SMALL_STATE(732)] = 35335,
  [SMALL_STATE(733)] = 35374,
  [SMALL_STATE(734)] = 35411,
  [SMALL_STATE(735)] = 35452,
  [SMALL_STATE(736)] = 35491,
  [SMALL_STATE(737)] = 35528,
  [SMALL_STATE(738)] = 35573,
  [SMALL_STATE(739)] = 35610,
  [SMALL_STATE(740)] = 35647,
  [SMALL_STATE(741)] = 35684,
  [SMALL_STATE(742)] = 35725,
  [SMALL_STATE(743)] = 35766,
  [SMALL_STATE(744)] = 35811,
  [SMALL_STATE(745)] = 35854,
  [SMALL_STATE(746)] = 35893,
  [SMALL_STATE(747)] = 35930,
  [SMALL_STATE(748)] = 35971,
  [SMALL_STATE(749)] = 36014,
  [SMALL_STATE(750)] = 36059,
  [SMALL_STATE(751)] = 36100,
  [SMALL_STATE(752)] = 36139,
  [SMALL_STATE(753)] = 36178,
  [SMALL_STATE(754)] = 36223,
  [SMALL_STATE(755)] = 36262,
  [SMALL_STATE(756)] = 36299,
  [SMALL_STATE(757)] = 36336,
  [SMALL_STATE(758)] = 36379,
  [SMALL_STATE(759)] = 36422,
  [SMALL_STATE(760)] = 36463,
  [SMALL_STATE(761)] = 36502,
  [SMALL_STATE(762)] = 36541,
  [SMALL_STATE(763)] = 36578,
  [SMALL_STATE(764)] = 36619,
  [SMALL_STATE(765)] = 36660,
  [SMALL_STATE(766)] = 36703,
  [SMALL_STATE(767)] = 36742,
  [SMALL_STATE(768)] = 36779,
  [SMALL_STATE(769)] = 36820,
  [SMALL_STATE(770)] = 36861,
  [SMALL_STATE(771)] = 36904,
  [SMALL_STATE(772)] = 36949,
  [SMALL_STATE(773)] = 36988,
  [SMALL_STATE(774)] = 37033,
  [SMALL_STATE(775)] = 37072,
  [SMALL_STATE(776)] = 37117,
  [SMALL_STATE(777)] = 37160,
  [SMALL_STATE(778)] = 37199,
  [SMALL_STATE(779)] = 37244,
  [SMALL_STATE(780)] = 37287,
  [SMALL_STATE(781)] = 37332,
  [SMALL_STATE(782)] = 37371,
  [SMALL_STATE(783)] = 37408,
  [SMALL_STATE(784)] = 37451,
  [SMALL_STATE(785)] = 37488,
  [SMALL_STATE(786)] = 37525,
  [SMALL_STATE(787)] = 37562,
  [SMALL_STATE(788)] = 37603,
  [SMALL_STATE(789)] = 37640,
  [SMALL_STATE(790)] = 37677,
  [SMALL_STATE(791)] = 37714,
  [SMALL_STATE(792)] = 37761,
  [SMALL_STATE(793)] = 37800,
  [SMALL_STATE(794)] = 37837,
  [SMALL_STATE(795)] = 37882,
  [SMALL_STATE(796)] = 37925,
  [SMALL_STATE(797)] = 37966,
  [SMALL_STATE(798)] = 38003,
  [SMALL_STATE(799)] = 38044,
  [SMALL_STATE(800)] = 38087,
  [SMALL_STATE(801)] = 38132,
  [SMALL_STATE(802)] = 38179,
  [SMALL_STATE(803)] = 38226,
  [SMALL_STATE(804)] = 38263,
  [SMALL_STATE(805)] = 38308,
  [SMALL_STATE(806)] = 38353,
  [SMALL_STATE(807)] = 38390,
  [SMALL_STATE(808)] = 38427,
  [SMALL_STATE(809)] = 38471,
  [SMALL_STATE(810)] = 38513,
  [SMALL_STATE(811)] = 38553,
  [SMALL_STATE(812)] = 38595,
  [SMALL_STATE(813)] = 38661,
  [SMALL_STATE(814)] = 38711,
  [SMALL_STATE(815)] = 38751,
  [SMALL_STATE(816)] = 38795,
  [SMALL_STATE(817)] = 38833,
  [SMALL_STATE(818)] = 38877,
  [SMALL_STATE(819)] = 38921,
  [SMALL_STATE(820)] = 38966,
  [SMALL_STATE(821)] = 39011,
  [SMALL_STATE(822)] = 39048,
  [SMALL_STATE(823)] = 39093,
  [SMALL_STATE(824)] = 39130,
  [SMALL_STATE(825)] = 39175,
  [SMALL_STATE(826)] = 39238,
  [SMALL_STATE(827)] = 39299,
  [SMALL_STATE(828)] = 39344,
  [SMALL_STATE(829)] = 39387,
  [SMALL_STATE(830)] = 39432,
  [SMALL_STATE(831)] = 39477,
  [SMALL_STATE(832)] = 39522,
  [SMALL_STATE(833)] = 39585,
  [SMALL_STATE(834)] = 39648,
  [SMALL_STATE(835)] = 39693,
  [SMALL_STATE(836)] = 39738,
  [SMALL_STATE(837)] = 39783,
  [SMALL_STATE(838)] = 39828,
  [SMALL_STATE(839)] = 39889,
  [SMALL_STATE(840)] = 39930,
  [SMALL_STATE(841)] = 39975,
  [SMALL_STATE(842)] = 40020,
  [SMALL_STATE(843)] = 40065,
  [SMALL_STATE(844)] = 40110,
  [SMALL_STATE(845)] = 40155,
  [SMALL_STATE(846)] = 40193,
  [SMALL_STATE(847)] = 40235,
  [SMALL_STATE(848)] = 40277,
  [SMALL_STATE(849)] = 40319,
  [SMALL_STATE(850)] = 40359,
  [SMALL_STATE(851)] = 40403,
  [SMALL_STATE(852)] = 40445,
  [SMALL_STATE(853)] = 40487,
  [SMALL_STATE(854)] = 40526,
  [SMALL_STATE(855)] = 40585,
  [SMALL_STATE(856)] = 40624,
  [SMALL_STATE(857)] = 40681,
  [SMALL_STATE(858)] = 40720,
  [SMALL_STATE(859)] = 40759,
  [SMALL_STATE(860)] = 40809,
  [SMALL_STATE(861)] = 40863,
  [SMALL_STATE(862)] = 40913,
  [SMALL_STATE(863)] = 40960,
  [SMALL_STATE(864)] = 41007,
  [SMALL_STATE(865)] = 41055,
  [SMALL_STATE(866)] = 41103,
  [SMALL_STATE(867)] = 41155,
  [SMALL_STATE(868)] = 41203,
  [SMALL_STATE(869)] = 41255,
  [SMALL_STATE(870)] = 41303,
  [SMALL_STATE(871)] = 41351,
  [SMALL_STATE(872)] = 41399,
  [SMALL_STATE(873)] = 41444,
  [SMALL_STATE(874)] = 41497,
  [SMALL_STATE(875)] = 41550,
  [SMALL_STATE(876)] = 41581,
  [SMALL_STATE(877)] = 41634,
  [SMALL_STATE(878)] = 41666,
  [SMALL_STATE(879)] = 41692,
  [SMALL_STATE(880)] = 41736,
  [SMALL_STATE(881)] = 41768,
  [SMALL_STATE(882)] = 41812,
  [SMALL_STATE(883)] = 41844,
  [SMALL_STATE(884)] = 41888,
  [SMALL_STATE(885)] = 41932,
  [SMALL_STATE(886)] = 41976,
  [SMALL_STATE(887)] = 42020,
  [SMALL_STATE(888)] = 42046,
  [SMALL_STATE(889)] = 42085,
  [SMALL_STATE(890)] = 42114,
  [SMALL_STATE(891)] = 42145,
  [SMALL_STATE(892)] = 42174,
  [SMALL_STATE(893)] = 42211,
  [SMALL_STATE(894)] = 42242,
  [SMALL_STATE(895)] = 42271,
  [SMALL_STATE(896)] = 42310,
  [SMALL_STATE(897)] = 42343,
  [SMALL_STATE(898)] = 42374,
  [SMALL_STATE(899)] = 42401,
  [SMALL_STATE(900)] = 42440,
  [SMALL_STATE(901)] = 42479,
  [SMALL_STATE(902)] = 42516,
  [SMALL_STATE(903)] = 42557,
  [SMALL_STATE(904)] = 42596,
  [SMALL_STATE(905)] = 42620,
  [SMALL_STATE(906)] = 42658,
  [SMALL_STATE(907)] = 42694,
  [SMALL_STATE(908)] = 42732,
  [SMALL_STATE(909)] = 42756,
  [SMALL_STATE(910)] = 42780,
  [SMALL_STATE(911)] = 42822,
  [SMALL_STATE(912)] = 42858,
  [SMALL_STATE(913)] = 42894,
  [SMALL_STATE(914)] = 42930,
  [SMALL_STATE(915)] = 42966,
  [SMALL_STATE(916)] = 43008,
  [SMALL_STATE(917)] = 43046,
  [SMALL_STATE(918)] = 43072,
  [SMALL_STATE(919)] = 43100,
  [SMALL_STATE(920)] = 43124,
  [SMALL_STATE(921)] = 43148,
  [SMALL_STATE(922)] = 43184,
  [SMALL_STATE(923)] = 43210,
  [SMALL_STATE(924)] = 43238,
  [SMALL_STATE(925)] = 43266,
  [SMALL_STATE(926)] = 43294,
  [SMALL_STATE(927)] = 43318,
  [SMALL_STATE(928)] = 43342,
  [SMALL_STATE(929)] = 43366,
  [SMALL_STATE(930)] = 43390,
  [SMALL_STATE(931)] = 43414,
  [SMALL_STATE(932)] = 43438,
  [SMALL_STATE(933)] = 43480,
  [SMALL_STATE(934)] = 43516,
  [SMALL_STATE(935)] = 43545,
  [SMALL_STATE(936)] = 43580,
  [SMALL_STATE(937)] = 43607,
  [SMALL_STATE(938)] = 43636,
  [SMALL_STATE(939)] = 43665,
  [SMALL_STATE(940)] = 43700,
  [SMALL_STATE(941)] = 43729,
  [SMALL_STATE(942)] = 43754,
  [SMALL_STATE(943)] = 43791,
  [SMALL_STATE(944)] = 43820,
  [SMALL_STATE(945)] = 43849,
  [SMALL_STATE(946)] = 43878,
  [SMALL_STATE(947)] = 43913,
  [SMALL_STATE(948)] = 43938,
  [SMALL_STATE(949)] = 43965,
  [SMALL_STATE(950)] = 43990,
  [SMALL_STATE(951)] = 44023,
  [SMALL_STATE(952)] = 44052,
  [SMALL_STATE(953)] = 44089,
  [SMALL_STATE(954)] = 44117,
  [SMALL_STATE(955)] = 44139,
  [SMALL_STATE(956)] = 44167,
  [SMALL_STATE(957)] = 44191,
  [SMALL_STATE(958)] = 44213,
  [SMALL_STATE(959)] = 44241,
  [SMALL_STATE(960)] = 44269,
  [SMALL_STATE(961)] = 44299,
  [SMALL_STATE(962)] = 44329,
  [SMALL_STATE(963)] = 44353,
  [SMALL_STATE(964)] = 44383,
  [SMALL_STATE(965)] = 44413,
  [SMALL_STATE(966)] = 44441,
  [SMALL_STATE(967)] = 44471,
  [SMALL_STATE(968)] = 44502,
  [SMALL_STATE(969)] = 44531,
  [SMALL_STATE(970)] = 44560,
  [SMALL_STATE(971)] = 44583,
  [SMALL_STATE(972)] = 44612,
  [SMALL_STATE(973)] = 44635,
  [SMALL_STATE(974)] = 44658,
  [SMALL_STATE(975)] = 44691,
  [SMALL_STATE(976)] = 44724,
  [SMALL_STATE(977)] = 44757,
  [SMALL_STATE(978)] = 44790,
  [SMALL_STATE(979)] = 44817,
  [SMALL_STATE(980)] = 44846,
  [SMALL_STATE(981)] = 44875,
  [SMALL_STATE(982)] = 44904,
  [SMALL_STATE(983)] = 44933,
  [SMALL_STATE(984)] = 44964,
  [SMALL_STATE(985)] = 44995,
  [SMALL_STATE(986)] = 45018,
  [SMALL_STATE(987)] = 45047,
  [SMALL_STATE(988)] = 45078,
  [SMALL_STATE(989)] = 45109,
  [SMALL_STATE(990)] = 45140,
  [SMALL_STATE(991)] = 45171,
  [SMALL_STATE(992)] = 45202,
  [SMALL_STATE(993)] = 45233,
  [SMALL_STATE(994)] = 45262,
  [SMALL_STATE(995)] = 45293,
  [SMALL_STATE(996)] = 45324,
  [SMALL_STATE(997)] = 45355,
  [SMALL_STATE(998)] = 45386,
  [SMALL_STATE(999)] = 45419,
  [SMALL_STATE(1000)] = 45439,
  [SMALL_STATE(1001)] = 45465,
  [SMALL_STATE(1002)] = 45491,
  [SMALL_STATE(1003)] = 45519,
  [SMALL_STATE(1004)] = 45541,
  [SMALL_STATE(1005)] = 45567,
  [SMALL_STATE(1006)] = 45599,
  [SMALL_STATE(1007)] = 45625,
  [SMALL_STATE(1008)] = 45647,
  [SMALL_STATE(1009)] = 45667,
  [SMALL_STATE(1010)] = 45699,
  [SMALL_STATE(1011)] = 45726,
  [SMALL_STATE(1012)] = 45753,
  [SMALL_STATE(1013)] = 45780,
  [SMALL_STATE(1014)] = 45805,
  [SMALL_STATE(1015)] = 45838,
  [SMALL_STATE(1016)] = 45871,
  [SMALL_STATE(1017)] = 45896,
  [SMALL_STATE(1018)] = 45927,
  [SMALL_STATE(1019)] = 45954,
  [SMALL_STATE(1020)] = 45981,
  [SMALL_STATE(1021)] = 46012,
  [SMALL_STATE(1022)] = 46039,
  [SMALL_STATE(1023)] = 46064,
  [SMALL_STATE(1024)] = 46095,
  [SMALL_STATE(1025)] = 46114,
  [SMALL_STATE(1026)] = 46141,
  [SMALL_STATE(1027)] = 46168,
  [SMALL_STATE(1028)] = 46195,
  [SMALL_STATE(1029)] = 46222,
  [SMALL_STATE(1030)] = 46252,
  [SMALL_STATE(1031)] = 46282,
  [SMALL_STATE(1032)] = 46306,
  [SMALL_STATE(1033)] = 46332,
  [SMALL_STATE(1034)] = 46362,
  [SMALL_STATE(1035)] = 46392,
  [SMALL_STATE(1036)] = 46416,
  [SMALL_STATE(1037)] = 46440,
  [SMALL_STATE(1038)] = 46464,
  [SMALL_STATE(1039)] = 46488,
  [SMALL_STATE(1040)] = 46512,
  [SMALL_STATE(1041)] = 46536,
  [SMALL_STATE(1042)] = 46560,
  [SMALL_STATE(1043)] = 46584,
  [SMALL_STATE(1044)] = 46608,
  [SMALL_STATE(1045)] = 46632,
  [SMALL_STATE(1046)] = 46656,
  [SMALL_STATE(1047)] = 46680,
  [SMALL_STATE(1048)] = 46704,
  [SMALL_STATE(1049)] = 46728,
  [SMALL_STATE(1050)] = 46752,
  [SMALL_STATE(1051)] = 46778,
  [SMALL_STATE(1052)] = 46802,
  [SMALL_STATE(1053)] = 46826,
  [SMALL_STATE(1054)] = 46850,
  [SMALL_STATE(1055)] = 46874,
  [SMALL_STATE(1056)] = 46898,
  [SMALL_STATE(1057)] = 46922,
  [SMALL_STATE(1058)] = 46942,
  [SMALL_STATE(1059)] = 46966,
  [SMALL_STATE(1060)] = 46992,
  [SMALL_STATE(1061)] = 47022,
  [SMALL_STATE(1062)] = 47046,
  [SMALL_STATE(1063)] = 47070,
  [SMALL_STATE(1064)] = 47094,
  [SMALL_STATE(1065)] = 47118,
  [SMALL_STATE(1066)] = 47148,
  [SMALL_STATE(1067)] = 47172,
  [SMALL_STATE(1068)] = 47196,
  [SMALL_STATE(1069)] = 47220,
  [SMALL_STATE(1070)] = 47244,
  [SMALL_STATE(1071)] = 47268,
  [SMALL_STATE(1072)] = 47292,
  [SMALL_STATE(1073)] = 47316,
  [SMALL_STATE(1074)] = 47340,
  [SMALL_STATE(1075)] = 47364,
  [SMALL_STATE(1076)] = 47394,
  [SMALL_STATE(1077)] = 47418,
  [SMALL_STATE(1078)] = 47448,
  [SMALL_STATE(1079)] = 47472,
  [SMALL_STATE(1080)] = 47496,
  [SMALL_STATE(1081)] = 47526,
  [SMALL_STATE(1082)] = 47550,
  [SMALL_STATE(1083)] = 47580,
  [SMALL_STATE(1084)] = 47604,
  [SMALL_STATE(1085)] = 47628,
  [SMALL_STATE(1086)] = 47654,
  [SMALL_STATE(1087)] = 47678,
  [SMALL_STATE(1088)] = 47702,
  [SMALL_STATE(1089)] = 47726,
  [SMALL_STATE(1090)] = 47750,
  [SMALL_STATE(1091)] = 47771,
  [SMALL_STATE(1092)] = 47796,
  [SMALL_STATE(1093)] = 47817,
  [SMALL_STATE(1094)] = 47838,
  [SMALL_STATE(1095)] = 47859,
  [SMALL_STATE(1096)] = 47880,
  [SMALL_STATE(1097)] = 47901,
  [SMALL_STATE(1098)] = 47922,
  [SMALL_STATE(1099)] = 47947,
  [SMALL_STATE(1100)] = 47974,
  [SMALL_STATE(1101)] = 47995,
  [SMALL_STATE(1102)] = 48016,
  [SMALL_STATE(1103)] = 48043,
  [SMALL_STATE(1104)] = 48068,
  [SMALL_STATE(1105)] = 48089,
  [SMALL_STATE(1106)] = 48116,
  [SMALL_STATE(1107)] = 48137,
  [SMALL_STATE(1108)] = 48158,
  [SMALL_STATE(1109)] = 48179,
  [SMALL_STATE(1110)] = 48200,
  [SMALL_STATE(1111)] = 48221,
  [SMALL_STATE(1112)] = 48242,
  [SMALL_STATE(1113)] = 48263,
  [SMALL_STATE(1114)] = 48284,
  [SMALL_STATE(1115)] = 48305,
  [SMALL_STATE(1116)] = 48326,
  [SMALL_STATE(1117)] = 48347,
  [SMALL_STATE(1118)] = 48368,
  [SMALL_STATE(1119)] = 48389,
  [SMALL_STATE(1120)] = 48410,
  [SMALL_STATE(1121)] = 48431,
  [SMALL_STATE(1122)] = 48455,
  [SMALL_STATE(1123)] = 48479,
  [SMALL_STATE(1124)] = 48503,
  [SMALL_STATE(1125)] = 48527,
  [SMALL_STATE(1126)] = 48547,
  [SMALL_STATE(1127)] = 48571,
  [SMALL_STATE(1128)] = 48595,
  [SMALL_STATE(1129)] = 48619,
  [SMALL_STATE(1130)] = 48643,
  [SMALL_STATE(1131)] = 48667,
  [SMALL_STATE(1132)] = 48691,
  [SMALL_STATE(1133)] = 48715,
  [SMALL_STATE(1134)] = 48739,
  [SMALL_STATE(1135)] = 48763,
  [SMALL_STATE(1136)] = 48783,
  [SMALL_STATE(1137)] = 48807,
  [SMALL_STATE(1138)] = 48831,
  [SMALL_STATE(1139)] = 48855,
  [SMALL_STATE(1140)] = 48879,
  [SMALL_STATE(1141)] = 48903,
  [SMALL_STATE(1142)] = 48927,
  [SMALL_STATE(1143)] = 48951,
  [SMALL_STATE(1144)] = 48975,
  [SMALL_STATE(1145)] = 48999,
  [SMALL_STATE(1146)] = 49023,
  [SMALL_STATE(1147)] = 49047,
  [SMALL_STATE(1148)] = 49071,
  [SMALL_STATE(1149)] = 49092,
  [SMALL_STATE(1150)] = 49113,
  [SMALL_STATE(1151)] = 49136,
  [SMALL_STATE(1152)] = 49157,
  [SMALL_STATE(1153)] = 49178,
  [SMALL_STATE(1154)] = 49193,
  [SMALL_STATE(1155)] = 49214,
  [SMALL_STATE(1156)] = 49235,
  [SMALL_STATE(1157)] = 49256,
  [SMALL_STATE(1158)] = 49279,
  [SMALL_STATE(1159)] = 49300,
  [SMALL_STATE(1160)] = 49323,
  [SMALL_STATE(1161)] = 49344,
  [SMALL_STATE(1162)] = 49365,
  [SMALL_STATE(1163)] = 49386,
  [SMALL_STATE(1164)] = 49407,
  [SMALL_STATE(1165)] = 49422,
  [SMALL_STATE(1166)] = 49443,
  [SMALL_STATE(1167)] = 49459,
  [SMALL_STATE(1168)] = 49479,
  [SMALL_STATE(1169)] = 49497,
  [SMALL_STATE(1170)] = 49513,
  [SMALL_STATE(1171)] = 49529,
  [SMALL_STATE(1172)] = 49545,
  [SMALL_STATE(1173)] = 49561,
  [SMALL_STATE(1174)] = 49581,
  [SMALL_STATE(1175)] = 49597,
  [SMALL_STATE(1176)] = 49613,
  [SMALL_STATE(1177)] = 49629,
  [SMALL_STATE(1178)] = 49647,
  [SMALL_STATE(1179)] = 49665,
  [SMALL_STATE(1180)] = 49683,
  [SMALL_STATE(1181)] = 49703,
  [SMALL_STATE(1182)] = 49723,
  [SMALL_STATE(1183)] = 49739,
  [SMALL_STATE(1184)] = 49759,
  [SMALL_STATE(1185)] = 49777,
  [SMALL_STATE(1186)] = 49793,
  [SMALL_STATE(1187)] = 49813,
  [SMALL_STATE(1188)] = 49831,
  [SMALL_STATE(1189)] = 49851,
  [SMALL_STATE(1190)] = 49867,
  [SMALL_STATE(1191)] = 49883,
  [SMALL_STATE(1192)] = 49899,
  [SMALL_STATE(1193)] = 49919,
  [SMALL_STATE(1194)] = 49939,
  [SMALL_STATE(1195)] = 49957,
  [SMALL_STATE(1196)] = 49973,
  [SMALL_STATE(1197)] = 49993,
  [SMALL_STATE(1198)] = 50009,
  [SMALL_STATE(1199)] = 50029,
  [SMALL_STATE(1200)] = 50049,
  [SMALL_STATE(1201)] = 50065,
  [SMALL_STATE(1202)] = 50083,
  [SMALL_STATE(1203)] = 50103,
  [SMALL_STATE(1204)] = 50123,
  [SMALL_STATE(1205)] = 50143,
  [SMALL_STATE(1206)] = 50161,
  [SMALL_STATE(1207)] = 50179,
  [SMALL_STATE(1208)] = 50195,
  [SMALL_STATE(1209)] = 50213,
  [SMALL_STATE(1210)] = 50231,
  [SMALL_STATE(1211)] = 50249,
  [SMALL_STATE(1212)] = 50269,
  [SMALL_STATE(1213)] = 50287,
  [SMALL_STATE(1214)] = 50305,
  [SMALL_STATE(1215)] = 50323,
  [SMALL_STATE(1216)] = 50343,
  [SMALL_STATE(1217)] = 50363,
  [SMALL_STATE(1218)] = 50379,
  [SMALL_STATE(1219)] = 50397,
  [SMALL_STATE(1220)] = 50417,
  [SMALL_STATE(1221)] = 50437,
  [SMALL_STATE(1222)] = 50457,
  [SMALL_STATE(1223)] = 50475,
  [SMALL_STATE(1224)] = 50491,
  [SMALL_STATE(1225)] = 50509,
  [SMALL_STATE(1226)] = 50524,
  [SMALL_STATE(1227)] = 50541,
  [SMALL_STATE(1228)] = 50558,
  [SMALL_STATE(1229)] = 50577,
  [SMALL_STATE(1230)] = 50592,
  [SMALL_STATE(1231)] = 50611,
  [SMALL_STATE(1232)] = 50630,
  [SMALL_STATE(1233)] = 50647,
  [SMALL_STATE(1234)] = 50664,
  [SMALL_STATE(1235)] = 50683,
  [SMALL_STATE(1236)] = 50702,
  [SMALL_STATE(1237)] = 50715,
  [SMALL_STATE(1238)] = 50734,
  [SMALL_STATE(1239)] = 50751,
  [SMALL_STATE(1240)] = 50770,
  [SMALL_STATE(1241)] = 50791,
  [SMALL_STATE(1242)] = 50810,
  [SMALL_STATE(1243)] = 50827,
  [SMALL_STATE(1244)] = 50840,
  [SMALL_STATE(1245)] = 50853,
  [SMALL_STATE(1246)] = 50866,
  [SMALL_STATE(1247)] = 50887,
  [SMALL_STATE(1248)] = 50904,
  [SMALL_STATE(1249)] = 50925,
  [SMALL_STATE(1250)] = 50944,
  [SMALL_STATE(1251)] = 50965,
  [SMALL_STATE(1252)] = 50984,
  [SMALL_STATE(1253)] = 51001,
  [SMALL_STATE(1254)] = 51018,
  [SMALL_STATE(1255)] = 51035,
  [SMALL_STATE(1256)] = 51048,
  [SMALL_STATE(1257)] = 51061,
  [SMALL_STATE(1258)] = 51078,
  [SMALL_STATE(1259)] = 51095,
  [SMALL_STATE(1260)] = 51110,
  [SMALL_STATE(1261)] = 51123,
  [SMALL_STATE(1262)] = 51136,
  [SMALL_STATE(1263)] = 51157,
  [SMALL_STATE(1264)] = 51172,
  [SMALL_STATE(1265)] = 51187,
  [SMALL_STATE(1266)] = 51204,
  [SMALL_STATE(1267)] = 51221,
  [SMALL_STATE(1268)] = 51238,
  [SMALL_STATE(1269)] = 51255,
  [SMALL_STATE(1270)] = 51268,
  [SMALL_STATE(1271)] = 51285,
  [SMALL_STATE(1272)] = 51298,
  [SMALL_STATE(1273)] = 51313,
  [SMALL_STATE(1274)] = 51334,
  [SMALL_STATE(1275)] = 51351,
  [SMALL_STATE(1276)] = 51372,
  [SMALL_STATE(1277)] = 51389,
  [SMALL_STATE(1278)] = 51408,
  [SMALL_STATE(1279)] = 51423,
  [SMALL_STATE(1280)] = 51440,
  [SMALL_STATE(1281)] = 51459,
  [SMALL_STATE(1282)] = 51478,
  [SMALL_STATE(1283)] = 51495,
  [SMALL_STATE(1284)] = 51510,
  [SMALL_STATE(1285)] = 51527,
  [SMALL_STATE(1286)] = 51542,
  [SMALL_STATE(1287)] = 51561,
  [SMALL_STATE(1288)] = 51578,
  [SMALL_STATE(1289)] = 51595,
  [SMALL_STATE(1290)] = 51608,
  [SMALL_STATE(1291)] = 51625,
  [SMALL_STATE(1292)] = 51640,
  [SMALL_STATE(1293)] = 51659,
  [SMALL_STATE(1294)] = 51676,
  [SMALL_STATE(1295)] = 51695,
  [SMALL_STATE(1296)] = 51712,
  [SMALL_STATE(1297)] = 51729,
  [SMALL_STATE(1298)] = 51746,
  [SMALL_STATE(1299)] = 51763,
  [SMALL_STATE(1300)] = 51780,
  [SMALL_STATE(1301)] = 51797,
  [SMALL_STATE(1302)] = 51812,
  [SMALL_STATE(1303)] = 51829,
  [SMALL_STATE(1304)] = 51846,
  [SMALL_STATE(1305)] = 51863,
  [SMALL_STATE(1306)] = 51882,
  [SMALL_STATE(1307)] = 51899,
  [SMALL_STATE(1308)] = 51916,
  [SMALL_STATE(1309)] = 51933,
  [SMALL_STATE(1310)] = 51952,
  [SMALL_STATE(1311)] = 51971,
  [SMALL_STATE(1312)] = 51990,
  [SMALL_STATE(1313)] = 52005,
  [SMALL_STATE(1314)] = 52022,
  [SMALL_STATE(1315)] = 52039,
  [SMALL_STATE(1316)] = 52058,
  [SMALL_STATE(1317)] = 52077,
  [SMALL_STATE(1318)] = 52094,
  [SMALL_STATE(1319)] = 52111,
  [SMALL_STATE(1320)] = 52128,
  [SMALL_STATE(1321)] = 52143,
  [SMALL_STATE(1322)] = 52160,
  [SMALL_STATE(1323)] = 52177,
  [SMALL_STATE(1324)] = 52196,
  [SMALL_STATE(1325)] = 52215,
  [SMALL_STATE(1326)] = 52232,
  [SMALL_STATE(1327)] = 52249,
  [SMALL_STATE(1328)] = 52268,
  [SMALL_STATE(1329)] = 52285,
  [SMALL_STATE(1330)] = 52304,
  [SMALL_STATE(1331)] = 52323,
  [SMALL_STATE(1332)] = 52340,
  [SMALL_STATE(1333)] = 52359,
  [SMALL_STATE(1334)] = 52374,
  [SMALL_STATE(1335)] = 52391,
  [SMALL_STATE(1336)] = 52408,
  [SMALL_STATE(1337)] = 52425,
  [SMALL_STATE(1338)] = 52444,
  [SMALL_STATE(1339)] = 52461,
  [SMALL_STATE(1340)] = 52480,
  [SMALL_STATE(1341)] = 52495,
  [SMALL_STATE(1342)] = 52514,
  [SMALL_STATE(1343)] = 52531,
  [SMALL_STATE(1344)] = 52552,
  [SMALL_STATE(1345)] = 52573,
  [SMALL_STATE(1346)] = 52586,
  [SMALL_STATE(1347)] = 52603,
  [SMALL_STATE(1348)] = 52619,
  [SMALL_STATE(1349)] = 52633,
  [SMALL_STATE(1350)] = 52645,
  [SMALL_STATE(1351)] = 52663,
  [SMALL_STATE(1352)] = 52677,
  [SMALL_STATE(1353)] = 52695,
  [SMALL_STATE(1354)] = 52711,
  [SMALL_STATE(1355)] = 52729,
  [SMALL_STATE(1356)] = 52741,
  [SMALL_STATE(1357)] = 52757,
  [SMALL_STATE(1358)] = 52771,
  [SMALL_STATE(1359)] = 52785,
  [SMALL_STATE(1360)] = 52799,
  [SMALL_STATE(1361)] = 52817,
  [SMALL_STATE(1362)] = 52831,
  [SMALL_STATE(1363)] = 52845,
  [SMALL_STATE(1364)] = 52861,
  [SMALL_STATE(1365)] = 52879,
  [SMALL_STATE(1366)] = 52897,
  [SMALL_STATE(1367)] = 52913,
  [SMALL_STATE(1368)] = 52927,
  [SMALL_STATE(1369)] = 52941,
  [SMALL_STATE(1370)] = 52955,
  [SMALL_STATE(1371)] = 52969,
  [SMALL_STATE(1372)] = 52983,
  [SMALL_STATE(1373)] = 52997,
  [SMALL_STATE(1374)] = 53011,
  [SMALL_STATE(1375)] = 53025,
  [SMALL_STATE(1376)] = 53041,
  [SMALL_STATE(1377)] = 53059,
  [SMALL_STATE(1378)] = 53075,
  [SMALL_STATE(1379)] = 53091,
  [SMALL_STATE(1380)] = 53107,
  [SMALL_STATE(1381)] = 53127,
  [SMALL_STATE(1382)] = 53139,
  [SMALL_STATE(1383)] = 53155,
  [SMALL_STATE(1384)] = 53169,
  [SMALL_STATE(1385)] = 53185,
  [SMALL_STATE(1386)] = 53199,
  [SMALL_STATE(1387)] = 53213,
  [SMALL_STATE(1388)] = 53227,
  [SMALL_STATE(1389)] = 53241,
  [SMALL_STATE(1390)] = 53257,
  [SMALL_STATE(1391)] = 53273,
  [SMALL_STATE(1392)] = 53287,
  [SMALL_STATE(1393)] = 53303,
  [SMALL_STATE(1394)] = 53319,
  [SMALL_STATE(1395)] = 53333,
  [SMALL_STATE(1396)] = 53347,
  [SMALL_STATE(1397)] = 53363,
  [SMALL_STATE(1398)] = 53379,
  [SMALL_STATE(1399)] = 53395,
  [SMALL_STATE(1400)] = 53411,
  [SMALL_STATE(1401)] = 53423,
  [SMALL_STATE(1402)] = 53437,
  [SMALL_STATE(1403)] = 53451,
  [SMALL_STATE(1404)] = 53465,
  [SMALL_STATE(1405)] = 53480,
  [SMALL_STATE(1406)] = 53495,
  [SMALL_STATE(1407)] = 53506,
  [SMALL_STATE(1408)] = 53523,
  [SMALL_STATE(1409)] = 53538,
  [SMALL_STATE(1410)] = 53551,
  [SMALL_STATE(1411)] = 53562,
  [SMALL_STATE(1412)] = 53579,
  [SMALL_STATE(1413)] = 53594,
  [SMALL_STATE(1414)] = 53605,
  [SMALL_STATE(1415)] = 53616,
  [SMALL_STATE(1416)] = 53627,
  [SMALL_STATE(1417)] = 53638,
  [SMALL_STATE(1418)] = 53653,
  [SMALL_STATE(1419)] = 53664,
  [SMALL_STATE(1420)] = 53675,
  [SMALL_STATE(1421)] = 53686,
  [SMALL_STATE(1422)] = 53701,
  [SMALL_STATE(1423)] = 53712,
  [SMALL_STATE(1424)] = 53723,
  [SMALL_STATE(1425)] = 53736,
  [SMALL_STATE(1426)] = 53753,
  [SMALL_STATE(1427)] = 53770,
  [SMALL_STATE(1428)] = 53781,
  [SMALL_STATE(1429)] = 53796,
  [SMALL_STATE(1430)] = 53807,
  [SMALL_STATE(1431)] = 53822,
  [SMALL_STATE(1432)] = 53833,
  [SMALL_STATE(1433)] = 53848,
  [SMALL_STATE(1434)] = 53859,
  [SMALL_STATE(1435)] = 53872,
  [SMALL_STATE(1436)] = 53887,
  [SMALL_STATE(1437)] = 53902,
  [SMALL_STATE(1438)] = 53913,
  [SMALL_STATE(1439)] = 53924,
  [SMALL_STATE(1440)] = 53935,
  [SMALL_STATE(1441)] = 53950,
  [SMALL_STATE(1442)] = 53961,
  [SMALL_STATE(1443)] = 53976,
  [SMALL_STATE(1444)] = 53987,
  [SMALL_STATE(1445)] = 54000,
  [SMALL_STATE(1446)] = 54011,
  [SMALL_STATE(1447)] = 54022,
  [SMALL_STATE(1448)] = 54035,
  [SMALL_STATE(1449)] = 54046,
  [SMALL_STATE(1450)] = 54057,
  [SMALL_STATE(1451)] = 54068,
  [SMALL_STATE(1452)] = 54081,
  [SMALL_STATE(1453)] = 54096,
  [SMALL_STATE(1454)] = 54109,
  [SMALL_STATE(1455)] = 54120,
  [SMALL_STATE(1456)] = 54133,
  [SMALL_STATE(1457)] = 54144,
  [SMALL_STATE(1458)] = 54157,
  [SMALL_STATE(1459)] = 54172,
  [SMALL_STATE(1460)] = 54183,
  [SMALL_STATE(1461)] = 54194,
  [SMALL_STATE(1462)] = 54205,
  [SMALL_STATE(1463)] = 54216,
  [SMALL_STATE(1464)] = 54233,
  [SMALL_STATE(1465)] = 54244,
  [SMALL_STATE(1466)] = 54259,
  [SMALL_STATE(1467)] = 54274,
  [SMALL_STATE(1468)] = 54285,
  [SMALL_STATE(1469)] = 54300,
  [SMALL_STATE(1470)] = 54315,
  [SMALL_STATE(1471)] = 54330,
  [SMALL_STATE(1472)] = 54345,
  [SMALL_STATE(1473)] = 54360,
  [SMALL_STATE(1474)] = 54375,
  [SMALL_STATE(1475)] = 54392,
  [SMALL_STATE(1476)] = 54409,
  [SMALL_STATE(1477)] = 54426,
  [SMALL_STATE(1478)] = 54441,
  [SMALL_STATE(1479)] = 54452,
  [SMALL_STATE(1480)] = 54469,
  [SMALL_STATE(1481)] = 54486,
  [SMALL_STATE(1482)] = 54501,
  [SMALL_STATE(1483)] = 54512,
  [SMALL_STATE(1484)] = 54527,
  [SMALL_STATE(1485)] = 54538,
  [SMALL_STATE(1486)] = 54555,
  [SMALL_STATE(1487)] = 54572,
  [SMALL_STATE(1488)] = 54589,
  [SMALL_STATE(1489)] = 54606,
  [SMALL_STATE(1490)] = 54623,
  [SMALL_STATE(1491)] = 54634,
  [SMALL_STATE(1492)] = 54649,
  [SMALL_STATE(1493)] = 54664,
  [SMALL_STATE(1494)] = 54675,
  [SMALL_STATE(1495)] = 54692,
  [SMALL_STATE(1496)] = 54709,
  [SMALL_STATE(1497)] = 54726,
  [SMALL_STATE(1498)] = 54741,
  [SMALL_STATE(1499)] = 54758,
  [SMALL_STATE(1500)] = 54773,
  [SMALL_STATE(1501)] = 54790,
  [SMALL_STATE(1502)] = 54807,
  [SMALL_STATE(1503)] = 54824,
  [SMALL_STATE(1504)] = 54839,
  [SMALL_STATE(1505)] = 54850,
  [SMALL_STATE(1506)] = 54865,
  [SMALL_STATE(1507)] = 54882,
  [SMALL_STATE(1508)] = 54893,
  [SMALL_STATE(1509)] = 54908,
  [SMALL_STATE(1510)] = 54919,
  [SMALL_STATE(1511)] = 54930,
  [SMALL_STATE(1512)] = 54945,
  [SMALL_STATE(1513)] = 54962,
  [SMALL_STATE(1514)] = 54977,
  [SMALL_STATE(1515)] = 54988,
  [SMALL_STATE(1516)] = 54999,
  [SMALL_STATE(1517)] = 55016,
  [SMALL_STATE(1518)] = 55027,
  [SMALL_STATE(1519)] = 55044,
  [SMALL_STATE(1520)] = 55055,
  [SMALL_STATE(1521)] = 55068,
  [SMALL_STATE(1522)] = 55081,
  [SMALL_STATE(1523)] = 55092,
  [SMALL_STATE(1524)] = 55105,
  [SMALL_STATE(1525)] = 55116,
  [SMALL_STATE(1526)] = 55129,
  [SMALL_STATE(1527)] = 55146,
  [SMALL_STATE(1528)] = 55159,
  [SMALL_STATE(1529)] = 55170,
  [SMALL_STATE(1530)] = 55181,
  [SMALL_STATE(1531)] = 55192,
  [SMALL_STATE(1532)] = 55207,
  [SMALL_STATE(1533)] = 55220,
  [SMALL_STATE(1534)] = 55231,
  [SMALL_STATE(1535)] = 55242,
  [SMALL_STATE(1536)] = 55259,
  [SMALL_STATE(1537)] = 55276,
  [SMALL_STATE(1538)] = 55289,
  [SMALL_STATE(1539)] = 55302,
  [SMALL_STATE(1540)] = 55313,
  [SMALL_STATE(1541)] = 55324,
  [SMALL_STATE(1542)] = 55341,
  [SMALL_STATE(1543)] = 55356,
  [SMALL_STATE(1544)] = 55373,
  [SMALL_STATE(1545)] = 55388,
  [SMALL_STATE(1546)] = 55405,
  [SMALL_STATE(1547)] = 55422,
  [SMALL_STATE(1548)] = 55439,
  [SMALL_STATE(1549)] = 55456,
  [SMALL_STATE(1550)] = 55473,
  [SMALL_STATE(1551)] = 55490,
  [SMALL_STATE(1552)] = 55501,
  [SMALL_STATE(1553)] = 55516,
  [SMALL_STATE(1554)] = 55531,
  [SMALL_STATE(1555)] = 55548,
  [SMALL_STATE(1556)] = 55561,
  [SMALL_STATE(1557)] = 55576,
  [SMALL_STATE(1558)] = 55593,
  [SMALL_STATE(1559)] = 55610,
  [SMALL_STATE(1560)] = 55623,
  [SMALL_STATE(1561)] = 55638,
  [SMALL_STATE(1562)] = 55651,
  [SMALL_STATE(1563)] = 55668,
  [SMALL_STATE(1564)] = 55685,
  [SMALL_STATE(1565)] = 55696,
  [SMALL_STATE(1566)] = 55707,
  [SMALL_STATE(1567)] = 55724,
  [SMALL_STATE(1568)] = 55741,
  [SMALL_STATE(1569)] = 55758,
  [SMALL_STATE(1570)] = 55775,
  [SMALL_STATE(1571)] = 55792,
  [SMALL_STATE(1572)] = 55809,
  [SMALL_STATE(1573)] = 55822,
  [SMALL_STATE(1574)] = 55839,
  [SMALL_STATE(1575)] = 55856,
  [SMALL_STATE(1576)] = 55873,
  [SMALL_STATE(1577)] = 55886,
  [SMALL_STATE(1578)] = 55897,
  [SMALL_STATE(1579)] = 55912,
  [SMALL_STATE(1580)] = 55929,
  [SMALL_STATE(1581)] = 55940,
  [SMALL_STATE(1582)] = 55951,
  [SMALL_STATE(1583)] = 55962,
  [SMALL_STATE(1584)] = 55973,
  [SMALL_STATE(1585)] = 55984,
  [SMALL_STATE(1586)] = 55997,
  [SMALL_STATE(1587)] = 56008,
  [SMALL_STATE(1588)] = 56021,
  [SMALL_STATE(1589)] = 56032,
  [SMALL_STATE(1590)] = 56043,
  [SMALL_STATE(1591)] = 56056,
  [SMALL_STATE(1592)] = 56067,
  [SMALL_STATE(1593)] = 56080,
  [SMALL_STATE(1594)] = 56093,
  [SMALL_STATE(1595)] = 56104,
  [SMALL_STATE(1596)] = 56115,
  [SMALL_STATE(1597)] = 56126,
  [SMALL_STATE(1598)] = 56141,
  [SMALL_STATE(1599)] = 56152,
  [SMALL_STATE(1600)] = 56167,
  [SMALL_STATE(1601)] = 56181,
  [SMALL_STATE(1602)] = 56195,
  [SMALL_STATE(1603)] = 56209,
  [SMALL_STATE(1604)] = 56219,
  [SMALL_STATE(1605)] = 56231,
  [SMALL_STATE(1606)] = 56245,
  [SMALL_STATE(1607)] = 56259,
  [SMALL_STATE(1608)] = 56271,
  [SMALL_STATE(1609)] = 56285,
  [SMALL_STATE(1610)] = 56297,
  [SMALL_STATE(1611)] = 56307,
  [SMALL_STATE(1612)] = 56321,
  [SMALL_STATE(1613)] = 56331,
  [SMALL_STATE(1614)] = 56343,
  [SMALL_STATE(1615)] = 56355,
  [SMALL_STATE(1616)] = 56367,
  [SMALL_STATE(1617)] = 56379,
  [SMALL_STATE(1618)] = 56391,
  [SMALL_STATE(1619)] = 56405,
  [SMALL_STATE(1620)] = 56417,
  [SMALL_STATE(1621)] = 56431,
  [SMALL_STATE(1622)] = 56443,
  [SMALL_STATE(1623)] = 56455,
  [SMALL_STATE(1624)] = 56469,
  [SMALL_STATE(1625)] = 56481,
  [SMALL_STATE(1626)] = 56493,
  [SMALL_STATE(1627)] = 56505,
  [SMALL_STATE(1628)] = 56519,
  [SMALL_STATE(1629)] = 56531,
  [SMALL_STATE(1630)] = 56543,
  [SMALL_STATE(1631)] = 56555,
  [SMALL_STATE(1632)] = 56567,
  [SMALL_STATE(1633)] = 56579,
  [SMALL_STATE(1634)] = 56591,
  [SMALL_STATE(1635)] = 56605,
  [SMALL_STATE(1636)] = 56617,
  [SMALL_STATE(1637)] = 56629,
  [SMALL_STATE(1638)] = 56643,
  [SMALL_STATE(1639)] = 56657,
  [SMALL_STATE(1640)] = 56671,
  [SMALL_STATE(1641)] = 56683,
  [SMALL_STATE(1642)] = 56697,
  [SMALL_STATE(1643)] = 56711,
  [SMALL_STATE(1644)] = 56723,
  [SMALL_STATE(1645)] = 56737,
  [SMALL_STATE(1646)] = 56751,
  [SMALL_STATE(1647)] = 56765,
  [SMALL_STATE(1648)] = 56779,
  [SMALL_STATE(1649)] = 56793,
  [SMALL_STATE(1650)] = 56807,
  [SMALL_STATE(1651)] = 56819,
  [SMALL_STATE(1652)] = 56831,
  [SMALL_STATE(1653)] = 56843,
  [SMALL_STATE(1654)] = 56855,
  [SMALL_STATE(1655)] = 56867,
  [SMALL_STATE(1656)] = 56876,
  [SMALL_STATE(1657)] = 56885,
  [SMALL_STATE(1658)] = 56894,
  [SMALL_STATE(1659)] = 56905,
  [SMALL_STATE(1660)] = 56916,
  [SMALL_STATE(1661)] = 56925,
  [SMALL_STATE(1662)] = 56934,
  [SMALL_STATE(1663)] = 56943,
  [SMALL_STATE(1664)] = 56952,
  [SMALL_STATE(1665)] = 56963,
  [SMALL_STATE(1666)] = 56974,
  [SMALL_STATE(1667)] = 56983,
  [SMALL_STATE(1668)] = 56992,
  [SMALL_STATE(1669)] = 57001,
  [SMALL_STATE(1670)] = 57010,
  [SMALL_STATE(1671)] = 57021,
  [SMALL_STATE(1672)] = 57030,
  [SMALL_STATE(1673)] = 57041,
  [SMALL_STATE(1674)] = 57052,
  [SMALL_STATE(1675)] = 57063,
  [SMALL_STATE(1676)] = 57072,
  [SMALL_STATE(1677)] = 57081,
  [SMALL_STATE(1678)] = 57092,
  [SMALL_STATE(1679)] = 57103,
  [SMALL_STATE(1680)] = 57112,
  [SMALL_STATE(1681)] = 57123,
  [SMALL_STATE(1682)] = 57132,
  [SMALL_STATE(1683)] = 57141,
  [SMALL_STATE(1684)] = 57152,
  [SMALL_STATE(1685)] = 57161,
  [SMALL_STATE(1686)] = 57172,
  [SMALL_STATE(1687)] = 57183,
  [SMALL_STATE(1688)] = 57192,
  [SMALL_STATE(1689)] = 57203,
  [SMALL_STATE(1690)] = 57212,
  [SMALL_STATE(1691)] = 57221,
  [SMALL_STATE(1692)] = 57232,
  [SMALL_STATE(1693)] = 57243,
  [SMALL_STATE(1694)] = 57252,
  [SMALL_STATE(1695)] = 57263,
  [SMALL_STATE(1696)] = 57272,
  [SMALL_STATE(1697)] = 57281,
  [SMALL_STATE(1698)] = 57290,
  [SMALL_STATE(1699)] = 57299,
  [SMALL_STATE(1700)] = 57308,
  [SMALL_STATE(1701)] = 57319,
  [SMALL_STATE(1702)] = 57328,
  [SMALL_STATE(1703)] = 57337,
  [SMALL_STATE(1704)] = 57345,
  [SMALL_STATE(1705)] = 57353,
  [SMALL_STATE(1706)] = 57361,
  [SMALL_STATE(1707)] = 57369,
  [SMALL_STATE(1708)] = 57377,
  [SMALL_STATE(1709)] = 57385,
  [SMALL_STATE(1710)] = 57393,
  [SMALL_STATE(1711)] = 57401,
  [SMALL_STATE(1712)] = 57409,
  [SMALL_STATE(1713)] = 57417,
  [SMALL_STATE(1714)] = 57425,
  [SMALL_STATE(1715)] = 57433,
  [SMALL_STATE(1716)] = 57441,
  [SMALL_STATE(1717)] = 57449,
  [SMALL_STATE(1718)] = 57457,
  [SMALL_STATE(1719)] = 57465,
  [SMALL_STATE(1720)] = 57473,
  [SMALL_STATE(1721)] = 57481,
  [SMALL_STATE(1722)] = 57489,
  [SMALL_STATE(1723)] = 57497,
  [SMALL_STATE(1724)] = 57505,
  [SMALL_STATE(1725)] = 57513,
  [SMALL_STATE(1726)] = 57521,
  [SMALL_STATE(1727)] = 57529,
  [SMALL_STATE(1728)] = 57537,
  [SMALL_STATE(1729)] = 57545,
  [SMALL_STATE(1730)] = 57553,
  [SMALL_STATE(1731)] = 57561,
  [SMALL_STATE(1732)] = 57569,
  [SMALL_STATE(1733)] = 57577,
  [SMALL_STATE(1734)] = 57585,
  [SMALL_STATE(1735)] = 57593,
  [SMALL_STATE(1736)] = 57601,
  [SMALL_STATE(1737)] = 57609,
  [SMALL_STATE(1738)] = 57617,
  [SMALL_STATE(1739)] = 57625,
  [SMALL_STATE(1740)] = 57633,
  [SMALL_STATE(1741)] = 57641,
  [SMALL_STATE(1742)] = 57649,
  [SMALL_STATE(1743)] = 57657,
  [SMALL_STATE(1744)] = 57665,
  [SMALL_STATE(1745)] = 57673,
  [SMALL_STATE(1746)] = 57681,
  [SMALL_STATE(1747)] = 57689,
  [SMALL_STATE(1748)] = 57697,
  [SMALL_STATE(1749)] = 57705,
  [SMALL_STATE(1750)] = 57713,
  [SMALL_STATE(1751)] = 57721,
  [SMALL_STATE(1752)] = 57729,
  [SMALL_STATE(1753)] = 57737,
  [SMALL_STATE(1754)] = 57745,
  [SMALL_STATE(1755)] = 57753,
  [SMALL_STATE(1756)] = 57761,
  [SMALL_STATE(1757)] = 57769,
  [SMALL_STATE(1758)] = 57777,
  [SMALL_STATE(1759)] = 57785,
  [SMALL_STATE(1760)] = 57793,
  [SMALL_STATE(1761)] = 57801,
  [SMALL_STATE(1762)] = 57809,
  [SMALL_STATE(1763)] = 57817,
  [SMALL_STATE(1764)] = 57825,
  [SMALL_STATE(1765)] = 57833,
  [SMALL_STATE(1766)] = 57841,
  [SMALL_STATE(1767)] = 57849,
  [SMALL_STATE(1768)] = 57857,
  [SMALL_STATE(1769)] = 57865,
  [SMALL_STATE(1770)] = 57873,
  [SMALL_STATE(1771)] = 57881,
  [SMALL_STATE(1772)] = 57889,
  [SMALL_STATE(1773)] = 57897,
  [SMALL_STATE(1774)] = 57905,
  [SMALL_STATE(1775)] = 57913,
  [SMALL_STATE(1776)] = 57921,
  [SMALL_STATE(1777)] = 57929,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1406),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1461),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(506),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [69] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(265),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1097),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1043),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(25),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(238),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1406),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1420),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1461),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1195),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1021),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(273),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(276),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(961),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(960),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(412),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(309),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(310),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(311),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(338),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1171),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 2, 0, 7),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1217),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(253),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1170),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1207),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(950),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1169),
  [151] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_clause, 3, 0, 7),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1175),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 1, 0, 0),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1166),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [175] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 1, 0, 0),
  [177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1174),
  [179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, 0, 0),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1197),
  [185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(24),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1190),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1185),
  [195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1189),
  [211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0),
  [213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(279),
  [216] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(278),
  [219] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(265),
  [222] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1097),
  [225] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1043),
  [228] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(244),
  [231] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(238),
  [234] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1406),
  [237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1420),
  [240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1461),
  [243] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0),
  [245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(294),
  [248] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(581),
  [251] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1019),
  [254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1021),
  [257] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(273),
  [260] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(276),
  [263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(961),
  [266] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(960),
  [269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(412),
  [272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(932),
  [275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1010),
  [278] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(8),
  [281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(13),
  [284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(506),
  [287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(500),
  [290] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1307),
  [293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1356),
  [296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1382),
  [299] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(868),
  [302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 29),
  [304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1279),
  [306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 8),
  [314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1265),
  [316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 9),
  [320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1274),
  [322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 1, 0, 0),
  [326] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 1, 0, 0),
  [328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_block, 1, 0, 0), SHIFT(581),
  [331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 19),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1141),
  [335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 20),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 19),
  [345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1136),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 20),
  [351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1137),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 8),
  [357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1142),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1146),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 30),
  [367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1126),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 9),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 8),
  [379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1144),
  [381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1310),
  [383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1342),
  [389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 9),
  [397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 19),
  [403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1121),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 20),
  [409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1139),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 29),
  [419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 30),
  [425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1124),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1123),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1290),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1297),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 29),
  [455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1147),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 30),
  [461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1133),
  [463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1127),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1284),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1346),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1293),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1334),
  [487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1338),
  [491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1206),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1184),
  [507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1194),
  [519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1187),
  [527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1212),
  [535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1210),
  [539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1457),
  [541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1222),
  [547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1213),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1214),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1218),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1201),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [567] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_block, 1, 0, 0), SHIFT(581),
  [570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_block, 1, 0, 0), SHIFT(932),
  [573] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(581),
  [576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(458),
  [582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1040),
  [586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [590] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 0, 0),
  [601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 0, 0),
  [605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 17),
  [607] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 17), SHIFT_REPEAT(458),
  [610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 17),
  [612] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14),
  [614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14),
  [616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 2, 0, 4),
  [618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 2, 0, 4),
  [620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 3, 0, 15),
  [622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 3, 0, 15),
  [624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [626] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1118),
  [629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 1, -1, 0),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 1, -1, 0),
  [647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 2, -1, 0),
  [649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1063),
  [651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 2, -1, 0),
  [653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 6),
  [663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 6),
  [665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 2, 0, 0),
  [667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 2, 0, 0),
  [669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__extended_keywords, 1, 0, 0),
  [671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extended_keywords, 1, 0, 0),
  [673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 3),
  [675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 3),
  [677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 1, 0, 0),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 1, 0, 0),
  [687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 3, 0, 0),
  [689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 3, 0, 0),
  [691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 15),
  [693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 15),
  [695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 1, 0, 0),
  [697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 1, 0, 0),
  [699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 4, -1, 0),
  [701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 4, -1, 0),
  [703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 3, -1, 0),
  [705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 3, -1, 0),
  [707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 26),
  [709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 26),
  [711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 1, 0),
  [713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 1, 0),
  [718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, -1, 0),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not_operator, 2, 0, 0),
  [726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(359),
  [728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not_operator, 2, 0, 0),
  [730] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 2, 0, 0),
  [732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 2, 0, 0),
  [734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 2, 0, 0),
  [736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 2, 0, 0),
  [738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 2, 0, 0),
  [740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 2, 0, 0),
  [742] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [746] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 3, 0, 0),
  [754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 3, 0, 0),
  [756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 3, 0, 0),
  [758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 3, 0, 0),
  [760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 3, 0, 16),
  [766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 3, 0, 16),
  [772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 3, 0, 0),
  [776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(323),
  [778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 3, 0, 0),
  [780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 4, 0, 0),
  [782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 4, 0, 0),
  [784] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 4, 0, 0),
  [786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 4, 0, 0),
  [788] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 5, 0, 0),
  [790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 5, 0, 0),
  [792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 5, 0, 0),
  [794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 5, 0, 0),
  [796] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 5, 0, 0),
  [798] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 5, 0, 0),
  [805] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, -1, 0),
  [810] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_operator, 3, 0, 16),
  [812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_operator, 3, 0, 16),
  [814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(360),
  [816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 18),
  [818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 18),
  [822] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 27),
  [824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 27),
  [826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(316),
  [828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(210),
  [834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1049),
  [838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(214),
  [840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(674),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(576),
  [850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(480),
  [852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(635),
  [854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(582),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(677),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(823),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1068),
  [920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [924] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_row, 2, 0, 0), REDUCE(sym__index_row, 2, 0, 0),
  [927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_row, 2, 0, 0), REDUCE(sym__index_row, 2, 0, 0),
  [930] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_row, 3, 0, 0), REDUCE(sym__index_row, 3, 0, 0),
  [933] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_row, 3, 0, 0), REDUCE(sym__index_row, 3, 0, 0),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1111),
  [975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(348),
  [979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(249),
  [981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [985] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat2, 1, 0, 0),
  [987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat2, 1, 0, 0),
  [989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(541),
  [995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(733),
  [999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(540),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(554),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [1013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [1015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(629),
  [1017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [1019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(152),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(512),
  [1025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [1029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [1031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [1035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [1039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [1041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 2, 0, 0),
  [1043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 2, 0, 0),
  [1045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 4, 0, 0),
  [1047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 4, 0, 0),
  [1049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 3, 0, 0),
  [1051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 3, 0, 0),
  [1053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [1055] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [1057] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(253),
  [1060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 5),
  [1062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 5),
  [1064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_iterator, 3, 0, 0),
  [1066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_iterator, 3, 0, 0),
  [1068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [1070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(390),
  [1072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(380),
  [1074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [1076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [1078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(672),
  [1080] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__index_matrix_repeat1, 1, 0, 0),
  [1082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_matrix_repeat1, 1, 0, 0),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [1110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(720),
  [1112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [1118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [1120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [1122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(141),
  [1136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [1138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [1142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [1146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(320),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [1154] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(320),
  [1157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [1161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_row, 4, 0, 0),
  [1163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_row, 4, 0, 0),
  [1165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_row, 2, 0, 0),
  [1167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_row, 2, 0, 0),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [1171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_row, 3, 0, 0),
  [1173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_row, 3, 0, 0),
  [1175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [1179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [1185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [1187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1163),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [1196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [1198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [1202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [1204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 34),
  [1206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 34),
  [1208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [1210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [1212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 5, 0, 34),
  [1214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 5, 0, 34),
  [1216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1041),
  [1218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(201),
  [1220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(457),
  [1222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [1224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(516),
  [1226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [1228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1096),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [1233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [1235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__keywords, 1, 0, 0),
  [1237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(859),
  [1239] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_end_keyword, 1, 0, 0),
  [1241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1047),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(587),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(318),
  [1253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [1255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [1257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(583),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [1261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_binary_expression, 1, 0, 0),
  [1263] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__index_expression, 1, 0, 0),
  [1266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [1268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__index_expression, 1, 0, 0),
  [1271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range_element, 1, 0, 0),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [1277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [1281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [1283] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 17), SHIFT_REPEAT(457),
  [1286] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_unary_operator, 2, 0, 1),
  [1288] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_unary_operator, 2, 0, 1),
  [1290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [1292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_binary_expression, 1, 0, 0),
  [1294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1056),
  [1296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [1298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(456),
  [1302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [1304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [1308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(321),
  [1310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range_element, 1, 0, 0),
  [1312] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1115),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [1319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [1327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(464),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [1339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_expression, 1, 0, 0),
  [1341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_expression, 1, 0, 0),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1096),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [1349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [1352] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1090),
  [1355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [1357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1036),
  [1359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(330),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(331),
  [1369] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 17), SHIFT_REPEAT(442),
  [1372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [1374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [1376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(329),
  [1380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(334),
  [1382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1115),
  [1384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(324),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [1388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_end_keyword, 1, 0, 0),
  [1390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [1392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(343),
  [1394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(344),
  [1396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [1398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [1400] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 17), SHIFT_REPEAT(456),
  [1403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [1405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(298),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(302),
  [1411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [1413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1090),
  [1415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(354),
  [1417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [1419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [1421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_postfix_operator, 2, 0, 23),
  [1423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_postfix_operator, 2, 0, 23),
  [1425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_binary_expression, 1, 0, 10),
  [1427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_binary_expression, 1, 0, 10),
  [1429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_binary_expression, 1, 0, 11),
  [1431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range_element, 1, -1, 11),
  [1433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(702),
  [1435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(642),
  [1437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range_element, 1, -1, 11),
  [1439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_postfix_operator, 2, 0, 2),
  [1441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_postfix_operator, 2, 0, 2),
  [1443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range_element, 1, 0, 11),
  [1445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [1447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [1449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range_element, 1, 0, 11),
  [1451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range_element, 1, 1, 10),
  [1453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [1455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [1457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range_element, 1, 1, 10),
  [1459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [1461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(327),
  [1463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [1465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_unary_operator, 2, 0, 21),
  [1467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_unary_operator, 2, 0, 21),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [1471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_postfix_operator, 2, 0, 24),
  [1473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_postfix_operator, 2, 0, 24),
  [1475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_parenthesis, 3, 0, 0),
  [1477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_parenthesis, 3, 0, 0),
  [1479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_matrix, 3, 0, 0),
  [1481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_matrix, 3, 0, 0),
  [1483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_not_operator, 2, 0, 22),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(392),
  [1487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_not_operator, 2, 0, 22),
  [1489] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_matrix, 2, 0, 0), REDUCE(sym__index_matrix, 2, 0, 0),
  [1492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_matrix, 2, 0, 0), REDUCE(sym__index_matrix, 2, 0, 0),
  [1495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_expression, 1, 0, 10),
  [1497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_expression, 1, 0, 10),
  [1499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_matrix, 3, 0, 0), REDUCE(sym__index_matrix, 3, 0, 0),
  [1502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_matrix, 3, 0, 0), REDUCE(sym__index_matrix, 3, 0, 0),
  [1505] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range, 3, 0, 0),
  [1507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range, 3, 0, 0),
  [1509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [1511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_comparison_operator, 3, 0, 0),
  [1513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_comparison_operator, 3, 0, 0),
  [1515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_boolean_operator, 3, 0, 31),
  [1517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_boolean_operator, 3, 0, 31),
  [1519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [1521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_binary_operator, 3, 0, 16),
  [1523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [1525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(396),
  [1527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_binary_operator, 3, 0, 16),
  [1529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [1531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(398),
  [1533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_expression, 1, 0, 11),
  [1535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_expression, 1, 0, 11),
  [1537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_matrix, 4, 0, 0),
  [1539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_matrix, 4, 0, 0),
  [1541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_matrix, 2, 0, 0),
  [1543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_matrix, 2, 0, 0),
  [1545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_matrix, 5, 0, 0),
  [1547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_matrix, 5, 0, 0),
  [1549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_range, 5, 0, 0),
  [1551] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__index_range, 3, 0, 0), REDUCE(sym__index_range, 5, 0, 0),
  [1554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_range, 5, 0, 0),
  [1556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [1558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_binary_expression, 1, 0, 11),
  [1560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(349),
  [1562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [1564] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [1575] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [1578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(402),
  [1586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [1594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [1596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [1598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__index_range, 3, 0, 0), REDUCE(sym__index_range, 5, 0, 0),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [1613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1615] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [1618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [1620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [1622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [1624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1626] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(810),
  [1629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1286),
  [1633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [1635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [1637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(940),
  [1639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(942),
  [1641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [1643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [1645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(878),
  [1647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [1649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [1651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [1653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(882),
  [1657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [1659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1196),
  [1661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1514),
  [1663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(503),
  [1665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [1667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [1669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [1671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [1673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [1675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [1677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [1683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1752),
  [1685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1289),
  [1687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [1689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [1693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [1697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [1699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [1701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [1703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [1707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [1709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [1711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(941),
  [1713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(943),
  [1715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [1717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [1719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [1721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [1723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [1725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1269),
  [1727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(337),
  [1730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(999),
  [1733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(902),
  [1736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0),
  [1738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(581),
  [1741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(908),
  [1744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(337),
  [1746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(999),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [1750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [1752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(908),
  [1754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [1756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1749),
  [1758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [1760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [1762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [1764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1017),
  [1766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1581),
  [1768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(347),
  [1770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [1772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1256),
  [1774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [1776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1514),
  [1778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0),
  [1780] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1196),
  [1783] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(932),
  [1786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1514),
  [1789] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(503),
  [1792] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1196),
  [1795] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(868),
  [1798] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1215),
  [1801] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1095),
  [1804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [1806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0),
  [1808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(337),
  [1811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(952),
  [1814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0),
  [1816] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(581),
  [1819] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(908),
  [1822] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 5),
  [1824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 5),
  [1826] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(882),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [1831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [1833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [1835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [1837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [1839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 1, 0, 0),
  [1847] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1120),
  [1850] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1119),
  [1853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(888),
  [1855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1345),
  [1857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [1859] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(900),
  [1862] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0),
  [1864] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(412),
  [1867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(412),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [1872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [1874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(941),
  [1879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0),
  [1881] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [1884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [1886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [1888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [1890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1236),
  [1892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [1894] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(913),
  [1897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0),
  [1899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(412),
  [1902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(412),
  [1905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(912),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [1911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [1913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [1915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1243),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [1919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 1, 0, 0),
  [1921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1101),
  [1924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [1926] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 17), SHIFT_REPEAT(445),
  [1929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0),
  [1931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 6, 0, 3),
  [1933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 6, 0, 3),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [1937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 2, 0, 3),
  [1939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 2, 0, 3),
  [1941] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(943),
  [1944] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 3, 0, 3),
  [1946] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 3, 0, 3),
  [1948] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 5, 0, 3),
  [1950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 5, 0, 3),
  [1952] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_properties_repeat1, 2, 0, 0), SHIFT_REPEAT(941),
  [1955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_properties_repeat1, 2, 0, 0),
  [1957] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_properties_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [1960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [1962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 4, 0, 3),
  [1964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 4, 0, 3),
  [1966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [1968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 1, 0, 0),
  [1970] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 1, 0, 0),
  [1972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 2, 0, 0),
  [1974] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 2, 0, 0),
  [1976] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1108),
  [1979] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0),
  [1981] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [1984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [2001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [2007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 4, 0, 0),
  [2009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimensions, 4, 0, 0),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [2015] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 1, 0, 0),
  [2017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 1, 0, 0),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [2023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(978),
  [2026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(280),
  [2028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [2030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [2032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [2034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [2036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [2040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [2042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [2044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [2046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [2048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 3, 0, 0),
  [2050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimensions, 3, 0, 0),
  [2052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [2054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [2056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [2058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [2060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [2064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [2066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [2068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [2070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [2072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [2074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [2076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [2078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [2080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [2082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [2084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [2086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [2088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [2090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [2092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [2096] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [2098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [2100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0),
  [2102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [2104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__index_row, 1, 0, 0),
  [2106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_row, 1, 0, 0),
  [2108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [2110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0),
  [2112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [2114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [2116] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_value, 2, 0, 0),
  [2118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1086),
  [2120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [2122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment, 3, 0, 16),
  [2124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1125),
  [2126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1431),
  [2128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [2130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [2132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [2134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [2136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 5, 0, 13),
  [2138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__index_row_repeat1, 2, 0, 0),
  [2140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_row_repeat1, 2, 0, 0),
  [2142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [2148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [2150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [2152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [2156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [2158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 4, 0, 0),
  [2160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [2162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [2164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [2168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [2172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [2176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [2184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_argument, 1, -1, 0),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [2188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [2192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [2194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_output, 2, 0, 0),
  [2196] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_output, 2, 0, 0),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [2200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [2202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_argument, 1, 1, 0),
  [2204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [2206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [2208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [2210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [2212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [2214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [2216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [2224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [2232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1075),
  [2235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [2237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1165),
  [2240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1155),
  [2243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1173),
  [2246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1202),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [2259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1158),
  [2261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0),
  [2263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 0),
  [2265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [2267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [2269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 19),
  [2271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 19),
  [2273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1306),
  [2275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 19),
  [2277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 29),
  [2279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1238),
  [2281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 29),
  [2283] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 9),
  [2285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1287),
  [2287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 9),
  [2289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 30),
  [2291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1242),
  [2293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 30),
  [2295] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(1125),
  [2298] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 30),
  [2300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1326),
  [2302] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 30),
  [2304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 4, 0, 9),
  [2306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1233),
  [2308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 9),
  [2310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [2312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [2314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [2316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 20),
  [2318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 20),
  [2320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1328),
  [2322] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 20),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 30),
  [2328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 30),
  [2330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1325),
  [2332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 30),
  [2334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [2336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [2338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 19),
  [2340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1318),
  [2342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 19),
  [2344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 20),
  [2346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1336),
  [2348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 20),
  [2350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [2352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [2354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1314),
  [2356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 8),
  [2358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 9),
  [2360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 9),
  [2362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1232),
  [2364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 9),
  [2366] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 19),
  [2368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1288),
  [2370] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 19),
  [2372] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 8),
  [2374] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [2376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [2378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 8),
  [2380] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 20),
  [2382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [2384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 20),
  [2386] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [2388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1303),
  [2390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 8),
  [2392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [2394] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 29),
  [2396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1247),
  [2398] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 29),
  [2400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 29),
  [2402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 29),
  [2404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1322),
  [2406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 29),
  [2408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [2410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [2414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(994),
  [2416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [2418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1057),
  [2420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [2422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [2424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [2426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 4, 0, 0),
  [2428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1078),
  [2430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [2432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [2434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [2436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [2438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [2440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [2442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(33),
  [2444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [2446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [2450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 3, 0, 0),
  [2452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(863),
  [2454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 4, 0, 0),
  [2456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1052),
  [2458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [2460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 2, 0, 0),
  [2462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 7),
  [2464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 7),
  [2466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 7, 0, 0),
  [2468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(921),
  [2470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 7),
  [2472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 2, 0, 0),
  [2474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 6, 0, 0),
  [2476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1584),
  [2478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1586),
  [2480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1589),
  [2482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(32),
  [2484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(67),
  [2486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 0),
  [2488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(34),
  [2490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [2492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, 0, 0),
  [2494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [2496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1591),
  [2498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [2500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 8, 0, 0),
  [2502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 5, 0, 0),
  [2504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 3, 0, 0),
  [2506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(94),
  [2508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [2510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1529),
  [2512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 5, 0, 0),
  [2514] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 1, 0, 6),
  [2516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 4, 0, 0),
  [2518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [2520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(36),
  [2522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 3, 0, 0),
  [2524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1449),
  [2526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(895),
  [2528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [2530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [2532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1519),
  [2534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1522),
  [2536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 0),
  [2538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [2540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1524),
  [2542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1534),
  [2544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(47),
  [2546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1533),
  [2548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1422),
  [2550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1433),
  [2552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(103),
  [2554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 7),
  [2556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1446),
  [2558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(71),
  [2560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [2562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [2564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1456),
  [2566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 0),
  [2568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1598),
  [2570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 8),
  [2572] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [2574] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 8),
  [2576] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_property, 3, 0, 0),
  [2578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1331),
  [2580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 9),
  [2582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 9),
  [2584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 9),
  [2586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1254),
  [2588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 4, 0, 0),
  [2590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [2592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [2594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [2596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [2598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), SHIFT_REPEAT(264),
  [2601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 3, 0, 0),
  [2603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 4, 0, 0),
  [2605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 4, 0, 0),
  [2607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [2611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [2613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1054),
  [2615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 3, 0, 0),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [2619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [2621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1308),
  [2623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 9),
  [2625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 9),
  [2627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 9),
  [2629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 5, 0, 0),
  [2631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 5, 0, 0),
  [2633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [2635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 20),
  [2637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(862),
  [2639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 5, 0, 0),
  [2641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 5, 0, 0),
  [2643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_row, 1, 0, 0), REDUCE(sym__index_row, 1, 0, 0),
  [2646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_row, 1, 0, 0), REDUCE(sym__index_row, 1, 0, 0),
  [2649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [2651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(826),
  [2653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [2655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [2657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 2, 0, 0),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [2661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [2663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [2665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 3, 0, 0),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [2669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 4, 0, 0),
  [2671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(880),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [2679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(877),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [2687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 3, 0, 0),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [2691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [2697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [2701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [2703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 10, 0, 29),
  [2705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 10, 0, 29),
  [2707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 10, 0, 29),
  [2709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20),
  [2711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 19),
  [2713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 19),
  [2715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 19),
  [2717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 20),
  [2719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 20),
  [2721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 20),
  [2723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 19),
  [2725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 19),
  [2727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 19),
  [2729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 1, 0, 0),
  [2731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [2733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 2, 0, 9),
  [2735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1302),
  [2737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0),
  [2739] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0), SHIFT_REPEAT(1313),
  [2742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 10, 0, 30),
  [2744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 10, 0, 30),
  [2746] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 10, 0, 30),
  [2748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 2, 0, 0),
  [2750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [2752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_property, 4, 0, 0),
  [2754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 29),
  [2756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 29),
  [2758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 29),
  [2760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1300),
  [2762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 30),
  [2764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 30),
  [2766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 30),
  [2768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1317),
  [2770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 20),
  [2772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 20),
  [2774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 20),
  [2776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1304),
  [2778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 8),
  [2780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 8),
  [2782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 8),
  [2784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(937),
  [2786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1697),
  [2788] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0), SHIFT_REPEAT(1054),
  [2791] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [2795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(938),
  [2797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [2799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [2801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [2803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 3, 0, 0),
  [2805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [2807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [2809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1384),
  [2811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(914),
  [2813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 4, 0, 0),
  [2815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [2817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(903),
  [2819] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__index_row_repeat1, 2, 0, 0), SHIFT_REPEAT(383),
  [2822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [2824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [2826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [2828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [2830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(104),
  [2832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(83),
  [2834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0), SHIFT_REPEAT(232),
  [2837] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0), SHIFT_REPEAT(232),
  [2840] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0),
  [2842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(74),
  [2844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [2846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [2848] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(1363),
  [2851] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(338),
  [2854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [2856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [2858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0),
  [2860] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(347),
  [2863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [2865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(46),
  [2867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(40),
  [2869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [2871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [2873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [2875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(51),
  [2877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [2879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [2881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [2883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [2885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parfor_options, 1, 0, 0),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [2891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [2893] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(1384),
  [2896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [2898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [2900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [2902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [2904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [2906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [2908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [2910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(98),
  [2912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [2914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [2916] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 1, 0, 0),
  [2918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [2920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [2922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [2924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [2926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [2928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 3, 0, 0),
  [2930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(89),
  [2932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(91),
  [2934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [2936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1630),
  [2938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [2940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1614),
  [2942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 1, 0, 0),
  [2944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(258),
  [2946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [2948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1617),
  [2950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [2952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [2956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1632),
  [2958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, 0, 0),
  [2960] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 7),
  [2962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1311),
  [2964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [2966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [2968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [2970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [2972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 3, 0, 32),
  [2974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1462),
  [2976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [2978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_arguments, 1, 0, 12),
  [2980] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__index_arguments, 1, 0, 12), SHIFT(213),
  [2983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__index_arguments, 2, 0, 25),
  [2985] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__index_arguments, 2, 0, 25), SHIFT(213),
  [2988] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 4, 0, 7),
  [2990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1239),
  [2992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1464),
  [2994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1251),
  [2996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_arguments_repeat1, 2, 0, 33),
  [2998] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__index_arguments_repeat1, 2, 0, 33), SHIFT_REPEAT(213),
  [3001] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 2, 0, 0),
  [3003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 2, 0, 6),
  [3005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [3007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1633),
  [3009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 3, 0, 0),
  [3011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1607),
  [3013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 7, 0, 19),
  [3015] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 7),
  [3017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1310),
  [3019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 6, 0, 7),
  [3021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1332),
  [3023] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 4, 0, 0),
  [3025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 1, 0, 0),
  [3027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [3029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [3031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [3033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1339),
  [3035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0),
  [3037] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1093),
  [3040] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 7),
  [3042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1616),
  [3044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [3046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [3048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1621),
  [3050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [3052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [3054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1622),
  [3056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [3058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [3060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(525),
  [3062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1625),
  [3064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1628),
  [3066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 7),
  [3068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1631),
  [3070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [3072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [3074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [3076] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 5, 0, 7),
  [3078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1337),
  [3080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [3082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 4, 0, 35),
  [3084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(545),
  [3086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [3088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [3090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [3092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1280),
  [3094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [3096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [3098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(910),
  [3101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, 0, 8),
  [3103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [3105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [3107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [3109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 8),
  [3111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [3113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 3, 0, 28),
  [3115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1324),
  [3117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [3119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(523),
  [3121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1327),
  [3123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [3125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 9),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [3129] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__index_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(258),
  [3132] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__index_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(258),
  [3135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__index_matrix_repeat1, 2, 0, 0),
  [3137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1588),
  [3139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(807),
  [3141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 19),
  [3143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [3145] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), REDUCE(aux_sym__index_row_repeat1, 2, 0, 0),
  [3148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), REDUCE(aux_sym__index_row_repeat1, 2, 0, 0),
  [3151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [3153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 13),
  [3155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1650),
  [3157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [3159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(599),
  [3161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [3163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [3165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(609),
  [3167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 19),
  [3169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1651),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [3173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [3175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0),
  [3177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1652),
  [3179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [3181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1653),
  [3183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 0),
  [3185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 0),
  [3187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [3189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [3191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [3193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [3195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [3197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [3199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [3201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [3203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1613),
  [3205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 8),
  [3207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 7),
  [3209] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 20),
  [3211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 4, 0, 0),
  [3213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [3215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1419),
  [3217] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 9, 0, 0),
  [3219] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 5, 0, 0),
  [3221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1615),
  [3223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1615),
  [3225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [3227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 33),
  [3229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 33), SHIFT_REPEAT(1104),
  [3232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0),
  [3234] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [3237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 4, 0, 7),
  [3239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_matrix_repeat1, 2, 0, 0),
  [3241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [3243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [3245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [3247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [3249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0), SHIFT_REPEAT(274),
  [3252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [3254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__index_arguments_repeat1, 2, 0, 32),
  [3256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0),
  [3258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0), SHIFT_REPEAT(1309),
  [3261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_operator, 1, 0, 0),
  [3263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [3265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [3267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [3269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1698),
  [3271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 2, 0, 0),
  [3273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [3275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 1, 0, 13),
  [3277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [3279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [3281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [3283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [3285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 0),
  [3287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [3289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [3291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [3293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0),
  [3295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0), SHIFT_REPEAT(1069),
  [3298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [3300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [3302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [3304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [3306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [3308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [3310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [3312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [3314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 1, 0, 0),
  [3316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [3318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [3320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1593),
  [3322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1532),
  [3324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [3326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [3328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1525),
  [3330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [3332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1538),
  [3334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [3336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1585),
  [3338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [3340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1576),
  [3342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1527),
  [3344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1587),
  [3346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [3348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [3350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1590),
  [3352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1447),
  [3354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1451),
  [3356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1592),
  [3358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 32),
  [3360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1520),
  [3362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1424),
  [3364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [3366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1434),
  [3368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1434),
  [3370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1457),
  [3372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1523),
  [3374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [3376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [3378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [3380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [3382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 5, 0, 0),
  [3384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [3386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [3388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [3390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [3392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [3394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [3396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [3398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [3400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [3402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [3404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 6, 0, 0),
  [3406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [3408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [3410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 3, 0, 0),
  [3412] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [3414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [3416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [3418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [3420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [3422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [3424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 3, 0, 0),
  [3426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [3428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [3430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [3432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [3434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [3436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [3438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [3440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [3442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [3444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [3446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [3448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 2, 0, 0),
  [3450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [3452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [3454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 3, 0, 0),
  [3456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [3458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [3460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [3462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [3464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [3466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [3468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [3470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [3472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [3474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 4, 0, 0),
  [3476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [3478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [3480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [3482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [3484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 4, 0, 0),
  [3486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [3488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [3490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [3492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1510),
  [3494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_comment = 0,
  ts_external_token_line_continuation = 1,
  ts_external_token_command_name = 2,
  ts_external_token_command_argument = 3,
  ts_external_token__single_quote_string_start = 4,
  ts_external_token__single_quote_string_end = 5,
  ts_external_token__double_quote_string_start = 6,
  ts_external_token__double_quote_string_end = 7,
  ts_external_token_formatting_sequence = 8,
  ts_external_token_escape_sequence = 9,
  ts_external_token_string_content = 10,
  ts_external_token__entry_delimiter = 11,
  ts_external_token__multioutput_variable_start = 12,
  ts_external_token__external_identifier = 13,
  ts_external_token_error_sentinel = 14,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_comment] = sym_comment,
  [ts_external_token_line_continuation] = sym_line_continuation,
  [ts_external_token_command_name] = sym_command_name,
  [ts_external_token_command_argument] = sym_command_argument,
  [ts_external_token__single_quote_string_start] = sym__single_quote_string_start,
  [ts_external_token__single_quote_string_end] = sym__single_quote_string_end,
  [ts_external_token__double_quote_string_start] = sym__double_quote_string_start,
  [ts_external_token__double_quote_string_end] = sym__double_quote_string_end,
  [ts_external_token_formatting_sequence] = sym_formatting_sequence,
  [ts_external_token_escape_sequence] = sym_escape_sequence,
  [ts_external_token_string_content] = sym_string_content,
  [ts_external_token__entry_delimiter] = sym__entry_delimiter,
  [ts_external_token__multioutput_variable_start] = sym__multioutput_variable_start,
  [ts_external_token__external_identifier] = sym__external_identifier,
  [ts_external_token_error_sentinel] = sym_error_sentinel,
};

static const bool ts_external_scanner_states[12][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token_command_argument] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
    [ts_external_token__entry_delimiter] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token__external_identifier] = true,
    [ts_external_token_error_sentinel] = true,
  },
  [2] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token__external_identifier] = true,
  },
  [3] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__external_identifier] = true,
  },
  [4] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__entry_delimiter] = true,
    [ts_external_token__external_identifier] = true,
  },
  [5] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
  },
  [6] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__entry_delimiter] = true,
  },
  [7] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__external_identifier] = true,
  },
  [8] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token__external_identifier] = true,
  },
  [9] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_argument] = true,
  },
  [10] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
  [11] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_matlab_external_scanner_create(void);
void tree_sitter_matlab_external_scanner_destroy(void *);
bool tree_sitter_matlab_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_matlab_external_scanner_serialize(void *, char *);
void tree_sitter_matlab_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_matlab(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_matlab_external_scanner_create,
      tree_sitter_matlab_external_scanner_destroy,
      tree_sitter_matlab_external_scanner_scan,
      tree_sitter_matlab_external_scanner_serialize,
      tree_sitter_matlab_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "matlab",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 1,
      .minor_version = 1,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
